#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 14
#define STATE_COUNT 1273
#define LARGE_STATE_COUNT 76
#define SYMBOL_COUNT 189
#define ALIAS_COUNT 1
#define TOKEN_COUNT 90
#define EXTERNAL_TOKEN_COUNT 14
#define FIELD_COUNT 10
#define MAX_ALIAS_SEQUENCE_LENGTH 10
#define PRODUCTION_ID_COUNT 25

enum ts_symbol_identifiers {
  sym_identifier = 1,
  anon_sym_SEMI = 2,
  anon_sym_COMMA = 3,
  anon_sym_LPAREN = 4,
  anon_sym_RPAREN = 5,
  anon_sym_PLUS = 6,
  anon_sym_DOT_PLUS = 7,
  anon_sym_DASH = 8,
  anon_sym_DOT_DASH = 9,
  anon_sym_STAR = 10,
  anon_sym_DOT_STAR = 11,
  anon_sym_SLASH = 12,
  anon_sym_DOT_SLASH = 13,
  anon_sym_BSLASH = 14,
  anon_sym_DOT_BSLASH = 15,
  anon_sym_CARET = 16,
  anon_sym_DOT_CARET = 17,
  anon_sym_PIPE = 18,
  anon_sym_AMP = 19,
  anon_sym_DOT = 20,
  anon_sym_TILDE = 21,
  anon_sym_QMARK = 22,
  anon_sym_AT = 23,
  anon_sym_LT = 24,
  anon_sym_LT_EQ = 25,
  anon_sym_EQ_EQ = 26,
  anon_sym_TILDE_EQ = 27,
  anon_sym_GT_EQ = 28,
  anon_sym_GT = 29,
  anon_sym_AMP_AMP = 30,
  anon_sym_PIPE_PIPE = 31,
  anon_sym_DOT_SQUOTE = 32,
  anon_sym_SQUOTE = 33,
  anon_sym_LBRACK = 34,
  aux_sym_matrix_token1 = 35,
  anon_sym_RBRACK = 36,
  anon_sym_LBRACE = 37,
  anon_sym_RBRACE = 38,
  anon_sym_EQ = 39,
  anon_sym_COLON = 40,
  sym_return_statement = 41,
  sym_continue_statement = 42,
  sym_break_statement = 43,
  anon_sym_elseif = 44,
  anon_sym_else = 45,
  anon_sym_if = 46,
  anon_sym_end = 47,
  anon_sym_for = 48,
  anon_sym_parfor = 49,
  anon_sym_while = 50,
  anon_sym_case = 51,
  anon_sym_otherwise = 52,
  anon_sym_switch = 53,
  anon_sym_global = 54,
  anon_sym_persistent = 55,
  anon_sym_arguments = 56,
  anon_sym_function = 57,
  anon_sym_get_DOT = 58,
  anon_sym_set_DOT = 59,
  anon_sym_endfunction = 60,
  anon_sym_vector = 61,
  anon_sym_matrix = 62,
  anon_sym_scalar = 63,
  anon_sym_properties = 64,
  anon_sym_methods = 65,
  anon_sym_events = 66,
  anon_sym_enumeration = 67,
  anon_sym_classdef = 68,
  anon_sym_catch = 69,
  anon_sym_try = 70,
  sym_number = 71,
  anon_sym_true = 72,
  anon_sym_false = 73,
  anon_sym_LF = 74,
  anon_sym_CR = 75,
  sym_comment = 76,
  sym_line_continuation = 77,
  sym_command_name = 78,
  sym_command_argument = 79,
  sym__single_quote_string_start = 80,
  sym__single_quote_string_end = 81,
  sym__double_quote_string_start = 82,
  sym__double_quote_string_end = 83,
  sym_formatting_sequence = 84,
  sym_escape_sequence = 85,
  sym_string_content = 86,
  sym__entry_delimiter = 87,
  sym__multioutput_variable_start = 88,
  sym_error_sentinel = 89,
  sym_source_file = 90,
  aux_sym__block = 91,
  sym_block = 92,
  sym__statement = 93,
  sym__expression = 94,
  sym_parenthesis = 95,
  sym__binary_expression = 96,
  sym_binary_operator = 97,
  sym_unary_operator = 98,
  sym_indirect_access = 99,
  sym_field_expression = 100,
  sym_not_operator = 101,
  sym_metaclass_operator = 102,
  sym_handle_operator = 103,
  sym_comparison_operator = 104,
  sym_boolean_operator = 105,
  sym_postfix_operator = 106,
  sym_string = 107,
  sym_row = 108,
  sym_matrix = 109,
  sym_cell = 110,
  sym_ignored_argument = 111,
  sym_assignment = 112,
  sym_multioutput_variable = 113,
  sym_spread_operator = 114,
  sym_arguments = 115,
  sym__args = 116,
  sym_function_call = 117,
  sym_command = 118,
  sym__range_element = 119,
  sym_range = 120,
  sym_elseif_clause = 121,
  sym_else_clause = 122,
  sym_if_statement = 123,
  sym_iterator = 124,
  sym_parfor_options = 125,
  sym_for_statement = 126,
  sym_while_statement = 127,
  sym_case_clause = 128,
  sym_otherwise_clause = 129,
  sym_switch_statement = 130,
  sym__lambda_arguments = 131,
  sym_lambda = 132,
  sym_global_operator = 133,
  sym_persistent_operator = 134,
  sym__argument_attributes = 135,
  sym_arguments_statement = 136,
  sym_function_output = 137,
  sym_function_arguments = 138,
  sym_function_definition = 139,
  sym__function_definition_with_end = 140,
  sym_attribute = 141,
  sym_attributes = 142,
  sym_superclasses = 143,
  sym_dimensions = 144,
  sym_validation_functions = 145,
  sym_default_value = 146,
  sym_property_name = 147,
  sym_property = 148,
  sym_properties = 149,
  sym_function_signature = 150,
  sym_methods = 151,
  sym_events = 152,
  sym__enum_value = 153,
  sym_enum = 154,
  sym_enumeration = 155,
  sym_class_definition = 156,
  sym_catch_clause = 157,
  sym_try_statement = 158,
  sym_boolean = 159,
  sym__end_of_line = 160,
  aux_sym_source_file_repeat1 = 161,
  aux_sym__block_repeat1 = 162,
  aux_sym_field_expression_repeat1 = 163,
  aux_sym_metaclass_operator_repeat1 = 164,
  aux_sym_string_repeat1 = 165,
  aux_sym_row_repeat1 = 166,
  aux_sym_matrix_repeat1 = 167,
  aux_sym_multioutput_variable_repeat1 = 168,
  aux_sym_arguments_repeat1 = 169,
  aux_sym_arguments_repeat2 = 170,
  aux_sym_command_repeat1 = 171,
  aux_sym_elseif_clause_repeat1 = 172,
  aux_sym_if_statement_repeat1 = 173,
  aux_sym_switch_statement_repeat1 = 174,
  aux_sym__lambda_arguments_repeat1 = 175,
  aux_sym_global_operator_repeat1 = 176,
  aux_sym__argument_attributes_repeat1 = 177,
  aux_sym_arguments_statement_repeat1 = 178,
  aux_sym_function_definition_repeat1 = 179,
  aux_sym_attributes_repeat1 = 180,
  aux_sym_superclasses_repeat1 = 181,
  aux_sym_dimensions_repeat1 = 182,
  aux_sym_validation_functions_repeat1 = 183,
  aux_sym_methods_repeat1 = 184,
  aux_sym_events_repeat1 = 185,
  aux_sym_enum_repeat1 = 186,
  aux_sym_enumeration_repeat1 = 187,
  aux_sym_class_definition_repeat1 = 188,
  alias_sym_superclass = 189,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym_identifier] = "identifier",
  [anon_sym_SEMI] = ";",
  [anon_sym_COMMA] = ",",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_PLUS] = "+",
  [anon_sym_DOT_PLUS] = ".+",
  [anon_sym_DASH] = "-",
  [anon_sym_DOT_DASH] = ".-",
  [anon_sym_STAR] = "*",
  [anon_sym_DOT_STAR] = ".*",
  [anon_sym_SLASH] = "/",
  [anon_sym_DOT_SLASH] = "./",
  [anon_sym_BSLASH] = "\\",
  [anon_sym_DOT_BSLASH] = ".\\",
  [anon_sym_CARET] = "^",
  [anon_sym_DOT_CARET] = ".^",
  [anon_sym_PIPE] = "|",
  [anon_sym_AMP] = "&",
  [anon_sym_DOT] = ".",
  [anon_sym_TILDE] = "~",
  [anon_sym_QMARK] = "\?",
  [anon_sym_AT] = "@",
  [anon_sym_LT] = "<",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_EQ_EQ] = "==",
  [anon_sym_TILDE_EQ] = "~=",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_GT] = ">",
  [anon_sym_AMP_AMP] = "&&",
  [anon_sym_PIPE_PIPE] = "||",
  [anon_sym_DOT_SQUOTE] = ".'",
  [anon_sym_SQUOTE] = "'",
  [anon_sym_LBRACK] = "[",
  [aux_sym_matrix_token1] = "matrix_token1",
  [anon_sym_RBRACK] = "]",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [anon_sym_EQ] = "=",
  [anon_sym_COLON] = ":",
  [sym_return_statement] = "return_statement",
  [sym_continue_statement] = "continue_statement",
  [sym_break_statement] = "break_statement",
  [anon_sym_elseif] = "elseif",
  [anon_sym_else] = "else",
  [anon_sym_if] = "if",
  [anon_sym_end] = "end",
  [anon_sym_for] = "for",
  [anon_sym_parfor] = "parfor",
  [anon_sym_while] = "while",
  [anon_sym_case] = "case",
  [anon_sym_otherwise] = "otherwise",
  [anon_sym_switch] = "switch",
  [anon_sym_global] = "global",
  [anon_sym_persistent] = "persistent",
  [anon_sym_arguments] = "arguments",
  [anon_sym_function] = "function",
  [anon_sym_get_DOT] = "get.",
  [anon_sym_set_DOT] = "set.",
  [anon_sym_endfunction] = "endfunction",
  [anon_sym_vector] = "identifier",
  [anon_sym_matrix] = "identifier",
  [anon_sym_scalar] = "identifier",
  [anon_sym_properties] = "properties",
  [anon_sym_methods] = "methods",
  [anon_sym_events] = "events",
  [anon_sym_enumeration] = "enumeration",
  [anon_sym_classdef] = "classdef",
  [anon_sym_catch] = "catch",
  [anon_sym_try] = "try",
  [sym_number] = "number",
  [anon_sym_true] = "true",
  [anon_sym_false] = "false",
  [anon_sym_LF] = "\n",
  [anon_sym_CR] = "\r",
  [sym_comment] = "comment",
  [sym_line_continuation] = "line_continuation",
  [sym_command_name] = "command_name",
  [sym_command_argument] = "command_argument",
  [sym__single_quote_string_start] = "'",
  [sym__single_quote_string_end] = "'",
  [sym__double_quote_string_start] = "\"",
  [sym__double_quote_string_end] = "\"",
  [sym_formatting_sequence] = "formatting_sequence",
  [sym_escape_sequence] = "escape_sequence",
  [sym_string_content] = "string_content",
  [sym__entry_delimiter] = ";",
  [sym__multioutput_variable_start] = "[",
  [sym_error_sentinel] = "error_sentinel",
  [sym_source_file] = "source_file",
  [aux_sym__block] = "_block",
  [sym_block] = "block",
  [sym__statement] = "_statement",
  [sym__expression] = "_expression",
  [sym_parenthesis] = "parenthesis",
  [sym__binary_expression] = "_binary_expression",
  [sym_binary_operator] = "binary_operator",
  [sym_unary_operator] = "unary_operator",
  [sym_indirect_access] = "indirect_access",
  [sym_field_expression] = "field_expression",
  [sym_not_operator] = "not_operator",
  [sym_metaclass_operator] = "metaclass_operator",
  [sym_handle_operator] = "handle_operator",
  [sym_comparison_operator] = "comparison_operator",
  [sym_boolean_operator] = "boolean_operator",
  [sym_postfix_operator] = "postfix_operator",
  [sym_string] = "string",
  [sym_row] = "row",
  [sym_matrix] = "matrix",
  [sym_cell] = "cell",
  [sym_ignored_argument] = "ignored_argument",
  [sym_assignment] = "assignment",
  [sym_multioutput_variable] = "multioutput_variable",
  [sym_spread_operator] = "spread_operator",
  [sym_arguments] = "arguments",
  [sym__args] = "_args",
  [sym_function_call] = "function_call",
  [sym_command] = "command",
  [sym__range_element] = "_range_element",
  [sym_range] = "range",
  [sym_elseif_clause] = "elseif_clause",
  [sym_else_clause] = "else_clause",
  [sym_if_statement] = "if_statement",
  [sym_iterator] = "iterator",
  [sym_parfor_options] = "parfor_options",
  [sym_for_statement] = "for_statement",
  [sym_while_statement] = "while_statement",
  [sym_case_clause] = "case_clause",
  [sym_otherwise_clause] = "otherwise_clause",
  [sym_switch_statement] = "switch_statement",
  [sym__lambda_arguments] = "_lambda_arguments",
  [sym_lambda] = "lambda",
  [sym_global_operator] = "global_operator",
  [sym_persistent_operator] = "persistent_operator",
  [sym__argument_attributes] = "attributes",
  [sym_arguments_statement] = "arguments_statement",
  [sym_function_output] = "function_output",
  [sym_function_arguments] = "function_arguments",
  [sym_function_definition] = "function_definition",
  [sym__function_definition_with_end] = "function_definition",
  [sym_attribute] = "attribute",
  [sym_attributes] = "attributes",
  [sym_superclasses] = "superclasses",
  [sym_dimensions] = "dimensions",
  [sym_validation_functions] = "validation_functions",
  [sym_default_value] = "default_value",
  [sym_property_name] = "property_name",
  [sym_property] = "property",
  [sym_properties] = "properties",
  [sym_function_signature] = "function_signature",
  [sym_methods] = "methods",
  [sym_events] = "events",
  [sym__enum_value] = "_enum_value",
  [sym_enum] = "enum",
  [sym_enumeration] = "enumeration",
  [sym_class_definition] = "class_definition",
  [sym_catch_clause] = "catch_clause",
  [sym_try_statement] = "try_statement",
  [sym_boolean] = "boolean",
  [sym__end_of_line] = "_end_of_line",
  [aux_sym_source_file_repeat1] = "source_file_repeat1",
  [aux_sym__block_repeat1] = "_block_repeat1",
  [aux_sym_field_expression_repeat1] = "field_expression_repeat1",
  [aux_sym_metaclass_operator_repeat1] = "metaclass_operator_repeat1",
  [aux_sym_string_repeat1] = "string_repeat1",
  [aux_sym_row_repeat1] = "row_repeat1",
  [aux_sym_matrix_repeat1] = "matrix_repeat1",
  [aux_sym_multioutput_variable_repeat1] = "multioutput_variable_repeat1",
  [aux_sym_arguments_repeat1] = "arguments_repeat1",
  [aux_sym_arguments_repeat2] = "arguments_repeat2",
  [aux_sym_command_repeat1] = "command_repeat1",
  [aux_sym_elseif_clause_repeat1] = "elseif_clause_repeat1",
  [aux_sym_if_statement_repeat1] = "if_statement_repeat1",
  [aux_sym_switch_statement_repeat1] = "switch_statement_repeat1",
  [aux_sym__lambda_arguments_repeat1] = "_lambda_arguments_repeat1",
  [aux_sym_global_operator_repeat1] = "global_operator_repeat1",
  [aux_sym__argument_attributes_repeat1] = "_argument_attributes_repeat1",
  [aux_sym_arguments_statement_repeat1] = "arguments_statement_repeat1",
  [aux_sym_function_definition_repeat1] = "function_definition_repeat1",
  [aux_sym_attributes_repeat1] = "attributes_repeat1",
  [aux_sym_superclasses_repeat1] = "superclasses_repeat1",
  [aux_sym_dimensions_repeat1] = "dimensions_repeat1",
  [aux_sym_validation_functions_repeat1] = "validation_functions_repeat1",
  [aux_sym_methods_repeat1] = "methods_repeat1",
  [aux_sym_events_repeat1] = "events_repeat1",
  [aux_sym_enum_repeat1] = "enum_repeat1",
  [aux_sym_enumeration_repeat1] = "enumeration_repeat1",
  [aux_sym_class_definition_repeat1] = "class_definition_repeat1",
  [alias_sym_superclass] = "superclass",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym_identifier] = sym_identifier,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_DOT_PLUS] = anon_sym_DOT_PLUS,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_DOT_DASH] = anon_sym_DOT_DASH,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_DOT_STAR] = anon_sym_DOT_STAR,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_DOT_SLASH] = anon_sym_DOT_SLASH,
  [anon_sym_BSLASH] = anon_sym_BSLASH,
  [anon_sym_DOT_BSLASH] = anon_sym_DOT_BSLASH,
  [anon_sym_CARET] = anon_sym_CARET,
  [anon_sym_DOT_CARET] = anon_sym_DOT_CARET,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_AMP] = anon_sym_AMP,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [anon_sym_AT] = anon_sym_AT,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_EQ_EQ] = anon_sym_EQ_EQ,
  [anon_sym_TILDE_EQ] = anon_sym_TILDE_EQ,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_AMP_AMP] = anon_sym_AMP_AMP,
  [anon_sym_PIPE_PIPE] = anon_sym_PIPE_PIPE,
  [anon_sym_DOT_SQUOTE] = anon_sym_DOT_SQUOTE,
  [anon_sym_SQUOTE] = anon_sym_SQUOTE,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [aux_sym_matrix_token1] = aux_sym_matrix_token1,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_COLON] = anon_sym_COLON,
  [sym_return_statement] = sym_return_statement,
  [sym_continue_statement] = sym_continue_statement,
  [sym_break_statement] = sym_break_statement,
  [anon_sym_elseif] = anon_sym_elseif,
  [anon_sym_else] = anon_sym_else,
  [anon_sym_if] = anon_sym_if,
  [anon_sym_end] = anon_sym_end,
  [anon_sym_for] = anon_sym_for,
  [anon_sym_parfor] = anon_sym_parfor,
  [anon_sym_while] = anon_sym_while,
  [anon_sym_case] = anon_sym_case,
  [anon_sym_otherwise] = anon_sym_otherwise,
  [anon_sym_switch] = anon_sym_switch,
  [anon_sym_global] = anon_sym_global,
  [anon_sym_persistent] = anon_sym_persistent,
  [anon_sym_arguments] = anon_sym_arguments,
  [anon_sym_function] = anon_sym_function,
  [anon_sym_get_DOT] = anon_sym_get_DOT,
  [anon_sym_set_DOT] = anon_sym_set_DOT,
  [anon_sym_endfunction] = anon_sym_endfunction,
  [anon_sym_vector] = sym_identifier,
  [anon_sym_matrix] = sym_identifier,
  [anon_sym_scalar] = sym_identifier,
  [anon_sym_properties] = anon_sym_properties,
  [anon_sym_methods] = anon_sym_methods,
  [anon_sym_events] = anon_sym_events,
  [anon_sym_enumeration] = anon_sym_enumeration,
  [anon_sym_classdef] = anon_sym_classdef,
  [anon_sym_catch] = anon_sym_catch,
  [anon_sym_try] = anon_sym_try,
  [sym_number] = sym_number,
  [anon_sym_true] = anon_sym_true,
  [anon_sym_false] = anon_sym_false,
  [anon_sym_LF] = anon_sym_LF,
  [anon_sym_CR] = anon_sym_CR,
  [sym_comment] = sym_comment,
  [sym_line_continuation] = sym_line_continuation,
  [sym_command_name] = sym_command_name,
  [sym_command_argument] = sym_command_argument,
  [sym__single_quote_string_start] = anon_sym_SQUOTE,
  [sym__single_quote_string_end] = anon_sym_SQUOTE,
  [sym__double_quote_string_start] = sym__double_quote_string_start,
  [sym__double_quote_string_end] = sym__double_quote_string_start,
  [sym_formatting_sequence] = sym_formatting_sequence,
  [sym_escape_sequence] = sym_escape_sequence,
  [sym_string_content] = sym_string_content,
  [sym__entry_delimiter] = anon_sym_SEMI,
  [sym__multioutput_variable_start] = anon_sym_LBRACK,
  [sym_error_sentinel] = sym_error_sentinel,
  [sym_source_file] = sym_source_file,
  [aux_sym__block] = aux_sym__block,
  [sym_block] = sym_block,
  [sym__statement] = sym__statement,
  [sym__expression] = sym__expression,
  [sym_parenthesis] = sym_parenthesis,
  [sym__binary_expression] = sym__binary_expression,
  [sym_binary_operator] = sym_binary_operator,
  [sym_unary_operator] = sym_unary_operator,
  [sym_indirect_access] = sym_indirect_access,
  [sym_field_expression] = sym_field_expression,
  [sym_not_operator] = sym_not_operator,
  [sym_metaclass_operator] = sym_metaclass_operator,
  [sym_handle_operator] = sym_handle_operator,
  [sym_comparison_operator] = sym_comparison_operator,
  [sym_boolean_operator] = sym_boolean_operator,
  [sym_postfix_operator] = sym_postfix_operator,
  [sym_string] = sym_string,
  [sym_row] = sym_row,
  [sym_matrix] = sym_matrix,
  [sym_cell] = sym_cell,
  [sym_ignored_argument] = sym_ignored_argument,
  [sym_assignment] = sym_assignment,
  [sym_multioutput_variable] = sym_multioutput_variable,
  [sym_spread_operator] = sym_spread_operator,
  [sym_arguments] = sym_arguments,
  [sym__args] = sym__args,
  [sym_function_call] = sym_function_call,
  [sym_command] = sym_command,
  [sym__range_element] = sym__range_element,
  [sym_range] = sym_range,
  [sym_elseif_clause] = sym_elseif_clause,
  [sym_else_clause] = sym_else_clause,
  [sym_if_statement] = sym_if_statement,
  [sym_iterator] = sym_iterator,
  [sym_parfor_options] = sym_parfor_options,
  [sym_for_statement] = sym_for_statement,
  [sym_while_statement] = sym_while_statement,
  [sym_case_clause] = sym_case_clause,
  [sym_otherwise_clause] = sym_otherwise_clause,
  [sym_switch_statement] = sym_switch_statement,
  [sym__lambda_arguments] = sym__lambda_arguments,
  [sym_lambda] = sym_lambda,
  [sym_global_operator] = sym_global_operator,
  [sym_persistent_operator] = sym_persistent_operator,
  [sym__argument_attributes] = sym_attributes,
  [sym_arguments_statement] = sym_arguments_statement,
  [sym_function_output] = sym_function_output,
  [sym_function_arguments] = sym_function_arguments,
  [sym_function_definition] = sym_function_definition,
  [sym__function_definition_with_end] = sym_function_definition,
  [sym_attribute] = sym_attribute,
  [sym_attributes] = sym_attributes,
  [sym_superclasses] = sym_superclasses,
  [sym_dimensions] = sym_dimensions,
  [sym_validation_functions] = sym_validation_functions,
  [sym_default_value] = sym_default_value,
  [sym_property_name] = sym_property_name,
  [sym_property] = sym_property,
  [sym_properties] = sym_properties,
  [sym_function_signature] = sym_function_signature,
  [sym_methods] = sym_methods,
  [sym_events] = sym_events,
  [sym__enum_value] = sym__enum_value,
  [sym_enum] = sym_enum,
  [sym_enumeration] = sym_enumeration,
  [sym_class_definition] = sym_class_definition,
  [sym_catch_clause] = sym_catch_clause,
  [sym_try_statement] = sym_try_statement,
  [sym_boolean] = sym_boolean,
  [sym__end_of_line] = sym__end_of_line,
  [aux_sym_source_file_repeat1] = aux_sym_source_file_repeat1,
  [aux_sym__block_repeat1] = aux_sym__block_repeat1,
  [aux_sym_field_expression_repeat1] = aux_sym_field_expression_repeat1,
  [aux_sym_metaclass_operator_repeat1] = aux_sym_metaclass_operator_repeat1,
  [aux_sym_string_repeat1] = aux_sym_string_repeat1,
  [aux_sym_row_repeat1] = aux_sym_row_repeat1,
  [aux_sym_matrix_repeat1] = aux_sym_matrix_repeat1,
  [aux_sym_multioutput_variable_repeat1] = aux_sym_multioutput_variable_repeat1,
  [aux_sym_arguments_repeat1] = aux_sym_arguments_repeat1,
  [aux_sym_arguments_repeat2] = aux_sym_arguments_repeat2,
  [aux_sym_command_repeat1] = aux_sym_command_repeat1,
  [aux_sym_elseif_clause_repeat1] = aux_sym_elseif_clause_repeat1,
  [aux_sym_if_statement_repeat1] = aux_sym_if_statement_repeat1,
  [aux_sym_switch_statement_repeat1] = aux_sym_switch_statement_repeat1,
  [aux_sym__lambda_arguments_repeat1] = aux_sym__lambda_arguments_repeat1,
  [aux_sym_global_operator_repeat1] = aux_sym_global_operator_repeat1,
  [aux_sym__argument_attributes_repeat1] = aux_sym__argument_attributes_repeat1,
  [aux_sym_arguments_statement_repeat1] = aux_sym_arguments_statement_repeat1,
  [aux_sym_function_definition_repeat1] = aux_sym_function_definition_repeat1,
  [aux_sym_attributes_repeat1] = aux_sym_attributes_repeat1,
  [aux_sym_superclasses_repeat1] = aux_sym_superclasses_repeat1,
  [aux_sym_dimensions_repeat1] = aux_sym_dimensions_repeat1,
  [aux_sym_validation_functions_repeat1] = aux_sym_validation_functions_repeat1,
  [aux_sym_methods_repeat1] = aux_sym_methods_repeat1,
  [aux_sym_events_repeat1] = aux_sym_events_repeat1,
  [aux_sym_enum_repeat1] = aux_sym_enum_repeat1,
  [aux_sym_enumeration_repeat1] = aux_sym_enumeration_repeat1,
  [aux_sym_class_definition_repeat1] = aux_sym_class_definition_repeat1,
  [alias_sym_superclass] = alias_sym_superclass,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BSLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_BSLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_matrix_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [sym_return_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_continue_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_break_statement] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_elseif] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_else] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_if] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_end] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_for] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_parfor] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_while] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_case] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_otherwise] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_switch] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_global] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_persistent] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_arguments] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_function] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_get_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_set_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_endfunction] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_vector] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_matrix] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_scalar] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_properties] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_methods] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_events] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_enumeration] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_classdef] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_catch] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_try] = {
    .visible = true,
    .named = false,
  },
  [sym_number] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_true] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_false] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LF] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CR] = {
    .visible = true,
    .named = false,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_line_continuation] = {
    .visible = true,
    .named = true,
  },
  [sym_command_name] = {
    .visible = true,
    .named = true,
  },
  [sym_command_argument] = {
    .visible = true,
    .named = true,
  },
  [sym__single_quote_string_start] = {
    .visible = true,
    .named = false,
  },
  [sym__single_quote_string_end] = {
    .visible = true,
    .named = false,
  },
  [sym__double_quote_string_start] = {
    .visible = true,
    .named = false,
  },
  [sym__double_quote_string_end] = {
    .visible = true,
    .named = false,
  },
  [sym_formatting_sequence] = {
    .visible = true,
    .named = true,
  },
  [sym_escape_sequence] = {
    .visible = true,
    .named = true,
  },
  [sym_string_content] = {
    .visible = true,
    .named = true,
  },
  [sym__entry_delimiter] = {
    .visible = true,
    .named = false,
  },
  [sym__multioutput_variable_start] = {
    .visible = true,
    .named = false,
  },
  [sym_error_sentinel] = {
    .visible = true,
    .named = true,
  },
  [sym_source_file] = {
    .visible = true,
    .named = true,
  },
  [aux_sym__block] = {
    .visible = false,
    .named = false,
  },
  [sym_block] = {
    .visible = true,
    .named = true,
  },
  [sym__statement] = {
    .visible = false,
    .named = true,
  },
  [sym__expression] = {
    .visible = false,
    .named = true,
  },
  [sym_parenthesis] = {
    .visible = true,
    .named = true,
  },
  [sym__binary_expression] = {
    .visible = false,
    .named = true,
  },
  [sym_binary_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_unary_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_indirect_access] = {
    .visible = true,
    .named = true,
  },
  [sym_field_expression] = {
    .visible = true,
    .named = true,
  },
  [sym_not_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_metaclass_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_handle_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_comparison_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_boolean_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_postfix_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [sym_row] = {
    .visible = true,
    .named = true,
  },
  [sym_matrix] = {
    .visible = true,
    .named = true,
  },
  [sym_cell] = {
    .visible = true,
    .named = true,
  },
  [sym_ignored_argument] = {
    .visible = true,
    .named = true,
  },
  [sym_assignment] = {
    .visible = true,
    .named = true,
  },
  [sym_multioutput_variable] = {
    .visible = true,
    .named = true,
  },
  [sym_spread_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym__args] = {
    .visible = false,
    .named = true,
  },
  [sym_function_call] = {
    .visible = true,
    .named = true,
  },
  [sym_command] = {
    .visible = true,
    .named = true,
  },
  [sym__range_element] = {
    .visible = false,
    .named = true,
  },
  [sym_range] = {
    .visible = true,
    .named = true,
  },
  [sym_elseif_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_else_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_if_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_iterator] = {
    .visible = true,
    .named = true,
  },
  [sym_parfor_options] = {
    .visible = true,
    .named = true,
  },
  [sym_for_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_while_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_case_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_otherwise_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_switch_statement] = {
    .visible = true,
    .named = true,
  },
  [sym__lambda_arguments] = {
    .visible = false,
    .named = true,
  },
  [sym_lambda] = {
    .visible = true,
    .named = true,
  },
  [sym_global_operator] = {
    .visible = true,
    .named = true,
  },
  [sym_persistent_operator] = {
    .visible = true,
    .named = true,
  },
  [sym__argument_attributes] = {
    .visible = true,
    .named = true,
  },
  [sym_arguments_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_function_output] = {
    .visible = true,
    .named = true,
  },
  [sym_function_arguments] = {
    .visible = true,
    .named = true,
  },
  [sym_function_definition] = {
    .visible = true,
    .named = true,
  },
  [sym__function_definition_with_end] = {
    .visible = true,
    .named = true,
  },
  [sym_attribute] = {
    .visible = true,
    .named = true,
  },
  [sym_attributes] = {
    .visible = true,
    .named = true,
  },
  [sym_superclasses] = {
    .visible = true,
    .named = true,
  },
  [sym_dimensions] = {
    .visible = true,
    .named = true,
  },
  [sym_validation_functions] = {
    .visible = true,
    .named = true,
  },
  [sym_default_value] = {
    .visible = true,
    .named = true,
  },
  [sym_property_name] = {
    .visible = true,
    .named = true,
  },
  [sym_property] = {
    .visible = true,
    .named = true,
  },
  [sym_properties] = {
    .visible = true,
    .named = true,
  },
  [sym_function_signature] = {
    .visible = true,
    .named = true,
  },
  [sym_methods] = {
    .visible = true,
    .named = true,
  },
  [sym_events] = {
    .visible = true,
    .named = true,
  },
  [sym__enum_value] = {
    .visible = false,
    .named = true,
  },
  [sym_enum] = {
    .visible = true,
    .named = true,
  },
  [sym_enumeration] = {
    .visible = true,
    .named = true,
  },
  [sym_class_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_catch_clause] = {
    .visible = true,
    .named = true,
  },
  [sym_try_statement] = {
    .visible = true,
    .named = true,
  },
  [sym_boolean] = {
    .visible = true,
    .named = true,
  },
  [sym__end_of_line] = {
    .visible = false,
    .named = true,
  },
  [aux_sym_source_file_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__block_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_field_expression_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_metaclass_operator_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_row_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_matrix_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_multioutput_variable_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_arguments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_arguments_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_command_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_elseif_clause_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_if_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_switch_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__lambda_arguments_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_global_operator_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__argument_attributes_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_arguments_statement_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_function_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_attributes_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_superclasses_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_dimensions_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_validation_functions_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_methods_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_events_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enum_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enumeration_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_class_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [alias_sym_superclass] = {
    .visible = true,
    .named = true,
  },
};

enum ts_field_identifiers {
  field_argument = 1,
  field_arguments = 2,
  field_condition = 3,
  field_expression = 4,
  field_field = 5,
  field_left = 6,
  field_name = 7,
  field_object = 8,
  field_operand = 9,
  field_right = 10,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_argument] = "argument",
  [field_arguments] = "arguments",
  [field_condition] = "condition",
  [field_expression] = "expression",
  [field_field] = "field",
  [field_left] = "left",
  [field_name] = "name",
  [field_object] = "object",
  [field_operand] = "operand",
  [field_right] = "right",
};

static const TSFieldMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [1] = {.index = 0, .length = 1},
  [2] = {.index = 1, .length = 1},
  [3] = {.index = 2, .length = 1},
  [4] = {.index = 3, .length = 2},
  [5] = {.index = 5, .length = 1},
  [6] = {.index = 2, .length = 1},
  [7] = {.index = 6, .length = 1},
  [8] = {.index = 7, .length = 1},
  [9] = {.index = 8, .length = 1},
  [10] = {.index = 9, .length = 1},
  [11] = {.index = 10, .length = 2},
  [12] = {.index = 12, .length = 2},
  [13] = {.index = 14, .length = 1},
  [14] = {.index = 15, .length = 1},
  [15] = {.index = 16, .length = 2},
  [16] = {.index = 2, .length = 1},
  [17] = {.index = 2, .length = 1},
  [18] = {.index = 18, .length = 1},
  [19] = {.index = 19, .length = 1},
  [20] = {.index = 20, .length = 1},
  [21] = {.index = 21, .length = 1},
  [22] = {.index = 22, .length = 2},
  [23] = {.index = 24, .length = 1},
  [24] = {.index = 25, .length = 2},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_operand, 1},
  [1] =
    {field_operand, 0},
  [2] =
    {field_name, 0},
  [3] =
    {field_field, 1, .inherited = true},
    {field_object, 0},
  [5] =
    {field_name, 0, .inherited = true},
  [6] =
    {field_condition, 1},
  [7] =
    {field_name, 1},
  [8] =
    {field_argument, 0},
  [9] =
    {field_field, 1},
  [10] =
    {field_left, 0},
    {field_right, 2},
  [12] =
    {field_field, 0, .inherited = true},
    {field_field, 1, .inherited = true},
  [14] =
    {field_expression, 3},
  [15] =
    {field_name, 2},
  [16] =
    {field_argument, 0},
    {field_argument, 1, .inherited = true},
  [18] =
    {field_expression, 4},
  [19] =
    {field_arguments, 1},
  [20] =
    {field_name, 3},
  [21] =
    {field_argument, 1},
  [22] =
    {field_argument, 0, .inherited = true},
    {field_argument, 1, .inherited = true},
  [24] =
    {field_argument, 1, .inherited = true},
  [25] =
    {field_argument, 1},
    {field_argument, 2, .inherited = true},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [6] = {
    [0] = sym_identifier,
  },
  [16] = {
    [2] = alias_sym_superclass,
  },
  [17] = {
    [0] = sym_identifier,
    [2] = alias_sym_superclass,
  },
  [18] = {
    [2] = sym_arguments,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  sym__lambda_arguments, 2,
    sym__lambda_arguments,
    sym_arguments,
  sym_property_name, 2,
    sym_property_name,
    alias_sym_superclass,
  sym_boolean, 2,
    sym_boolean,
    sym_identifier,
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 5,
  [6] = 6,
  [7] = 7,
  [8] = 8,
  [9] = 9,
  [10] = 10,
  [11] = 11,
  [12] = 12,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 16,
  [17] = 17,
  [18] = 18,
  [19] = 19,
  [20] = 20,
  [21] = 21,
  [22] = 22,
  [23] = 23,
  [24] = 24,
  [25] = 25,
  [26] = 26,
  [27] = 27,
  [28] = 28,
  [29] = 29,
  [30] = 30,
  [31] = 31,
  [32] = 32,
  [33] = 33,
  [34] = 34,
  [35] = 35,
  [36] = 36,
  [37] = 37,
  [38] = 38,
  [39] = 39,
  [40] = 40,
  [41] = 41,
  [42] = 42,
  [43] = 43,
  [44] = 44,
  [45] = 45,
  [46] = 46,
  [47] = 47,
  [48] = 48,
  [49] = 49,
  [50] = 50,
  [51] = 51,
  [52] = 52,
  [53] = 53,
  [54] = 54,
  [55] = 47,
  [56] = 56,
  [57] = 57,
  [58] = 53,
  [59] = 59,
  [60] = 60,
  [61] = 45,
  [62] = 57,
  [63] = 59,
  [64] = 46,
  [65] = 49,
  [66] = 54,
  [67] = 50,
  [68] = 56,
  [69] = 51,
  [70] = 52,
  [71] = 71,
  [72] = 48,
  [73] = 60,
  [74] = 48,
  [75] = 60,
  [76] = 76,
  [77] = 76,
  [78] = 76,
  [79] = 76,
  [80] = 80,
  [81] = 81,
  [82] = 82,
  [83] = 83,
  [84] = 84,
  [85] = 85,
  [86] = 86,
  [87] = 87,
  [88] = 88,
  [89] = 89,
  [90] = 90,
  [91] = 90,
  [92] = 92,
  [93] = 90,
  [94] = 94,
  [95] = 95,
  [96] = 90,
  [97] = 97,
  [98] = 98,
  [99] = 99,
  [100] = 100,
  [101] = 101,
  [102] = 102,
  [103] = 103,
  [104] = 104,
  [105] = 105,
  [106] = 106,
  [107] = 107,
  [108] = 108,
  [109] = 109,
  [110] = 110,
  [111] = 111,
  [112] = 112,
  [113] = 113,
  [114] = 114,
  [115] = 115,
  [116] = 116,
  [117] = 117,
  [118] = 118,
  [119] = 119,
  [120] = 120,
  [121] = 121,
  [122] = 122,
  [123] = 120,
  [124] = 124,
  [125] = 125,
  [126] = 126,
  [127] = 127,
  [128] = 128,
  [129] = 129,
  [130] = 121,
  [131] = 120,
  [132] = 122,
  [133] = 120,
  [134] = 122,
  [135] = 124,
  [136] = 121,
  [137] = 121,
  [138] = 138,
  [139] = 122,
  [140] = 140,
  [141] = 129,
  [142] = 142,
  [143] = 143,
  [144] = 144,
  [145] = 145,
  [146] = 146,
  [147] = 124,
  [148] = 128,
  [149] = 126,
  [150] = 127,
  [151] = 125,
  [152] = 83,
  [153] = 81,
  [154] = 84,
  [155] = 85,
  [156] = 82,
  [157] = 92,
  [158] = 158,
  [159] = 159,
  [160] = 160,
  [161] = 161,
  [162] = 162,
  [163] = 163,
  [164] = 164,
  [165] = 165,
  [166] = 166,
  [167] = 167,
  [168] = 168,
  [169] = 169,
  [170] = 165,
  [171] = 169,
  [172] = 172,
  [173] = 168,
  [174] = 165,
  [175] = 175,
  [176] = 176,
  [177] = 172,
  [178] = 178,
  [179] = 179,
  [180] = 169,
  [181] = 172,
  [182] = 168,
  [183] = 165,
  [184] = 169,
  [185] = 172,
  [186] = 168,
  [187] = 165,
  [188] = 168,
  [189] = 76,
  [190] = 80,
  [191] = 76,
  [192] = 76,
  [193] = 76,
  [194] = 86,
  [195] = 94,
  [196] = 99,
  [197] = 100,
  [198] = 198,
  [199] = 89,
  [200] = 200,
  [201] = 95,
  [202] = 202,
  [203] = 97,
  [204] = 101,
  [205] = 205,
  [206] = 76,
  [207] = 76,
  [208] = 90,
  [209] = 80,
  [210] = 210,
  [211] = 211,
  [212] = 164,
  [213] = 213,
  [214] = 90,
  [215] = 76,
  [216] = 216,
  [217] = 90,
  [218] = 90,
  [219] = 76,
  [220] = 98,
  [221] = 221,
  [222] = 222,
  [223] = 223,
  [224] = 223,
  [225] = 225,
  [226] = 226,
  [227] = 227,
  [228] = 228,
  [229] = 229,
  [230] = 230,
  [231] = 225,
  [232] = 226,
  [233] = 233,
  [234] = 234,
  [235] = 235,
  [236] = 236,
  [237] = 237,
  [238] = 238,
  [239] = 239,
  [240] = 237,
  [241] = 233,
  [242] = 242,
  [243] = 243,
  [244] = 138,
  [245] = 245,
  [246] = 234,
  [247] = 227,
  [248] = 228,
  [249] = 229,
  [250] = 230,
  [251] = 225,
  [252] = 226,
  [253] = 233,
  [254] = 234,
  [255] = 235,
  [256] = 256,
  [257] = 235,
  [258] = 236,
  [259] = 86,
  [260] = 260,
  [261] = 238,
  [262] = 87,
  [263] = 237,
  [264] = 175,
  [265] = 227,
  [266] = 238,
  [267] = 228,
  [268] = 229,
  [269] = 230,
  [270] = 225,
  [271] = 271,
  [272] = 226,
  [273] = 233,
  [274] = 234,
  [275] = 235,
  [276] = 227,
  [277] = 228,
  [278] = 229,
  [279] = 279,
  [280] = 236,
  [281] = 236,
  [282] = 229,
  [283] = 237,
  [284] = 284,
  [285] = 285,
  [286] = 236,
  [287] = 227,
  [288] = 228,
  [289] = 229,
  [290] = 236,
  [291] = 237,
  [292] = 292,
  [293] = 227,
  [294] = 228,
  [295] = 229,
  [296] = 236,
  [297] = 237,
  [298] = 298,
  [299] = 299,
  [300] = 300,
  [301] = 227,
  [302] = 228,
  [303] = 229,
  [304] = 304,
  [305] = 236,
  [306] = 306,
  [307] = 307,
  [308] = 237,
  [309] = 176,
  [310] = 167,
  [311] = 237,
  [312] = 312,
  [313] = 313,
  [314] = 314,
  [315] = 179,
  [316] = 88,
  [317] = 238,
  [318] = 318,
  [319] = 243,
  [320] = 222,
  [321] = 285,
  [322] = 236,
  [323] = 299,
  [324] = 237,
  [325] = 285,
  [326] = 243,
  [327] = 222,
  [328] = 285,
  [329] = 243,
  [330] = 222,
  [331] = 166,
  [332] = 222,
  [333] = 227,
  [334] = 228,
  [335] = 223,
  [336] = 236,
  [337] = 237,
  [338] = 236,
  [339] = 237,
  [340] = 236,
  [341] = 237,
  [342] = 223,
  [343] = 236,
  [344] = 237,
  [345] = 230,
  [346] = 82,
  [347] = 85,
  [348] = 97,
  [349] = 90,
  [350] = 99,
  [351] = 76,
  [352] = 98,
  [353] = 353,
  [354] = 100,
  [355] = 101,
  [356] = 90,
  [357] = 89,
  [358] = 76,
  [359] = 76,
  [360] = 90,
  [361] = 90,
  [362] = 81,
  [363] = 76,
  [364] = 83,
  [365] = 80,
  [366] = 76,
  [367] = 95,
  [368] = 94,
  [369] = 84,
  [370] = 138,
  [371] = 92,
  [372] = 372,
  [373] = 373,
  [374] = 86,
  [375] = 375,
  [376] = 376,
  [377] = 377,
  [378] = 378,
  [379] = 142,
  [380] = 84,
  [381] = 120,
  [382] = 122,
  [383] = 144,
  [384] = 121,
  [385] = 145,
  [386] = 120,
  [387] = 122,
  [388] = 124,
  [389] = 146,
  [390] = 377,
  [391] = 117,
  [392] = 90,
  [393] = 82,
  [394] = 121,
  [395] = 90,
  [396] = 121,
  [397] = 85,
  [398] = 118,
  [399] = 377,
  [400] = 129,
  [401] = 103,
  [402] = 101,
  [403] = 377,
  [404] = 88,
  [405] = 124,
  [406] = 111,
  [407] = 126,
  [408] = 104,
  [409] = 125,
  [410] = 105,
  [411] = 122,
  [412] = 89,
  [413] = 122,
  [414] = 116,
  [415] = 120,
  [416] = 94,
  [417] = 90,
  [418] = 97,
  [419] = 377,
  [420] = 128,
  [421] = 98,
  [422] = 377,
  [423] = 106,
  [424] = 81,
  [425] = 143,
  [426] = 95,
  [427] = 140,
  [428] = 83,
  [429] = 112,
  [430] = 129,
  [431] = 113,
  [432] = 119,
  [433] = 107,
  [434] = 114,
  [435] = 108,
  [436] = 87,
  [437] = 121,
  [438] = 102,
  [439] = 127,
  [440] = 377,
  [441] = 109,
  [442] = 110,
  [443] = 115,
  [444] = 99,
  [445] = 90,
  [446] = 100,
  [447] = 120,
  [448] = 92,
  [449] = 138,
  [450] = 450,
  [451] = 140,
  [452] = 143,
  [453] = 108,
  [454] = 144,
  [455] = 145,
  [456] = 109,
  [457] = 110,
  [458] = 103,
  [459] = 88,
  [460] = 121,
  [461] = 111,
  [462] = 146,
  [463] = 112,
  [464] = 113,
  [465] = 114,
  [466] = 115,
  [467] = 102,
  [468] = 116,
  [469] = 104,
  [470] = 105,
  [471] = 117,
  [472] = 472,
  [473] = 120,
  [474] = 118,
  [475] = 122,
  [476] = 120,
  [477] = 122,
  [478] = 124,
  [479] = 107,
  [480] = 106,
  [481] = 81,
  [482] = 83,
  [483] = 121,
  [484] = 121,
  [485] = 84,
  [486] = 87,
  [487] = 82,
  [488] = 85,
  [489] = 120,
  [490] = 119,
  [491] = 124,
  [492] = 492,
  [493] = 124,
  [494] = 120,
  [495] = 121,
  [496] = 122,
  [497] = 125,
  [498] = 126,
  [499] = 127,
  [500] = 128,
  [501] = 129,
  [502] = 129,
  [503] = 142,
  [504] = 122,
  [505] = 126,
  [506] = 128,
  [507] = 127,
  [508] = 92,
  [509] = 125,
  [510] = 102,
  [511] = 121,
  [512] = 108,
  [513] = 125,
  [514] = 126,
  [515] = 121,
  [516] = 120,
  [517] = 118,
  [518] = 127,
  [519] = 112,
  [520] = 128,
  [521] = 120,
  [522] = 140,
  [523] = 129,
  [524] = 121,
  [525] = 142,
  [526] = 109,
  [527] = 124,
  [528] = 143,
  [529] = 129,
  [530] = 144,
  [531] = 145,
  [532] = 103,
  [533] = 119,
  [534] = 120,
  [535] = 122,
  [536] = 124,
  [537] = 146,
  [538] = 113,
  [539] = 104,
  [540] = 105,
  [541] = 124,
  [542] = 106,
  [543] = 117,
  [544] = 111,
  [545] = 114,
  [546] = 115,
  [547] = 120,
  [548] = 122,
  [549] = 107,
  [550] = 110,
  [551] = 122,
  [552] = 122,
  [553] = 116,
  [554] = 121,
  [555] = 127,
  [556] = 556,
  [557] = 557,
  [558] = 128,
  [559] = 125,
  [560] = 560,
  [561] = 561,
  [562] = 562,
  [563] = 126,
  [564] = 562,
  [565] = 565,
  [566] = 124,
  [567] = 557,
  [568] = 561,
  [569] = 562,
  [570] = 561,
  [571] = 557,
  [572] = 561,
  [573] = 561,
  [574] = 562,
  [575] = 557,
  [576] = 561,
  [577] = 562,
  [578] = 557,
  [579] = 562,
  [580] = 557,
  [581] = 121,
  [582] = 126,
  [583] = 125,
  [584] = 127,
  [585] = 128,
  [586] = 121,
  [587] = 587,
  [588] = 121,
  [589] = 129,
  [590] = 129,
  [591] = 129,
  [592] = 85,
  [593] = 92,
  [594] = 594,
  [595] = 595,
  [596] = 83,
  [597] = 82,
  [598] = 84,
  [599] = 81,
  [600] = 600,
  [601] = 84,
  [602] = 82,
  [603] = 85,
  [604] = 81,
  [605] = 83,
  [606] = 85,
  [607] = 92,
  [608] = 608,
  [609] = 609,
  [610] = 610,
  [611] = 611,
  [612] = 612,
  [613] = 92,
  [614] = 610,
  [615] = 610,
  [616] = 610,
  [617] = 617,
  [618] = 83,
  [619] = 619,
  [620] = 620,
  [621] = 84,
  [622] = 622,
  [623] = 82,
  [624] = 622,
  [625] = 625,
  [626] = 622,
  [627] = 81,
  [628] = 628,
  [629] = 629,
  [630] = 99,
  [631] = 631,
  [632] = 632,
  [633] = 633,
  [634] = 634,
  [635] = 94,
  [636] = 97,
  [637] = 637,
  [638] = 638,
  [639] = 639,
  [640] = 640,
  [641] = 100,
  [642] = 642,
  [643] = 101,
  [644] = 644,
  [645] = 89,
  [646] = 646,
  [647] = 647,
  [648] = 648,
  [649] = 649,
  [650] = 650,
  [651] = 651,
  [652] = 652,
  [653] = 653,
  [654] = 654,
  [655] = 655,
  [656] = 656,
  [657] = 657,
  [658] = 658,
  [659] = 86,
  [660] = 660,
  [661] = 661,
  [662] = 662,
  [663] = 663,
  [664] = 664,
  [665] = 665,
  [666] = 666,
  [667] = 667,
  [668] = 668,
  [669] = 669,
  [670] = 670,
  [671] = 95,
  [672] = 672,
  [673] = 673,
  [674] = 674,
  [675] = 675,
  [676] = 159,
  [677] = 87,
  [678] = 678,
  [679] = 160,
  [680] = 678,
  [681] = 681,
  [682] = 682,
  [683] = 678,
  [684] = 678,
  [685] = 88,
  [686] = 686,
  [687] = 682,
  [688] = 688,
  [689] = 689,
  [690] = 688,
  [691] = 691,
  [692] = 692,
  [693] = 692,
  [694] = 692,
  [695] = 692,
  [696] = 692,
  [697] = 697,
  [698] = 698,
  [699] = 699,
  [700] = 700,
  [701] = 701,
  [702] = 702,
  [703] = 697,
  [704] = 704,
  [705] = 705,
  [706] = 706,
  [707] = 707,
  [708] = 708,
  [709] = 709,
  [710] = 710,
  [711] = 711,
  [712] = 712,
  [713] = 713,
  [714] = 714,
  [715] = 715,
  [716] = 716,
  [717] = 717,
  [718] = 718,
  [719] = 719,
  [720] = 720,
  [721] = 721,
  [722] = 709,
  [723] = 723,
  [724] = 724,
  [725] = 725,
  [726] = 726,
  [727] = 727,
  [728] = 728,
  [729] = 729,
  [730] = 730,
  [731] = 731,
  [732] = 732,
  [733] = 733,
  [734] = 709,
  [735] = 735,
  [736] = 736,
  [737] = 737,
  [738] = 738,
  [739] = 709,
  [740] = 740,
  [741] = 709,
  [742] = 742,
  [743] = 743,
  [744] = 744,
  [745] = 745,
  [746] = 712,
  [747] = 747,
  [748] = 748,
  [749] = 749,
  [750] = 750,
  [751] = 751,
  [752] = 752,
  [753] = 753,
  [754] = 754,
  [755] = 755,
  [756] = 756,
  [757] = 757,
  [758] = 758,
  [759] = 759,
  [760] = 760,
  [761] = 761,
  [762] = 762,
  [763] = 763,
  [764] = 764,
  [765] = 765,
  [766] = 766,
  [767] = 767,
  [768] = 768,
  [769] = 769,
  [770] = 770,
  [771] = 771,
  [772] = 772,
  [773] = 773,
  [774] = 774,
  [775] = 775,
  [776] = 776,
  [777] = 777,
  [778] = 778,
  [779] = 779,
  [780] = 780,
  [781] = 781,
  [782] = 782,
  [783] = 783,
  [784] = 784,
  [785] = 785,
  [786] = 786,
  [787] = 787,
  [788] = 788,
  [789] = 789,
  [790] = 790,
  [791] = 791,
  [792] = 792,
  [793] = 793,
  [794] = 794,
  [795] = 795,
  [796] = 796,
  [797] = 797,
  [798] = 798,
  [799] = 799,
  [800] = 800,
  [801] = 801,
  [802] = 802,
  [803] = 803,
  [804] = 804,
  [805] = 805,
  [806] = 806,
  [807] = 807,
  [808] = 808,
  [809] = 809,
  [810] = 810,
  [811] = 811,
  [812] = 812,
  [813] = 813,
  [814] = 814,
  [815] = 815,
  [816] = 816,
  [817] = 817,
  [818] = 818,
  [819] = 819,
  [820] = 820,
  [821] = 821,
  [822] = 822,
  [823] = 823,
  [824] = 824,
  [825] = 825,
  [826] = 826,
  [827] = 827,
  [828] = 828,
  [829] = 829,
  [830] = 830,
  [831] = 831,
  [832] = 832,
  [833] = 790,
  [834] = 834,
  [835] = 835,
  [836] = 836,
  [837] = 837,
  [838] = 838,
  [839] = 839,
  [840] = 840,
  [841] = 841,
  [842] = 835,
  [843] = 843,
  [844] = 844,
  [845] = 845,
  [846] = 846,
  [847] = 847,
  [848] = 848,
  [849] = 849,
  [850] = 850,
  [851] = 851,
  [852] = 852,
  [853] = 853,
  [854] = 854,
  [855] = 855,
  [856] = 856,
  [857] = 857,
  [858] = 858,
  [859] = 859,
  [860] = 860,
  [861] = 861,
  [862] = 847,
  [863] = 846,
  [864] = 854,
  [865] = 848,
  [866] = 866,
  [867] = 867,
  [868] = 868,
  [869] = 869,
  [870] = 835,
  [871] = 867,
  [872] = 868,
  [873] = 873,
  [874] = 869,
  [875] = 875,
  [876] = 854,
  [877] = 877,
  [878] = 848,
  [879] = 879,
  [880] = 867,
  [881] = 868,
  [882] = 869,
  [883] = 883,
  [884] = 835,
  [885] = 846,
  [886] = 854,
  [887] = 887,
  [888] = 868,
  [889] = 869,
  [890] = 890,
  [891] = 891,
  [892] = 835,
  [893] = 835,
  [894] = 835,
  [895] = 835,
  [896] = 835,
  [897] = 844,
  [898] = 837,
  [899] = 852,
  [900] = 900,
  [901] = 901,
  [902] = 835,
  [903] = 835,
  [904] = 835,
  [905] = 905,
  [906] = 835,
  [907] = 907,
  [908] = 908,
  [909] = 846,
  [910] = 731,
  [911] = 911,
  [912] = 912,
  [913] = 913,
  [914] = 914,
  [915] = 915,
  [916] = 758,
  [917] = 917,
  [918] = 918,
  [919] = 919,
  [920] = 920,
  [921] = 921,
  [922] = 922,
  [923] = 923,
  [924] = 759,
  [925] = 701,
  [926] = 926,
  [927] = 927,
  [928] = 928,
  [929] = 929,
  [930] = 930,
  [931] = 931,
  [932] = 932,
  [933] = 933,
  [934] = 760,
  [935] = 914,
  [936] = 719,
  [937] = 937,
  [938] = 938,
  [939] = 939,
  [940] = 940,
  [941] = 728,
  [942] = 942,
  [943] = 943,
  [944] = 944,
  [945] = 919,
  [946] = 946,
  [947] = 827,
  [948] = 795,
  [949] = 730,
  [950] = 938,
  [951] = 951,
  [952] = 952,
  [953] = 953,
  [954] = 954,
  [955] = 753,
  [956] = 956,
  [957] = 957,
  [958] = 958,
  [959] = 959,
  [960] = 960,
  [961] = 961,
  [962] = 962,
  [963] = 963,
  [964] = 964,
  [965] = 940,
  [966] = 966,
  [967] = 967,
  [968] = 968,
  [969] = 914,
  [970] = 642,
  [971] = 718,
  [972] = 972,
  [973] = 973,
  [974] = 974,
  [975] = 975,
  [976] = 976,
  [977] = 977,
  [978] = 978,
  [979] = 944,
  [980] = 919,
  [981] = 981,
  [982] = 938,
  [983] = 951,
  [984] = 752,
  [985] = 724,
  [986] = 951,
  [987] = 987,
  [988] = 736,
  [989] = 755,
  [990] = 914,
  [991] = 725,
  [992] = 992,
  [993] = 940,
  [994] = 829,
  [995] = 747,
  [996] = 996,
  [997] = 944,
  [998] = 919,
  [999] = 999,
  [1000] = 749,
  [1001] = 938,
  [1002] = 951,
  [1003] = 914,
  [1004] = 940,
  [1005] = 756,
  [1006] = 1006,
  [1007] = 1007,
  [1008] = 757,
  [1009] = 1009,
  [1010] = 735,
  [1011] = 944,
  [1012] = 721,
  [1013] = 1013,
  [1014] = 1014,
  [1015] = 1015,
  [1016] = 1016,
  [1017] = 1017,
  [1018] = 1018,
  [1019] = 1019,
  [1020] = 1020,
  [1021] = 1021,
  [1022] = 1022,
  [1023] = 1023,
  [1024] = 1024,
  [1025] = 1025,
  [1026] = 1026,
  [1027] = 1027,
  [1028] = 1028,
  [1029] = 1029,
  [1030] = 1030,
  [1031] = 754,
  [1032] = 1032,
  [1033] = 940,
  [1034] = 1034,
  [1035] = 1035,
  [1036] = 1036,
  [1037] = 1037,
  [1038] = 1038,
  [1039] = 1039,
  [1040] = 1040,
  [1041] = 1041,
  [1042] = 1042,
  [1043] = 1043,
  [1044] = 1044,
  [1045] = 1045,
  [1046] = 1046,
  [1047] = 1047,
  [1048] = 1048,
  [1049] = 1049,
  [1050] = 1050,
  [1051] = 1051,
  [1052] = 1052,
  [1053] = 1053,
  [1054] = 1054,
  [1055] = 1055,
  [1056] = 1056,
  [1057] = 1035,
  [1058] = 1058,
  [1059] = 1053,
  [1060] = 1060,
  [1061] = 1061,
  [1062] = 1062,
  [1063] = 1063,
  [1064] = 1064,
  [1065] = 1065,
  [1066] = 1066,
  [1067] = 1067,
  [1068] = 1068,
  [1069] = 1058,
  [1070] = 1070,
  [1071] = 1071,
  [1072] = 1072,
  [1073] = 1073,
  [1074] = 1074,
  [1075] = 1075,
  [1076] = 1076,
  [1077] = 1035,
  [1078] = 1034,
  [1079] = 1058,
  [1080] = 1080,
  [1081] = 1081,
  [1082] = 1056,
  [1083] = 1083,
  [1084] = 1084,
  [1085] = 1085,
  [1086] = 1035,
  [1087] = 1058,
  [1088] = 1088,
  [1089] = 1089,
  [1090] = 1090,
  [1091] = 1091,
  [1092] = 1035,
  [1093] = 1058,
  [1094] = 1094,
  [1095] = 1095,
  [1096] = 1096,
  [1097] = 1097,
  [1098] = 1098,
  [1099] = 1099,
  [1100] = 1100,
  [1101] = 1101,
  [1102] = 1102,
  [1103] = 1103,
  [1104] = 1104,
  [1105] = 1105,
  [1106] = 1106,
  [1107] = 1107,
  [1108] = 1108,
  [1109] = 1109,
  [1110] = 1110,
  [1111] = 1111,
  [1112] = 1112,
  [1113] = 1113,
  [1114] = 1114,
  [1115] = 1115,
  [1116] = 1116,
  [1117] = 1117,
  [1118] = 1118,
  [1119] = 1119,
  [1120] = 1115,
  [1121] = 1121,
  [1122] = 1122,
  [1123] = 1123,
  [1124] = 1117,
  [1125] = 1125,
  [1126] = 1126,
  [1127] = 1127,
  [1128] = 1128,
  [1129] = 673,
  [1130] = 1130,
  [1131] = 1112,
  [1132] = 1132,
  [1133] = 1118,
  [1134] = 1134,
  [1135] = 1135,
  [1136] = 672,
  [1137] = 1137,
  [1138] = 1119,
  [1139] = 1139,
  [1140] = 1140,
  [1141] = 1111,
  [1142] = 1142,
  [1143] = 1143,
  [1144] = 1130,
  [1145] = 1125,
  [1146] = 1118,
  [1147] = 1118,
  [1148] = 1118,
  [1149] = 1118,
  [1150] = 1118,
  [1151] = 1118,
  [1152] = 1152,
  [1153] = 1116,
  [1154] = 1154,
  [1155] = 1104,
  [1156] = 1156,
  [1157] = 1157,
  [1158] = 1118,
  [1159] = 1140,
  [1160] = 1156,
  [1161] = 1113,
  [1162] = 1118,
  [1163] = 1118,
  [1164] = 1164,
  [1165] = 1165,
  [1166] = 1154,
  [1167] = 1104,
  [1168] = 1135,
  [1169] = 1169,
  [1170] = 1154,
  [1171] = 1154,
  [1172] = 1104,
  [1173] = 1154,
  [1174] = 1104,
  [1175] = 1118,
  [1176] = 1118,
  [1177] = 1177,
  [1178] = 1178,
  [1179] = 1179,
  [1180] = 1180,
  [1181] = 1181,
  [1182] = 1182,
  [1183] = 1183,
  [1184] = 1184,
  [1185] = 1185,
  [1186] = 1186,
  [1187] = 1185,
  [1188] = 1188,
  [1189] = 1177,
  [1190] = 1190,
  [1191] = 1184,
  [1192] = 1192,
  [1193] = 1177,
  [1194] = 1194,
  [1195] = 1194,
  [1196] = 1196,
  [1197] = 1197,
  [1198] = 1188,
  [1199] = 1199,
  [1200] = 1194,
  [1201] = 1194,
  [1202] = 1202,
  [1203] = 1178,
  [1204] = 1204,
  [1205] = 1185,
  [1206] = 1188,
  [1207] = 1184,
  [1208] = 1208,
  [1209] = 1177,
  [1210] = 1210,
  [1211] = 1194,
  [1212] = 1212,
  [1213] = 1213,
  [1214] = 1185,
  [1215] = 1188,
  [1216] = 1194,
  [1217] = 1217,
  [1218] = 1218,
  [1219] = 1185,
  [1220] = 1188,
  [1221] = 1194,
  [1222] = 976,
  [1223] = 1184,
  [1224] = 1185,
  [1225] = 1225,
  [1226] = 1226,
  [1227] = 1227,
  [1228] = 1228,
  [1229] = 1229,
  [1230] = 1230,
  [1231] = 1231,
  [1232] = 1197,
  [1233] = 1233,
  [1234] = 1234,
  [1235] = 1185,
  [1236] = 1188,
  [1237] = 1188,
  [1238] = 1238,
  [1239] = 1239,
  [1240] = 1240,
  [1241] = 1184,
  [1242] = 1242,
  [1243] = 1178,
  [1244] = 1244,
  [1245] = 1245,
  [1246] = 1177,
  [1247] = 1247,
  [1248] = 1248,
  [1249] = 1249,
  [1250] = 1188,
  [1251] = 1251,
  [1252] = 1188,
  [1253] = 1253,
  [1254] = 1188,
  [1255] = 1255,
  [1256] = 1256,
  [1257] = 1194,
  [1258] = 1258,
  [1259] = 1259,
  [1260] = 1260,
  [1261] = 1188,
  [1262] = 1185,
  [1263] = 1263,
  [1264] = 1188,
  [1265] = 1178,
  [1266] = 1266,
  [1267] = 1267,
  [1268] = 1231,
  [1269] = 1269,
  [1270] = 1227,
  [1271] = 1007,
  [1272] = 1188,
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(16);
      ADVANCE_MAP(
        '&', 35,
        '\'', 53,
        '(', 19,
        ')', 20,
        '*', 25,
        '+', 21,
        ',', 18,
        '-', 23,
        '.', 38,
        '/', 27,
        ':', 61,
        ';', 17,
        '<', 44,
        '=', 60,
        '>', 49,
        '?', 42,
        '@', 43,
        '[', 54,
        '\\', 29,
        ']', 56,
        '^', 31,
        'g', 70,
        's', 71,
        '{', 57,
        '|', 33,
        '}', 58,
        '~', 41,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(65);
      if (('A' <= lookahead && lookahead <= '_') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 1:
      ADVANCE_MAP(
        '\n', 75,
        '\r', 76,
        '&', 35,
        '(', 19,
        '+', 21,
        ',', 18,
        '-', 23,
        '.', 39,
        ';', 17,
        '<', 44,
        '=', 60,
        '>', 49,
        '?', 42,
        '@', 43,
        '[', 54,
        '{', 57,
        '|', 10,
        '~', 41,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(1);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(65);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 2:
      ADVANCE_MAP(
        '\n', 75,
        '\r', 76,
        '&', 34,
        '(', 19,
        '+', 21,
        ',', 18,
        '-', 23,
        '.', 39,
        ';', 17,
        '=', 59,
        '?', 42,
        '@', 43,
        '[', 54,
        '{', 57,
        '~', 40,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(2);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(65);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 3:
      ADVANCE_MAP(
        '&', 35,
        '\'', 53,
        '(', 19,
        '*', 25,
        '+', 21,
        '-', 23,
        '.', 37,
        '/', 27,
        ':', 61,
        ';', 17,
        '<', 44,
        '=', 8,
        '>', 49,
        '@', 43,
        '\\', 29,
        ']', 56,
        '^', 31,
        '{', 57,
        '|', 33,
        '}', 58,
        '~', 9,
        '\n', 55,
        '\r', 55,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(3);
      END_STATE();
    case 4:
      if (lookahead == '&') ADVANCE(50);
      END_STATE();
    case 5:
      ADVANCE_MAP(
        '&', 4,
        '(', 19,
        ')', 20,
        ',', 18,
        '.', 36,
        '<', 44,
        '=', 8,
        '>', 49,
        '{', 57,
        '|', 10,
        '}', 58,
        '~', 9,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(5);
      END_STATE();
    case 6:
      ADVANCE_MAP(
        '&', 4,
        '.', 36,
        ';', 17,
        '<', 44,
        '=', 8,
        '>', 49,
        ']', 56,
        '|', 10,
        '}', 58,
        '~', 9,
        '\n', 55,
        '\r', 55,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(6);
      END_STATE();
    case 7:
      ADVANCE_MAP(
        '(', 19,
        '+', 21,
        ',', 18,
        '-', 23,
        '.', 12,
        ';', 17,
        '?', 42,
        '@', 43,
        '[', 54,
        ']', 56,
        '{', 57,
        '}', 58,
        '~', 40,
        '\n', 55,
        '\r', 55,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(7);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(65);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 8:
      if (lookahead == '=') ADVANCE(46);
      END_STATE();
    case 9:
      if (lookahead == '=') ADVANCE(47);
      END_STATE();
    case 10:
      if (lookahead == '|') ADVANCE(51);
      END_STATE();
    case 11:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(13);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(67);
      END_STATE();
    case 12:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(66);
      END_STATE();
    case 13:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(67);
      END_STATE();
    case 14:
      if (eof) ADVANCE(16);
      ADVANCE_MAP(
        '\n', 75,
        '\r', 76,
        '&', 35,
        '\'', 53,
        '(', 19,
        '*', 25,
        '+', 21,
        ',', 18,
        '-', 23,
        '.', 38,
        '/', 27,
        ':', 61,
        ';', 17,
        '<', 44,
        '=', 60,
        '>', 49,
        '?', 42,
        '@', 43,
        '[', 54,
        '\\', 29,
        '^', 31,
        '{', 57,
        '|', 33,
        '~', 41,
      );
      if (('\t' <= lookahead && lookahead <= '\f') ||
          lookahead == ' ') SKIP(14);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(65);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 15:
      if (eof) ADVANCE(16);
      ADVANCE_MAP(
        '(', 19,
        ')', 20,
        '*', 25,
        '+', 21,
        ',', 18,
        '-', 23,
        '.', 39,
        ':', 61,
        ';', 17,
        '=', 59,
        '?', 42,
        '@', 43,
        '[', 54,
        ']', 56,
        '{', 57,
        '}', 58,
        '~', 40,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(15);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(65);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 16:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 17:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 18:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 19:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 20:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 21:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 22:
      ACCEPT_TOKEN(anon_sym_DOT_PLUS);
      END_STATE();
    case 23:
      ACCEPT_TOKEN(anon_sym_DASH);
      END_STATE();
    case 24:
      ACCEPT_TOKEN(anon_sym_DOT_DASH);
      END_STATE();
    case 25:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 26:
      ACCEPT_TOKEN(anon_sym_DOT_STAR);
      END_STATE();
    case 27:
      ACCEPT_TOKEN(anon_sym_SLASH);
      END_STATE();
    case 28:
      ACCEPT_TOKEN(anon_sym_DOT_SLASH);
      END_STATE();
    case 29:
      ACCEPT_TOKEN(anon_sym_BSLASH);
      END_STATE();
    case 30:
      ACCEPT_TOKEN(anon_sym_DOT_BSLASH);
      END_STATE();
    case 31:
      ACCEPT_TOKEN(anon_sym_CARET);
      END_STATE();
    case 32:
      ACCEPT_TOKEN(anon_sym_DOT_CARET);
      END_STATE();
    case 33:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '|') ADVANCE(51);
      END_STATE();
    case 34:
      ACCEPT_TOKEN(anon_sym_AMP);
      END_STATE();
    case 35:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(50);
      END_STATE();
    case 36:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 37:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '\'') ADVANCE(52);
      if (lookahead == '*') ADVANCE(26);
      if (lookahead == '+') ADVANCE(22);
      if (lookahead == '-') ADVANCE(24);
      if (lookahead == '/') ADVANCE(28);
      if (lookahead == '\\') ADVANCE(30);
      if (lookahead == '^') ADVANCE(32);
      END_STATE();
    case 38:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '\'') ADVANCE(52);
      if (lookahead == '*') ADVANCE(26);
      if (lookahead == '+') ADVANCE(22);
      if (lookahead == '-') ADVANCE(24);
      if (lookahead == '/') ADVANCE(28);
      if (lookahead == '\\') ADVANCE(30);
      if (lookahead == '^') ADVANCE(32);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(66);
      END_STATE();
    case 39:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(66);
      END_STATE();
    case 40:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 41:
      ACCEPT_TOKEN(anon_sym_TILDE);
      if (lookahead == '=') ADVANCE(47);
      END_STATE();
    case 42:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    case 43:
      ACCEPT_TOKEN(anon_sym_AT);
      END_STATE();
    case 44:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '=') ADVANCE(45);
      END_STATE();
    case 45:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 46:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      END_STATE();
    case 47:
      ACCEPT_TOKEN(anon_sym_TILDE_EQ);
      END_STATE();
    case 48:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 49:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(48);
      END_STATE();
    case 50:
      ACCEPT_TOKEN(anon_sym_AMP_AMP);
      END_STATE();
    case 51:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE);
      END_STATE();
    case 52:
      ACCEPT_TOKEN(anon_sym_DOT_SQUOTE);
      END_STATE();
    case 53:
      ACCEPT_TOKEN(anon_sym_SQUOTE);
      END_STATE();
    case 54:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 55:
      ACCEPT_TOKEN(aux_sym_matrix_token1);
      if (lookahead == '\n' ||
          lookahead == '\r') ADVANCE(55);
      END_STATE();
    case 56:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 57:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 58:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 59:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 60:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(46);
      END_STATE();
    case 61:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 62:
      ACCEPT_TOKEN(anon_sym_get_DOT);
      END_STATE();
    case 63:
      ACCEPT_TOKEN(anon_sym_set_DOT);
      END_STATE();
    case 64:
      ACCEPT_TOKEN(sym_number);
      END_STATE();
    case 65:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == '.') ADVANCE(66);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(11);
      if (lookahead == 'i' ||
          lookahead == 'j') ADVANCE(64);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(65);
      END_STATE();
    case 66:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(11);
      if (lookahead == 'i' ||
          lookahead == 'j') ADVANCE(64);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(66);
      END_STATE();
    case 67:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == 'i' ||
          lookahead == 'j') ADVANCE(64);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(67);
      END_STATE();
    case 68:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '.') ADVANCE(62);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 69:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '.') ADVANCE(63);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 70:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(72);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 71:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(73);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 72:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(68);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 73:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(69);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 74:
      ACCEPT_TOKEN(sym_identifier);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(74);
      END_STATE();
    case 75:
      ACCEPT_TOKEN(anon_sym_LF);
      if (lookahead == '\n') ADVANCE(75);
      if (lookahead == '\r') ADVANCE(76);
      END_STATE();
    case 76:
      ACCEPT_TOKEN(anon_sym_CR);
      if (lookahead == '\n') ADVANCE(75);
      if (lookahead == '\r') ADVANCE(76);
      END_STATE();
    default:
      return false;
  }
}

static bool ts_lex_keywords(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      ADVANCE_MAP(
        'a', 1,
        'b', 2,
        'c', 3,
        'e', 4,
        'f', 5,
        'g', 6,
        'i', 7,
        'm', 8,
        'o', 9,
        'p', 10,
        'r', 11,
        's', 12,
        't', 13,
        'v', 14,
        'w', 15,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(0);
      END_STATE();
    case 1:
      if (lookahead == 'r') ADVANCE(16);
      END_STATE();
    case 2:
      if (lookahead == 'r') ADVANCE(17);
      END_STATE();
    case 3:
      if (lookahead == 'a') ADVANCE(18);
      if (lookahead == 'l') ADVANCE(19);
      if (lookahead == 'o') ADVANCE(20);
      END_STATE();
    case 4:
      if (lookahead == 'l') ADVANCE(21);
      if (lookahead == 'n') ADVANCE(22);
      if (lookahead == 'v') ADVANCE(23);
      END_STATE();
    case 5:
      if (lookahead == 'a') ADVANCE(24);
      if (lookahead == 'o') ADVANCE(25);
      if (lookahead == 'u') ADVANCE(26);
      END_STATE();
    case 6:
      if (lookahead == 'l') ADVANCE(27);
      END_STATE();
    case 7:
      if (lookahead == 'f') ADVANCE(28);
      END_STATE();
    case 8:
      if (lookahead == 'a') ADVANCE(29);
      if (lookahead == 'e') ADVANCE(30);
      END_STATE();
    case 9:
      if (lookahead == 't') ADVANCE(31);
      END_STATE();
    case 10:
      if (lookahead == 'a') ADVANCE(32);
      if (lookahead == 'e') ADVANCE(33);
      if (lookahead == 'r') ADVANCE(34);
      END_STATE();
    case 11:
      if (lookahead == 'e') ADVANCE(35);
      END_STATE();
    case 12:
      if (lookahead == 'c') ADVANCE(36);
      if (lookahead == 'w') ADVANCE(37);
      END_STATE();
    case 13:
      if (lookahead == 'r') ADVANCE(38);
      END_STATE();
    case 14:
      if (lookahead == 'e') ADVANCE(39);
      END_STATE();
    case 15:
      if (lookahead == 'h') ADVANCE(40);
      END_STATE();
    case 16:
      if (lookahead == 'g') ADVANCE(41);
      END_STATE();
    case 17:
      if (lookahead == 'e') ADVANCE(42);
      END_STATE();
    case 18:
      if (lookahead == 's') ADVANCE(43);
      if (lookahead == 't') ADVANCE(44);
      END_STATE();
    case 19:
      if (lookahead == 'a') ADVANCE(45);
      END_STATE();
    case 20:
      if (lookahead == 'n') ADVANCE(46);
      END_STATE();
    case 21:
      if (lookahead == 's') ADVANCE(47);
      END_STATE();
    case 22:
      if (lookahead == 'd') ADVANCE(48);
      if (lookahead == 'u') ADVANCE(49);
      END_STATE();
    case 23:
      if (lookahead == 'e') ADVANCE(50);
      END_STATE();
    case 24:
      if (lookahead == 'l') ADVANCE(51);
      END_STATE();
    case 25:
      if (lookahead == 'r') ADVANCE(52);
      END_STATE();
    case 26:
      if (lookahead == 'n') ADVANCE(53);
      END_STATE();
    case 27:
      if (lookahead == 'o') ADVANCE(54);
      END_STATE();
    case 28:
      ACCEPT_TOKEN(anon_sym_if);
      END_STATE();
    case 29:
      if (lookahead == 't') ADVANCE(55);
      END_STATE();
    case 30:
      if (lookahead == 't') ADVANCE(56);
      END_STATE();
    case 31:
      if (lookahead == 'h') ADVANCE(57);
      END_STATE();
    case 32:
      if (lookahead == 'r') ADVANCE(58);
      END_STATE();
    case 33:
      if (lookahead == 'r') ADVANCE(59);
      END_STATE();
    case 34:
      if (lookahead == 'o') ADVANCE(60);
      END_STATE();
    case 35:
      if (lookahead == 't') ADVANCE(61);
      END_STATE();
    case 36:
      if (lookahead == 'a') ADVANCE(62);
      END_STATE();
    case 37:
      if (lookahead == 'i') ADVANCE(63);
      END_STATE();
    case 38:
      if (lookahead == 'u') ADVANCE(64);
      if (lookahead == 'y') ADVANCE(65);
      END_STATE();
    case 39:
      if (lookahead == 'c') ADVANCE(66);
      END_STATE();
    case 40:
      if (lookahead == 'i') ADVANCE(67);
      END_STATE();
    case 41:
      if (lookahead == 'u') ADVANCE(68);
      END_STATE();
    case 42:
      if (lookahead == 'a') ADVANCE(69);
      END_STATE();
    case 43:
      if (lookahead == 'e') ADVANCE(70);
      END_STATE();
    case 44:
      if (lookahead == 'c') ADVANCE(71);
      END_STATE();
    case 45:
      if (lookahead == 's') ADVANCE(72);
      END_STATE();
    case 46:
      if (lookahead == 't') ADVANCE(73);
      END_STATE();
    case 47:
      if (lookahead == 'e') ADVANCE(74);
      END_STATE();
    case 48:
      ACCEPT_TOKEN(anon_sym_end);
      if (lookahead == 'f') ADVANCE(75);
      END_STATE();
    case 49:
      if (lookahead == 'm') ADVANCE(76);
      END_STATE();
    case 50:
      if (lookahead == 'n') ADVANCE(77);
      END_STATE();
    case 51:
      if (lookahead == 's') ADVANCE(78);
      END_STATE();
    case 52:
      ACCEPT_TOKEN(anon_sym_for);
      END_STATE();
    case 53:
      if (lookahead == 'c') ADVANCE(79);
      END_STATE();
    case 54:
      if (lookahead == 'b') ADVANCE(80);
      END_STATE();
    case 55:
      if (lookahead == 'r') ADVANCE(81);
      END_STATE();
    case 56:
      if (lookahead == 'h') ADVANCE(82);
      END_STATE();
    case 57:
      if (lookahead == 'e') ADVANCE(83);
      END_STATE();
    case 58:
      if (lookahead == 'f') ADVANCE(84);
      END_STATE();
    case 59:
      if (lookahead == 's') ADVANCE(85);
      END_STATE();
    case 60:
      if (lookahead == 'p') ADVANCE(86);
      END_STATE();
    case 61:
      if (lookahead == 'u') ADVANCE(87);
      END_STATE();
    case 62:
      if (lookahead == 'l') ADVANCE(88);
      END_STATE();
    case 63:
      if (lookahead == 't') ADVANCE(89);
      END_STATE();
    case 64:
      if (lookahead == 'e') ADVANCE(90);
      END_STATE();
    case 65:
      ACCEPT_TOKEN(anon_sym_try);
      END_STATE();
    case 66:
      if (lookahead == 't') ADVANCE(91);
      END_STATE();
    case 67:
      if (lookahead == 'l') ADVANCE(92);
      END_STATE();
    case 68:
      if (lookahead == 'm') ADVANCE(93);
      END_STATE();
    case 69:
      if (lookahead == 'k') ADVANCE(94);
      END_STATE();
    case 70:
      ACCEPT_TOKEN(anon_sym_case);
      END_STATE();
    case 71:
      if (lookahead == 'h') ADVANCE(95);
      END_STATE();
    case 72:
      if (lookahead == 's') ADVANCE(96);
      END_STATE();
    case 73:
      if (lookahead == 'i') ADVANCE(97);
      END_STATE();
    case 74:
      ACCEPT_TOKEN(anon_sym_else);
      if (lookahead == 'i') ADVANCE(98);
      END_STATE();
    case 75:
      if (lookahead == 'u') ADVANCE(99);
      END_STATE();
    case 76:
      if (lookahead == 'e') ADVANCE(100);
      END_STATE();
    case 77:
      if (lookahead == 't') ADVANCE(101);
      END_STATE();
    case 78:
      if (lookahead == 'e') ADVANCE(102);
      END_STATE();
    case 79:
      if (lookahead == 't') ADVANCE(103);
      END_STATE();
    case 80:
      if (lookahead == 'a') ADVANCE(104);
      END_STATE();
    case 81:
      if (lookahead == 'i') ADVANCE(105);
      END_STATE();
    case 82:
      if (lookahead == 'o') ADVANCE(106);
      END_STATE();
    case 83:
      if (lookahead == 'r') ADVANCE(107);
      END_STATE();
    case 84:
      if (lookahead == 'o') ADVANCE(108);
      END_STATE();
    case 85:
      if (lookahead == 'i') ADVANCE(109);
      END_STATE();
    case 86:
      if (lookahead == 'e') ADVANCE(110);
      END_STATE();
    case 87:
      if (lookahead == 'r') ADVANCE(111);
      END_STATE();
    case 88:
      if (lookahead == 'a') ADVANCE(112);
      END_STATE();
    case 89:
      if (lookahead == 'c') ADVANCE(113);
      END_STATE();
    case 90:
      ACCEPT_TOKEN(anon_sym_true);
      END_STATE();
    case 91:
      if (lookahead == 'o') ADVANCE(114);
      END_STATE();
    case 92:
      if (lookahead == 'e') ADVANCE(115);
      END_STATE();
    case 93:
      if (lookahead == 'e') ADVANCE(116);
      END_STATE();
    case 94:
      ACCEPT_TOKEN(sym_break_statement);
      END_STATE();
    case 95:
      ACCEPT_TOKEN(anon_sym_catch);
      END_STATE();
    case 96:
      if (lookahead == 'd') ADVANCE(117);
      END_STATE();
    case 97:
      if (lookahead == 'n') ADVANCE(118);
      END_STATE();
    case 98:
      if (lookahead == 'f') ADVANCE(119);
      END_STATE();
    case 99:
      if (lookahead == 'n') ADVANCE(120);
      END_STATE();
    case 100:
      if (lookahead == 'r') ADVANCE(121);
      END_STATE();
    case 101:
      if (lookahead == 's') ADVANCE(122);
      END_STATE();
    case 102:
      ACCEPT_TOKEN(anon_sym_false);
      END_STATE();
    case 103:
      if (lookahead == 'i') ADVANCE(123);
      END_STATE();
    case 104:
      if (lookahead == 'l') ADVANCE(124);
      END_STATE();
    case 105:
      if (lookahead == 'x') ADVANCE(125);
      END_STATE();
    case 106:
      if (lookahead == 'd') ADVANCE(126);
      END_STATE();
    case 107:
      if (lookahead == 'w') ADVANCE(127);
      END_STATE();
    case 108:
      if (lookahead == 'r') ADVANCE(128);
      END_STATE();
    case 109:
      if (lookahead == 's') ADVANCE(129);
      END_STATE();
    case 110:
      if (lookahead == 'r') ADVANCE(130);
      END_STATE();
    case 111:
      if (lookahead == 'n') ADVANCE(131);
      END_STATE();
    case 112:
      if (lookahead == 'r') ADVANCE(132);
      END_STATE();
    case 113:
      if (lookahead == 'h') ADVANCE(133);
      END_STATE();
    case 114:
      if (lookahead == 'r') ADVANCE(134);
      END_STATE();
    case 115:
      ACCEPT_TOKEN(anon_sym_while);
      END_STATE();
    case 116:
      if (lookahead == 'n') ADVANCE(135);
      END_STATE();
    case 117:
      if (lookahead == 'e') ADVANCE(136);
      END_STATE();
    case 118:
      if (lookahead == 'u') ADVANCE(137);
      END_STATE();
    case 119:
      ACCEPT_TOKEN(anon_sym_elseif);
      END_STATE();
    case 120:
      if (lookahead == 'c') ADVANCE(138);
      END_STATE();
    case 121:
      if (lookahead == 'a') ADVANCE(139);
      END_STATE();
    case 122:
      ACCEPT_TOKEN(anon_sym_events);
      END_STATE();
    case 123:
      if (lookahead == 'o') ADVANCE(140);
      END_STATE();
    case 124:
      ACCEPT_TOKEN(anon_sym_global);
      END_STATE();
    case 125:
      ACCEPT_TOKEN(anon_sym_matrix);
      END_STATE();
    case 126:
      if (lookahead == 's') ADVANCE(141);
      END_STATE();
    case 127:
      if (lookahead == 'i') ADVANCE(142);
      END_STATE();
    case 128:
      ACCEPT_TOKEN(anon_sym_parfor);
      END_STATE();
    case 129:
      if (lookahead == 't') ADVANCE(143);
      END_STATE();
    case 130:
      if (lookahead == 't') ADVANCE(144);
      END_STATE();
    case 131:
      ACCEPT_TOKEN(sym_return_statement);
      END_STATE();
    case 132:
      ACCEPT_TOKEN(anon_sym_scalar);
      END_STATE();
    case 133:
      ACCEPT_TOKEN(anon_sym_switch);
      END_STATE();
    case 134:
      ACCEPT_TOKEN(anon_sym_vector);
      END_STATE();
    case 135:
      if (lookahead == 't') ADVANCE(145);
      END_STATE();
    case 136:
      if (lookahead == 'f') ADVANCE(146);
      END_STATE();
    case 137:
      if (lookahead == 'e') ADVANCE(147);
      END_STATE();
    case 138:
      if (lookahead == 't') ADVANCE(148);
      END_STATE();
    case 139:
      if (lookahead == 't') ADVANCE(149);
      END_STATE();
    case 140:
      if (lookahead == 'n') ADVANCE(150);
      END_STATE();
    case 141:
      ACCEPT_TOKEN(anon_sym_methods);
      END_STATE();
    case 142:
      if (lookahead == 's') ADVANCE(151);
      END_STATE();
    case 143:
      if (lookahead == 'e') ADVANCE(152);
      END_STATE();
    case 144:
      if (lookahead == 'i') ADVANCE(153);
      END_STATE();
    case 145:
      if (lookahead == 's') ADVANCE(154);
      END_STATE();
    case 146:
      ACCEPT_TOKEN(anon_sym_classdef);
      END_STATE();
    case 147:
      ACCEPT_TOKEN(sym_continue_statement);
      END_STATE();
    case 148:
      if (lookahead == 'i') ADVANCE(155);
      END_STATE();
    case 149:
      if (lookahead == 'i') ADVANCE(156);
      END_STATE();
    case 150:
      ACCEPT_TOKEN(anon_sym_function);
      END_STATE();
    case 151:
      if (lookahead == 'e') ADVANCE(157);
      END_STATE();
    case 152:
      if (lookahead == 'n') ADVANCE(158);
      END_STATE();
    case 153:
      if (lookahead == 'e') ADVANCE(159);
      END_STATE();
    case 154:
      ACCEPT_TOKEN(anon_sym_arguments);
      END_STATE();
    case 155:
      if (lookahead == 'o') ADVANCE(160);
      END_STATE();
    case 156:
      if (lookahead == 'o') ADVANCE(161);
      END_STATE();
    case 157:
      ACCEPT_TOKEN(anon_sym_otherwise);
      END_STATE();
    case 158:
      if (lookahead == 't') ADVANCE(162);
      END_STATE();
    case 159:
      if (lookahead == 's') ADVANCE(163);
      END_STATE();
    case 160:
      if (lookahead == 'n') ADVANCE(164);
      END_STATE();
    case 161:
      if (lookahead == 'n') ADVANCE(165);
      END_STATE();
    case 162:
      ACCEPT_TOKEN(anon_sym_persistent);
      END_STATE();
    case 163:
      ACCEPT_TOKEN(anon_sym_properties);
      END_STATE();
    case 164:
      ACCEPT_TOKEN(anon_sym_endfunction);
      END_STATE();
    case 165:
      ACCEPT_TOKEN(anon_sym_enumeration);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0, .external_lex_state = 1},
  [1] = {.lex_state = 15, .external_lex_state = 2},
  [2] = {.lex_state = 14, .external_lex_state = 2},
  [3] = {.lex_state = 14, .external_lex_state = 2},
  [4] = {.lex_state = 14, .external_lex_state = 2},
  [5] = {.lex_state = 2, .external_lex_state = 2},
  [6] = {.lex_state = 2, .external_lex_state = 2},
  [7] = {.lex_state = 2, .external_lex_state = 2},
  [8] = {.lex_state = 2, .external_lex_state = 2},
  [9] = {.lex_state = 2, .external_lex_state = 2},
  [10] = {.lex_state = 2, .external_lex_state = 2},
  [11] = {.lex_state = 2, .external_lex_state = 2},
  [12] = {.lex_state = 2, .external_lex_state = 2},
  [13] = {.lex_state = 2, .external_lex_state = 2},
  [14] = {.lex_state = 2, .external_lex_state = 2},
  [15] = {.lex_state = 2, .external_lex_state = 2},
  [16] = {.lex_state = 2, .external_lex_state = 2},
  [17] = {.lex_state = 2, .external_lex_state = 2},
  [18] = {.lex_state = 2, .external_lex_state = 2},
  [19] = {.lex_state = 2, .external_lex_state = 2},
  [20] = {.lex_state = 2, .external_lex_state = 2},
  [21] = {.lex_state = 15, .external_lex_state = 2},
  [22] = {.lex_state = 15, .external_lex_state = 2},
  [23] = {.lex_state = 15, .external_lex_state = 2},
  [24] = {.lex_state = 15, .external_lex_state = 2},
  [25] = {.lex_state = 15, .external_lex_state = 2},
  [26] = {.lex_state = 15, .external_lex_state = 2},
  [27] = {.lex_state = 15, .external_lex_state = 2},
  [28] = {.lex_state = 15, .external_lex_state = 2},
  [29] = {.lex_state = 15, .external_lex_state = 2},
  [30] = {.lex_state = 15, .external_lex_state = 2},
  [31] = {.lex_state = 15, .external_lex_state = 2},
  [32] = {.lex_state = 15, .external_lex_state = 2},
  [33] = {.lex_state = 15, .external_lex_state = 2},
  [34] = {.lex_state = 15, .external_lex_state = 2},
  [35] = {.lex_state = 15, .external_lex_state = 2},
  [36] = {.lex_state = 15, .external_lex_state = 2},
  [37] = {.lex_state = 15, .external_lex_state = 2},
  [38] = {.lex_state = 15, .external_lex_state = 2},
  [39] = {.lex_state = 15, .external_lex_state = 2},
  [40] = {.lex_state = 15, .external_lex_state = 2},
  [41] = {.lex_state = 15, .external_lex_state = 2},
  [42] = {.lex_state = 15, .external_lex_state = 2},
  [43] = {.lex_state = 15, .external_lex_state = 2},
  [44] = {.lex_state = 15, .external_lex_state = 2},
  [45] = {.lex_state = 15, .external_lex_state = 2},
  [46] = {.lex_state = 15, .external_lex_state = 2},
  [47] = {.lex_state = 15, .external_lex_state = 2},
  [48] = {.lex_state = 15, .external_lex_state = 2},
  [49] = {.lex_state = 15, .external_lex_state = 2},
  [50] = {.lex_state = 15, .external_lex_state = 2},
  [51] = {.lex_state = 15, .external_lex_state = 2},
  [52] = {.lex_state = 15, .external_lex_state = 2},
  [53] = {.lex_state = 15, .external_lex_state = 2},
  [54] = {.lex_state = 15, .external_lex_state = 2},
  [55] = {.lex_state = 15, .external_lex_state = 2},
  [56] = {.lex_state = 15, .external_lex_state = 2},
  [57] = {.lex_state = 15, .external_lex_state = 2},
  [58] = {.lex_state = 15, .external_lex_state = 2},
  [59] = {.lex_state = 15, .external_lex_state = 2},
  [60] = {.lex_state = 15, .external_lex_state = 2},
  [61] = {.lex_state = 15, .external_lex_state = 2},
  [62] = {.lex_state = 15, .external_lex_state = 2},
  [63] = {.lex_state = 15, .external_lex_state = 2},
  [64] = {.lex_state = 15, .external_lex_state = 2},
  [65] = {.lex_state = 15, .external_lex_state = 2},
  [66] = {.lex_state = 15, .external_lex_state = 2},
  [67] = {.lex_state = 15, .external_lex_state = 2},
  [68] = {.lex_state = 15, .external_lex_state = 2},
  [69] = {.lex_state = 15, .external_lex_state = 2},
  [70] = {.lex_state = 15, .external_lex_state = 2},
  [71] = {.lex_state = 15, .external_lex_state = 2},
  [72] = {.lex_state = 15, .external_lex_state = 2},
  [73] = {.lex_state = 15, .external_lex_state = 2},
  [74] = {.lex_state = 15, .external_lex_state = 2},
  [75] = {.lex_state = 15, .external_lex_state = 2},
  [76] = {.lex_state = 14, .external_lex_state = 2},
  [77] = {.lex_state = 14, .external_lex_state = 2},
  [78] = {.lex_state = 14, .external_lex_state = 2},
  [79] = {.lex_state = 14, .external_lex_state = 2},
  [80] = {.lex_state = 14, .external_lex_state = 2},
  [81] = {.lex_state = 14, .external_lex_state = 2},
  [82] = {.lex_state = 14, .external_lex_state = 2},
  [83] = {.lex_state = 14, .external_lex_state = 2},
  [84] = {.lex_state = 14, .external_lex_state = 2},
  [85] = {.lex_state = 14, .external_lex_state = 2},
  [86] = {.lex_state = 14, .external_lex_state = 2},
  [87] = {.lex_state = 14, .external_lex_state = 2},
  [88] = {.lex_state = 14, .external_lex_state = 2},
  [89] = {.lex_state = 14, .external_lex_state = 2},
  [90] = {.lex_state = 14, .external_lex_state = 2},
  [91] = {.lex_state = 14, .external_lex_state = 2},
  [92] = {.lex_state = 14, .external_lex_state = 2},
  [93] = {.lex_state = 14, .external_lex_state = 2},
  [94] = {.lex_state = 14, .external_lex_state = 2},
  [95] = {.lex_state = 14, .external_lex_state = 2},
  [96] = {.lex_state = 14, .external_lex_state = 2},
  [97] = {.lex_state = 14, .external_lex_state = 2},
  [98] = {.lex_state = 14, .external_lex_state = 2},
  [99] = {.lex_state = 14, .external_lex_state = 2},
  [100] = {.lex_state = 14, .external_lex_state = 2},
  [101] = {.lex_state = 14, .external_lex_state = 2},
  [102] = {.lex_state = 14, .external_lex_state = 2},
  [103] = {.lex_state = 14, .external_lex_state = 2},
  [104] = {.lex_state = 14, .external_lex_state = 2},
  [105] = {.lex_state = 14, .external_lex_state = 2},
  [106] = {.lex_state = 14, .external_lex_state = 2},
  [107] = {.lex_state = 14, .external_lex_state = 2},
  [108] = {.lex_state = 14, .external_lex_state = 2},
  [109] = {.lex_state = 14, .external_lex_state = 2},
  [110] = {.lex_state = 14, .external_lex_state = 2},
  [111] = {.lex_state = 14, .external_lex_state = 2},
  [112] = {.lex_state = 14, .external_lex_state = 2},
  [113] = {.lex_state = 14, .external_lex_state = 2},
  [114] = {.lex_state = 14, .external_lex_state = 2},
  [115] = {.lex_state = 14, .external_lex_state = 2},
  [116] = {.lex_state = 14, .external_lex_state = 2},
  [117] = {.lex_state = 14, .external_lex_state = 2},
  [118] = {.lex_state = 14, .external_lex_state = 2},
  [119] = {.lex_state = 14, .external_lex_state = 2},
  [120] = {.lex_state = 14, .external_lex_state = 2},
  [121] = {.lex_state = 14, .external_lex_state = 2},
  [122] = {.lex_state = 14, .external_lex_state = 2},
  [123] = {.lex_state = 14, .external_lex_state = 2},
  [124] = {.lex_state = 14, .external_lex_state = 2},
  [125] = {.lex_state = 14, .external_lex_state = 2},
  [126] = {.lex_state = 14, .external_lex_state = 2},
  [127] = {.lex_state = 14, .external_lex_state = 2},
  [128] = {.lex_state = 14, .external_lex_state = 2},
  [129] = {.lex_state = 14, .external_lex_state = 2},
  [130] = {.lex_state = 14, .external_lex_state = 2},
  [131] = {.lex_state = 14, .external_lex_state = 2},
  [132] = {.lex_state = 14, .external_lex_state = 2},
  [133] = {.lex_state = 14, .external_lex_state = 2},
  [134] = {.lex_state = 14, .external_lex_state = 2},
  [135] = {.lex_state = 14, .external_lex_state = 2},
  [136] = {.lex_state = 14, .external_lex_state = 2},
  [137] = {.lex_state = 14, .external_lex_state = 2},
  [138] = {.lex_state = 14, .external_lex_state = 2},
  [139] = {.lex_state = 14, .external_lex_state = 2},
  [140] = {.lex_state = 14, .external_lex_state = 2},
  [141] = {.lex_state = 14, .external_lex_state = 2},
  [142] = {.lex_state = 14, .external_lex_state = 2},
  [143] = {.lex_state = 14, .external_lex_state = 2},
  [144] = {.lex_state = 14, .external_lex_state = 2},
  [145] = {.lex_state = 14, .external_lex_state = 2},
  [146] = {.lex_state = 14, .external_lex_state = 2},
  [147] = {.lex_state = 14, .external_lex_state = 2},
  [148] = {.lex_state = 14, .external_lex_state = 2},
  [149] = {.lex_state = 14, .external_lex_state = 2},
  [150] = {.lex_state = 14, .external_lex_state = 2},
  [151] = {.lex_state = 14, .external_lex_state = 2},
  [152] = {.lex_state = 1, .external_lex_state = 2},
  [153] = {.lex_state = 1, .external_lex_state = 2},
  [154] = {.lex_state = 1, .external_lex_state = 2},
  [155] = {.lex_state = 1, .external_lex_state = 2},
  [156] = {.lex_state = 1, .external_lex_state = 2},
  [157] = {.lex_state = 1, .external_lex_state = 2},
  [158] = {.lex_state = 7, .external_lex_state = 3},
  [159] = {.lex_state = 14, .external_lex_state = 2},
  [160] = {.lex_state = 2, .external_lex_state = 2},
  [161] = {.lex_state = 7, .external_lex_state = 3},
  [162] = {.lex_state = 7, .external_lex_state = 3},
  [163] = {.lex_state = 7, .external_lex_state = 3},
  [164] = {.lex_state = 7, .external_lex_state = 4},
  [165] = {.lex_state = 15, .external_lex_state = 3},
  [166] = {.lex_state = 15, .external_lex_state = 2},
  [167] = {.lex_state = 15, .external_lex_state = 2},
  [168] = {.lex_state = 15, .external_lex_state = 3},
  [169] = {.lex_state = 15, .external_lex_state = 3},
  [170] = {.lex_state = 15, .external_lex_state = 3},
  [171] = {.lex_state = 15, .external_lex_state = 3},
  [172] = {.lex_state = 15, .external_lex_state = 3},
  [173] = {.lex_state = 15, .external_lex_state = 3},
  [174] = {.lex_state = 15, .external_lex_state = 3},
  [175] = {.lex_state = 15, .external_lex_state = 2},
  [176] = {.lex_state = 15, .external_lex_state = 2},
  [177] = {.lex_state = 15, .external_lex_state = 3},
  [178] = {.lex_state = 15, .external_lex_state = 3},
  [179] = {.lex_state = 15, .external_lex_state = 2},
  [180] = {.lex_state = 15, .external_lex_state = 3},
  [181] = {.lex_state = 15, .external_lex_state = 3},
  [182] = {.lex_state = 15, .external_lex_state = 3},
  [183] = {.lex_state = 15, .external_lex_state = 3},
  [184] = {.lex_state = 15, .external_lex_state = 3},
  [185] = {.lex_state = 15, .external_lex_state = 3},
  [186] = {.lex_state = 15, .external_lex_state = 3},
  [187] = {.lex_state = 15, .external_lex_state = 3},
  [188] = {.lex_state = 15, .external_lex_state = 3},
  [189] = {.lex_state = 14, .external_lex_state = 5},
  [190] = {.lex_state = 14, .external_lex_state = 5},
  [191] = {.lex_state = 14, .external_lex_state = 5},
  [192] = {.lex_state = 14, .external_lex_state = 5},
  [193] = {.lex_state = 14, .external_lex_state = 5},
  [194] = {.lex_state = 14, .external_lex_state = 5},
  [195] = {.lex_state = 14, .external_lex_state = 5},
  [196] = {.lex_state = 14, .external_lex_state = 5},
  [197] = {.lex_state = 14, .external_lex_state = 5},
  [198] = {.lex_state = 15, .external_lex_state = 3},
  [199] = {.lex_state = 14, .external_lex_state = 5},
  [200] = {.lex_state = 15, .external_lex_state = 3},
  [201] = {.lex_state = 14, .external_lex_state = 5},
  [202] = {.lex_state = 15, .external_lex_state = 3},
  [203] = {.lex_state = 14, .external_lex_state = 5},
  [204] = {.lex_state = 14, .external_lex_state = 5},
  [205] = {.lex_state = 15, .external_lex_state = 3},
  [206] = {.lex_state = 3, .external_lex_state = 6},
  [207] = {.lex_state = 3, .external_lex_state = 6},
  [208] = {.lex_state = 14, .external_lex_state = 5},
  [209] = {.lex_state = 3, .external_lex_state = 6},
  [210] = {.lex_state = 15, .external_lex_state = 3},
  [211] = {.lex_state = 14, .external_lex_state = 5},
  [212] = {.lex_state = 15, .external_lex_state = 3},
  [213] = {.lex_state = 15, .external_lex_state = 3},
  [214] = {.lex_state = 14, .external_lex_state = 5},
  [215] = {.lex_state = 3, .external_lex_state = 6},
  [216] = {.lex_state = 15, .external_lex_state = 3},
  [217] = {.lex_state = 14, .external_lex_state = 5},
  [218] = {.lex_state = 14, .external_lex_state = 5},
  [219] = {.lex_state = 3, .external_lex_state = 6},
  [220] = {.lex_state = 14, .external_lex_state = 5},
  [221] = {.lex_state = 15, .external_lex_state = 3},
  [222] = {.lex_state = 15, .external_lex_state = 3},
  [223] = {.lex_state = 15, .external_lex_state = 3},
  [224] = {.lex_state = 15, .external_lex_state = 3},
  [225] = {.lex_state = 15, .external_lex_state = 3},
  [226] = {.lex_state = 15, .external_lex_state = 3},
  [227] = {.lex_state = 15, .external_lex_state = 3},
  [228] = {.lex_state = 15, .external_lex_state = 3},
  [229] = {.lex_state = 15, .external_lex_state = 3},
  [230] = {.lex_state = 15, .external_lex_state = 3},
  [231] = {.lex_state = 15, .external_lex_state = 3},
  [232] = {.lex_state = 15, .external_lex_state = 3},
  [233] = {.lex_state = 15, .external_lex_state = 3},
  [234] = {.lex_state = 15, .external_lex_state = 3},
  [235] = {.lex_state = 15, .external_lex_state = 3},
  [236] = {.lex_state = 15, .external_lex_state = 3},
  [237] = {.lex_state = 15, .external_lex_state = 3},
  [238] = {.lex_state = 15, .external_lex_state = 3},
  [239] = {.lex_state = 15, .external_lex_state = 3},
  [240] = {.lex_state = 15, .external_lex_state = 3},
  [241] = {.lex_state = 15, .external_lex_state = 3},
  [242] = {.lex_state = 15, .external_lex_state = 3},
  [243] = {.lex_state = 15, .external_lex_state = 3},
  [244] = {.lex_state = 14, .external_lex_state = 5},
  [245] = {.lex_state = 15, .external_lex_state = 3},
  [246] = {.lex_state = 15, .external_lex_state = 3},
  [247] = {.lex_state = 15, .external_lex_state = 3},
  [248] = {.lex_state = 15, .external_lex_state = 3},
  [249] = {.lex_state = 15, .external_lex_state = 3},
  [250] = {.lex_state = 15, .external_lex_state = 3},
  [251] = {.lex_state = 15, .external_lex_state = 3},
  [252] = {.lex_state = 15, .external_lex_state = 3},
  [253] = {.lex_state = 15, .external_lex_state = 3},
  [254] = {.lex_state = 15, .external_lex_state = 3},
  [255] = {.lex_state = 15, .external_lex_state = 3},
  [256] = {.lex_state = 15, .external_lex_state = 3},
  [257] = {.lex_state = 15, .external_lex_state = 3},
  [258] = {.lex_state = 15, .external_lex_state = 3},
  [259] = {.lex_state = 3, .external_lex_state = 6},
  [260] = {.lex_state = 15, .external_lex_state = 3},
  [261] = {.lex_state = 15, .external_lex_state = 3},
  [262] = {.lex_state = 14, .external_lex_state = 5},
  [263] = {.lex_state = 15, .external_lex_state = 3},
  [264] = {.lex_state = 15, .external_lex_state = 2},
  [265] = {.lex_state = 15, .external_lex_state = 3},
  [266] = {.lex_state = 15, .external_lex_state = 3},
  [267] = {.lex_state = 15, .external_lex_state = 3},
  [268] = {.lex_state = 15, .external_lex_state = 3},
  [269] = {.lex_state = 15, .external_lex_state = 3},
  [270] = {.lex_state = 15, .external_lex_state = 3},
  [271] = {.lex_state = 15, .external_lex_state = 2},
  [272] = {.lex_state = 15, .external_lex_state = 3},
  [273] = {.lex_state = 15, .external_lex_state = 3},
  [274] = {.lex_state = 15, .external_lex_state = 3},
  [275] = {.lex_state = 15, .external_lex_state = 3},
  [276] = {.lex_state = 15, .external_lex_state = 3},
  [277] = {.lex_state = 15, .external_lex_state = 3},
  [278] = {.lex_state = 15, .external_lex_state = 3},
  [279] = {.lex_state = 0, .external_lex_state = 5},
  [280] = {.lex_state = 15, .external_lex_state = 3},
  [281] = {.lex_state = 15, .external_lex_state = 3},
  [282] = {.lex_state = 15, .external_lex_state = 3},
  [283] = {.lex_state = 15, .external_lex_state = 3},
  [284] = {.lex_state = 15, .external_lex_state = 3},
  [285] = {.lex_state = 15, .external_lex_state = 3},
  [286] = {.lex_state = 15, .external_lex_state = 3},
  [287] = {.lex_state = 15, .external_lex_state = 3},
  [288] = {.lex_state = 15, .external_lex_state = 3},
  [289] = {.lex_state = 15, .external_lex_state = 3},
  [290] = {.lex_state = 15, .external_lex_state = 3},
  [291] = {.lex_state = 15, .external_lex_state = 3},
  [292] = {.lex_state = 15, .external_lex_state = 3},
  [293] = {.lex_state = 15, .external_lex_state = 3},
  [294] = {.lex_state = 15, .external_lex_state = 3},
  [295] = {.lex_state = 15, .external_lex_state = 3},
  [296] = {.lex_state = 15, .external_lex_state = 3},
  [297] = {.lex_state = 15, .external_lex_state = 3},
  [298] = {.lex_state = 0, .external_lex_state = 5},
  [299] = {.lex_state = 15, .external_lex_state = 3},
  [300] = {.lex_state = 0, .external_lex_state = 5},
  [301] = {.lex_state = 15, .external_lex_state = 3},
  [302] = {.lex_state = 15, .external_lex_state = 3},
  [303] = {.lex_state = 15, .external_lex_state = 3},
  [304] = {.lex_state = 15, .external_lex_state = 3},
  [305] = {.lex_state = 15, .external_lex_state = 3},
  [306] = {.lex_state = 15, .external_lex_state = 3},
  [307] = {.lex_state = 15, .external_lex_state = 3},
  [308] = {.lex_state = 15, .external_lex_state = 3},
  [309] = {.lex_state = 15, .external_lex_state = 2},
  [310] = {.lex_state = 15, .external_lex_state = 2},
  [311] = {.lex_state = 15, .external_lex_state = 3},
  [312] = {.lex_state = 0, .external_lex_state = 5},
  [313] = {.lex_state = 15, .external_lex_state = 3},
  [314] = {.lex_state = 15, .external_lex_state = 3},
  [315] = {.lex_state = 15, .external_lex_state = 2},
  [316] = {.lex_state = 14, .external_lex_state = 5},
  [317] = {.lex_state = 15, .external_lex_state = 3},
  [318] = {.lex_state = 15, .external_lex_state = 3},
  [319] = {.lex_state = 15, .external_lex_state = 3},
  [320] = {.lex_state = 15, .external_lex_state = 3},
  [321] = {.lex_state = 15, .external_lex_state = 3},
  [322] = {.lex_state = 15, .external_lex_state = 3},
  [323] = {.lex_state = 15, .external_lex_state = 3},
  [324] = {.lex_state = 15, .external_lex_state = 3},
  [325] = {.lex_state = 15, .external_lex_state = 3},
  [326] = {.lex_state = 15, .external_lex_state = 3},
  [327] = {.lex_state = 15, .external_lex_state = 3},
  [328] = {.lex_state = 15, .external_lex_state = 3},
  [329] = {.lex_state = 15, .external_lex_state = 3},
  [330] = {.lex_state = 15, .external_lex_state = 3},
  [331] = {.lex_state = 15, .external_lex_state = 2},
  [332] = {.lex_state = 15, .external_lex_state = 3},
  [333] = {.lex_state = 15, .external_lex_state = 3},
  [334] = {.lex_state = 15, .external_lex_state = 3},
  [335] = {.lex_state = 15, .external_lex_state = 3},
  [336] = {.lex_state = 15, .external_lex_state = 3},
  [337] = {.lex_state = 15, .external_lex_state = 3},
  [338] = {.lex_state = 15, .external_lex_state = 3},
  [339] = {.lex_state = 15, .external_lex_state = 3},
  [340] = {.lex_state = 15, .external_lex_state = 3},
  [341] = {.lex_state = 15, .external_lex_state = 3},
  [342] = {.lex_state = 15, .external_lex_state = 3},
  [343] = {.lex_state = 15, .external_lex_state = 3},
  [344] = {.lex_state = 15, .external_lex_state = 3},
  [345] = {.lex_state = 15, .external_lex_state = 3},
  [346] = {.lex_state = 14, .external_lex_state = 5},
  [347] = {.lex_state = 14, .external_lex_state = 5},
  [348] = {.lex_state = 3, .external_lex_state = 6},
  [349] = {.lex_state = 3, .external_lex_state = 6},
  [350] = {.lex_state = 3, .external_lex_state = 6},
  [351] = {.lex_state = 0, .external_lex_state = 5},
  [352] = {.lex_state = 3, .external_lex_state = 6},
  [353] = {.lex_state = 0, .external_lex_state = 5},
  [354] = {.lex_state = 3, .external_lex_state = 6},
  [355] = {.lex_state = 3, .external_lex_state = 6},
  [356] = {.lex_state = 3, .external_lex_state = 6},
  [357] = {.lex_state = 3, .external_lex_state = 6},
  [358] = {.lex_state = 0, .external_lex_state = 5},
  [359] = {.lex_state = 0, .external_lex_state = 5},
  [360] = {.lex_state = 3, .external_lex_state = 6},
  [361] = {.lex_state = 3, .external_lex_state = 6},
  [362] = {.lex_state = 14, .external_lex_state = 5},
  [363] = {.lex_state = 0, .external_lex_state = 5},
  [364] = {.lex_state = 14, .external_lex_state = 5},
  [365] = {.lex_state = 0, .external_lex_state = 5},
  [366] = {.lex_state = 0, .external_lex_state = 5},
  [367] = {.lex_state = 3, .external_lex_state = 6},
  [368] = {.lex_state = 3, .external_lex_state = 6},
  [369] = {.lex_state = 14, .external_lex_state = 5},
  [370] = {.lex_state = 3, .external_lex_state = 6},
  [371] = {.lex_state = 14, .external_lex_state = 5},
  [372] = {.lex_state = 0, .external_lex_state = 5},
  [373] = {.lex_state = 15, .external_lex_state = 2},
  [374] = {.lex_state = 0, .external_lex_state = 5},
  [375] = {.lex_state = 15, .external_lex_state = 2},
  [376] = {.lex_state = 15, .external_lex_state = 2},
  [377] = {.lex_state = 0, .external_lex_state = 5},
  [378] = {.lex_state = 15, .external_lex_state = 2},
  [379] = {.lex_state = 14, .external_lex_state = 5},
  [380] = {.lex_state = 3, .external_lex_state = 6},
  [381] = {.lex_state = 14, .external_lex_state = 5},
  [382] = {.lex_state = 14, .external_lex_state = 5},
  [383] = {.lex_state = 14, .external_lex_state = 5},
  [384] = {.lex_state = 14, .external_lex_state = 5},
  [385] = {.lex_state = 14, .external_lex_state = 5},
  [386] = {.lex_state = 14, .external_lex_state = 5},
  [387] = {.lex_state = 14, .external_lex_state = 5},
  [388] = {.lex_state = 14, .external_lex_state = 5},
  [389] = {.lex_state = 14, .external_lex_state = 5},
  [390] = {.lex_state = 0, .external_lex_state = 5},
  [391] = {.lex_state = 14, .external_lex_state = 5},
  [392] = {.lex_state = 0, .external_lex_state = 5},
  [393] = {.lex_state = 3, .external_lex_state = 6},
  [394] = {.lex_state = 14, .external_lex_state = 5},
  [395] = {.lex_state = 0, .external_lex_state = 5},
  [396] = {.lex_state = 14, .external_lex_state = 5},
  [397] = {.lex_state = 3, .external_lex_state = 6},
  [398] = {.lex_state = 14, .external_lex_state = 5},
  [399] = {.lex_state = 0, .external_lex_state = 5},
  [400] = {.lex_state = 14, .external_lex_state = 5},
  [401] = {.lex_state = 14, .external_lex_state = 5},
  [402] = {.lex_state = 0, .external_lex_state = 5},
  [403] = {.lex_state = 0, .external_lex_state = 5},
  [404] = {.lex_state = 3, .external_lex_state = 6},
  [405] = {.lex_state = 14, .external_lex_state = 5},
  [406] = {.lex_state = 14, .external_lex_state = 5},
  [407] = {.lex_state = 14, .external_lex_state = 5},
  [408] = {.lex_state = 14, .external_lex_state = 5},
  [409] = {.lex_state = 14, .external_lex_state = 5},
  [410] = {.lex_state = 14, .external_lex_state = 5},
  [411] = {.lex_state = 14, .external_lex_state = 5},
  [412] = {.lex_state = 0, .external_lex_state = 5},
  [413] = {.lex_state = 14, .external_lex_state = 5},
  [414] = {.lex_state = 14, .external_lex_state = 5},
  [415] = {.lex_state = 14, .external_lex_state = 5},
  [416] = {.lex_state = 0, .external_lex_state = 5},
  [417] = {.lex_state = 0, .external_lex_state = 5},
  [418] = {.lex_state = 0, .external_lex_state = 5},
  [419] = {.lex_state = 0, .external_lex_state = 5},
  [420] = {.lex_state = 14, .external_lex_state = 5},
  [421] = {.lex_state = 0, .external_lex_state = 5},
  [422] = {.lex_state = 0, .external_lex_state = 5},
  [423] = {.lex_state = 14, .external_lex_state = 5},
  [424] = {.lex_state = 3, .external_lex_state = 6},
  [425] = {.lex_state = 14, .external_lex_state = 5},
  [426] = {.lex_state = 0, .external_lex_state = 5},
  [427] = {.lex_state = 14, .external_lex_state = 5},
  [428] = {.lex_state = 3, .external_lex_state = 6},
  [429] = {.lex_state = 14, .external_lex_state = 5},
  [430] = {.lex_state = 14, .external_lex_state = 5},
  [431] = {.lex_state = 14, .external_lex_state = 5},
  [432] = {.lex_state = 14, .external_lex_state = 5},
  [433] = {.lex_state = 14, .external_lex_state = 5},
  [434] = {.lex_state = 14, .external_lex_state = 5},
  [435] = {.lex_state = 14, .external_lex_state = 5},
  [436] = {.lex_state = 3, .external_lex_state = 6},
  [437] = {.lex_state = 14, .external_lex_state = 5},
  [438] = {.lex_state = 14, .external_lex_state = 5},
  [439] = {.lex_state = 14, .external_lex_state = 5},
  [440] = {.lex_state = 0, .external_lex_state = 5},
  [441] = {.lex_state = 14, .external_lex_state = 5},
  [442] = {.lex_state = 14, .external_lex_state = 5},
  [443] = {.lex_state = 14, .external_lex_state = 5},
  [444] = {.lex_state = 0, .external_lex_state = 5},
  [445] = {.lex_state = 0, .external_lex_state = 5},
  [446] = {.lex_state = 0, .external_lex_state = 5},
  [447] = {.lex_state = 14, .external_lex_state = 5},
  [448] = {.lex_state = 3, .external_lex_state = 6},
  [449] = {.lex_state = 0, .external_lex_state = 5},
  [450] = {.lex_state = 0, .external_lex_state = 5},
  [451] = {.lex_state = 3, .external_lex_state = 6},
  [452] = {.lex_state = 3, .external_lex_state = 6},
  [453] = {.lex_state = 3, .external_lex_state = 6},
  [454] = {.lex_state = 3, .external_lex_state = 6},
  [455] = {.lex_state = 3, .external_lex_state = 6},
  [456] = {.lex_state = 3, .external_lex_state = 6},
  [457] = {.lex_state = 3, .external_lex_state = 6},
  [458] = {.lex_state = 3, .external_lex_state = 6},
  [459] = {.lex_state = 0, .external_lex_state = 5},
  [460] = {.lex_state = 3, .external_lex_state = 6},
  [461] = {.lex_state = 3, .external_lex_state = 6},
  [462] = {.lex_state = 3, .external_lex_state = 6},
  [463] = {.lex_state = 3, .external_lex_state = 6},
  [464] = {.lex_state = 3, .external_lex_state = 6},
  [465] = {.lex_state = 3, .external_lex_state = 6},
  [466] = {.lex_state = 3, .external_lex_state = 6},
  [467] = {.lex_state = 3, .external_lex_state = 6},
  [468] = {.lex_state = 3, .external_lex_state = 6},
  [469] = {.lex_state = 3, .external_lex_state = 6},
  [470] = {.lex_state = 3, .external_lex_state = 6},
  [471] = {.lex_state = 3, .external_lex_state = 6},
  [472] = {.lex_state = 0, .external_lex_state = 5},
  [473] = {.lex_state = 3, .external_lex_state = 6},
  [474] = {.lex_state = 3, .external_lex_state = 6},
  [475] = {.lex_state = 3, .external_lex_state = 6},
  [476] = {.lex_state = 3, .external_lex_state = 6},
  [477] = {.lex_state = 3, .external_lex_state = 6},
  [478] = {.lex_state = 3, .external_lex_state = 6},
  [479] = {.lex_state = 3, .external_lex_state = 6},
  [480] = {.lex_state = 3, .external_lex_state = 6},
  [481] = {.lex_state = 0, .external_lex_state = 5},
  [482] = {.lex_state = 0, .external_lex_state = 5},
  [483] = {.lex_state = 3, .external_lex_state = 6},
  [484] = {.lex_state = 3, .external_lex_state = 6},
  [485] = {.lex_state = 0, .external_lex_state = 5},
  [486] = {.lex_state = 0, .external_lex_state = 5},
  [487] = {.lex_state = 0, .external_lex_state = 5},
  [488] = {.lex_state = 0, .external_lex_state = 5},
  [489] = {.lex_state = 3, .external_lex_state = 6},
  [490] = {.lex_state = 3, .external_lex_state = 6},
  [491] = {.lex_state = 3, .external_lex_state = 6},
  [492] = {.lex_state = 14, .external_lex_state = 5},
  [493] = {.lex_state = 14, .external_lex_state = 5},
  [494] = {.lex_state = 3, .external_lex_state = 6},
  [495] = {.lex_state = 3, .external_lex_state = 6},
  [496] = {.lex_state = 3, .external_lex_state = 6},
  [497] = {.lex_state = 3, .external_lex_state = 6},
  [498] = {.lex_state = 3, .external_lex_state = 6},
  [499] = {.lex_state = 3, .external_lex_state = 6},
  [500] = {.lex_state = 3, .external_lex_state = 6},
  [501] = {.lex_state = 3, .external_lex_state = 6},
  [502] = {.lex_state = 3, .external_lex_state = 6},
  [503] = {.lex_state = 3, .external_lex_state = 6},
  [504] = {.lex_state = 3, .external_lex_state = 6},
  [505] = {.lex_state = 14, .external_lex_state = 5},
  [506] = {.lex_state = 14, .external_lex_state = 5},
  [507] = {.lex_state = 14, .external_lex_state = 5},
  [508] = {.lex_state = 0, .external_lex_state = 5},
  [509] = {.lex_state = 14, .external_lex_state = 5},
  [510] = {.lex_state = 0, .external_lex_state = 5},
  [511] = {.lex_state = 0, .external_lex_state = 5},
  [512] = {.lex_state = 0, .external_lex_state = 5},
  [513] = {.lex_state = 0, .external_lex_state = 5},
  [514] = {.lex_state = 0, .external_lex_state = 5},
  [515] = {.lex_state = 0, .external_lex_state = 5},
  [516] = {.lex_state = 0, .external_lex_state = 5},
  [517] = {.lex_state = 0, .external_lex_state = 5},
  [518] = {.lex_state = 0, .external_lex_state = 5},
  [519] = {.lex_state = 0, .external_lex_state = 5},
  [520] = {.lex_state = 0, .external_lex_state = 5},
  [521] = {.lex_state = 0, .external_lex_state = 5},
  [522] = {.lex_state = 0, .external_lex_state = 5},
  [523] = {.lex_state = 0, .external_lex_state = 5},
  [524] = {.lex_state = 0, .external_lex_state = 5},
  [525] = {.lex_state = 0, .external_lex_state = 5},
  [526] = {.lex_state = 0, .external_lex_state = 5},
  [527] = {.lex_state = 0, .external_lex_state = 5},
  [528] = {.lex_state = 0, .external_lex_state = 5},
  [529] = {.lex_state = 0, .external_lex_state = 5},
  [530] = {.lex_state = 0, .external_lex_state = 5},
  [531] = {.lex_state = 0, .external_lex_state = 5},
  [532] = {.lex_state = 0, .external_lex_state = 5},
  [533] = {.lex_state = 0, .external_lex_state = 5},
  [534] = {.lex_state = 0, .external_lex_state = 5},
  [535] = {.lex_state = 0, .external_lex_state = 5},
  [536] = {.lex_state = 0, .external_lex_state = 5},
  [537] = {.lex_state = 0, .external_lex_state = 5},
  [538] = {.lex_state = 0, .external_lex_state = 5},
  [539] = {.lex_state = 0, .external_lex_state = 5},
  [540] = {.lex_state = 0, .external_lex_state = 5},
  [541] = {.lex_state = 3, .external_lex_state = 6},
  [542] = {.lex_state = 0, .external_lex_state = 5},
  [543] = {.lex_state = 0, .external_lex_state = 5},
  [544] = {.lex_state = 0, .external_lex_state = 5},
  [545] = {.lex_state = 0, .external_lex_state = 5},
  [546] = {.lex_state = 0, .external_lex_state = 5},
  [547] = {.lex_state = 0, .external_lex_state = 5},
  [548] = {.lex_state = 0, .external_lex_state = 5},
  [549] = {.lex_state = 0, .external_lex_state = 5},
  [550] = {.lex_state = 0, .external_lex_state = 5},
  [551] = {.lex_state = 0, .external_lex_state = 5},
  [552] = {.lex_state = 0, .external_lex_state = 5},
  [553] = {.lex_state = 0, .external_lex_state = 5},
  [554] = {.lex_state = 0, .external_lex_state = 5},
  [555] = {.lex_state = 3, .external_lex_state = 6},
  [556] = {.lex_state = 0, .external_lex_state = 5},
  [557] = {.lex_state = 0, .external_lex_state = 5},
  [558] = {.lex_state = 3, .external_lex_state = 6},
  [559] = {.lex_state = 3, .external_lex_state = 6},
  [560] = {.lex_state = 0, .external_lex_state = 5},
  [561] = {.lex_state = 0, .external_lex_state = 5},
  [562] = {.lex_state = 0, .external_lex_state = 5},
  [563] = {.lex_state = 3, .external_lex_state = 6},
  [564] = {.lex_state = 0, .external_lex_state = 5},
  [565] = {.lex_state = 0, .external_lex_state = 5},
  [566] = {.lex_state = 0, .external_lex_state = 5},
  [567] = {.lex_state = 0, .external_lex_state = 5},
  [568] = {.lex_state = 0, .external_lex_state = 5},
  [569] = {.lex_state = 0, .external_lex_state = 5},
  [570] = {.lex_state = 0, .external_lex_state = 5},
  [571] = {.lex_state = 0, .external_lex_state = 5},
  [572] = {.lex_state = 0, .external_lex_state = 5},
  [573] = {.lex_state = 0, .external_lex_state = 5},
  [574] = {.lex_state = 0, .external_lex_state = 5},
  [575] = {.lex_state = 0, .external_lex_state = 5},
  [576] = {.lex_state = 0, .external_lex_state = 5},
  [577] = {.lex_state = 0, .external_lex_state = 5},
  [578] = {.lex_state = 0, .external_lex_state = 5},
  [579] = {.lex_state = 0, .external_lex_state = 5},
  [580] = {.lex_state = 0, .external_lex_state = 5},
  [581] = {.lex_state = 0, .external_lex_state = 5},
  [582] = {.lex_state = 0, .external_lex_state = 5},
  [583] = {.lex_state = 0, .external_lex_state = 5},
  [584] = {.lex_state = 0, .external_lex_state = 5},
  [585] = {.lex_state = 0, .external_lex_state = 5},
  [586] = {.lex_state = 0, .external_lex_state = 5},
  [587] = {.lex_state = 0, .external_lex_state = 5},
  [588] = {.lex_state = 0, .external_lex_state = 5},
  [589] = {.lex_state = 0, .external_lex_state = 5},
  [590] = {.lex_state = 0, .external_lex_state = 5},
  [591] = {.lex_state = 0, .external_lex_state = 5},
  [592] = {.lex_state = 1, .external_lex_state = 5},
  [593] = {.lex_state = 1, .external_lex_state = 5},
  [594] = {.lex_state = 14, .external_lex_state = 5},
  [595] = {.lex_state = 15, .external_lex_state = 5},
  [596] = {.lex_state = 1, .external_lex_state = 5},
  [597] = {.lex_state = 1, .external_lex_state = 5},
  [598] = {.lex_state = 1, .external_lex_state = 5},
  [599] = {.lex_state = 1, .external_lex_state = 5},
  [600] = {.lex_state = 2, .external_lex_state = 5},
  [601] = {.lex_state = 6, .external_lex_state = 6},
  [602] = {.lex_state = 6, .external_lex_state = 6},
  [603] = {.lex_state = 6, .external_lex_state = 6},
  [604] = {.lex_state = 6, .external_lex_state = 6},
  [605] = {.lex_state = 6, .external_lex_state = 6},
  [606] = {.lex_state = 5, .external_lex_state = 5},
  [607] = {.lex_state = 6, .external_lex_state = 6},
  [608] = {.lex_state = 3, .external_lex_state = 6},
  [609] = {.lex_state = 14, .external_lex_state = 5},
  [610] = {.lex_state = 0, .external_lex_state = 5},
  [611] = {.lex_state = 3, .external_lex_state = 6},
  [612] = {.lex_state = 14, .external_lex_state = 5},
  [613] = {.lex_state = 5, .external_lex_state = 5},
  [614] = {.lex_state = 0, .external_lex_state = 5},
  [615] = {.lex_state = 0, .external_lex_state = 5},
  [616] = {.lex_state = 0, .external_lex_state = 5},
  [617] = {.lex_state = 15, .external_lex_state = 5},
  [618] = {.lex_state = 5, .external_lex_state = 5},
  [619] = {.lex_state = 3, .external_lex_state = 6},
  [620] = {.lex_state = 15, .external_lex_state = 5},
  [621] = {.lex_state = 5, .external_lex_state = 5},
  [622] = {.lex_state = 14, .external_lex_state = 5},
  [623] = {.lex_state = 5, .external_lex_state = 5},
  [624] = {.lex_state = 14, .external_lex_state = 5},
  [625] = {.lex_state = 15, .external_lex_state = 5},
  [626] = {.lex_state = 14, .external_lex_state = 5},
  [627] = {.lex_state = 5, .external_lex_state = 5},
  [628] = {.lex_state = 0, .external_lex_state = 5},
  [629] = {.lex_state = 14, .external_lex_state = 5},
  [630] = {.lex_state = 15, .external_lex_state = 5},
  [631] = {.lex_state = 0, .external_lex_state = 5},
  [632] = {.lex_state = 15, .external_lex_state = 3},
  [633] = {.lex_state = 0, .external_lex_state = 5},
  [634] = {.lex_state = 14, .external_lex_state = 5},
  [635] = {.lex_state = 15, .external_lex_state = 5},
  [636] = {.lex_state = 15, .external_lex_state = 5},
  [637] = {.lex_state = 0, .external_lex_state = 5},
  [638] = {.lex_state = 14, .external_lex_state = 5},
  [639] = {.lex_state = 0, .external_lex_state = 5},
  [640] = {.lex_state = 15, .external_lex_state = 5},
  [641] = {.lex_state = 15, .external_lex_state = 5},
  [642] = {.lex_state = 2, .external_lex_state = 5},
  [643] = {.lex_state = 15, .external_lex_state = 5},
  [644] = {.lex_state = 15, .external_lex_state = 5},
  [645] = {.lex_state = 15, .external_lex_state = 5},
  [646] = {.lex_state = 15, .external_lex_state = 5},
  [647] = {.lex_state = 15, .external_lex_state = 5},
  [648] = {.lex_state = 15, .external_lex_state = 5},
  [649] = {.lex_state = 15, .external_lex_state = 5},
  [650] = {.lex_state = 15, .external_lex_state = 5},
  [651] = {.lex_state = 0, .external_lex_state = 7},
  [652] = {.lex_state = 0, .external_lex_state = 7},
  [653] = {.lex_state = 14, .external_lex_state = 5},
  [654] = {.lex_state = 15, .external_lex_state = 5},
  [655] = {.lex_state = 15, .external_lex_state = 5},
  [656] = {.lex_state = 2, .external_lex_state = 5},
  [657] = {.lex_state = 0, .external_lex_state = 7},
  [658] = {.lex_state = 0, .external_lex_state = 7},
  [659] = {.lex_state = 15, .external_lex_state = 5},
  [660] = {.lex_state = 15, .external_lex_state = 5},
  [661] = {.lex_state = 2, .external_lex_state = 5},
  [662] = {.lex_state = 15, .external_lex_state = 5},
  [663] = {.lex_state = 15, .external_lex_state = 5},
  [664] = {.lex_state = 15, .external_lex_state = 5},
  [665] = {.lex_state = 0, .external_lex_state = 7},
  [666] = {.lex_state = 15, .external_lex_state = 5},
  [667] = {.lex_state = 0, .external_lex_state = 5},
  [668] = {.lex_state = 0, .external_lex_state = 5},
  [669] = {.lex_state = 0, .external_lex_state = 5},
  [670] = {.lex_state = 15, .external_lex_state = 5},
  [671] = {.lex_state = 15, .external_lex_state = 5},
  [672] = {.lex_state = 14, .external_lex_state = 5},
  [673] = {.lex_state = 14, .external_lex_state = 5},
  [674] = {.lex_state = 14, .external_lex_state = 5},
  [675] = {.lex_state = 14, .external_lex_state = 5},
  [676] = {.lex_state = 0, .external_lex_state = 5},
  [677] = {.lex_state = 15, .external_lex_state = 5},
  [678] = {.lex_state = 0, .external_lex_state = 5},
  [679] = {.lex_state = 14, .external_lex_state = 5},
  [680] = {.lex_state = 0, .external_lex_state = 5},
  [681] = {.lex_state = 14, .external_lex_state = 5},
  [682] = {.lex_state = 14, .external_lex_state = 5},
  [683] = {.lex_state = 0, .external_lex_state = 5},
  [684] = {.lex_state = 0, .external_lex_state = 5},
  [685] = {.lex_state = 15, .external_lex_state = 5},
  [686] = {.lex_state = 14, .external_lex_state = 5},
  [687] = {.lex_state = 15, .external_lex_state = 5},
  [688] = {.lex_state = 14, .external_lex_state = 5},
  [689] = {.lex_state = 14, .external_lex_state = 5},
  [690] = {.lex_state = 14, .external_lex_state = 5},
  [691] = {.lex_state = 14, .external_lex_state = 5},
  [692] = {.lex_state = 0, .external_lex_state = 5},
  [693] = {.lex_state = 0, .external_lex_state = 5},
  [694] = {.lex_state = 0, .external_lex_state = 5},
  [695] = {.lex_state = 0, .external_lex_state = 5},
  [696] = {.lex_state = 0, .external_lex_state = 5},
  [697] = {.lex_state = 14, .external_lex_state = 5},
  [698] = {.lex_state = 15, .external_lex_state = 5},
  [699] = {.lex_state = 15, .external_lex_state = 5},
  [700] = {.lex_state = 14, .external_lex_state = 5},
  [701] = {.lex_state = 0, .external_lex_state = 7},
  [702] = {.lex_state = 14, .external_lex_state = 5},
  [703] = {.lex_state = 14, .external_lex_state = 5},
  [704] = {.lex_state = 14, .external_lex_state = 5},
  [705] = {.lex_state = 15, .external_lex_state = 5},
  [706] = {.lex_state = 14, .external_lex_state = 5},
  [707] = {.lex_state = 15, .external_lex_state = 5},
  [708] = {.lex_state = 15, .external_lex_state = 5},
  [709] = {.lex_state = 15, .external_lex_state = 5},
  [710] = {.lex_state = 14, .external_lex_state = 5},
  [711] = {.lex_state = 14, .external_lex_state = 5},
  [712] = {.lex_state = 14, .external_lex_state = 5},
  [713] = {.lex_state = 15, .external_lex_state = 5},
  [714] = {.lex_state = 15, .external_lex_state = 5},
  [715] = {.lex_state = 14, .external_lex_state = 5},
  [716] = {.lex_state = 14, .external_lex_state = 5},
  [717] = {.lex_state = 14, .external_lex_state = 5},
  [718] = {.lex_state = 2, .external_lex_state = 5},
  [719] = {.lex_state = 0, .external_lex_state = 7},
  [720] = {.lex_state = 14, .external_lex_state = 5},
  [721] = {.lex_state = 0, .external_lex_state = 7},
  [722] = {.lex_state = 15, .external_lex_state = 5},
  [723] = {.lex_state = 15, .external_lex_state = 5},
  [724] = {.lex_state = 0, .external_lex_state = 7},
  [725] = {.lex_state = 0, .external_lex_state = 7},
  [726] = {.lex_state = 14, .external_lex_state = 5},
  [727] = {.lex_state = 15, .external_lex_state = 5},
  [728] = {.lex_state = 0, .external_lex_state = 7},
  [729] = {.lex_state = 14, .external_lex_state = 5},
  [730] = {.lex_state = 0, .external_lex_state = 7},
  [731] = {.lex_state = 0, .external_lex_state = 7},
  [732] = {.lex_state = 14, .external_lex_state = 5},
  [733] = {.lex_state = 15, .external_lex_state = 5},
  [734] = {.lex_state = 15, .external_lex_state = 5},
  [735] = {.lex_state = 0, .external_lex_state = 7},
  [736] = {.lex_state = 0, .external_lex_state = 7},
  [737] = {.lex_state = 14, .external_lex_state = 5},
  [738] = {.lex_state = 14, .external_lex_state = 5},
  [739] = {.lex_state = 15, .external_lex_state = 5},
  [740] = {.lex_state = 15, .external_lex_state = 5},
  [741] = {.lex_state = 15, .external_lex_state = 5},
  [742] = {.lex_state = 15, .external_lex_state = 5},
  [743] = {.lex_state = 0, .external_lex_state = 5},
  [744] = {.lex_state = 14, .external_lex_state = 5},
  [745] = {.lex_state = 14, .external_lex_state = 5},
  [746] = {.lex_state = 14, .external_lex_state = 5},
  [747] = {.lex_state = 0, .external_lex_state = 7},
  [748] = {.lex_state = 14, .external_lex_state = 5},
  [749] = {.lex_state = 0, .external_lex_state = 7},
  [750] = {.lex_state = 14, .external_lex_state = 5},
  [751] = {.lex_state = 15, .external_lex_state = 5},
  [752] = {.lex_state = 0, .external_lex_state = 7},
  [753] = {.lex_state = 0, .external_lex_state = 7},
  [754] = {.lex_state = 0, .external_lex_state = 7},
  [755] = {.lex_state = 0, .external_lex_state = 7},
  [756] = {.lex_state = 0, .external_lex_state = 7},
  [757] = {.lex_state = 0, .external_lex_state = 7},
  [758] = {.lex_state = 0, .external_lex_state = 7},
  [759] = {.lex_state = 0, .external_lex_state = 7},
  [760] = {.lex_state = 0, .external_lex_state = 7},
  [761] = {.lex_state = 15, .external_lex_state = 5},
  [762] = {.lex_state = 15, .external_lex_state = 5},
  [763] = {.lex_state = 0, .external_lex_state = 5},
  [764] = {.lex_state = 14, .external_lex_state = 5},
  [765] = {.lex_state = 0, .external_lex_state = 7},
  [766] = {.lex_state = 15, .external_lex_state = 5},
  [767] = {.lex_state = 14, .external_lex_state = 5},
  [768] = {.lex_state = 14, .external_lex_state = 8},
  [769] = {.lex_state = 14, .external_lex_state = 5},
  [770] = {.lex_state = 0, .external_lex_state = 7},
  [771] = {.lex_state = 14, .external_lex_state = 8},
  [772] = {.lex_state = 14, .external_lex_state = 5},
  [773] = {.lex_state = 15, .external_lex_state = 5},
  [774] = {.lex_state = 14, .external_lex_state = 5},
  [775] = {.lex_state = 14, .external_lex_state = 5},
  [776] = {.lex_state = 14, .external_lex_state = 5},
  [777] = {.lex_state = 14, .external_lex_state = 5},
  [778] = {.lex_state = 14, .external_lex_state = 5},
  [779] = {.lex_state = 14, .external_lex_state = 5},
  [780] = {.lex_state = 14, .external_lex_state = 5},
  [781] = {.lex_state = 15, .external_lex_state = 5},
  [782] = {.lex_state = 15, .external_lex_state = 5},
  [783] = {.lex_state = 14, .external_lex_state = 5},
  [784] = {.lex_state = 7, .external_lex_state = 6},
  [785] = {.lex_state = 14, .external_lex_state = 5},
  [786] = {.lex_state = 7, .external_lex_state = 6},
  [787] = {.lex_state = 14, .external_lex_state = 5},
  [788] = {.lex_state = 14, .external_lex_state = 5},
  [789] = {.lex_state = 14, .external_lex_state = 5},
  [790] = {.lex_state = 0, .external_lex_state = 7},
  [791] = {.lex_state = 14, .external_lex_state = 8},
  [792] = {.lex_state = 14, .external_lex_state = 5},
  [793] = {.lex_state = 14, .external_lex_state = 5},
  [794] = {.lex_state = 15, .external_lex_state = 5},
  [795] = {.lex_state = 0, .external_lex_state = 7},
  [796] = {.lex_state = 0, .external_lex_state = 7},
  [797] = {.lex_state = 15, .external_lex_state = 5},
  [798] = {.lex_state = 15, .external_lex_state = 5},
  [799] = {.lex_state = 0, .external_lex_state = 7},
  [800] = {.lex_state = 15, .external_lex_state = 5},
  [801] = {.lex_state = 15, .external_lex_state = 5},
  [802] = {.lex_state = 7, .external_lex_state = 6},
  [803] = {.lex_state = 14, .external_lex_state = 5},
  [804] = {.lex_state = 14, .external_lex_state = 5},
  [805] = {.lex_state = 14, .external_lex_state = 5},
  [806] = {.lex_state = 14, .external_lex_state = 5},
  [807] = {.lex_state = 14, .external_lex_state = 5},
  [808] = {.lex_state = 14, .external_lex_state = 5},
  [809] = {.lex_state = 14, .external_lex_state = 5},
  [810] = {.lex_state = 15, .external_lex_state = 5},
  [811] = {.lex_state = 15, .external_lex_state = 5},
  [812] = {.lex_state = 0, .external_lex_state = 7},
  [813] = {.lex_state = 15, .external_lex_state = 5},
  [814] = {.lex_state = 15, .external_lex_state = 5},
  [815] = {.lex_state = 14, .external_lex_state = 5},
  [816] = {.lex_state = 15, .external_lex_state = 5},
  [817] = {.lex_state = 14, .external_lex_state = 5},
  [818] = {.lex_state = 14, .external_lex_state = 5},
  [819] = {.lex_state = 0, .external_lex_state = 7},
  [820] = {.lex_state = 7, .external_lex_state = 6},
  [821] = {.lex_state = 0, .external_lex_state = 7},
  [822] = {.lex_state = 0, .external_lex_state = 7},
  [823] = {.lex_state = 14, .external_lex_state = 5},
  [824] = {.lex_state = 14, .external_lex_state = 5},
  [825] = {.lex_state = 14, .external_lex_state = 5},
  [826] = {.lex_state = 7, .external_lex_state = 6},
  [827] = {.lex_state = 0, .external_lex_state = 7},
  [828] = {.lex_state = 0, .external_lex_state = 7},
  [829] = {.lex_state = 0, .external_lex_state = 7},
  [830] = {.lex_state = 14, .external_lex_state = 5},
  [831] = {.lex_state = 14, .external_lex_state = 5},
  [832] = {.lex_state = 15, .external_lex_state = 5},
  [833] = {.lex_state = 0, .external_lex_state = 7},
  [834] = {.lex_state = 15, .external_lex_state = 5},
  [835] = {.lex_state = 15, .external_lex_state = 5},
  [836] = {.lex_state = 14, .external_lex_state = 5},
  [837] = {.lex_state = 14, .external_lex_state = 5},
  [838] = {.lex_state = 14, .external_lex_state = 5},
  [839] = {.lex_state = 14, .external_lex_state = 5},
  [840] = {.lex_state = 15, .external_lex_state = 5},
  [841] = {.lex_state = 14, .external_lex_state = 5},
  [842] = {.lex_state = 15, .external_lex_state = 5},
  [843] = {.lex_state = 14, .external_lex_state = 5},
  [844] = {.lex_state = 14, .external_lex_state = 5},
  [845] = {.lex_state = 14, .external_lex_state = 5},
  [846] = {.lex_state = 0, .external_lex_state = 9},
  [847] = {.lex_state = 0, .external_lex_state = 10},
  [848] = {.lex_state = 14, .external_lex_state = 5},
  [849] = {.lex_state = 14, .external_lex_state = 5},
  [850] = {.lex_state = 14, .external_lex_state = 5},
  [851] = {.lex_state = 14, .external_lex_state = 5},
  [852] = {.lex_state = 14, .external_lex_state = 5},
  [853] = {.lex_state = 14, .external_lex_state = 5},
  [854] = {.lex_state = 0, .external_lex_state = 10},
  [855] = {.lex_state = 14, .external_lex_state = 5},
  [856] = {.lex_state = 14, .external_lex_state = 5},
  [857] = {.lex_state = 14, .external_lex_state = 5},
  [858] = {.lex_state = 14, .external_lex_state = 5},
  [859] = {.lex_state = 14, .external_lex_state = 5},
  [860] = {.lex_state = 14, .external_lex_state = 5},
  [861] = {.lex_state = 0, .external_lex_state = 5},
  [862] = {.lex_state = 0, .external_lex_state = 9},
  [863] = {.lex_state = 0, .external_lex_state = 9},
  [864] = {.lex_state = 0, .external_lex_state = 10},
  [865] = {.lex_state = 14, .external_lex_state = 5},
  [866] = {.lex_state = 14, .external_lex_state = 5},
  [867] = {.lex_state = 14, .external_lex_state = 5},
  [868] = {.lex_state = 0, .external_lex_state = 9},
  [869] = {.lex_state = 0, .external_lex_state = 10},
  [870] = {.lex_state = 15, .external_lex_state = 5},
  [871] = {.lex_state = 14, .external_lex_state = 5},
  [872] = {.lex_state = 0, .external_lex_state = 9},
  [873] = {.lex_state = 14, .external_lex_state = 5},
  [874] = {.lex_state = 0, .external_lex_state = 10},
  [875] = {.lex_state = 14, .external_lex_state = 5},
  [876] = {.lex_state = 0, .external_lex_state = 10},
  [877] = {.lex_state = 7, .external_lex_state = 5},
  [878] = {.lex_state = 14, .external_lex_state = 5},
  [879] = {.lex_state = 15, .external_lex_state = 5},
  [880] = {.lex_state = 14, .external_lex_state = 5},
  [881] = {.lex_state = 0, .external_lex_state = 9},
  [882] = {.lex_state = 0, .external_lex_state = 10},
  [883] = {.lex_state = 15, .external_lex_state = 5},
  [884] = {.lex_state = 15, .external_lex_state = 5},
  [885] = {.lex_state = 0, .external_lex_state = 9},
  [886] = {.lex_state = 0, .external_lex_state = 10},
  [887] = {.lex_state = 14, .external_lex_state = 5},
  [888] = {.lex_state = 0, .external_lex_state = 9},
  [889] = {.lex_state = 0, .external_lex_state = 10},
  [890] = {.lex_state = 7, .external_lex_state = 6},
  [891] = {.lex_state = 14, .external_lex_state = 5},
  [892] = {.lex_state = 15, .external_lex_state = 5},
  [893] = {.lex_state = 15, .external_lex_state = 5},
  [894] = {.lex_state = 15, .external_lex_state = 5},
  [895] = {.lex_state = 15, .external_lex_state = 5},
  [896] = {.lex_state = 15, .external_lex_state = 5},
  [897] = {.lex_state = 14, .external_lex_state = 5},
  [898] = {.lex_state = 14, .external_lex_state = 5},
  [899] = {.lex_state = 14, .external_lex_state = 5},
  [900] = {.lex_state = 14, .external_lex_state = 5},
  [901] = {.lex_state = 14, .external_lex_state = 5},
  [902] = {.lex_state = 15, .external_lex_state = 5},
  [903] = {.lex_state = 15, .external_lex_state = 5},
  [904] = {.lex_state = 15, .external_lex_state = 5},
  [905] = {.lex_state = 14, .external_lex_state = 5},
  [906] = {.lex_state = 15, .external_lex_state = 5},
  [907] = {.lex_state = 14, .external_lex_state = 5},
  [908] = {.lex_state = 14, .external_lex_state = 5},
  [909] = {.lex_state = 0, .external_lex_state = 9},
  [910] = {.lex_state = 14, .external_lex_state = 5},
  [911] = {.lex_state = 14, .external_lex_state = 5},
  [912] = {.lex_state = 14, .external_lex_state = 5},
  [913] = {.lex_state = 14, .external_lex_state = 5},
  [914] = {.lex_state = 0, .external_lex_state = 5},
  [915] = {.lex_state = 15, .external_lex_state = 5},
  [916] = {.lex_state = 14, .external_lex_state = 5},
  [917] = {.lex_state = 14, .external_lex_state = 5},
  [918] = {.lex_state = 15, .external_lex_state = 5},
  [919] = {.lex_state = 7, .external_lex_state = 5},
  [920] = {.lex_state = 15, .external_lex_state = 5},
  [921] = {.lex_state = 14, .external_lex_state = 5},
  [922] = {.lex_state = 14, .external_lex_state = 5},
  [923] = {.lex_state = 14, .external_lex_state = 5},
  [924] = {.lex_state = 14, .external_lex_state = 5},
  [925] = {.lex_state = 14, .external_lex_state = 5},
  [926] = {.lex_state = 14, .external_lex_state = 5},
  [927] = {.lex_state = 15, .external_lex_state = 5},
  [928] = {.lex_state = 15, .external_lex_state = 5},
  [929] = {.lex_state = 14, .external_lex_state = 5},
  [930] = {.lex_state = 0, .external_lex_state = 5},
  [931] = {.lex_state = 14, .external_lex_state = 5},
  [932] = {.lex_state = 15, .external_lex_state = 5},
  [933] = {.lex_state = 15, .external_lex_state = 5},
  [934] = {.lex_state = 14, .external_lex_state = 5},
  [935] = {.lex_state = 0, .external_lex_state = 5},
  [936] = {.lex_state = 14, .external_lex_state = 5},
  [937] = {.lex_state = 15, .external_lex_state = 5},
  [938] = {.lex_state = 7, .external_lex_state = 5},
  [939] = {.lex_state = 14, .external_lex_state = 5},
  [940] = {.lex_state = 0, .external_lex_state = 5},
  [941] = {.lex_state = 14, .external_lex_state = 5},
  [942] = {.lex_state = 14, .external_lex_state = 5},
  [943] = {.lex_state = 14, .external_lex_state = 5},
  [944] = {.lex_state = 7, .external_lex_state = 5},
  [945] = {.lex_state = 7, .external_lex_state = 5},
  [946] = {.lex_state = 14, .external_lex_state = 5},
  [947] = {.lex_state = 14, .external_lex_state = 5},
  [948] = {.lex_state = 14, .external_lex_state = 5},
  [949] = {.lex_state = 14, .external_lex_state = 5},
  [950] = {.lex_state = 7, .external_lex_state = 5},
  [951] = {.lex_state = 7, .external_lex_state = 5},
  [952] = {.lex_state = 0, .external_lex_state = 5},
  [953] = {.lex_state = 0, .external_lex_state = 5},
  [954] = {.lex_state = 14, .external_lex_state = 5},
  [955] = {.lex_state = 14, .external_lex_state = 5},
  [956] = {.lex_state = 15, .external_lex_state = 5},
  [957] = {.lex_state = 14, .external_lex_state = 5},
  [958] = {.lex_state = 15, .external_lex_state = 5},
  [959] = {.lex_state = 14, .external_lex_state = 5},
  [960] = {.lex_state = 14, .external_lex_state = 5},
  [961] = {.lex_state = 0, .external_lex_state = 5},
  [962] = {.lex_state = 15, .external_lex_state = 5},
  [963] = {.lex_state = 0, .external_lex_state = 5},
  [964] = {.lex_state = 15, .external_lex_state = 5},
  [965] = {.lex_state = 0, .external_lex_state = 5},
  [966] = {.lex_state = 0, .external_lex_state = 5},
  [967] = {.lex_state = 15, .external_lex_state = 5},
  [968] = {.lex_state = 15, .external_lex_state = 5},
  [969] = {.lex_state = 0, .external_lex_state = 5},
  [970] = {.lex_state = 15, .external_lex_state = 5},
  [971] = {.lex_state = 15, .external_lex_state = 5},
  [972] = {.lex_state = 15, .external_lex_state = 5},
  [973] = {.lex_state = 15, .external_lex_state = 5},
  [974] = {.lex_state = 14, .external_lex_state = 5},
  [975] = {.lex_state = 15, .external_lex_state = 5},
  [976] = {.lex_state = 14, .external_lex_state = 5},
  [977] = {.lex_state = 14, .external_lex_state = 5},
  [978] = {.lex_state = 14, .external_lex_state = 5},
  [979] = {.lex_state = 7, .external_lex_state = 5},
  [980] = {.lex_state = 7, .external_lex_state = 5},
  [981] = {.lex_state = 14, .external_lex_state = 5},
  [982] = {.lex_state = 7, .external_lex_state = 5},
  [983] = {.lex_state = 7, .external_lex_state = 5},
  [984] = {.lex_state = 14, .external_lex_state = 5},
  [985] = {.lex_state = 14, .external_lex_state = 5},
  [986] = {.lex_state = 7, .external_lex_state = 5},
  [987] = {.lex_state = 15, .external_lex_state = 5},
  [988] = {.lex_state = 14, .external_lex_state = 5},
  [989] = {.lex_state = 14, .external_lex_state = 5},
  [990] = {.lex_state = 0, .external_lex_state = 5},
  [991] = {.lex_state = 14, .external_lex_state = 5},
  [992] = {.lex_state = 15, .external_lex_state = 5},
  [993] = {.lex_state = 0, .external_lex_state = 5},
  [994] = {.lex_state = 14, .external_lex_state = 5},
  [995] = {.lex_state = 14, .external_lex_state = 5},
  [996] = {.lex_state = 14, .external_lex_state = 5},
  [997] = {.lex_state = 7, .external_lex_state = 5},
  [998] = {.lex_state = 7, .external_lex_state = 5},
  [999] = {.lex_state = 14, .external_lex_state = 5},
  [1000] = {.lex_state = 14, .external_lex_state = 5},
  [1001] = {.lex_state = 7, .external_lex_state = 5},
  [1002] = {.lex_state = 7, .external_lex_state = 5},
  [1003] = {.lex_state = 0, .external_lex_state = 5},
  [1004] = {.lex_state = 0, .external_lex_state = 5},
  [1005] = {.lex_state = 14, .external_lex_state = 5},
  [1006] = {.lex_state = 0, .external_lex_state = 5},
  [1007] = {.lex_state = 14, .external_lex_state = 5},
  [1008] = {.lex_state = 14, .external_lex_state = 5},
  [1009] = {.lex_state = 14, .external_lex_state = 5},
  [1010] = {.lex_state = 14, .external_lex_state = 5},
  [1011] = {.lex_state = 7, .external_lex_state = 5},
  [1012] = {.lex_state = 14, .external_lex_state = 5},
  [1013] = {.lex_state = 14, .external_lex_state = 5},
  [1014] = {.lex_state = 7, .external_lex_state = 5},
  [1015] = {.lex_state = 15, .external_lex_state = 5},
  [1016] = {.lex_state = 15, .external_lex_state = 5},
  [1017] = {.lex_state = 15, .external_lex_state = 5},
  [1018] = {.lex_state = 14, .external_lex_state = 5},
  [1019] = {.lex_state = 14, .external_lex_state = 5},
  [1020] = {.lex_state = 14, .external_lex_state = 5},
  [1021] = {.lex_state = 0, .external_lex_state = 5},
  [1022] = {.lex_state = 0, .external_lex_state = 5},
  [1023] = {.lex_state = 14, .external_lex_state = 5},
  [1024] = {.lex_state = 14, .external_lex_state = 5},
  [1025] = {.lex_state = 14, .external_lex_state = 5},
  [1026] = {.lex_state = 15, .external_lex_state = 5},
  [1027] = {.lex_state = 14, .external_lex_state = 5},
  [1028] = {.lex_state = 15, .external_lex_state = 5},
  [1029] = {.lex_state = 15, .external_lex_state = 5},
  [1030] = {.lex_state = 15, .external_lex_state = 5},
  [1031] = {.lex_state = 14, .external_lex_state = 5},
  [1032] = {.lex_state = 14, .external_lex_state = 5},
  [1033] = {.lex_state = 0, .external_lex_state = 5},
  [1034] = {.lex_state = 0, .external_lex_state = 5},
  [1035] = {.lex_state = 0, .external_lex_state = 5},
  [1036] = {.lex_state = 0, .external_lex_state = 5},
  [1037] = {.lex_state = 15, .external_lex_state = 5},
  [1038] = {.lex_state = 15, .external_lex_state = 5},
  [1039] = {.lex_state = 0, .external_lex_state = 5},
  [1040] = {.lex_state = 15, .external_lex_state = 5},
  [1041] = {.lex_state = 15, .external_lex_state = 5},
  [1042] = {.lex_state = 0, .external_lex_state = 5},
  [1043] = {.lex_state = 0, .external_lex_state = 5},
  [1044] = {.lex_state = 15, .external_lex_state = 5},
  [1045] = {.lex_state = 15, .external_lex_state = 5},
  [1046] = {.lex_state = 0, .external_lex_state = 5},
  [1047] = {.lex_state = 0, .external_lex_state = 5},
  [1048] = {.lex_state = 0, .external_lex_state = 5},
  [1049] = {.lex_state = 15, .external_lex_state = 5},
  [1050] = {.lex_state = 15, .external_lex_state = 5},
  [1051] = {.lex_state = 15, .external_lex_state = 5},
  [1052] = {.lex_state = 15, .external_lex_state = 5},
  [1053] = {.lex_state = 0, .external_lex_state = 5},
  [1054] = {.lex_state = 15, .external_lex_state = 5},
  [1055] = {.lex_state = 0, .external_lex_state = 5},
  [1056] = {.lex_state = 0, .external_lex_state = 5},
  [1057] = {.lex_state = 0, .external_lex_state = 5},
  [1058] = {.lex_state = 0, .external_lex_state = 5},
  [1059] = {.lex_state = 0, .external_lex_state = 5},
  [1060] = {.lex_state = 0, .external_lex_state = 5},
  [1061] = {.lex_state = 0, .external_lex_state = 5},
  [1062] = {.lex_state = 15, .external_lex_state = 5},
  [1063] = {.lex_state = 15, .external_lex_state = 5},
  [1064] = {.lex_state = 15, .external_lex_state = 5},
  [1065] = {.lex_state = 15, .external_lex_state = 5},
  [1066] = {.lex_state = 15, .external_lex_state = 5},
  [1067] = {.lex_state = 15, .external_lex_state = 5},
  [1068] = {.lex_state = 15, .external_lex_state = 5},
  [1069] = {.lex_state = 0, .external_lex_state = 5},
  [1070] = {.lex_state = 0, .external_lex_state = 5},
  [1071] = {.lex_state = 15, .external_lex_state = 5},
  [1072] = {.lex_state = 0, .external_lex_state = 5},
  [1073] = {.lex_state = 15, .external_lex_state = 5},
  [1074] = {.lex_state = 15, .external_lex_state = 5},
  [1075] = {.lex_state = 15, .external_lex_state = 5},
  [1076] = {.lex_state = 15, .external_lex_state = 5},
  [1077] = {.lex_state = 0, .external_lex_state = 5},
  [1078] = {.lex_state = 0, .external_lex_state = 5},
  [1079] = {.lex_state = 0, .external_lex_state = 5},
  [1080] = {.lex_state = 0, .external_lex_state = 5},
  [1081] = {.lex_state = 0, .external_lex_state = 5},
  [1082] = {.lex_state = 0, .external_lex_state = 5},
  [1083] = {.lex_state = 0, .external_lex_state = 5},
  [1084] = {.lex_state = 0, .external_lex_state = 5},
  [1085] = {.lex_state = 0, .external_lex_state = 5},
  [1086] = {.lex_state = 0, .external_lex_state = 5},
  [1087] = {.lex_state = 0, .external_lex_state = 5},
  [1088] = {.lex_state = 0, .external_lex_state = 5},
  [1089] = {.lex_state = 15, .external_lex_state = 5},
  [1090] = {.lex_state = 0, .external_lex_state = 5},
  [1091] = {.lex_state = 0, .external_lex_state = 5},
  [1092] = {.lex_state = 0, .external_lex_state = 5},
  [1093] = {.lex_state = 0, .external_lex_state = 5},
  [1094] = {.lex_state = 15, .external_lex_state = 5},
  [1095] = {.lex_state = 15, .external_lex_state = 5},
  [1096] = {.lex_state = 0, .external_lex_state = 5},
  [1097] = {.lex_state = 15, .external_lex_state = 5},
  [1098] = {.lex_state = 15, .external_lex_state = 5},
  [1099] = {.lex_state = 15, .external_lex_state = 5},
  [1100] = {.lex_state = 0, .external_lex_state = 5},
  [1101] = {.lex_state = 0, .external_lex_state = 5},
  [1102] = {.lex_state = 0, .external_lex_state = 5},
  [1103] = {.lex_state = 15, .external_lex_state = 5},
  [1104] = {.lex_state = 15, .external_lex_state = 5},
  [1105] = {.lex_state = 15, .external_lex_state = 5},
  [1106] = {.lex_state = 0, .external_lex_state = 5},
  [1107] = {.lex_state = 15, .external_lex_state = 5},
  [1108] = {.lex_state = 15, .external_lex_state = 5},
  [1109] = {.lex_state = 15, .external_lex_state = 5},
  [1110] = {.lex_state = 15, .external_lex_state = 5},
  [1111] = {.lex_state = 15, .external_lex_state = 5},
  [1112] = {.lex_state = 15, .external_lex_state = 5},
  [1113] = {.lex_state = 15, .external_lex_state = 5},
  [1114] = {.lex_state = 15, .external_lex_state = 5},
  [1115] = {.lex_state = 15, .external_lex_state = 5},
  [1116] = {.lex_state = 15, .external_lex_state = 5},
  [1117] = {.lex_state = 15, .external_lex_state = 5},
  [1118] = {.lex_state = 15, .external_lex_state = 5},
  [1119] = {.lex_state = 15, .external_lex_state = 5},
  [1120] = {.lex_state = 15, .external_lex_state = 5},
  [1121] = {.lex_state = 0, .external_lex_state = 5},
  [1122] = {.lex_state = 0, .external_lex_state = 5},
  [1123] = {.lex_state = 0, .external_lex_state = 5},
  [1124] = {.lex_state = 15, .external_lex_state = 5},
  [1125] = {.lex_state = 15, .external_lex_state = 5},
  [1126] = {.lex_state = 15, .external_lex_state = 5},
  [1127] = {.lex_state = 15, .external_lex_state = 5},
  [1128] = {.lex_state = 15, .external_lex_state = 5},
  [1129] = {.lex_state = 0, .external_lex_state = 5},
  [1130] = {.lex_state = 15, .external_lex_state = 5},
  [1131] = {.lex_state = 15, .external_lex_state = 5},
  [1132] = {.lex_state = 15, .external_lex_state = 5},
  [1133] = {.lex_state = 15, .external_lex_state = 5},
  [1134] = {.lex_state = 0, .external_lex_state = 5},
  [1135] = {.lex_state = 15, .external_lex_state = 5},
  [1136] = {.lex_state = 0, .external_lex_state = 5},
  [1137] = {.lex_state = 15, .external_lex_state = 5},
  [1138] = {.lex_state = 15, .external_lex_state = 5},
  [1139] = {.lex_state = 15, .external_lex_state = 5},
  [1140] = {.lex_state = 15, .external_lex_state = 5},
  [1141] = {.lex_state = 15, .external_lex_state = 5},
  [1142] = {.lex_state = 15, .external_lex_state = 5},
  [1143] = {.lex_state = 15, .external_lex_state = 5},
  [1144] = {.lex_state = 15, .external_lex_state = 5},
  [1145] = {.lex_state = 15, .external_lex_state = 5},
  [1146] = {.lex_state = 15, .external_lex_state = 5},
  [1147] = {.lex_state = 15, .external_lex_state = 5},
  [1148] = {.lex_state = 15, .external_lex_state = 5},
  [1149] = {.lex_state = 15, .external_lex_state = 5},
  [1150] = {.lex_state = 15, .external_lex_state = 5},
  [1151] = {.lex_state = 15, .external_lex_state = 5},
  [1152] = {.lex_state = 15, .external_lex_state = 5},
  [1153] = {.lex_state = 15, .external_lex_state = 5},
  [1154] = {.lex_state = 15, .external_lex_state = 5},
  [1155] = {.lex_state = 15, .external_lex_state = 5},
  [1156] = {.lex_state = 15, .external_lex_state = 5},
  [1157] = {.lex_state = 15, .external_lex_state = 5},
  [1158] = {.lex_state = 15, .external_lex_state = 5},
  [1159] = {.lex_state = 15, .external_lex_state = 5},
  [1160] = {.lex_state = 15, .external_lex_state = 5},
  [1161] = {.lex_state = 15, .external_lex_state = 5},
  [1162] = {.lex_state = 15, .external_lex_state = 5},
  [1163] = {.lex_state = 15, .external_lex_state = 5},
  [1164] = {.lex_state = 15, .external_lex_state = 5},
  [1165] = {.lex_state = 15, .external_lex_state = 5},
  [1166] = {.lex_state = 15, .external_lex_state = 5},
  [1167] = {.lex_state = 15, .external_lex_state = 5},
  [1168] = {.lex_state = 15, .external_lex_state = 5},
  [1169] = {.lex_state = 15, .external_lex_state = 5},
  [1170] = {.lex_state = 15, .external_lex_state = 5},
  [1171] = {.lex_state = 15, .external_lex_state = 5},
  [1172] = {.lex_state = 15, .external_lex_state = 5},
  [1173] = {.lex_state = 15, .external_lex_state = 5},
  [1174] = {.lex_state = 15, .external_lex_state = 5},
  [1175] = {.lex_state = 15, .external_lex_state = 5},
  [1176] = {.lex_state = 15, .external_lex_state = 5},
  [1177] = {.lex_state = 0, .external_lex_state = 5},
  [1178] = {.lex_state = 0, .external_lex_state = 5},
  [1179] = {.lex_state = 0, .external_lex_state = 5},
  [1180] = {.lex_state = 15, .external_lex_state = 5},
  [1181] = {.lex_state = 15, .external_lex_state = 5},
  [1182] = {.lex_state = 0, .external_lex_state = 5},
  [1183] = {.lex_state = 15, .external_lex_state = 5},
  [1184] = {.lex_state = 0, .external_lex_state = 5},
  [1185] = {.lex_state = 15, .external_lex_state = 5},
  [1186] = {.lex_state = 15, .external_lex_state = 5},
  [1187] = {.lex_state = 15, .external_lex_state = 5},
  [1188] = {.lex_state = 0, .external_lex_state = 5},
  [1189] = {.lex_state = 0, .external_lex_state = 5},
  [1190] = {.lex_state = 15, .external_lex_state = 5},
  [1191] = {.lex_state = 0, .external_lex_state = 5},
  [1192] = {.lex_state = 15, .external_lex_state = 5},
  [1193] = {.lex_state = 0, .external_lex_state = 5},
  [1194] = {.lex_state = 15, .external_lex_state = 5},
  [1195] = {.lex_state = 15, .external_lex_state = 5},
  [1196] = {.lex_state = 15, .external_lex_state = 5},
  [1197] = {.lex_state = 0, .external_lex_state = 5},
  [1198] = {.lex_state = 0, .external_lex_state = 5},
  [1199] = {.lex_state = 15, .external_lex_state = 5},
  [1200] = {.lex_state = 15, .external_lex_state = 5},
  [1201] = {.lex_state = 15, .external_lex_state = 5},
  [1202] = {.lex_state = 15, .external_lex_state = 5},
  [1203] = {.lex_state = 0, .external_lex_state = 5},
  [1204] = {.lex_state = 15, .external_lex_state = 5},
  [1205] = {.lex_state = 15, .external_lex_state = 5},
  [1206] = {.lex_state = 0, .external_lex_state = 5},
  [1207] = {.lex_state = 0, .external_lex_state = 5},
  [1208] = {.lex_state = 15, .external_lex_state = 5},
  [1209] = {.lex_state = 0, .external_lex_state = 5},
  [1210] = {.lex_state = 15, .external_lex_state = 5},
  [1211] = {.lex_state = 15, .external_lex_state = 5},
  [1212] = {.lex_state = 15, .external_lex_state = 5},
  [1213] = {.lex_state = 0, .external_lex_state = 5},
  [1214] = {.lex_state = 15, .external_lex_state = 5},
  [1215] = {.lex_state = 0, .external_lex_state = 5},
  [1216] = {.lex_state = 15, .external_lex_state = 5},
  [1217] = {.lex_state = 15, .external_lex_state = 5},
  [1218] = {.lex_state = 0, .external_lex_state = 5},
  [1219] = {.lex_state = 15, .external_lex_state = 5},
  [1220] = {.lex_state = 0, .external_lex_state = 5},
  [1221] = {.lex_state = 15, .external_lex_state = 5},
  [1222] = {.lex_state = 15, .external_lex_state = 5},
  [1223] = {.lex_state = 0, .external_lex_state = 5},
  [1224] = {.lex_state = 15, .external_lex_state = 5},
  [1225] = {.lex_state = 15, .external_lex_state = 5},
  [1226] = {.lex_state = 0, .external_lex_state = 5},
  [1227] = {.lex_state = 15, .external_lex_state = 5},
  [1228] = {.lex_state = 15, .external_lex_state = 5},
  [1229] = {.lex_state = 15, .external_lex_state = 5},
  [1230] = {.lex_state = 15, .external_lex_state = 5},
  [1231] = {.lex_state = 15, .external_lex_state = 5},
  [1232] = {.lex_state = 0, .external_lex_state = 5},
  [1233] = {.lex_state = 15, .external_lex_state = 5},
  [1234] = {.lex_state = 15, .external_lex_state = 5},
  [1235] = {.lex_state = 15, .external_lex_state = 5},
  [1236] = {.lex_state = 0, .external_lex_state = 5},
  [1237] = {.lex_state = 0, .external_lex_state = 5},
  [1238] = {.lex_state = 15, .external_lex_state = 5},
  [1239] = {.lex_state = 0, .external_lex_state = 5},
  [1240] = {.lex_state = 15, .external_lex_state = 5},
  [1241] = {.lex_state = 0, .external_lex_state = 5},
  [1242] = {.lex_state = 15, .external_lex_state = 5},
  [1243] = {.lex_state = 0, .external_lex_state = 5},
  [1244] = {.lex_state = 0, .external_lex_state = 5},
  [1245] = {.lex_state = 15, .external_lex_state = 5},
  [1246] = {.lex_state = 0, .external_lex_state = 5},
  [1247] = {.lex_state = 15, .external_lex_state = 5},
  [1248] = {.lex_state = 15, .external_lex_state = 5},
  [1249] = {.lex_state = 15, .external_lex_state = 5},
  [1250] = {.lex_state = 0, .external_lex_state = 5},
  [1251] = {.lex_state = 0, .external_lex_state = 5},
  [1252] = {.lex_state = 0, .external_lex_state = 5},
  [1253] = {.lex_state = 15, .external_lex_state = 5},
  [1254] = {.lex_state = 0, .external_lex_state = 5},
  [1255] = {.lex_state = 15, .external_lex_state = 5},
  [1256] = {.lex_state = 15, .external_lex_state = 5},
  [1257] = {.lex_state = 15, .external_lex_state = 5},
  [1258] = {.lex_state = 15, .external_lex_state = 5},
  [1259] = {.lex_state = 0, .external_lex_state = 5},
  [1260] = {.lex_state = 0, .external_lex_state = 5},
  [1261] = {.lex_state = 0, .external_lex_state = 5},
  [1262] = {.lex_state = 15, .external_lex_state = 5},
  [1263] = {.lex_state = 0, .external_lex_state = 5},
  [1264] = {.lex_state = 0, .external_lex_state = 5},
  [1265] = {.lex_state = 0, .external_lex_state = 5},
  [1266] = {.lex_state = 15, .external_lex_state = 5},
  [1267] = {.lex_state = 15, .external_lex_state = 5},
  [1268] = {.lex_state = 15, .external_lex_state = 5},
  [1269] = {.lex_state = 0, .external_lex_state = 5},
  [1270] = {.lex_state = 15, .external_lex_state = 5},
  [1271] = {.lex_state = 15, .external_lex_state = 5},
  [1272] = {.lex_state = 0, .external_lex_state = 5},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [0] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym_identifier] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_DOT_PLUS] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_DOT_DASH] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_DOT_STAR] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_DOT_SLASH] = ACTIONS(1),
    [anon_sym_BSLASH] = ACTIONS(1),
    [anon_sym_DOT_BSLASH] = ACTIONS(1),
    [anon_sym_CARET] = ACTIONS(1),
    [anon_sym_DOT_CARET] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_AMP] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [anon_sym_AT] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_EQ_EQ] = ACTIONS(1),
    [anon_sym_TILDE_EQ] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_AMP_AMP] = ACTIONS(1),
    [anon_sym_PIPE_PIPE] = ACTIONS(1),
    [anon_sym_DOT_SQUOTE] = ACTIONS(1),
    [anon_sym_SQUOTE] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [sym_return_statement] = ACTIONS(1),
    [sym_continue_statement] = ACTIONS(1),
    [sym_break_statement] = ACTIONS(1),
    [anon_sym_elseif] = ACTIONS(1),
    [anon_sym_else] = ACTIONS(1),
    [anon_sym_if] = ACTIONS(1),
    [anon_sym_end] = ACTIONS(1),
    [anon_sym_for] = ACTIONS(1),
    [anon_sym_parfor] = ACTIONS(1),
    [anon_sym_while] = ACTIONS(1),
    [anon_sym_case] = ACTIONS(1),
    [anon_sym_otherwise] = ACTIONS(1),
    [anon_sym_switch] = ACTIONS(1),
    [anon_sym_global] = ACTIONS(1),
    [anon_sym_persistent] = ACTIONS(1),
    [anon_sym_arguments] = ACTIONS(1),
    [anon_sym_function] = ACTIONS(1),
    [anon_sym_get_DOT] = ACTIONS(1),
    [anon_sym_set_DOT] = ACTIONS(1),
    [anon_sym_endfunction] = ACTIONS(1),
    [anon_sym_vector] = ACTIONS(1),
    [anon_sym_matrix] = ACTIONS(1),
    [anon_sym_scalar] = ACTIONS(1),
    [anon_sym_properties] = ACTIONS(1),
    [anon_sym_methods] = ACTIONS(1),
    [anon_sym_events] = ACTIONS(1),
    [anon_sym_enumeration] = ACTIONS(1),
    [anon_sym_classdef] = ACTIONS(1),
    [anon_sym_catch] = ACTIONS(1),
    [anon_sym_try] = ACTIONS(1),
    [sym_number] = ACTIONS(1),
    [anon_sym_true] = ACTIONS(1),
    [anon_sym_false] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(1),
    [sym_command_argument] = ACTIONS(1),
    [sym__single_quote_string_start] = ACTIONS(1),
    [sym__single_quote_string_end] = ACTIONS(1),
    [sym__double_quote_string_start] = ACTIONS(1),
    [sym__double_quote_string_end] = ACTIONS(1),
    [sym_formatting_sequence] = ACTIONS(1),
    [sym_escape_sequence] = ACTIONS(1),
    [sym_string_content] = ACTIONS(1),
    [sym__entry_delimiter] = ACTIONS(1),
    [sym__multioutput_variable_start] = ACTIONS(1),
    [sym_error_sentinel] = ACTIONS(1),
  },
  [1] = {
    [sym_source_file] = STATE(1260),
    [aux_sym__block] = STATE(71),
    [sym__statement] = STATE(848),
    [sym__expression] = STATE(624),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(624),
    [sym_handle_operator] = STATE(624),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(848),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(848),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(624),
    [sym_if_statement] = STATE(848),
    [sym_for_statement] = STATE(848),
    [sym_while_statement] = STATE(848),
    [sym_switch_statement] = STATE(848),
    [sym_lambda] = STATE(624),
    [sym_global_operator] = STATE(848),
    [sym_persistent_operator] = STATE(848),
    [sym_function_definition] = STATE(987),
    [sym__function_definition_with_end] = STATE(871),
    [sym_class_definition] = STATE(848),
    [sym_try_statement] = STATE(848),
    [sym_boolean] = STATE(214),
    [aux_sym_source_file_repeat1] = STATE(987),
    [ts_builtin_sym_end] = ACTIONS(5),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(23),
    [sym_continue_statement] = ACTIONS(23),
    [sym_break_statement] = ACTIONS(23),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(39),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [2] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(800),
    [sym__statement] = STATE(865),
    [sym__expression] = STATE(622),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(622),
    [sym_handle_operator] = STATE(622),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(865),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(865),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(622),
    [sym_elseif_clause] = STATE(801),
    [sym_else_clause] = STATE(1190),
    [sym_if_statement] = STATE(865),
    [sym_for_statement] = STATE(865),
    [sym_while_statement] = STATE(865),
    [sym_switch_statement] = STATE(865),
    [sym_lambda] = STATE(622),
    [sym_global_operator] = STATE(865),
    [sym_persistent_operator] = STATE(865),
    [sym__function_definition_with_end] = STATE(867),
    [sym_class_definition] = STATE(865),
    [sym_try_statement] = STATE(865),
    [sym_boolean] = STATE(214),
    [sym__end_of_line] = STATE(5),
    [aux_sym_elseif_clause_repeat1] = STATE(5),
    [aux_sym_if_statement_repeat1] = STATE(801),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(57),
    [anon_sym_COMMA] = ACTIONS(57),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LT] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_GT] = ACTIONS(69),
    [anon_sym_AMP_AMP] = ACTIONS(71),
    [anon_sym_PIPE_PIPE] = ACTIONS(73),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_elseif] = ACTIONS(81),
    [anon_sym_else] = ACTIONS(83),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(85),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(57),
    [anon_sym_CR] = ACTIONS(57),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [3] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(1051),
    [sym__statement] = STATE(865),
    [sym__expression] = STATE(622),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(622),
    [sym_handle_operator] = STATE(622),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(865),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(865),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(622),
    [sym_if_statement] = STATE(865),
    [sym_for_statement] = STATE(865),
    [sym_while_statement] = STATE(865),
    [sym_switch_statement] = STATE(865),
    [sym_lambda] = STATE(622),
    [sym_global_operator] = STATE(865),
    [sym_persistent_operator] = STATE(865),
    [sym__function_definition_with_end] = STATE(867),
    [sym_class_definition] = STATE(865),
    [sym_try_statement] = STATE(865),
    [sym_boolean] = STATE(214),
    [sym__end_of_line] = STATE(8),
    [aux_sym_elseif_clause_repeat1] = STATE(8),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(91),
    [anon_sym_COMMA] = ACTIONS(91),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LT] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_GT] = ACTIONS(69),
    [anon_sym_AMP_AMP] = ACTIONS(71),
    [anon_sym_PIPE_PIPE] = ACTIONS(73),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_elseif] = ACTIONS(93),
    [anon_sym_else] = ACTIONS(93),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(93),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(91),
    [anon_sym_CR] = ACTIONS(91),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [4] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(1256),
    [sym__statement] = STATE(865),
    [sym__expression] = STATE(622),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(622),
    [sym_handle_operator] = STATE(622),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(865),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(865),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(622),
    [sym_if_statement] = STATE(865),
    [sym_for_statement] = STATE(865),
    [sym_while_statement] = STATE(865),
    [sym_switch_statement] = STATE(865),
    [sym_lambda] = STATE(622),
    [sym_global_operator] = STATE(865),
    [sym_persistent_operator] = STATE(865),
    [sym__function_definition_with_end] = STATE(867),
    [sym_class_definition] = STATE(865),
    [sym_try_statement] = STATE(865),
    [sym_boolean] = STATE(214),
    [sym__end_of_line] = STATE(13),
    [aux_sym_elseif_clause_repeat1] = STATE(13),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(95),
    [anon_sym_COMMA] = ACTIONS(95),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LT] = ACTIONS(69),
    [anon_sym_LT_EQ] = ACTIONS(69),
    [anon_sym_EQ_EQ] = ACTIONS(69),
    [anon_sym_TILDE_EQ] = ACTIONS(69),
    [anon_sym_GT_EQ] = ACTIONS(69),
    [anon_sym_GT] = ACTIONS(69),
    [anon_sym_AMP_AMP] = ACTIONS(71),
    [anon_sym_PIPE_PIPE] = ACTIONS(73),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(97),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(95),
    [anon_sym_CR] = ACTIONS(95),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [5] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(762),
    [sym__statement] = STATE(865),
    [sym__expression] = STATE(622),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(622),
    [sym_handle_operator] = STATE(622),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(865),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(865),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(622),
    [sym_elseif_clause] = STATE(761),
    [sym_else_clause] = STATE(1248),
    [sym_if_statement] = STATE(865),
    [sym_for_statement] = STATE(865),
    [sym_while_statement] = STATE(865),
    [sym_switch_statement] = STATE(865),
    [sym_lambda] = STATE(622),
    [sym_global_operator] = STATE(865),
    [sym_persistent_operator] = STATE(865),
    [sym__function_definition_with_end] = STATE(867),
    [sym_class_definition] = STATE(865),
    [sym_try_statement] = STATE(865),
    [sym_boolean] = STATE(214),
    [sym__end_of_line] = STATE(160),
    [aux_sym_elseif_clause_repeat1] = STATE(160),
    [aux_sym_if_statement_repeat1] = STATE(761),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_elseif] = ACTIONS(81),
    [anon_sym_else] = ACTIONS(83),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(101),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(99),
    [anon_sym_CR] = ACTIONS(99),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [6] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(1064),
    [sym__statement] = STATE(865),
    [sym__expression] = STATE(622),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(622),
    [sym_handle_operator] = STATE(622),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(865),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(865),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(622),
    [sym_if_statement] = STATE(865),
    [sym_for_statement] = STATE(865),
    [sym_while_statement] = STATE(865),
    [sym_switch_statement] = STATE(865),
    [sym_lambda] = STATE(622),
    [sym_global_operator] = STATE(865),
    [sym_persistent_operator] = STATE(865),
    [sym__function_definition_with_end] = STATE(867),
    [sym_class_definition] = STATE(865),
    [sym_catch_clause] = STATE(1228),
    [sym_try_statement] = STATE(865),
    [sym_boolean] = STATE(214),
    [sym__end_of_line] = STATE(7),
    [aux_sym_elseif_clause_repeat1] = STATE(7),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(103),
    [anon_sym_COMMA] = ACTIONS(103),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(105),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_catch] = ACTIONS(107),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(103),
    [anon_sym_CR] = ACTIONS(103),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [7] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(1076),
    [sym__statement] = STATE(865),
    [sym__expression] = STATE(622),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(622),
    [sym_handle_operator] = STATE(622),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(865),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(865),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(622),
    [sym_if_statement] = STATE(865),
    [sym_for_statement] = STATE(865),
    [sym_while_statement] = STATE(865),
    [sym_switch_statement] = STATE(865),
    [sym_lambda] = STATE(622),
    [sym_global_operator] = STATE(865),
    [sym_persistent_operator] = STATE(865),
    [sym__function_definition_with_end] = STATE(867),
    [sym_class_definition] = STATE(865),
    [sym_catch_clause] = STATE(1199),
    [sym_try_statement] = STATE(865),
    [sym_boolean] = STATE(214),
    [sym__end_of_line] = STATE(160),
    [aux_sym_elseif_clause_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(109),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_catch] = ACTIONS(107),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(99),
    [anon_sym_CR] = ACTIONS(99),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [8] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(1050),
    [sym__statement] = STATE(865),
    [sym__expression] = STATE(622),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(622),
    [sym_handle_operator] = STATE(622),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(865),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(865),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(622),
    [sym_if_statement] = STATE(865),
    [sym_for_statement] = STATE(865),
    [sym_while_statement] = STATE(865),
    [sym_switch_statement] = STATE(865),
    [sym_lambda] = STATE(622),
    [sym_global_operator] = STATE(865),
    [sym_persistent_operator] = STATE(865),
    [sym__function_definition_with_end] = STATE(867),
    [sym_class_definition] = STATE(865),
    [sym_try_statement] = STATE(865),
    [sym_boolean] = STATE(214),
    [sym__end_of_line] = STATE(160),
    [aux_sym_elseif_clause_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_elseif] = ACTIONS(111),
    [anon_sym_else] = ACTIONS(111),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(111),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(99),
    [anon_sym_CR] = ACTIONS(99),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [9] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(1052),
    [sym__statement] = STATE(865),
    [sym__expression] = STATE(622),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(622),
    [sym_handle_operator] = STATE(622),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(865),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(865),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(622),
    [sym_if_statement] = STATE(865),
    [sym_for_statement] = STATE(865),
    [sym_while_statement] = STATE(865),
    [sym_switch_statement] = STATE(865),
    [sym_lambda] = STATE(622),
    [sym_global_operator] = STATE(865),
    [sym_persistent_operator] = STATE(865),
    [sym__function_definition_with_end] = STATE(867),
    [sym_class_definition] = STATE(865),
    [sym_try_statement] = STATE(865),
    [sym_boolean] = STATE(214),
    [sym__end_of_line] = STATE(160),
    [aux_sym_elseif_clause_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(113),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_case] = ACTIONS(113),
    [anon_sym_otherwise] = ACTIONS(113),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(99),
    [anon_sym_CR] = ACTIONS(99),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [10] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(1238),
    [sym__statement] = STATE(865),
    [sym__expression] = STATE(622),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(622),
    [sym_handle_operator] = STATE(622),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(865),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(865),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(622),
    [sym_if_statement] = STATE(865),
    [sym_for_statement] = STATE(865),
    [sym_while_statement] = STATE(865),
    [sym_switch_statement] = STATE(865),
    [sym_lambda] = STATE(622),
    [sym_global_operator] = STATE(865),
    [sym_persistent_operator] = STATE(865),
    [sym__function_definition_with_end] = STATE(867),
    [sym_class_definition] = STATE(865),
    [sym_try_statement] = STATE(865),
    [sym_boolean] = STATE(214),
    [sym__end_of_line] = STATE(12),
    [aux_sym_elseif_clause_repeat1] = STATE(12),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(115),
    [anon_sym_COMMA] = ACTIONS(115),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(117),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(115),
    [anon_sym_CR] = ACTIONS(115),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [11] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(1192),
    [sym__statement] = STATE(865),
    [sym__expression] = STATE(622),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(622),
    [sym_handle_operator] = STATE(622),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(865),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(865),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(622),
    [sym_if_statement] = STATE(865),
    [sym_for_statement] = STATE(865),
    [sym_while_statement] = STATE(865),
    [sym_switch_statement] = STATE(865),
    [sym_lambda] = STATE(622),
    [sym_global_operator] = STATE(865),
    [sym_persistent_operator] = STATE(865),
    [sym__function_definition_with_end] = STATE(867),
    [sym_class_definition] = STATE(865),
    [sym_try_statement] = STATE(865),
    [sym_boolean] = STATE(214),
    [sym__end_of_line] = STATE(18),
    [aux_sym_elseif_clause_repeat1] = STATE(18),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(119),
    [anon_sym_COMMA] = ACTIONS(119),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(121),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(119),
    [anon_sym_CR] = ACTIONS(119),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [12] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(1258),
    [sym__statement] = STATE(865),
    [sym__expression] = STATE(622),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(622),
    [sym_handle_operator] = STATE(622),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(865),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(865),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(622),
    [sym_if_statement] = STATE(865),
    [sym_for_statement] = STATE(865),
    [sym_while_statement] = STATE(865),
    [sym_switch_statement] = STATE(865),
    [sym_lambda] = STATE(622),
    [sym_global_operator] = STATE(865),
    [sym_persistent_operator] = STATE(865),
    [sym__function_definition_with_end] = STATE(867),
    [sym_class_definition] = STATE(865),
    [sym_try_statement] = STATE(865),
    [sym_boolean] = STATE(214),
    [sym__end_of_line] = STATE(160),
    [aux_sym_elseif_clause_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(123),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(99),
    [anon_sym_CR] = ACTIONS(99),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [13] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(1266),
    [sym__statement] = STATE(865),
    [sym__expression] = STATE(622),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(622),
    [sym_handle_operator] = STATE(622),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(865),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(865),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(622),
    [sym_if_statement] = STATE(865),
    [sym_for_statement] = STATE(865),
    [sym_while_statement] = STATE(865),
    [sym_switch_statement] = STATE(865),
    [sym_lambda] = STATE(622),
    [sym_global_operator] = STATE(865),
    [sym_persistent_operator] = STATE(865),
    [sym__function_definition_with_end] = STATE(867),
    [sym_class_definition] = STATE(865),
    [sym_try_statement] = STATE(865),
    [sym_boolean] = STATE(214),
    [sym__end_of_line] = STATE(160),
    [aux_sym_elseif_clause_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(125),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(99),
    [anon_sym_CR] = ACTIONS(99),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [14] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(1247),
    [sym__statement] = STATE(865),
    [sym__expression] = STATE(622),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(622),
    [sym_handle_operator] = STATE(622),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(865),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(865),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(622),
    [sym_if_statement] = STATE(865),
    [sym_for_statement] = STATE(865),
    [sym_while_statement] = STATE(865),
    [sym_switch_statement] = STATE(865),
    [sym_lambda] = STATE(622),
    [sym_global_operator] = STATE(865),
    [sym_persistent_operator] = STATE(865),
    [sym__function_definition_with_end] = STATE(867),
    [sym_class_definition] = STATE(865),
    [sym_try_statement] = STATE(865),
    [sym_boolean] = STATE(214),
    [sym__end_of_line] = STATE(15),
    [aux_sym_elseif_clause_repeat1] = STATE(15),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(127),
    [anon_sym_COMMA] = ACTIONS(127),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(129),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(127),
    [anon_sym_CR] = ACTIONS(127),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [15] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(1181),
    [sym__statement] = STATE(865),
    [sym__expression] = STATE(622),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(622),
    [sym_handle_operator] = STATE(622),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(865),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(865),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(622),
    [sym_if_statement] = STATE(865),
    [sym_for_statement] = STATE(865),
    [sym_while_statement] = STATE(865),
    [sym_switch_statement] = STATE(865),
    [sym_lambda] = STATE(622),
    [sym_global_operator] = STATE(865),
    [sym_persistent_operator] = STATE(865),
    [sym__function_definition_with_end] = STATE(867),
    [sym_class_definition] = STATE(865),
    [sym_try_statement] = STATE(865),
    [sym_boolean] = STATE(214),
    [sym__end_of_line] = STATE(160),
    [aux_sym_elseif_clause_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(131),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(99),
    [anon_sym_CR] = ACTIONS(99),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [16] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(1240),
    [sym__statement] = STATE(865),
    [sym__expression] = STATE(622),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(622),
    [sym_handle_operator] = STATE(622),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(865),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(865),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(622),
    [sym_if_statement] = STATE(865),
    [sym_for_statement] = STATE(865),
    [sym_while_statement] = STATE(865),
    [sym_switch_statement] = STATE(865),
    [sym_lambda] = STATE(622),
    [sym_global_operator] = STATE(865),
    [sym_persistent_operator] = STATE(865),
    [sym__function_definition_with_end] = STATE(867),
    [sym_class_definition] = STATE(865),
    [sym_try_statement] = STATE(865),
    [sym_boolean] = STATE(214),
    [sym__end_of_line] = STATE(160),
    [aux_sym_elseif_clause_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(133),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(99),
    [anon_sym_CR] = ACTIONS(99),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [17] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(1230),
    [sym__statement] = STATE(865),
    [sym__expression] = STATE(622),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(622),
    [sym_handle_operator] = STATE(622),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(865),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(865),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(622),
    [sym_if_statement] = STATE(865),
    [sym_for_statement] = STATE(865),
    [sym_while_statement] = STATE(865),
    [sym_switch_statement] = STATE(865),
    [sym_lambda] = STATE(622),
    [sym_global_operator] = STATE(865),
    [sym_persistent_operator] = STATE(865),
    [sym__function_definition_with_end] = STATE(867),
    [sym_class_definition] = STATE(865),
    [sym_try_statement] = STATE(865),
    [sym_boolean] = STATE(214),
    [sym__end_of_line] = STATE(160),
    [aux_sym_elseif_clause_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(135),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(99),
    [anon_sym_CR] = ACTIONS(99),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [18] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(1233),
    [sym__statement] = STATE(865),
    [sym__expression] = STATE(622),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(622),
    [sym_handle_operator] = STATE(622),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(865),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(865),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(622),
    [sym_if_statement] = STATE(865),
    [sym_for_statement] = STATE(865),
    [sym_while_statement] = STATE(865),
    [sym_switch_statement] = STATE(865),
    [sym_lambda] = STATE(622),
    [sym_global_operator] = STATE(865),
    [sym_persistent_operator] = STATE(865),
    [sym__function_definition_with_end] = STATE(867),
    [sym_class_definition] = STATE(865),
    [sym_try_statement] = STATE(865),
    [sym_boolean] = STATE(214),
    [sym__end_of_line] = STATE(160),
    [aux_sym_elseif_clause_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(137),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(99),
    [anon_sym_CR] = ACTIONS(99),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [19] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(1242),
    [sym__statement] = STATE(865),
    [sym__expression] = STATE(622),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(622),
    [sym_handle_operator] = STATE(622),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(865),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(865),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(622),
    [sym_if_statement] = STATE(865),
    [sym_for_statement] = STATE(865),
    [sym_while_statement] = STATE(865),
    [sym_switch_statement] = STATE(865),
    [sym_lambda] = STATE(622),
    [sym_global_operator] = STATE(865),
    [sym_persistent_operator] = STATE(865),
    [sym__function_definition_with_end] = STATE(867),
    [sym_class_definition] = STATE(865),
    [sym_try_statement] = STATE(865),
    [sym_boolean] = STATE(214),
    [sym__end_of_line] = STATE(20),
    [aux_sym_elseif_clause_repeat1] = STATE(20),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_COMMA] = ACTIONS(139),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(141),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(139),
    [anon_sym_CR] = ACTIONS(139),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [20] = {
    [aux_sym__block] = STATE(48),
    [sym_block] = STATE(1234),
    [sym__statement] = STATE(865),
    [sym__expression] = STATE(622),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(622),
    [sym_handle_operator] = STATE(622),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(865),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(865),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(622),
    [sym_if_statement] = STATE(865),
    [sym_for_statement] = STATE(865),
    [sym_while_statement] = STATE(865),
    [sym_switch_statement] = STATE(865),
    [sym_lambda] = STATE(622),
    [sym_global_operator] = STATE(865),
    [sym_persistent_operator] = STATE(865),
    [sym__function_definition_with_end] = STATE(867),
    [sym_class_definition] = STATE(865),
    [sym_try_statement] = STATE(865),
    [sym_boolean] = STATE(214),
    [sym__end_of_line] = STATE(160),
    [aux_sym_elseif_clause_repeat1] = STATE(160),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_SEMI] = ACTIONS(99),
    [anon_sym_COMMA] = ACTIONS(99),
    [anon_sym_LPAREN] = ACTIONS(59),
    [anon_sym_PLUS] = ACTIONS(61),
    [anon_sym_DASH] = ACTIONS(61),
    [anon_sym_TILDE] = ACTIONS(63),
    [anon_sym_QMARK] = ACTIONS(65),
    [anon_sym_AT] = ACTIONS(67),
    [anon_sym_LBRACK] = ACTIONS(75),
    [anon_sym_LBRACE] = ACTIONS(77),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(143),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(89),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [anon_sym_LF] = ACTIONS(99),
    [anon_sym_CR] = ACTIONS(99),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [21] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(973),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(42),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(42),
    [ts_builtin_sym_end] = ACTIONS(145),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(149),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(149),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [22] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(967),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(271),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(271),
    [ts_builtin_sym_end] = ACTIONS(153),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(155),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(155),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [23] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(972),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(30),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(30),
    [ts_builtin_sym_end] = ACTIONS(157),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(159),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(159),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [24] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(915),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(32),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(32),
    [ts_builtin_sym_end] = ACTIONS(161),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(163),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(163),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [25] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(915),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(271),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(271),
    [ts_builtin_sym_end] = ACTIONS(161),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(163),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(163),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [26] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(927),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(271),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(271),
    [ts_builtin_sym_end] = ACTIONS(165),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(167),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(167),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [27] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(937),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(34),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(34),
    [ts_builtin_sym_end] = ACTIONS(145),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(169),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(169),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [28] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(1015),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(36),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(36),
    [ts_builtin_sym_end] = ACTIONS(171),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(173),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(173),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [29] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(1017),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(37),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(37),
    [ts_builtin_sym_end] = ACTIONS(153),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(175),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(175),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [30] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(1017),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(271),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(271),
    [ts_builtin_sym_end] = ACTIONS(153),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(175),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(175),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [31] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(962),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(22),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(22),
    [ts_builtin_sym_end] = ACTIONS(157),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(177),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(177),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [32] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(1030),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(271),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(271),
    [ts_builtin_sym_end] = ACTIONS(179),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(181),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(181),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [33] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(918),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(39),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(39),
    [ts_builtin_sym_end] = ACTIONS(183),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(185),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [34] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(918),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(271),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(271),
    [ts_builtin_sym_end] = ACTIONS(183),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(185),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(185),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [35] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(956),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(40),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(40),
    [ts_builtin_sym_end] = ACTIONS(161),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(187),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(187),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [36] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(956),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(271),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(271),
    [ts_builtin_sym_end] = ACTIONS(161),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(187),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(187),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [37] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(964),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(271),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(271),
    [ts_builtin_sym_end] = ACTIONS(165),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(189),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(189),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [38] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(958),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(25),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(25),
    [ts_builtin_sym_end] = ACTIONS(171),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(191),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(191),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [39] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(1028),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(271),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(271),
    [ts_builtin_sym_end] = ACTIONS(193),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(195),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(195),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [40] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(1016),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(271),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(271),
    [ts_builtin_sym_end] = ACTIONS(179),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(197),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(197),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [41] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(992),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(43),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(43),
    [ts_builtin_sym_end] = ACTIONS(183),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(199),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(199),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [42] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(992),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(271),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(271),
    [ts_builtin_sym_end] = ACTIONS(183),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(199),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(199),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [43] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(920),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(271),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(271),
    [ts_builtin_sym_end] = ACTIONS(193),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(201),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(201),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [44] = {
    [aux_sym__block] = STATE(72),
    [sym_block] = STATE(967),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(26),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(26),
    [ts_builtin_sym_end] = ACTIONS(153),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(155),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(155),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [45] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1161),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(46),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(46),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(203),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(203),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [46] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1124),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(271),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(271),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(205),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(205),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [47] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1140),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(271),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(271),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(207),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(207),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [48] = {
    [aux_sym__block] = STATE(60),
    [sym__statement] = STATE(865),
    [sym__expression] = STATE(622),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(622),
    [sym_handle_operator] = STATE(622),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(865),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(865),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(622),
    [sym_if_statement] = STATE(865),
    [sym_for_statement] = STATE(865),
    [sym_while_statement] = STATE(865),
    [sym_switch_statement] = STATE(865),
    [sym_lambda] = STATE(622),
    [sym_global_operator] = STATE(865),
    [sym_persistent_operator] = STATE(865),
    [sym__function_definition_with_end] = STATE(867),
    [sym_class_definition] = STATE(865),
    [sym_try_statement] = STATE(865),
    [sym_boolean] = STATE(214),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(79),
    [sym_continue_statement] = ACTIONS(79),
    [sym_break_statement] = ACTIONS(79),
    [anon_sym_elseif] = ACTIONS(209),
    [anon_sym_else] = ACTIONS(209),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(209),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_case] = ACTIONS(209),
    [anon_sym_otherwise] = ACTIONS(209),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_catch] = ACTIONS(209),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [49] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1145),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(50),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(50),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(211),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(211),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [50] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1168),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(271),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(271),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(213),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(213),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [51] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1119),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(55),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(55),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(215),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(215),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [52] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1119),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(271),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(271),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(215),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(215),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [53] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1144),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(271),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(271),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(217),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(217),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [54] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1145),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(271),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(271),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(211),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(211),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [55] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1159),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(271),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(271),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(219),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(219),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [56] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1112),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(52),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(52),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(221),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(221),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [57] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1120),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(54),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(54),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(223),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(223),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [58] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1130),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(271),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(271),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(225),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(225),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [59] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1124),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(53),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(53),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(205),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(205),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [60] = {
    [aux_sym__block] = STATE(60),
    [sym__statement] = STATE(865),
    [sym__expression] = STATE(622),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(622),
    [sym_handle_operator] = STATE(622),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(865),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(865),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(622),
    [sym_if_statement] = STATE(865),
    [sym_for_statement] = STATE(865),
    [sym_while_statement] = STATE(865),
    [sym_switch_statement] = STATE(865),
    [sym_lambda] = STATE(622),
    [sym_global_operator] = STATE(865),
    [sym_persistent_operator] = STATE(865),
    [sym__function_definition_with_end] = STATE(867),
    [sym_class_definition] = STATE(865),
    [sym_try_statement] = STATE(865),
    [sym_boolean] = STATE(214),
    [sym_identifier] = ACTIONS(227),
    [anon_sym_LPAREN] = ACTIONS(230),
    [anon_sym_PLUS] = ACTIONS(233),
    [anon_sym_DASH] = ACTIONS(233),
    [anon_sym_TILDE] = ACTIONS(236),
    [anon_sym_QMARK] = ACTIONS(239),
    [anon_sym_AT] = ACTIONS(242),
    [anon_sym_LBRACK] = ACTIONS(245),
    [anon_sym_LBRACE] = ACTIONS(248),
    [sym_return_statement] = ACTIONS(251),
    [sym_continue_statement] = ACTIONS(251),
    [sym_break_statement] = ACTIONS(251),
    [anon_sym_elseif] = ACTIONS(254),
    [anon_sym_else] = ACTIONS(254),
    [anon_sym_if] = ACTIONS(256),
    [anon_sym_end] = ACTIONS(254),
    [anon_sym_for] = ACTIONS(259),
    [anon_sym_parfor] = ACTIONS(262),
    [anon_sym_while] = ACTIONS(265),
    [anon_sym_case] = ACTIONS(254),
    [anon_sym_otherwise] = ACTIONS(254),
    [anon_sym_switch] = ACTIONS(268),
    [anon_sym_global] = ACTIONS(271),
    [anon_sym_persistent] = ACTIONS(274),
    [anon_sym_function] = ACTIONS(277),
    [anon_sym_classdef] = ACTIONS(280),
    [anon_sym_catch] = ACTIONS(254),
    [anon_sym_try] = ACTIONS(283),
    [sym_number] = ACTIONS(286),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(292),
    [sym__single_quote_string_start] = ACTIONS(295),
    [sym__double_quote_string_start] = ACTIONS(298),
    [sym__multioutput_variable_start] = ACTIONS(301),
  },
  [61] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1113),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(64),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(64),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(304),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(304),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [62] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1115),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(66),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(66),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(306),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(306),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [63] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1117),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(58),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(58),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(308),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(308),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [64] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1117),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(271),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(271),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(308),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(308),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [65] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1125),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(67),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(67),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(310),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(310),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [66] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1125),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(271),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(271),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(310),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(310),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [67] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1135),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(271),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(271),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(312),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(312),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [68] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1131),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(70),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(70),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(314),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(314),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [69] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1138),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(47),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(47),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(316),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(316),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [70] = {
    [aux_sym__block] = STATE(74),
    [sym_block] = STATE(1138),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym_arguments_statement] = STATE(271),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [aux_sym_function_definition_repeat1] = STATE(271),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(316),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_arguments] = ACTIONS(151),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(316),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [71] = {
    [aux_sym__block] = STATE(75),
    [sym__statement] = STATE(848),
    [sym__expression] = STATE(624),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(624),
    [sym_handle_operator] = STATE(624),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(848),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(848),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(624),
    [sym_if_statement] = STATE(848),
    [sym_for_statement] = STATE(848),
    [sym_while_statement] = STATE(848),
    [sym_switch_statement] = STATE(848),
    [sym_lambda] = STATE(624),
    [sym_global_operator] = STATE(848),
    [sym_persistent_operator] = STATE(848),
    [sym_function_definition] = STATE(933),
    [sym__function_definition_with_end] = STATE(871),
    [sym_class_definition] = STATE(848),
    [sym_try_statement] = STATE(848),
    [sym_boolean] = STATE(214),
    [aux_sym_source_file_repeat1] = STATE(933),
    [ts_builtin_sym_end] = ACTIONS(318),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(23),
    [sym_continue_statement] = ACTIONS(23),
    [sym_break_statement] = ACTIONS(23),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(39),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [72] = {
    [aux_sym__block] = STATE(73),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [ts_builtin_sym_end] = ACTIONS(320),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(209),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(322),
    [anon_sym_endfunction] = ACTIONS(209),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [73] = {
    [aux_sym__block] = STATE(73),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [ts_builtin_sym_end] = ACTIONS(325),
    [sym_identifier] = ACTIONS(227),
    [anon_sym_LPAREN] = ACTIONS(230),
    [anon_sym_PLUS] = ACTIONS(233),
    [anon_sym_DASH] = ACTIONS(233),
    [anon_sym_TILDE] = ACTIONS(236),
    [anon_sym_QMARK] = ACTIONS(239),
    [anon_sym_AT] = ACTIONS(242),
    [anon_sym_LBRACK] = ACTIONS(245),
    [anon_sym_LBRACE] = ACTIONS(248),
    [sym_return_statement] = ACTIONS(327),
    [sym_continue_statement] = ACTIONS(327),
    [sym_break_statement] = ACTIONS(327),
    [anon_sym_if] = ACTIONS(256),
    [anon_sym_end] = ACTIONS(254),
    [anon_sym_for] = ACTIONS(259),
    [anon_sym_parfor] = ACTIONS(262),
    [anon_sym_while] = ACTIONS(265),
    [anon_sym_switch] = ACTIONS(268),
    [anon_sym_global] = ACTIONS(271),
    [anon_sym_persistent] = ACTIONS(274),
    [anon_sym_function] = ACTIONS(277),
    [anon_sym_endfunction] = ACTIONS(254),
    [anon_sym_classdef] = ACTIONS(280),
    [anon_sym_try] = ACTIONS(283),
    [sym_number] = ACTIONS(286),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(292),
    [sym__single_quote_string_start] = ACTIONS(295),
    [sym__double_quote_string_start] = ACTIONS(298),
    [sym__multioutput_variable_start] = ACTIONS(301),
  },
  [74] = {
    [aux_sym__block] = STATE(73),
    [sym__statement] = STATE(878),
    [sym__expression] = STATE(626),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(626),
    [sym_handle_operator] = STATE(626),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(878),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(878),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(626),
    [sym_if_statement] = STATE(878),
    [sym_for_statement] = STATE(878),
    [sym_while_statement] = STATE(878),
    [sym_switch_statement] = STATE(878),
    [sym_lambda] = STATE(626),
    [sym_global_operator] = STATE(878),
    [sym_persistent_operator] = STATE(878),
    [sym__function_definition_with_end] = STATE(880),
    [sym_class_definition] = STATE(878),
    [sym_try_statement] = STATE(878),
    [sym_boolean] = STATE(214),
    [sym_identifier] = ACTIONS(7),
    [anon_sym_LPAREN] = ACTIONS(9),
    [anon_sym_PLUS] = ACTIONS(11),
    [anon_sym_DASH] = ACTIONS(11),
    [anon_sym_TILDE] = ACTIONS(13),
    [anon_sym_QMARK] = ACTIONS(15),
    [anon_sym_AT] = ACTIONS(17),
    [anon_sym_LBRACK] = ACTIONS(19),
    [anon_sym_LBRACE] = ACTIONS(21),
    [sym_return_statement] = ACTIONS(147),
    [sym_continue_statement] = ACTIONS(147),
    [sym_break_statement] = ACTIONS(147),
    [anon_sym_if] = ACTIONS(25),
    [anon_sym_end] = ACTIONS(209),
    [anon_sym_for] = ACTIONS(27),
    [anon_sym_parfor] = ACTIONS(29),
    [anon_sym_while] = ACTIONS(31),
    [anon_sym_switch] = ACTIONS(33),
    [anon_sym_global] = ACTIONS(35),
    [anon_sym_persistent] = ACTIONS(37),
    [anon_sym_function] = ACTIONS(87),
    [anon_sym_endfunction] = ACTIONS(209),
    [anon_sym_classdef] = ACTIONS(41),
    [anon_sym_try] = ACTIONS(43),
    [sym_number] = ACTIONS(45),
    [anon_sym_true] = ACTIONS(47),
    [anon_sym_false] = ACTIONS(47),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(49),
    [sym__single_quote_string_start] = ACTIONS(51),
    [sym__double_quote_string_start] = ACTIONS(53),
    [sym__multioutput_variable_start] = ACTIONS(55),
  },
  [75] = {
    [aux_sym__block] = STATE(75),
    [sym__statement] = STATE(848),
    [sym__expression] = STATE(624),
    [sym_parenthesis] = STATE(415),
    [sym__binary_expression] = STATE(614),
    [sym_binary_operator] = STATE(384),
    [sym_unary_operator] = STATE(411),
    [sym_indirect_access] = STATE(914),
    [sym_field_expression] = STATE(492),
    [sym_not_operator] = STATE(493),
    [sym_metaclass_operator] = STATE(624),
    [sym_handle_operator] = STATE(624),
    [sym_comparison_operator] = STATE(427),
    [sym_boolean_operator] = STATE(427),
    [sym_postfix_operator] = STATE(415),
    [sym_string] = STATE(415),
    [sym_matrix] = STATE(415),
    [sym_cell] = STATE(430),
    [sym_ignored_argument] = STATE(1179),
    [sym_assignment] = STATE(848),
    [sym_multioutput_variable] = STATE(1179),
    [sym_function_call] = STATE(211),
    [sym_command] = STATE(848),
    [sym__range_element] = STATE(1243),
    [sym_range] = STATE(624),
    [sym_if_statement] = STATE(848),
    [sym_for_statement] = STATE(848),
    [sym_while_statement] = STATE(848),
    [sym_switch_statement] = STATE(848),
    [sym_lambda] = STATE(624),
    [sym_global_operator] = STATE(848),
    [sym_persistent_operator] = STATE(848),
    [sym__function_definition_with_end] = STATE(871),
    [sym_class_definition] = STATE(848),
    [sym_try_statement] = STATE(848),
    [sym_boolean] = STATE(214),
    [ts_builtin_sym_end] = ACTIONS(325),
    [sym_identifier] = ACTIONS(227),
    [anon_sym_LPAREN] = ACTIONS(230),
    [anon_sym_PLUS] = ACTIONS(233),
    [anon_sym_DASH] = ACTIONS(233),
    [anon_sym_TILDE] = ACTIONS(236),
    [anon_sym_QMARK] = ACTIONS(239),
    [anon_sym_AT] = ACTIONS(242),
    [anon_sym_LBRACK] = ACTIONS(245),
    [anon_sym_LBRACE] = ACTIONS(248),
    [sym_return_statement] = ACTIONS(330),
    [sym_continue_statement] = ACTIONS(330),
    [sym_break_statement] = ACTIONS(330),
    [anon_sym_if] = ACTIONS(256),
    [anon_sym_for] = ACTIONS(259),
    [anon_sym_parfor] = ACTIONS(262),
    [anon_sym_while] = ACTIONS(265),
    [anon_sym_switch] = ACTIONS(268),
    [anon_sym_global] = ACTIONS(271),
    [anon_sym_persistent] = ACTIONS(274),
    [anon_sym_function] = ACTIONS(277),
    [anon_sym_classdef] = ACTIONS(280),
    [anon_sym_try] = ACTIONS(283),
    [sym_number] = ACTIONS(286),
    [anon_sym_true] = ACTIONS(289),
    [anon_sym_false] = ACTIONS(289),
    [sym_comment] = ACTIONS(3),
    [sym_line_continuation] = ACTIONS(3),
    [sym_command_name] = ACTIONS(292),
    [sym__single_quote_string_start] = ACTIONS(295),
    [sym__double_quote_string_start] = ACTIONS(298),
    [sym__multioutput_variable_start] = ACTIONS(301),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 10,
    ACTIONS(335), 1,
      anon_sym_LPAREN,
    ACTIONS(337), 1,
      anon_sym_DOT,
    ACTIONS(339), 1,
      anon_sym_AT,
    ACTIONS(343), 1,
      anon_sym_LBRACE,
    STATE(87), 1,
      aux_sym_field_expression_repeat1,
    STATE(94), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(341), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(345), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(333), 50,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [85] = 12,
    ACTIONS(335), 1,
      anon_sym_LPAREN,
    ACTIONS(337), 1,
      anon_sym_DOT,
    ACTIONS(339), 1,
      anon_sym_AT,
    ACTIONS(343), 1,
      anon_sym_LBRACE,
    ACTIONS(349), 1,
      anon_sym_COLON,
    STATE(87), 1,
      aux_sym_field_expression_repeat1,
    STATE(94), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(341), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 35,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [174] = 12,
    ACTIONS(335), 1,
      anon_sym_LPAREN,
    ACTIONS(337), 1,
      anon_sym_DOT,
    ACTIONS(339), 1,
      anon_sym_AT,
    ACTIONS(343), 1,
      anon_sym_LBRACE,
    ACTIONS(354), 1,
      anon_sym_COLON,
    STATE(87), 1,
      aux_sym_field_expression_repeat1,
    STATE(94), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(341), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 35,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [263] = 12,
    ACTIONS(335), 1,
      anon_sym_LPAREN,
    ACTIONS(337), 1,
      anon_sym_DOT,
    ACTIONS(339), 1,
      anon_sym_AT,
    ACTIONS(343), 1,
      anon_sym_LBRACE,
    STATE(87), 1,
      aux_sym_field_expression_repeat1,
    STATE(94), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(341), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(356), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(349), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(354), 28,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [352] = 10,
    ACTIONS(335), 1,
      anon_sym_LPAREN,
    ACTIONS(337), 1,
      anon_sym_DOT,
    ACTIONS(339), 1,
      anon_sym_AT,
    ACTIONS(343), 1,
      anon_sym_LBRACE,
    STATE(87), 1,
      aux_sym_field_expression_repeat1,
    STATE(94), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(341), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(358), 50,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [437] = 5,
    ACTIONS(364), 1,
      anon_sym_DOT,
    STATE(84), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(366), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(362), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [511] = 5,
    ACTIONS(364), 1,
      anon_sym_DOT,
    STATE(85), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(368), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [585] = 5,
    ACTIONS(364), 1,
      anon_sym_DOT,
    STATE(82), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(374), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(372), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [659] = 5,
    ACTIONS(364), 1,
      anon_sym_DOT,
    STATE(85), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(378), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(376), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [733] = 5,
    ACTIONS(382), 1,
      anon_sym_DOT,
    STATE(85), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(385), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(380), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [807] = 7,
    ACTIONS(335), 1,
      anon_sym_LPAREN,
    ACTIONS(339), 1,
      anon_sym_AT,
    ACTIONS(343), 1,
      anon_sym_LBRACE,
    STATE(94), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(389), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(387), 53,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [885] = 5,
    ACTIONS(337), 1,
      anon_sym_DOT,
    STATE(88), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(393), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(391), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [959] = 5,
    ACTIONS(397), 1,
      anon_sym_DOT,
    STATE(88), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(400), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(395), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1033] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(404), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(402), 56,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1102] = 10,
    ACTIONS(335), 1,
      anon_sym_LPAREN,
    ACTIONS(343), 1,
      anon_sym_LBRACE,
    ACTIONS(349), 1,
      anon_sym_COLON,
    ACTIONS(406), 1,
      anon_sym_AT,
    STATE(97), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(341), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 35,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1185] = 8,
    ACTIONS(335), 1,
      anon_sym_LPAREN,
    ACTIONS(343), 1,
      anon_sym_LBRACE,
    ACTIONS(406), 1,
      anon_sym_AT,
    STATE(97), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(341), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(345), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(333), 50,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1264] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(385), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(380), 56,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1333] = 10,
    ACTIONS(335), 1,
      anon_sym_LPAREN,
    ACTIONS(343), 1,
      anon_sym_LBRACE,
    ACTIONS(406), 1,
      anon_sym_AT,
    STATE(97), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(341), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(356), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(349), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(354), 28,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LBRACK,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1416] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(410), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(408), 56,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1485] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(414), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(412), 56,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1554] = 10,
    ACTIONS(335), 1,
      anon_sym_LPAREN,
    ACTIONS(343), 1,
      anon_sym_LBRACE,
    ACTIONS(354), 1,
      anon_sym_COLON,
    ACTIONS(406), 1,
      anon_sym_AT,
    STATE(97), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(341), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 35,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1637] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(418), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(416), 56,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1706] = 8,
    ACTIONS(335), 1,
      anon_sym_LPAREN,
    ACTIONS(343), 1,
      anon_sym_LBRACE,
    ACTIONS(406), 1,
      anon_sym_AT,
    STATE(97), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(341), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(358), 50,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1785] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(422), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(420), 56,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1854] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(426), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(424), 56,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1923] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(430), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(428), 56,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [1992] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(438), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(434), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(440), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(436), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(432), 43,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2066] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(341), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(358), 53,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2136] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(444), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(442), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2204] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(448), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(446), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2272] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(452), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(450), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2340] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(456), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(454), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2408] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(460), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(458), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2476] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(462), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2544] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(468), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(466), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2612] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(472), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(470), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2680] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(438), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(440), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(436), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(432), 47,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2752] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(438), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(440), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(432), 53,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2822] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(438), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(440), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(432), 53,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2892] = 7,
    ACTIONS(474), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(438), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(434), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(440), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(436), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(432), 42,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PIPE,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [2968] = 4,
    ACTIONS(478), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(480), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(476), 54,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3038] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(484), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(482), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3106] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(488), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(486), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3174] = 5,
    ACTIONS(495), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(497), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(492), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(490), 46,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3246] = 6,
    ACTIONS(354), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(341), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 38,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3320] = 6,
    ACTIONS(499), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(341), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 38,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3394] = 6,
    ACTIONS(501), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(341), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 38,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3468] = 6,
    ACTIONS(349), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(341), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 38,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3542] = 5,
    ACTIONS(349), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(352), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 40,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3614] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(508), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(506), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(504), 49,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3684] = 5,
    ACTIONS(510), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(508), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(506), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(504), 48,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3756] = 6,
    ACTIONS(510), 1,
      anon_sym_AMP_AMP,
    ACTIONS(514), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(516), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(506), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(512), 47,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3830] = 6,
    ACTIONS(510), 1,
      anon_sym_AMP_AMP,
    ACTIONS(514), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(520), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(506), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(518), 47,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3904] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(341), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(345), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(333), 53,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [3974] = 6,
    ACTIONS(522), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(341), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 38,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4048] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(341), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(345), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(333), 53,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4118] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(341), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(345), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(333), 53,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4188] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(341), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(356), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(349), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(354), 31,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4262] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(341), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(527), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(501), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(525), 31,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4336] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(356), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(349), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(354), 33,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4408] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(341), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(345), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(333), 53,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4478] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(341), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(529), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(522), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(499), 31,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4552] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(533), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(531), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4620] = 6,
    ACTIONS(525), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(341), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 38,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4694] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(352), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 41,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4764] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(341), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 39,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4836] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(537), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(535), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4904] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(341), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(358), 53,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [4974] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(341), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(360), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(358), 53,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5044] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(358), 55,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5112] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(541), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(506), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(539), 49,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      anon_sym_COLON,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5182] = 5,
    ACTIONS(354), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(352), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 38,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5252] = 6,
    ACTIONS(71), 1,
      anon_sym_AMP_AMP,
    ACTIONS(73), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(520), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(69), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(518), 44,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5323] = 5,
    ACTIONS(71), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(508), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(69), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(504), 45,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5392] = 6,
    ACTIONS(71), 1,
      anon_sym_AMP_AMP,
    ACTIONS(73), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(516), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(69), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(512), 44,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5463] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(508), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(69), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(504), 46,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5530] = 5,
    ACTIONS(543), 1,
      anon_sym_DOT,
    STATE(156), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(374), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(372), 40,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5589] = 5,
    ACTIONS(543), 1,
      anon_sym_DOT,
    STATE(154), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(366), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(362), 40,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5648] = 5,
    ACTIONS(543), 1,
      anon_sym_DOT,
    STATE(155), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(378), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(376), 40,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5707] = 5,
    ACTIONS(545), 1,
      anon_sym_DOT,
    STATE(155), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(385), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(380), 40,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5766] = 5,
    ACTIONS(543), 1,
      anon_sym_DOT,
    STATE(155), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(368), 40,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5825] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(385), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(380), 41,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [5879] = 30,
    ACTIONS(548), 1,
      sym_identifier,
    ACTIONS(552), 1,
      anon_sym_COMMA,
    ACTIONS(554), 1,
      anon_sym_LPAREN,
    ACTIONS(558), 1,
      anon_sym_TILDE,
    ACTIONS(560), 1,
      anon_sym_QMARK,
    ACTIONS(562), 1,
      anon_sym_AT,
    ACTIONS(564), 1,
      anon_sym_LBRACK,
    ACTIONS(566), 1,
      aux_sym_matrix_token1,
    ACTIONS(568), 1,
      anon_sym_LBRACE,
    ACTIONS(570), 1,
      sym_number,
    ACTIONS(574), 1,
      sym__single_quote_string_start,
    ACTIONS(576), 1,
      sym__double_quote_string_start,
    STATE(207), 1,
      sym_function_call,
    STATE(356), 1,
      sym_boolean,
    STATE(495), 1,
      sym_binary_operator,
    STATE(496), 1,
      sym_unary_operator,
    STATE(501), 1,
      sym_cell,
    STATE(541), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(802), 1,
      sym_ignored_argument,
    STATE(990), 1,
      sym_indirect_access,
    STATE(1014), 1,
      sym_row,
    STATE(1203), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(556), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(572), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(451), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(550), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(494), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(611), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [5984] = 6,
    ACTIONS(71), 1,
      anon_sym_AMP_AMP,
    ACTIONS(73), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(580), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(69), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(578), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [6041] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(160), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(584), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(587), 4,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
    ACTIONS(582), 31,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      sym_number,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [6095] = 28,
    ACTIONS(548), 1,
      sym_identifier,
    ACTIONS(554), 1,
      anon_sym_LPAREN,
    ACTIONS(558), 1,
      anon_sym_TILDE,
    ACTIONS(560), 1,
      anon_sym_QMARK,
    ACTIONS(562), 1,
      anon_sym_AT,
    ACTIONS(564), 1,
      anon_sym_LBRACK,
    ACTIONS(568), 1,
      anon_sym_LBRACE,
    ACTIONS(570), 1,
      sym_number,
    ACTIONS(574), 1,
      sym__single_quote_string_start,
    ACTIONS(576), 1,
      sym__double_quote_string_start,
    ACTIONS(591), 1,
      aux_sym_matrix_token1,
    STATE(207), 1,
      sym_function_call,
    STATE(356), 1,
      sym_boolean,
    STATE(495), 1,
      sym_binary_operator,
    STATE(496), 1,
      sym_unary_operator,
    STATE(501), 1,
      sym_cell,
    STATE(541), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(890), 1,
      sym_ignored_argument,
    STATE(990), 1,
      sym_indirect_access,
    STATE(1203), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(556), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(572), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(451), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(589), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(494), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(619), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [6194] = 28,
    ACTIONS(548), 1,
      sym_identifier,
    ACTIONS(554), 1,
      anon_sym_LPAREN,
    ACTIONS(558), 1,
      anon_sym_TILDE,
    ACTIONS(560), 1,
      anon_sym_QMARK,
    ACTIONS(562), 1,
      anon_sym_AT,
    ACTIONS(564), 1,
      anon_sym_LBRACK,
    ACTIONS(568), 1,
      anon_sym_LBRACE,
    ACTIONS(570), 1,
      sym_number,
    ACTIONS(574), 1,
      sym__single_quote_string_start,
    ACTIONS(576), 1,
      sym__double_quote_string_start,
    ACTIONS(595), 1,
      aux_sym_matrix_token1,
    STATE(207), 1,
      sym_function_call,
    STATE(356), 1,
      sym_boolean,
    STATE(495), 1,
      sym_binary_operator,
    STATE(496), 1,
      sym_unary_operator,
    STATE(501), 1,
      sym_cell,
    STATE(541), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(890), 1,
      sym_ignored_argument,
    STATE(990), 1,
      sym_indirect_access,
    STATE(1203), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(556), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(572), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(451), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(593), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(494), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(619), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [6293] = 28,
    ACTIONS(548), 1,
      sym_identifier,
    ACTIONS(554), 1,
      anon_sym_LPAREN,
    ACTIONS(558), 1,
      anon_sym_TILDE,
    ACTIONS(560), 1,
      anon_sym_QMARK,
    ACTIONS(562), 1,
      anon_sym_AT,
    ACTIONS(564), 1,
      anon_sym_LBRACK,
    ACTIONS(568), 1,
      anon_sym_LBRACE,
    ACTIONS(570), 1,
      sym_number,
    ACTIONS(574), 1,
      sym__single_quote_string_start,
    ACTIONS(576), 1,
      sym__double_quote_string_start,
    ACTIONS(599), 1,
      aux_sym_matrix_token1,
    STATE(207), 1,
      sym_function_call,
    STATE(356), 1,
      sym_boolean,
    STATE(495), 1,
      sym_binary_operator,
    STATE(496), 1,
      sym_unary_operator,
    STATE(501), 1,
      sym_cell,
    STATE(541), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(890), 1,
      sym_ignored_argument,
    STATE(990), 1,
      sym_indirect_access,
    STATE(1203), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(556), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(572), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(451), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(597), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(494), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(619), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [6392] = 27,
    ACTIONS(554), 1,
      anon_sym_LPAREN,
    ACTIONS(564), 1,
      anon_sym_LBRACK,
    ACTIONS(568), 1,
      anon_sym_LBRACE,
    ACTIONS(574), 1,
      sym__single_quote_string_start,
    ACTIONS(576), 1,
      sym__double_quote_string_start,
    ACTIONS(601), 1,
      sym_identifier,
    ACTIONS(605), 1,
      anon_sym_TILDE,
    ACTIONS(607), 1,
      anon_sym_QMARK,
    ACTIONS(609), 1,
      anon_sym_AT,
    ACTIONS(613), 1,
      sym_number,
    STATE(215), 1,
      sym_function_call,
    STATE(349), 1,
      sym_boolean,
    STATE(460), 1,
      sym_binary_operator,
    STATE(491), 1,
      sym_not_operator,
    STATE(501), 1,
      sym_cell,
    STATE(504), 1,
      sym_unary_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(990), 1,
      sym_indirect_access,
    STATE(1203), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(556), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(572), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(611), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    STATE(451), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    ACTIONS(603), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    STATE(462), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(489), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [6489] = 29,
    ACTIONS(615), 1,
      sym_identifier,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(625), 1,
      anon_sym_AT,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(631), 1,
      anon_sym_RBRACE,
    ACTIONS(633), 1,
      anon_sym_COLON,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    STATE(351), 1,
      sym_function_call,
    STATE(417), 1,
      sym_boolean,
    STATE(511), 1,
      sym_binary_operator,
    STATE(523), 1,
      sym_cell,
    STATE(548), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(952), 1,
      sym_spread_operator,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    STATE(1246), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(516), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(633), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [6589] = 5,
    STATE(176), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(643), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(325), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(254), 22,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [6641] = 5,
    STATE(179), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(649), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(645), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(647), 22,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [6693] = 29,
    ACTIONS(615), 1,
      sym_identifier,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(625), 1,
      anon_sym_AT,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(631), 1,
      anon_sym_RPAREN,
    ACTIONS(633), 1,
      anon_sym_COLON,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    STATE(351), 1,
      sym_function_call,
    STATE(417), 1,
      sym_boolean,
    STATE(511), 1,
      sym_binary_operator,
    STATE(523), 1,
      sym_cell,
    STATE(548), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(952), 1,
      sym_spread_operator,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    STATE(1223), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(516), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(633), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [6793] = 29,
    ACTIONS(548), 1,
      sym_identifier,
    ACTIONS(574), 1,
      sym__single_quote_string_start,
    ACTIONS(576), 1,
      sym__double_quote_string_start,
    ACTIONS(651), 1,
      anon_sym_COMMA,
    ACTIONS(653), 1,
      anon_sym_LPAREN,
    ACTIONS(657), 1,
      anon_sym_TILDE,
    ACTIONS(659), 1,
      anon_sym_QMARK,
    ACTIONS(661), 1,
      anon_sym_AT,
    ACTIONS(663), 1,
      anon_sym_LBRACK,
    ACTIONS(665), 1,
      anon_sym_RBRACK,
    ACTIONS(667), 1,
      anon_sym_LBRACE,
    ACTIONS(669), 1,
      sym_number,
    STATE(207), 1,
      sym_function_call,
    STATE(356), 1,
      sym_boolean,
    STATE(495), 1,
      sym_binary_operator,
    STATE(496), 1,
      sym_unary_operator,
    STATE(501), 1,
      sym_cell,
    STATE(541), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(802), 1,
      sym_ignored_argument,
    STATE(990), 1,
      sym_indirect_access,
    STATE(1011), 1,
      sym_row,
    STATE(1203), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(572), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(655), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(451), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(494), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(611), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [6893] = 29,
    ACTIONS(615), 1,
      sym_identifier,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(625), 1,
      anon_sym_AT,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(633), 1,
      anon_sym_COLON,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(671), 1,
      anon_sym_RBRACE,
    STATE(351), 1,
      sym_function_call,
    STATE(417), 1,
      sym_boolean,
    STATE(511), 1,
      sym_binary_operator,
    STATE(523), 1,
      sym_cell,
    STATE(548), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(952), 1,
      sym_spread_operator,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    STATE(1209), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(516), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(633), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [6993] = 29,
    ACTIONS(548), 1,
      sym_identifier,
    ACTIONS(574), 1,
      sym__single_quote_string_start,
    ACTIONS(576), 1,
      sym__double_quote_string_start,
    ACTIONS(651), 1,
      anon_sym_COMMA,
    ACTIONS(653), 1,
      anon_sym_LPAREN,
    ACTIONS(657), 1,
      anon_sym_TILDE,
    ACTIONS(659), 1,
      anon_sym_QMARK,
    ACTIONS(661), 1,
      anon_sym_AT,
    ACTIONS(663), 1,
      anon_sym_LBRACK,
    ACTIONS(667), 1,
      anon_sym_LBRACE,
    ACTIONS(669), 1,
      sym_number,
    ACTIONS(673), 1,
      anon_sym_RBRACK,
    STATE(207), 1,
      sym_function_call,
    STATE(356), 1,
      sym_boolean,
    STATE(495), 1,
      sym_binary_operator,
    STATE(496), 1,
      sym_unary_operator,
    STATE(501), 1,
      sym_cell,
    STATE(541), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(802), 1,
      sym_ignored_argument,
    STATE(944), 1,
      sym_row,
    STATE(990), 1,
      sym_indirect_access,
    STATE(1203), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(572), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(655), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(451), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(494), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(611), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [7093] = 29,
    ACTIONS(548), 1,
      sym_identifier,
    ACTIONS(574), 1,
      sym__single_quote_string_start,
    ACTIONS(576), 1,
      sym__double_quote_string_start,
    ACTIONS(651), 1,
      anon_sym_COMMA,
    ACTIONS(653), 1,
      anon_sym_LPAREN,
    ACTIONS(657), 1,
      anon_sym_TILDE,
    ACTIONS(659), 1,
      anon_sym_QMARK,
    ACTIONS(661), 1,
      anon_sym_AT,
    ACTIONS(663), 1,
      anon_sym_LBRACK,
    ACTIONS(667), 1,
      anon_sym_LBRACE,
    ACTIONS(669), 1,
      sym_number,
    ACTIONS(675), 1,
      anon_sym_RBRACE,
    STATE(207), 1,
      sym_function_call,
    STATE(356), 1,
      sym_boolean,
    STATE(495), 1,
      sym_binary_operator,
    STATE(496), 1,
      sym_unary_operator,
    STATE(501), 1,
      sym_cell,
    STATE(541), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(802), 1,
      sym_ignored_argument,
    STATE(945), 1,
      sym_row,
    STATE(990), 1,
      sym_indirect_access,
    STATE(1203), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(572), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(655), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(451), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(494), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(611), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [7193] = 29,
    ACTIONS(615), 1,
      sym_identifier,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(625), 1,
      anon_sym_AT,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(633), 1,
      anon_sym_COLON,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(677), 1,
      anon_sym_RPAREN,
    STATE(351), 1,
      sym_function_call,
    STATE(417), 1,
      sym_boolean,
    STATE(511), 1,
      sym_binary_operator,
    STATE(523), 1,
      sym_cell,
    STATE(548), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(952), 1,
      sym_spread_operator,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    STATE(1184), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(516), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(633), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [7293] = 29,
    ACTIONS(615), 1,
      sym_identifier,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(625), 1,
      anon_sym_AT,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(633), 1,
      anon_sym_COLON,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(677), 1,
      anon_sym_RBRACE,
    STATE(351), 1,
      sym_function_call,
    STATE(417), 1,
      sym_boolean,
    STATE(511), 1,
      sym_binary_operator,
    STATE(523), 1,
      sym_cell,
    STATE(548), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(952), 1,
      sym_spread_operator,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    STATE(1189), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(516), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(633), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [7393] = 5,
    STATE(167), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(683), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(679), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(681), 22,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [7445] = 5,
    STATE(179), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(649), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(685), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(687), 22,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [7497] = 29,
    ACTIONS(548), 1,
      sym_identifier,
    ACTIONS(574), 1,
      sym__single_quote_string_start,
    ACTIONS(576), 1,
      sym__double_quote_string_start,
    ACTIONS(651), 1,
      anon_sym_COMMA,
    ACTIONS(653), 1,
      anon_sym_LPAREN,
    ACTIONS(657), 1,
      anon_sym_TILDE,
    ACTIONS(659), 1,
      anon_sym_QMARK,
    ACTIONS(661), 1,
      anon_sym_AT,
    ACTIONS(663), 1,
      anon_sym_LBRACK,
    ACTIONS(667), 1,
      anon_sym_LBRACE,
    ACTIONS(669), 1,
      sym_number,
    ACTIONS(689), 1,
      anon_sym_RBRACE,
    STATE(207), 1,
      sym_function_call,
    STATE(356), 1,
      sym_boolean,
    STATE(495), 1,
      sym_binary_operator,
    STATE(496), 1,
      sym_unary_operator,
    STATE(501), 1,
      sym_cell,
    STATE(541), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(802), 1,
      sym_ignored_argument,
    STATE(919), 1,
      sym_row,
    STATE(990), 1,
      sym_indirect_access,
    STATE(1203), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(572), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(655), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(451), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(494), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(611), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [7597] = 29,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(625), 1,
      anon_sym_AT,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(633), 1,
      anon_sym_COLON,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(677), 1,
      anon_sym_RPAREN,
    ACTIONS(691), 1,
      sym_identifier,
    STATE(377), 1,
      sym_function_call,
    STATE(417), 1,
      sym_boolean,
    STATE(523), 1,
      sym_cell,
    STATE(557), 1,
      sym_unary_operator,
    STATE(562), 1,
      sym_binary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(952), 1,
      sym_spread_operator,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    STATE(1184), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(561), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(633), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [7697] = 5,
    STATE(179), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(697), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(693), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(695), 22,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_elseif,
      anon_sym_else,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_classdef,
      anon_sym_catch,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [7749] = 29,
    ACTIONS(548), 1,
      sym_identifier,
    ACTIONS(574), 1,
      sym__single_quote_string_start,
    ACTIONS(576), 1,
      sym__double_quote_string_start,
    ACTIONS(651), 1,
      anon_sym_COMMA,
    ACTIONS(653), 1,
      anon_sym_LPAREN,
    ACTIONS(657), 1,
      anon_sym_TILDE,
    ACTIONS(659), 1,
      anon_sym_QMARK,
    ACTIONS(661), 1,
      anon_sym_AT,
    ACTIONS(663), 1,
      anon_sym_LBRACK,
    ACTIONS(667), 1,
      anon_sym_LBRACE,
    ACTIONS(669), 1,
      sym_number,
    ACTIONS(700), 1,
      anon_sym_RBRACK,
    STATE(207), 1,
      sym_function_call,
    STATE(356), 1,
      sym_boolean,
    STATE(495), 1,
      sym_binary_operator,
    STATE(496), 1,
      sym_unary_operator,
    STATE(501), 1,
      sym_cell,
    STATE(541), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(802), 1,
      sym_ignored_argument,
    STATE(979), 1,
      sym_row,
    STATE(990), 1,
      sym_indirect_access,
    STATE(1203), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(572), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(655), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(451), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(494), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(611), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [7849] = 29,
    ACTIONS(548), 1,
      sym_identifier,
    ACTIONS(574), 1,
      sym__single_quote_string_start,
    ACTIONS(576), 1,
      sym__double_quote_string_start,
    ACTIONS(651), 1,
      anon_sym_COMMA,
    ACTIONS(653), 1,
      anon_sym_LPAREN,
    ACTIONS(657), 1,
      anon_sym_TILDE,
    ACTIONS(659), 1,
      anon_sym_QMARK,
    ACTIONS(661), 1,
      anon_sym_AT,
    ACTIONS(663), 1,
      anon_sym_LBRACK,
    ACTIONS(667), 1,
      anon_sym_LBRACE,
    ACTIONS(669), 1,
      sym_number,
    ACTIONS(702), 1,
      anon_sym_RBRACE,
    STATE(207), 1,
      sym_function_call,
    STATE(356), 1,
      sym_boolean,
    STATE(495), 1,
      sym_binary_operator,
    STATE(496), 1,
      sym_unary_operator,
    STATE(501), 1,
      sym_cell,
    STATE(541), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(802), 1,
      sym_ignored_argument,
    STATE(980), 1,
      sym_row,
    STATE(990), 1,
      sym_indirect_access,
    STATE(1203), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(572), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(655), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(451), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(494), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(611), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [7949] = 29,
    ACTIONS(615), 1,
      sym_identifier,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(625), 1,
      anon_sym_AT,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(633), 1,
      anon_sym_COLON,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(704), 1,
      anon_sym_RPAREN,
    STATE(351), 1,
      sym_function_call,
    STATE(417), 1,
      sym_boolean,
    STATE(511), 1,
      sym_binary_operator,
    STATE(523), 1,
      sym_cell,
    STATE(548), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(952), 1,
      sym_spread_operator,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    STATE(1241), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(516), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(633), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [8049] = 29,
    ACTIONS(615), 1,
      sym_identifier,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(625), 1,
      anon_sym_AT,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(633), 1,
      anon_sym_COLON,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(704), 1,
      anon_sym_RBRACE,
    STATE(351), 1,
      sym_function_call,
    STATE(417), 1,
      sym_boolean,
    STATE(511), 1,
      sym_binary_operator,
    STATE(523), 1,
      sym_cell,
    STATE(548), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(952), 1,
      sym_spread_operator,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1177), 1,
      sym_arguments,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(516), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(633), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [8149] = 29,
    ACTIONS(548), 1,
      sym_identifier,
    ACTIONS(574), 1,
      sym__single_quote_string_start,
    ACTIONS(576), 1,
      sym__double_quote_string_start,
    ACTIONS(651), 1,
      anon_sym_COMMA,
    ACTIONS(653), 1,
      anon_sym_LPAREN,
    ACTIONS(657), 1,
      anon_sym_TILDE,
    ACTIONS(659), 1,
      anon_sym_QMARK,
    ACTIONS(661), 1,
      anon_sym_AT,
    ACTIONS(663), 1,
      anon_sym_LBRACK,
    ACTIONS(667), 1,
      anon_sym_LBRACE,
    ACTIONS(669), 1,
      sym_number,
    ACTIONS(706), 1,
      anon_sym_RBRACK,
    STATE(207), 1,
      sym_function_call,
    STATE(356), 1,
      sym_boolean,
    STATE(495), 1,
      sym_binary_operator,
    STATE(496), 1,
      sym_unary_operator,
    STATE(501), 1,
      sym_cell,
    STATE(541), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(802), 1,
      sym_ignored_argument,
    STATE(990), 1,
      sym_indirect_access,
    STATE(997), 1,
      sym_row,
    STATE(1203), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(572), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(655), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(451), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(494), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(611), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [8249] = 29,
    ACTIONS(548), 1,
      sym_identifier,
    ACTIONS(574), 1,
      sym__single_quote_string_start,
    ACTIONS(576), 1,
      sym__double_quote_string_start,
    ACTIONS(651), 1,
      anon_sym_COMMA,
    ACTIONS(653), 1,
      anon_sym_LPAREN,
    ACTIONS(657), 1,
      anon_sym_TILDE,
    ACTIONS(659), 1,
      anon_sym_QMARK,
    ACTIONS(661), 1,
      anon_sym_AT,
    ACTIONS(663), 1,
      anon_sym_LBRACK,
    ACTIONS(667), 1,
      anon_sym_LBRACE,
    ACTIONS(669), 1,
      sym_number,
    ACTIONS(708), 1,
      anon_sym_RBRACE,
    STATE(207), 1,
      sym_function_call,
    STATE(356), 1,
      sym_boolean,
    STATE(495), 1,
      sym_binary_operator,
    STATE(496), 1,
      sym_unary_operator,
    STATE(501), 1,
      sym_cell,
    STATE(541), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(802), 1,
      sym_ignored_argument,
    STATE(990), 1,
      sym_indirect_access,
    STATE(998), 1,
      sym_row,
    STATE(1203), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(572), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(655), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(451), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(494), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(611), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [8349] = 29,
    ACTIONS(615), 1,
      sym_identifier,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(625), 1,
      anon_sym_AT,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(633), 1,
      anon_sym_COLON,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(710), 1,
      anon_sym_RPAREN,
    STATE(351), 1,
      sym_function_call,
    STATE(417), 1,
      sym_boolean,
    STATE(511), 1,
      sym_binary_operator,
    STATE(523), 1,
      sym_cell,
    STATE(548), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(952), 1,
      sym_spread_operator,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    STATE(1191), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(516), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(633), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [8449] = 29,
    ACTIONS(615), 1,
      sym_identifier,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(625), 1,
      anon_sym_AT,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(633), 1,
      anon_sym_COLON,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(710), 1,
      anon_sym_RBRACE,
    STATE(351), 1,
      sym_function_call,
    STATE(417), 1,
      sym_boolean,
    STATE(511), 1,
      sym_binary_operator,
    STATE(523), 1,
      sym_cell,
    STATE(548), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(952), 1,
      sym_spread_operator,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    STATE(1193), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(516), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(633), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [8549] = 29,
    ACTIONS(615), 1,
      sym_identifier,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(625), 1,
      anon_sym_AT,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(633), 1,
      anon_sym_COLON,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(671), 1,
      anon_sym_RPAREN,
    STATE(351), 1,
      sym_function_call,
    STATE(417), 1,
      sym_boolean,
    STATE(511), 1,
      sym_binary_operator,
    STATE(523), 1,
      sym_cell,
    STATE(548), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(952), 1,
      sym_spread_operator,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    STATE(1207), 1,
      sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(516), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(633), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [8649] = 11,
    ACTIONS(712), 1,
      anon_sym_LPAREN,
    ACTIONS(714), 1,
      anon_sym_DOT,
    ACTIONS(716), 1,
      anon_sym_AT,
    ACTIONS(720), 1,
      anon_sym_LBRACE,
    STATE(195), 1,
      sym__args,
    STATE(262), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(718), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(349), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(354), 8,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [8712] = 9,
    ACTIONS(712), 1,
      anon_sym_LPAREN,
    ACTIONS(714), 1,
      anon_sym_DOT,
    ACTIONS(716), 1,
      anon_sym_AT,
    ACTIONS(720), 1,
      anon_sym_LBRACE,
    STATE(195), 1,
      sym__args,
    STATE(262), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(718), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(358), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [8771] = 9,
    ACTIONS(712), 1,
      anon_sym_LPAREN,
    ACTIONS(714), 1,
      anon_sym_DOT,
    ACTIONS(716), 1,
      anon_sym_AT,
    ACTIONS(720), 1,
      anon_sym_LBRACE,
    STATE(195), 1,
      sym__args,
    STATE(262), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(718), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(333), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [8830] = 11,
    ACTIONS(349), 1,
      anon_sym_COLON,
    ACTIONS(712), 1,
      anon_sym_LPAREN,
    ACTIONS(714), 1,
      anon_sym_DOT,
    ACTIONS(716), 1,
      anon_sym_AT,
    ACTIONS(720), 1,
      anon_sym_LBRACE,
    STATE(195), 1,
      sym__args,
    STATE(262), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(718), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [8893] = 11,
    ACTIONS(354), 1,
      anon_sym_COLON,
    ACTIONS(712), 1,
      anon_sym_LPAREN,
    ACTIONS(714), 1,
      anon_sym_DOT,
    ACTIONS(716), 1,
      anon_sym_AT,
    ACTIONS(720), 1,
      anon_sym_LBRACE,
    STATE(195), 1,
      sym__args,
    STATE(262), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(718), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [8956] = 6,
    ACTIONS(712), 1,
      anon_sym_LPAREN,
    ACTIONS(716), 1,
      anon_sym_AT,
    ACTIONS(720), 1,
      anon_sym_LBRACE,
    STATE(195), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(387), 34,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [9009] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(408), 37,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [9053] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(420), 37,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [9097] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(424), 37,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [9141] = 27,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(625), 1,
      anon_sym_AT,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(633), 1,
      anon_sym_COLON,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(722), 1,
      sym_identifier,
    STATE(351), 1,
      sym_function_call,
    STATE(417), 1,
      sym_boolean,
    STATE(511), 1,
      sym_binary_operator,
    STATE(523), 1,
      sym_cell,
    STATE(548), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1042), 1,
      sym_spread_operator,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(516), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(667), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [9235] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(402), 37,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [9279] = 27,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(625), 1,
      anon_sym_AT,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(633), 1,
      anon_sym_COLON,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(724), 1,
      sym_identifier,
    STATE(351), 1,
      sym_function_call,
    STATE(417), 1,
      sym_boolean,
    STATE(511), 1,
      sym_binary_operator,
    STATE(523), 1,
      sym_cell,
    STATE(548), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1042), 1,
      sym_spread_operator,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(516), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(667), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [9373] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(412), 37,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [9417] = 27,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(625), 1,
      anon_sym_AT,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(633), 1,
      anon_sym_COLON,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(726), 1,
      sym_identifier,
    STATE(351), 1,
      sym_function_call,
    STATE(417), 1,
      sym_boolean,
    STATE(511), 1,
      sym_binary_operator,
    STATE(523), 1,
      sym_cell,
    STATE(548), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1042), 1,
      sym_spread_operator,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(516), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(667), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [9511] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(416), 37,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [9555] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(428), 37,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [9599] = 27,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(625), 1,
      anon_sym_AT,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(633), 1,
      anon_sym_COLON,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(728), 1,
      sym_identifier,
    STATE(351), 1,
      sym_function_call,
    STATE(417), 1,
      sym_boolean,
    STATE(511), 1,
      sym_binary_operator,
    STATE(523), 1,
      sym_cell,
    STATE(548), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1042), 1,
      sym_spread_operator,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(516), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(667), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [9693] = 10,
    ACTIONS(730), 1,
      anon_sym_LPAREN,
    ACTIONS(732), 1,
      anon_sym_DOT,
    ACTIONS(734), 1,
      anon_sym_AT,
    ACTIONS(738), 1,
      anon_sym_LBRACE,
    STATE(368), 1,
      sym__args,
    STATE(436), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(345), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(333), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [9752] = 12,
    ACTIONS(354), 1,
      anon_sym_COLON,
    ACTIONS(730), 1,
      anon_sym_LPAREN,
    ACTIONS(732), 1,
      anon_sym_DOT,
    ACTIONS(734), 1,
      anon_sym_AT,
    ACTIONS(738), 1,
      anon_sym_LBRACE,
    STATE(368), 1,
      sym__args,
    STATE(436), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(352), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(347), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [9815] = 9,
    ACTIONS(349), 1,
      anon_sym_COLON,
    ACTIONS(712), 1,
      anon_sym_LPAREN,
    ACTIONS(720), 1,
      anon_sym_LBRACE,
    ACTIONS(740), 1,
      anon_sym_AT,
    STATE(203), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(718), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [9872] = 10,
    ACTIONS(730), 1,
      anon_sym_LPAREN,
    ACTIONS(732), 1,
      anon_sym_DOT,
    ACTIONS(734), 1,
      anon_sym_AT,
    ACTIONS(738), 1,
      anon_sym_LBRACE,
    STATE(368), 1,
      sym__args,
    STATE(436), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(358), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [9931] = 26,
    ACTIONS(548), 1,
      sym_identifier,
    ACTIONS(574), 1,
      sym__single_quote_string_start,
    ACTIONS(576), 1,
      sym__double_quote_string_start,
    ACTIONS(653), 1,
      anon_sym_LPAREN,
    ACTIONS(657), 1,
      anon_sym_TILDE,
    ACTIONS(659), 1,
      anon_sym_QMARK,
    ACTIONS(661), 1,
      anon_sym_AT,
    ACTIONS(663), 1,
      anon_sym_LBRACK,
    ACTIONS(667), 1,
      anon_sym_LBRACE,
    ACTIONS(669), 1,
      sym_number,
    STATE(207), 1,
      sym_function_call,
    STATE(356), 1,
      sym_boolean,
    STATE(495), 1,
      sym_binary_operator,
    STATE(496), 1,
      sym_unary_operator,
    STATE(501), 1,
      sym_cell,
    STATE(541), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(784), 1,
      sym_ignored_argument,
    STATE(990), 1,
      sym_indirect_access,
    STATE(1203), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(572), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(655), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(451), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(494), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(608), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [10022] = 12,
    ACTIONS(354), 1,
      anon_sym_COLON,
    ACTIONS(712), 1,
      anon_sym_LPAREN,
    ACTIONS(714), 1,
      anon_sym_DOT,
    ACTIONS(716), 1,
      anon_sym_AT,
    ACTIONS(720), 1,
      anon_sym_LBRACE,
    ACTIONS(742), 1,
      anon_sym_EQ,
    STATE(195), 1,
      sym__args,
    STATE(262), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(718), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(347), 12,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [10085] = 26,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(611), 1,
      anon_sym_EQ,
    ACTIONS(744), 1,
      sym_identifier,
    ACTIONS(746), 1,
      anon_sym_TILDE,
    ACTIONS(748), 1,
      anon_sym_QMARK,
    ACTIONS(750), 1,
      anon_sym_AT,
    ACTIONS(752), 1,
      sym_number,
    STATE(192), 1,
      sym_function_call,
    STATE(208), 1,
      sym_boolean,
    STATE(405), 1,
      sym_not_operator,
    STATE(413), 1,
      sym_unary_operator,
    STATE(430), 1,
      sym_cell,
    STATE(437), 1,
      sym_binary_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(914), 1,
      sym_indirect_access,
    STATE(1243), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(427), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(389), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(447), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [10176] = 26,
    ACTIONS(548), 1,
      sym_identifier,
    ACTIONS(574), 1,
      sym__single_quote_string_start,
    ACTIONS(576), 1,
      sym__double_quote_string_start,
    ACTIONS(653), 1,
      anon_sym_LPAREN,
    ACTIONS(657), 1,
      anon_sym_TILDE,
    ACTIONS(659), 1,
      anon_sym_QMARK,
    ACTIONS(661), 1,
      anon_sym_AT,
    ACTIONS(663), 1,
      anon_sym_LBRACK,
    ACTIONS(667), 1,
      anon_sym_LBRACE,
    ACTIONS(669), 1,
      sym_number,
    STATE(207), 1,
      sym_function_call,
    STATE(356), 1,
      sym_boolean,
    STATE(495), 1,
      sym_binary_operator,
    STATE(496), 1,
      sym_unary_operator,
    STATE(501), 1,
      sym_cell,
    STATE(541), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(890), 1,
      sym_ignored_argument,
    STATE(990), 1,
      sym_indirect_access,
    STATE(1203), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(572), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(655), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(451), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(494), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(619), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [10267] = 9,
    ACTIONS(354), 1,
      anon_sym_COLON,
    ACTIONS(712), 1,
      anon_sym_LPAREN,
    ACTIONS(720), 1,
      anon_sym_LBRACE,
    ACTIONS(740), 1,
      anon_sym_AT,
    STATE(203), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(718), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [10324] = 12,
    ACTIONS(349), 1,
      anon_sym_COLON,
    ACTIONS(730), 1,
      anon_sym_LPAREN,
    ACTIONS(732), 1,
      anon_sym_DOT,
    ACTIONS(734), 1,
      anon_sym_AT,
    ACTIONS(738), 1,
      anon_sym_LBRACE,
    STATE(368), 1,
      sym__args,
    STATE(436), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(352), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(347), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [10387] = 27,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(754), 1,
      sym_identifier,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(758), 1,
      sym_number,
    STATE(372), 1,
      sym_function_call,
    STATE(450), 1,
      sym_boolean,
    STATE(511), 1,
      sym_binary_operator,
    STATE(516), 1,
      sym_parenthesis,
    STATE(556), 1,
      sym_unary_operator,
    STATE(565), 1,
      sym_cell,
    STATE(587), 1,
      sym_not_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1096), 1,
      sym__enum_value,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(560), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(692), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [10480] = 7,
    ACTIONS(712), 1,
      anon_sym_LPAREN,
    ACTIONS(720), 1,
      anon_sym_LBRACE,
    ACTIONS(740), 1,
      anon_sym_AT,
    STATE(203), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(718), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(333), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [10533] = 9,
    ACTIONS(712), 1,
      anon_sym_LPAREN,
    ACTIONS(720), 1,
      anon_sym_LBRACE,
    ACTIONS(740), 1,
      anon_sym_AT,
    STATE(203), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(718), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(349), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(354), 8,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [10590] = 12,
    ACTIONS(730), 1,
      anon_sym_LPAREN,
    ACTIONS(732), 1,
      anon_sym_DOT,
    ACTIONS(734), 1,
      anon_sym_AT,
    ACTIONS(738), 1,
      anon_sym_LBRACE,
    STATE(368), 1,
      sym__args,
    STATE(436), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(356), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(354), 4,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(349), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [10653] = 7,
    ACTIONS(712), 1,
      anon_sym_LPAREN,
    ACTIONS(720), 1,
      anon_sym_LBRACE,
    ACTIONS(740), 1,
      anon_sym_AT,
    STATE(203), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(718), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(358), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [10706] = 27,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(754), 1,
      sym_identifier,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(758), 1,
      sym_number,
    STATE(372), 1,
      sym_function_call,
    STATE(450), 1,
      sym_boolean,
    STATE(511), 1,
      sym_binary_operator,
    STATE(516), 1,
      sym_parenthesis,
    STATE(556), 1,
      sym_unary_operator,
    STATE(565), 1,
      sym_cell,
    STATE(587), 1,
      sym_not_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1134), 1,
      sym__enum_value,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(560), 4,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(692), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [10799] = 25,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(760), 1,
      sym_identifier,
    STATE(417), 1,
      sym_boolean,
    STATE(419), 1,
      sym_function_call,
    STATE(523), 1,
      sym_cell,
    STATE(566), 1,
      sym_not_operator,
    STATE(567), 1,
      sym_unary_operator,
    STATE(569), 1,
      sym_binary_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(568), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(692), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [10887] = 25,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(762), 1,
      sym_identifier,
    STATE(399), 1,
      sym_function_call,
    STATE(417), 1,
      sym_boolean,
    STATE(523), 1,
      sym_cell,
    STATE(557), 1,
      sym_unary_operator,
    STATE(562), 1,
      sym_binary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(561), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(684), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [10975] = 25,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(762), 1,
      sym_identifier,
    STATE(399), 1,
      sym_function_call,
    STATE(417), 1,
      sym_boolean,
    STATE(523), 1,
      sym_cell,
    STATE(557), 1,
      sym_unary_operator,
    STATE(562), 1,
      sym_binary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(561), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(678), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [11063] = 23,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(764), 1,
      sym_identifier,
    ACTIONS(766), 1,
      sym_number,
    STATE(358), 1,
      sym_function_call,
    STATE(392), 1,
      sym_boolean,
    STATE(515), 1,
      sym_binary_operator,
    STATE(529), 1,
      sym_cell,
    STATE(552), 1,
      sym_unary_operator,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(538), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(547), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(693), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [11147] = 23,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(764), 1,
      sym_identifier,
    ACTIONS(766), 1,
      sym_number,
    STATE(358), 1,
      sym_function_call,
    STATE(392), 1,
      sym_boolean,
    STATE(515), 1,
      sym_binary_operator,
    STATE(529), 1,
      sym_cell,
    STATE(552), 1,
      sym_unary_operator,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(545), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(547), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(693), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [11231] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(744), 1,
      sym_identifier,
    ACTIONS(746), 1,
      anon_sym_TILDE,
    ACTIONS(748), 1,
      anon_sym_QMARK,
    ACTIONS(750), 1,
      anon_sym_AT,
    ACTIONS(752), 1,
      sym_number,
    STATE(192), 1,
      sym_function_call,
    STATE(208), 1,
      sym_boolean,
    STATE(405), 1,
      sym_not_operator,
    STATE(413), 1,
      sym_unary_operator,
    STATE(430), 1,
      sym_cell,
    STATE(437), 1,
      sym_binary_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(914), 1,
      sym_indirect_access,
    STATE(1243), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(427), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(406), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(447), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [11319] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(744), 1,
      sym_identifier,
    ACTIONS(746), 1,
      anon_sym_TILDE,
    ACTIONS(748), 1,
      anon_sym_QMARK,
    ACTIONS(750), 1,
      anon_sym_AT,
    ACTIONS(752), 1,
      sym_number,
    STATE(192), 1,
      sym_function_call,
    STATE(208), 1,
      sym_boolean,
    STATE(405), 1,
      sym_not_operator,
    STATE(413), 1,
      sym_unary_operator,
    STATE(430), 1,
      sym_cell,
    STATE(437), 1,
      sym_binary_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(914), 1,
      sym_indirect_access,
    STATE(1243), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(427), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(409), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(447), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [11407] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(744), 1,
      sym_identifier,
    ACTIONS(746), 1,
      anon_sym_TILDE,
    ACTIONS(748), 1,
      anon_sym_QMARK,
    ACTIONS(750), 1,
      anon_sym_AT,
    ACTIONS(752), 1,
      sym_number,
    STATE(192), 1,
      sym_function_call,
    STATE(208), 1,
      sym_boolean,
    STATE(405), 1,
      sym_not_operator,
    STATE(413), 1,
      sym_unary_operator,
    STATE(430), 1,
      sym_cell,
    STATE(437), 1,
      sym_binary_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(914), 1,
      sym_indirect_access,
    STATE(1243), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(427), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(407), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(447), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [11495] = 23,
    ACTIONS(574), 1,
      sym__single_quote_string_start,
    ACTIONS(576), 1,
      sym__double_quote_string_start,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(653), 1,
      anon_sym_LPAREN,
    ACTIONS(663), 1,
      anon_sym_LBRACK,
    ACTIONS(667), 1,
      anon_sym_LBRACE,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(768), 1,
      sym_identifier,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(772), 1,
      sym_number,
    STATE(206), 1,
      sym_function_call,
    STATE(360), 1,
      sym_boolean,
    STATE(475), 1,
      sym_unary_operator,
    STATE(483), 1,
      sym_binary_operator,
    STATE(502), 1,
      sym_cell,
    STATE(990), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(572), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(655), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(463), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(473), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(695), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [11579] = 23,
    ACTIONS(574), 1,
      sym__single_quote_string_start,
    ACTIONS(576), 1,
      sym__double_quote_string_start,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(653), 1,
      anon_sym_LPAREN,
    ACTIONS(663), 1,
      anon_sym_LBRACK,
    ACTIONS(667), 1,
      anon_sym_LBRACE,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(768), 1,
      sym_identifier,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(772), 1,
      sym_number,
    STATE(206), 1,
      sym_function_call,
    STATE(360), 1,
      sym_boolean,
    STATE(475), 1,
      sym_unary_operator,
    STATE(483), 1,
      sym_binary_operator,
    STATE(502), 1,
      sym_cell,
    STATE(990), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(572), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(655), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(464), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(473), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(695), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [11663] = 23,
    ACTIONS(574), 1,
      sym__single_quote_string_start,
    ACTIONS(576), 1,
      sym__double_quote_string_start,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(653), 1,
      anon_sym_LPAREN,
    ACTIONS(663), 1,
      anon_sym_LBRACK,
    ACTIONS(667), 1,
      anon_sym_LBRACE,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(768), 1,
      sym_identifier,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(772), 1,
      sym_number,
    STATE(206), 1,
      sym_function_call,
    STATE(360), 1,
      sym_boolean,
    STATE(475), 1,
      sym_unary_operator,
    STATE(483), 1,
      sym_binary_operator,
    STATE(502), 1,
      sym_cell,
    STATE(990), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(572), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(655), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(465), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(473), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(695), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [11747] = 23,
    ACTIONS(574), 1,
      sym__single_quote_string_start,
    ACTIONS(576), 1,
      sym__double_quote_string_start,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(653), 1,
      anon_sym_LPAREN,
    ACTIONS(663), 1,
      anon_sym_LBRACK,
    ACTIONS(667), 1,
      anon_sym_LBRACE,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(768), 1,
      sym_identifier,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(772), 1,
      sym_number,
    STATE(206), 1,
      sym_function_call,
    STATE(360), 1,
      sym_boolean,
    STATE(475), 1,
      sym_unary_operator,
    STATE(483), 1,
      sym_binary_operator,
    STATE(502), 1,
      sym_cell,
    STATE(990), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(572), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(655), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(466), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(473), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(695), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [11831] = 23,
    ACTIONS(574), 1,
      sym__single_quote_string_start,
    ACTIONS(576), 1,
      sym__double_quote_string_start,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(653), 1,
      anon_sym_LPAREN,
    ACTIONS(663), 1,
      anon_sym_LBRACK,
    ACTIONS(667), 1,
      anon_sym_LBRACE,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(768), 1,
      sym_identifier,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(772), 1,
      sym_number,
    STATE(206), 1,
      sym_function_call,
    STATE(360), 1,
      sym_boolean,
    STATE(475), 1,
      sym_unary_operator,
    STATE(483), 1,
      sym_binary_operator,
    STATE(502), 1,
      sym_cell,
    STATE(990), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(572), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(655), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(467), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(473), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(695), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [11915] = 25,
    ACTIONS(574), 1,
      sym__single_quote_string_start,
    ACTIONS(576), 1,
      sym__double_quote_string_start,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(653), 1,
      anon_sym_LPAREN,
    ACTIONS(663), 1,
      anon_sym_LBRACK,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(774), 1,
      sym_identifier,
    ACTIONS(776), 1,
      sym_number,
    STATE(219), 1,
      sym_function_call,
    STATE(361), 1,
      sym_boolean,
    STATE(468), 1,
      sym__range_element,
    STATE(477), 1,
      sym_unary_operator,
    STATE(478), 1,
      sym_not_operator,
    STATE(484), 1,
      sym_binary_operator,
    STATE(590), 1,
      sym_cell,
    STATE(615), 1,
      sym__binary_expression,
    STATE(990), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(572), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(655), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(476), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(692), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12003] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(744), 1,
      sym_identifier,
    ACTIONS(746), 1,
      anon_sym_TILDE,
    ACTIONS(748), 1,
      anon_sym_QMARK,
    ACTIONS(750), 1,
      anon_sym_AT,
    ACTIONS(752), 1,
      sym_number,
    STATE(192), 1,
      sym_function_call,
    STATE(208), 1,
      sym_boolean,
    STATE(405), 1,
      sym_not_operator,
    STATE(413), 1,
      sym_unary_operator,
    STATE(430), 1,
      sym_cell,
    STATE(437), 1,
      sym_binary_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(914), 1,
      sym_indirect_access,
    STATE(1243), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(427), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(439), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(447), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [12091] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(744), 1,
      sym_identifier,
    ACTIONS(746), 1,
      anon_sym_TILDE,
    ACTIONS(748), 1,
      anon_sym_QMARK,
    ACTIONS(750), 1,
      anon_sym_AT,
    ACTIONS(752), 1,
      sym_number,
    STATE(192), 1,
      sym_function_call,
    STATE(208), 1,
      sym_boolean,
    STATE(405), 1,
      sym_not_operator,
    STATE(413), 1,
      sym_unary_operator,
    STATE(430), 1,
      sym_cell,
    STATE(437), 1,
      sym_binary_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(914), 1,
      sym_indirect_access,
    STATE(1243), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(427), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(420), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(447), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [12179] = 25,
    ACTIONS(574), 1,
      sym__single_quote_string_start,
    ACTIONS(576), 1,
      sym__double_quote_string_start,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(653), 1,
      anon_sym_LPAREN,
    ACTIONS(663), 1,
      anon_sym_LBRACK,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(774), 1,
      sym_identifier,
    ACTIONS(776), 1,
      sym_number,
    STATE(219), 1,
      sym_function_call,
    STATE(361), 1,
      sym_boolean,
    STATE(477), 1,
      sym_unary_operator,
    STATE(478), 1,
      sym_not_operator,
    STATE(484), 1,
      sym_binary_operator,
    STATE(490), 1,
      sym__range_element,
    STATE(590), 1,
      sym_cell,
    STATE(615), 1,
      sym__binary_expression,
    STATE(990), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(572), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(655), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(476), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(692), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12267] = 25,
    ACTIONS(778), 1,
      sym_identifier,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(786), 1,
      anon_sym_QMARK,
    ACTIONS(788), 1,
      anon_sym_AT,
    ACTIONS(790), 1,
      anon_sym_LBRACK,
    ACTIONS(792), 1,
      anon_sym_LBRACE,
    ACTIONS(794), 1,
      sym_number,
    ACTIONS(798), 1,
      sym__single_quote_string_start,
    ACTIONS(800), 1,
      sym__double_quote_string_start,
    STATE(78), 1,
      sym_function_call,
    STATE(96), 1,
      sym_boolean,
    STATE(121), 1,
      sym_binary_operator,
    STATE(139), 1,
      sym_unary_operator,
    STATE(141), 1,
      sym_cell,
    STATE(147), 1,
      sym_not_operator,
    STATE(616), 1,
      sym__binary_expression,
    STATE(1003), 1,
      sym_indirect_access,
    STATE(1265), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(796), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(140), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(4), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(120), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [12355] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(15), 1,
      anon_sym_QMARK,
    ACTIONS(17), 1,
      anon_sym_AT,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      sym_number,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(746), 1,
      anon_sym_TILDE,
    ACTIONS(802), 1,
      sym_identifier,
    STATE(193), 1,
      sym_function_call,
    STATE(214), 1,
      sym_boolean,
    STATE(384), 1,
      sym_binary_operator,
    STATE(411), 1,
      sym_unary_operator,
    STATE(430), 1,
      sym_cell,
    STATE(493), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(914), 1,
      sym_indirect_access,
    STATE(1243), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(427), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(415), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(506), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12443] = 23,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(764), 1,
      sym_identifier,
    ACTIONS(766), 1,
      sym_number,
    STATE(358), 1,
      sym_function_call,
    STATE(392), 1,
      sym_boolean,
    STATE(515), 1,
      sym_binary_operator,
    STATE(529), 1,
      sym_cell,
    STATE(552), 1,
      sym_unary_operator,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(546), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(547), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(693), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12527] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(15), 1,
      anon_sym_QMARK,
    ACTIONS(17), 1,
      anon_sym_AT,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      sym_number,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(746), 1,
      anon_sym_TILDE,
    ACTIONS(802), 1,
      sym_identifier,
    STATE(193), 1,
      sym_function_call,
    STATE(214), 1,
      sym_boolean,
    STATE(384), 1,
      sym_binary_operator,
    STATE(411), 1,
      sym_unary_operator,
    STATE(430), 1,
      sym_cell,
    STATE(493), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(914), 1,
      sym_indirect_access,
    STATE(1243), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(427), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(415), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(594), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12615] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(746), 1,
      anon_sym_TILDE,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(804), 1,
      sym_identifier,
    ACTIONS(806), 1,
      sym_number,
    STATE(190), 1,
      sym_function_call,
    STATE(220), 1,
      sym_boolean,
    STATE(383), 1,
      sym_unary_operator,
    STATE(385), 1,
      sym_not_operator,
    STATE(401), 1,
      sym_cell,
    STATE(581), 1,
      sym_binary_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(914), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(425), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(692), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12703] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(531), 35,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [12745] = 25,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(625), 1,
      anon_sym_AT,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(722), 1,
      sym_identifier,
    STATE(351), 1,
      sym_function_call,
    STATE(417), 1,
      sym_boolean,
    STATE(511), 1,
      sym_binary_operator,
    STATE(523), 1,
      sym_cell,
    STATE(548), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(516), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(669), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12833] = 23,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(764), 1,
      sym_identifier,
    ACTIONS(766), 1,
      sym_number,
    STATE(358), 1,
      sym_function_call,
    STATE(392), 1,
      sym_boolean,
    STATE(515), 1,
      sym_binary_operator,
    STATE(529), 1,
      sym_cell,
    STATE(552), 1,
      sym_unary_operator,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(510), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(547), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(693), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [12917] = 25,
    ACTIONS(548), 1,
      sym_identifier,
    ACTIONS(574), 1,
      sym__single_quote_string_start,
    ACTIONS(576), 1,
      sym__double_quote_string_start,
    ACTIONS(653), 1,
      anon_sym_LPAREN,
    ACTIONS(663), 1,
      anon_sym_LBRACK,
    ACTIONS(667), 1,
      anon_sym_LBRACE,
    ACTIONS(669), 1,
      sym_number,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(808), 1,
      anon_sym_QMARK,
    ACTIONS(810), 1,
      anon_sym_AT,
    STATE(207), 1,
      sym_function_call,
    STATE(356), 1,
      sym_boolean,
    STATE(495), 1,
      sym_binary_operator,
    STATE(496), 1,
      sym_unary_operator,
    STATE(501), 1,
      sym_cell,
    STATE(541), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(990), 1,
      sym_indirect_access,
    STATE(1203), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(572), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(655), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(451), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(461), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(494), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [13005] = 25,
    ACTIONS(548), 1,
      sym_identifier,
    ACTIONS(574), 1,
      sym__single_quote_string_start,
    ACTIONS(576), 1,
      sym__double_quote_string_start,
    ACTIONS(653), 1,
      anon_sym_LPAREN,
    ACTIONS(663), 1,
      anon_sym_LBRACK,
    ACTIONS(667), 1,
      anon_sym_LBRACE,
    ACTIONS(669), 1,
      sym_number,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(808), 1,
      anon_sym_QMARK,
    ACTIONS(810), 1,
      anon_sym_AT,
    STATE(207), 1,
      sym_function_call,
    STATE(356), 1,
      sym_boolean,
    STATE(495), 1,
      sym_binary_operator,
    STATE(496), 1,
      sym_unary_operator,
    STATE(501), 1,
      sym_cell,
    STATE(541), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(990), 1,
      sym_indirect_access,
    STATE(1203), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(572), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(655), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(451), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(494), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(559), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13093] = 25,
    ACTIONS(548), 1,
      sym_identifier,
    ACTIONS(574), 1,
      sym__single_quote_string_start,
    ACTIONS(576), 1,
      sym__double_quote_string_start,
    ACTIONS(653), 1,
      anon_sym_LPAREN,
    ACTIONS(663), 1,
      anon_sym_LBRACK,
    ACTIONS(667), 1,
      anon_sym_LBRACE,
    ACTIONS(669), 1,
      sym_number,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(808), 1,
      anon_sym_QMARK,
    ACTIONS(810), 1,
      anon_sym_AT,
    STATE(207), 1,
      sym_function_call,
    STATE(356), 1,
      sym_boolean,
    STATE(495), 1,
      sym_binary_operator,
    STATE(496), 1,
      sym_unary_operator,
    STATE(501), 1,
      sym_cell,
    STATE(541), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(990), 1,
      sym_indirect_access,
    STATE(1203), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(572), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(655), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(451), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(494), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(563), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13181] = 23,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(790), 1,
      anon_sym_LBRACK,
    ACTIONS(792), 1,
      anon_sym_LBRACE,
    ACTIONS(798), 1,
      sym__single_quote_string_start,
    ACTIONS(800), 1,
      sym__double_quote_string_start,
    ACTIONS(812), 1,
      sym_identifier,
    ACTIONS(814), 1,
      sym_number,
    STATE(76), 1,
      sym_function_call,
    STATE(91), 1,
      sym_boolean,
    STATE(129), 1,
      sym_cell,
    STATE(132), 1,
      sym_unary_operator,
    STATE(136), 1,
      sym_binary_operator,
    STATE(1003), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(796), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(112), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(131), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(696), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13265] = 23,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(790), 1,
      anon_sym_LBRACK,
    ACTIONS(792), 1,
      anon_sym_LBRACE,
    ACTIONS(798), 1,
      sym__single_quote_string_start,
    ACTIONS(800), 1,
      sym__double_quote_string_start,
    ACTIONS(812), 1,
      sym_identifier,
    ACTIONS(814), 1,
      sym_number,
    STATE(76), 1,
      sym_function_call,
    STATE(91), 1,
      sym_boolean,
    STATE(129), 1,
      sym_cell,
    STATE(132), 1,
      sym_unary_operator,
    STATE(136), 1,
      sym_binary_operator,
    STATE(1003), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(796), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(113), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(131), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(696), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13349] = 23,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(790), 1,
      anon_sym_LBRACK,
    ACTIONS(792), 1,
      anon_sym_LBRACE,
    ACTIONS(798), 1,
      sym__single_quote_string_start,
    ACTIONS(800), 1,
      sym__double_quote_string_start,
    ACTIONS(812), 1,
      sym_identifier,
    ACTIONS(814), 1,
      sym_number,
    STATE(76), 1,
      sym_function_call,
    STATE(91), 1,
      sym_boolean,
    STATE(129), 1,
      sym_cell,
    STATE(132), 1,
      sym_unary_operator,
    STATE(136), 1,
      sym_binary_operator,
    STATE(1003), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(796), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(114), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(131), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(696), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13433] = 23,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(790), 1,
      anon_sym_LBRACK,
    ACTIONS(792), 1,
      anon_sym_LBRACE,
    ACTIONS(798), 1,
      sym__single_quote_string_start,
    ACTIONS(800), 1,
      sym__double_quote_string_start,
    ACTIONS(812), 1,
      sym_identifier,
    ACTIONS(814), 1,
      sym_number,
    STATE(76), 1,
      sym_function_call,
    STATE(91), 1,
      sym_boolean,
    STATE(129), 1,
      sym_cell,
    STATE(132), 1,
      sym_unary_operator,
    STATE(136), 1,
      sym_binary_operator,
    STATE(1003), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(796), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(115), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(131), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(696), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13517] = 23,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(790), 1,
      anon_sym_LBRACK,
    ACTIONS(792), 1,
      anon_sym_LBRACE,
    ACTIONS(798), 1,
      sym__single_quote_string_start,
    ACTIONS(800), 1,
      sym__double_quote_string_start,
    ACTIONS(812), 1,
      sym_identifier,
    ACTIONS(814), 1,
      sym_number,
    STATE(76), 1,
      sym_function_call,
    STATE(91), 1,
      sym_boolean,
    STATE(129), 1,
      sym_cell,
    STATE(132), 1,
      sym_unary_operator,
    STATE(136), 1,
      sym_binary_operator,
    STATE(1003), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(796), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(102), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(131), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(696), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13601] = 25,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(790), 1,
      anon_sym_LBRACK,
    ACTIONS(798), 1,
      sym__single_quote_string_start,
    ACTIONS(800), 1,
      sym__double_quote_string_start,
    ACTIONS(816), 1,
      sym_identifier,
    ACTIONS(818), 1,
      sym_number,
    STATE(79), 1,
      sym_function_call,
    STATE(93), 1,
      sym_boolean,
    STATE(116), 1,
      sym__range_element,
    STATE(134), 1,
      sym_unary_operator,
    STATE(135), 1,
      sym_not_operator,
    STATE(137), 1,
      sym_binary_operator,
    STATE(591), 1,
      sym_cell,
    STATE(616), 1,
      sym__binary_expression,
    STATE(1003), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(796), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(133), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(692), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13689] = 25,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(625), 1,
      anon_sym_AT,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(722), 1,
      sym_identifier,
    STATE(351), 1,
      sym_function_call,
    STATE(417), 1,
      sym_boolean,
    STATE(511), 1,
      sym_binary_operator,
    STATE(523), 1,
      sym_cell,
    STATE(548), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(516), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(631), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13777] = 25,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(820), 1,
      sym_identifier,
    ACTIONS(822), 1,
      sym_number,
    STATE(359), 1,
      sym_function_call,
    STATE(395), 1,
      sym_boolean,
    STATE(523), 1,
      sym_cell,
    STATE(535), 1,
      sym_unary_operator,
    STATE(536), 1,
      sym_not_operator,
    STATE(553), 1,
      sym__range_element,
    STATE(554), 1,
      sym_binary_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(521), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(692), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13865] = 25,
    ACTIONS(548), 1,
      sym_identifier,
    ACTIONS(574), 1,
      sym__single_quote_string_start,
    ACTIONS(576), 1,
      sym__double_quote_string_start,
    ACTIONS(653), 1,
      anon_sym_LPAREN,
    ACTIONS(659), 1,
      anon_sym_QMARK,
    ACTIONS(661), 1,
      anon_sym_AT,
    ACTIONS(663), 1,
      anon_sym_LBRACK,
    ACTIONS(667), 1,
      anon_sym_LBRACE,
    ACTIONS(669), 1,
      sym_number,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    STATE(207), 1,
      sym_function_call,
    STATE(356), 1,
      sym_boolean,
    STATE(495), 1,
      sym_binary_operator,
    STATE(496), 1,
      sym_unary_operator,
    STATE(501), 1,
      sym_cell,
    STATE(541), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(990), 1,
      sym_indirect_access,
    STATE(1203), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(572), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(655), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(451), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(494), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(555), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [13953] = 7,
    ACTIONS(730), 1,
      anon_sym_LPAREN,
    ACTIONS(734), 1,
      anon_sym_AT,
    ACTIONS(738), 1,
      anon_sym_LBRACE,
    STATE(368), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(389), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(387), 29,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [14005] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(15), 1,
      anon_sym_QMARK,
    ACTIONS(17), 1,
      anon_sym_AT,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      sym_number,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(746), 1,
      anon_sym_TILDE,
    ACTIONS(802), 1,
      sym_identifier,
    STATE(193), 1,
      sym_function_call,
    STATE(214), 1,
      sym_boolean,
    STATE(384), 1,
      sym_binary_operator,
    STATE(411), 1,
      sym_unary_operator,
    STATE(430), 1,
      sym_cell,
    STATE(493), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(914), 1,
      sym_indirect_access,
    STATE(1243), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(427), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(415), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(634), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [14093] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(746), 1,
      anon_sym_TILDE,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(824), 1,
      sym_identifier,
    ACTIONS(826), 1,
      sym_number,
    STATE(189), 1,
      sym_function_call,
    STATE(218), 1,
      sym_boolean,
    STATE(387), 1,
      sym_unary_operator,
    STATE(388), 1,
      sym_not_operator,
    STATE(396), 1,
      sym_binary_operator,
    STATE(432), 1,
      sym__range_element,
    STATE(589), 1,
      sym_cell,
    STATE(614), 1,
      sym__binary_expression,
    STATE(914), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(386), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(692), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [14181] = 4,
    ACTIONS(714), 1,
      anon_sym_DOT,
    STATE(316), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(391), 33,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [14227] = 25,
    ACTIONS(548), 1,
      sym_identifier,
    ACTIONS(574), 1,
      sym__single_quote_string_start,
    ACTIONS(576), 1,
      sym__double_quote_string_start,
    ACTIONS(653), 1,
      anon_sym_LPAREN,
    ACTIONS(659), 1,
      anon_sym_QMARK,
    ACTIONS(661), 1,
      anon_sym_AT,
    ACTIONS(663), 1,
      anon_sym_LBRACK,
    ACTIONS(667), 1,
      anon_sym_LBRACE,
    ACTIONS(669), 1,
      sym_number,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    STATE(207), 1,
      sym_function_call,
    STATE(356), 1,
      sym_boolean,
    STATE(495), 1,
      sym_binary_operator,
    STATE(496), 1,
      sym_unary_operator,
    STATE(501), 1,
      sym_cell,
    STATE(541), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(990), 1,
      sym_indirect_access,
    STATE(1203), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(572), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(655), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(451), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(494), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(558), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [14315] = 5,
    STATE(310), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(828), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(679), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(681), 18,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [14363] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      sym_number,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(746), 1,
      anon_sym_TILDE,
    ACTIONS(748), 1,
      anon_sym_QMARK,
    ACTIONS(802), 1,
      sym_identifier,
    ACTIONS(830), 1,
      anon_sym_AT,
    STATE(193), 1,
      sym_function_call,
    STATE(214), 1,
      sym_boolean,
    STATE(384), 1,
      sym_binary_operator,
    STATE(411), 1,
      sym_unary_operator,
    STATE(430), 1,
      sym_cell,
    STATE(493), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(914), 1,
      sym_indirect_access,
    STATE(1243), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(427), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(406), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(415), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [14451] = 25,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(790), 1,
      anon_sym_LBRACK,
    ACTIONS(798), 1,
      sym__single_quote_string_start,
    ACTIONS(800), 1,
      sym__double_quote_string_start,
    ACTIONS(816), 1,
      sym_identifier,
    ACTIONS(818), 1,
      sym_number,
    STATE(79), 1,
      sym_function_call,
    STATE(93), 1,
      sym_boolean,
    STATE(119), 1,
      sym__range_element,
    STATE(134), 1,
      sym_unary_operator,
    STATE(135), 1,
      sym_not_operator,
    STATE(137), 1,
      sym_binary_operator,
    STATE(591), 1,
      sym_cell,
    STATE(616), 1,
      sym__binary_expression,
    STATE(1003), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(796), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(133), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(692), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [14539] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      sym_number,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(746), 1,
      anon_sym_TILDE,
    ACTIONS(748), 1,
      anon_sym_QMARK,
    ACTIONS(802), 1,
      sym_identifier,
    ACTIONS(830), 1,
      anon_sym_AT,
    STATE(193), 1,
      sym_function_call,
    STATE(214), 1,
      sym_boolean,
    STATE(384), 1,
      sym_binary_operator,
    STATE(411), 1,
      sym_unary_operator,
    STATE(430), 1,
      sym_cell,
    STATE(493), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(914), 1,
      sym_indirect_access,
    STATE(1243), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(427), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(415), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(509), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [14627] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      sym_number,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(746), 1,
      anon_sym_TILDE,
    ACTIONS(748), 1,
      anon_sym_QMARK,
    ACTIONS(802), 1,
      sym_identifier,
    ACTIONS(830), 1,
      anon_sym_AT,
    STATE(193), 1,
      sym_function_call,
    STATE(214), 1,
      sym_boolean,
    STATE(384), 1,
      sym_binary_operator,
    STATE(411), 1,
      sym_unary_operator,
    STATE(430), 1,
      sym_cell,
    STATE(493), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(914), 1,
      sym_indirect_access,
    STATE(1243), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(427), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(415), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(505), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [14715] = 23,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(746), 1,
      anon_sym_TILDE,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(832), 1,
      sym_identifier,
    ACTIONS(834), 1,
      sym_number,
    STATE(191), 1,
      sym_function_call,
    STATE(217), 1,
      sym_boolean,
    STATE(382), 1,
      sym_unary_operator,
    STATE(394), 1,
      sym_binary_operator,
    STATE(400), 1,
      sym_cell,
    STATE(914), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(429), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(381), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(694), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [14799] = 23,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(746), 1,
      anon_sym_TILDE,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(832), 1,
      sym_identifier,
    ACTIONS(834), 1,
      sym_number,
    STATE(191), 1,
      sym_function_call,
    STATE(217), 1,
      sym_boolean,
    STATE(382), 1,
      sym_unary_operator,
    STATE(394), 1,
      sym_binary_operator,
    STATE(400), 1,
      sym_cell,
    STATE(914), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(431), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(381), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(694), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [14883] = 5,
    ACTIONS(840), 1,
      anon_sym_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(271), 2,
      sym_arguments_statement,
      aux_sym_function_definition_repeat1,
    ACTIONS(836), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(838), 18,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [14931] = 23,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(746), 1,
      anon_sym_TILDE,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(832), 1,
      sym_identifier,
    ACTIONS(834), 1,
      sym_number,
    STATE(191), 1,
      sym_function_call,
    STATE(217), 1,
      sym_boolean,
    STATE(382), 1,
      sym_unary_operator,
    STATE(394), 1,
      sym_binary_operator,
    STATE(400), 1,
      sym_cell,
    STATE(914), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(434), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(381), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(694), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [15015] = 23,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(746), 1,
      anon_sym_TILDE,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(832), 1,
      sym_identifier,
    ACTIONS(834), 1,
      sym_number,
    STATE(191), 1,
      sym_function_call,
    STATE(217), 1,
      sym_boolean,
    STATE(382), 1,
      sym_unary_operator,
    STATE(394), 1,
      sym_binary_operator,
    STATE(400), 1,
      sym_cell,
    STATE(914), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(443), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(381), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(694), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [15099] = 23,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(746), 1,
      anon_sym_TILDE,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(832), 1,
      sym_identifier,
    ACTIONS(834), 1,
      sym_number,
    STATE(191), 1,
      sym_function_call,
    STATE(217), 1,
      sym_boolean,
    STATE(382), 1,
      sym_unary_operator,
    STATE(394), 1,
      sym_binary_operator,
    STATE(400), 1,
      sym_cell,
    STATE(914), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(438), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(381), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(694), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [15183] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(746), 1,
      anon_sym_TILDE,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(824), 1,
      sym_identifier,
    ACTIONS(826), 1,
      sym_number,
    STATE(189), 1,
      sym_function_call,
    STATE(218), 1,
      sym_boolean,
    STATE(387), 1,
      sym_unary_operator,
    STATE(388), 1,
      sym_not_operator,
    STATE(396), 1,
      sym_binary_operator,
    STATE(414), 1,
      sym__range_element,
    STATE(589), 1,
      sym_cell,
    STATE(614), 1,
      sym__binary_expression,
    STATE(914), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(386), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(692), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [15271] = 25,
    ACTIONS(778), 1,
      sym_identifier,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(790), 1,
      anon_sym_LBRACK,
    ACTIONS(792), 1,
      anon_sym_LBRACE,
    ACTIONS(794), 1,
      sym_number,
    ACTIONS(798), 1,
      sym__single_quote_string_start,
    ACTIONS(800), 1,
      sym__double_quote_string_start,
    ACTIONS(843), 1,
      anon_sym_QMARK,
    ACTIONS(845), 1,
      anon_sym_AT,
    STATE(78), 1,
      sym_function_call,
    STATE(96), 1,
      sym_boolean,
    STATE(121), 1,
      sym_binary_operator,
    STATE(139), 1,
      sym_unary_operator,
    STATE(141), 1,
      sym_cell,
    STATE(147), 1,
      sym_not_operator,
    STATE(616), 1,
      sym__binary_expression,
    STATE(1003), 1,
      sym_indirect_access,
    STATE(1265), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(796), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(140), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(111), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(120), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [15359] = 25,
    ACTIONS(778), 1,
      sym_identifier,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(790), 1,
      anon_sym_LBRACK,
    ACTIONS(792), 1,
      anon_sym_LBRACE,
    ACTIONS(794), 1,
      sym_number,
    ACTIONS(798), 1,
      sym__single_quote_string_start,
    ACTIONS(800), 1,
      sym__double_quote_string_start,
    ACTIONS(843), 1,
      anon_sym_QMARK,
    ACTIONS(845), 1,
      anon_sym_AT,
    STATE(78), 1,
      sym_function_call,
    STATE(96), 1,
      sym_boolean,
    STATE(121), 1,
      sym_binary_operator,
    STATE(139), 1,
      sym_unary_operator,
    STATE(141), 1,
      sym_cell,
    STATE(147), 1,
      sym_not_operator,
    STATE(616), 1,
      sym__binary_expression,
    STATE(1003), 1,
      sym_indirect_access,
    STATE(1265), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(796), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(140), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(120), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(151), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [15447] = 25,
    ACTIONS(778), 1,
      sym_identifier,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(790), 1,
      anon_sym_LBRACK,
    ACTIONS(792), 1,
      anon_sym_LBRACE,
    ACTIONS(794), 1,
      sym_number,
    ACTIONS(798), 1,
      sym__single_quote_string_start,
    ACTIONS(800), 1,
      sym__double_quote_string_start,
    ACTIONS(843), 1,
      anon_sym_QMARK,
    ACTIONS(845), 1,
      anon_sym_AT,
    STATE(78), 1,
      sym_function_call,
    STATE(96), 1,
      sym_boolean,
    STATE(121), 1,
      sym_binary_operator,
    STATE(139), 1,
      sym_unary_operator,
    STATE(141), 1,
      sym_cell,
    STATE(147), 1,
      sym_not_operator,
    STATE(616), 1,
      sym__binary_expression,
    STATE(1003), 1,
      sym_indirect_access,
    STATE(1265), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(796), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(140), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(120), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(149), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [15535] = 14,
    ACTIONS(356), 1,
      anon_sym_COLON,
    ACTIONS(847), 1,
      anon_sym_LPAREN,
    ACTIONS(849), 1,
      anon_sym_DOT,
    ACTIONS(851), 1,
      anon_sym_AT,
    ACTIONS(855), 1,
      anon_sym_LBRACE,
    ACTIONS(857), 1,
      anon_sym_EQ,
    STATE(416), 1,
      sym__args,
    STATE(486), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [15601] = 25,
    ACTIONS(778), 1,
      sym_identifier,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(786), 1,
      anon_sym_QMARK,
    ACTIONS(788), 1,
      anon_sym_AT,
    ACTIONS(790), 1,
      anon_sym_LBRACK,
    ACTIONS(792), 1,
      anon_sym_LBRACE,
    ACTIONS(794), 1,
      sym_number,
    ACTIONS(798), 1,
      sym__single_quote_string_start,
    ACTIONS(800), 1,
      sym__double_quote_string_start,
    STATE(78), 1,
      sym_function_call,
    STATE(96), 1,
      sym_boolean,
    STATE(121), 1,
      sym_binary_operator,
    STATE(139), 1,
      sym_unary_operator,
    STATE(141), 1,
      sym_cell,
    STATE(147), 1,
      sym_not_operator,
    STATE(616), 1,
      sym__binary_expression,
    STATE(1003), 1,
      sym_indirect_access,
    STATE(1265), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(796), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(140), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(120), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(150), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [15689] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(15), 1,
      anon_sym_QMARK,
    ACTIONS(17), 1,
      anon_sym_AT,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      sym_number,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(746), 1,
      anon_sym_TILDE,
    ACTIONS(802), 1,
      sym_identifier,
    STATE(193), 1,
      sym_function_call,
    STATE(214), 1,
      sym_boolean,
    STATE(384), 1,
      sym_binary_operator,
    STATE(411), 1,
      sym_unary_operator,
    STATE(430), 1,
      sym_cell,
    STATE(493), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(914), 1,
      sym_indirect_access,
    STATE(1243), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(427), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(415), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(507), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [15777] = 25,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(859), 1,
      sym_identifier,
    ACTIONS(861), 1,
      anon_sym_QMARK,
    ACTIONS(863), 1,
      anon_sym_AT,
    STATE(366), 1,
      sym_function_call,
    STATE(417), 1,
      sym_boolean,
    STATE(511), 1,
      sym_binary_operator,
    STATE(523), 1,
      sym_cell,
    STATE(548), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(516), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(582), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [15865] = 25,
    ACTIONS(778), 1,
      sym_identifier,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(786), 1,
      anon_sym_QMARK,
    ACTIONS(788), 1,
      anon_sym_AT,
    ACTIONS(790), 1,
      anon_sym_LBRACK,
    ACTIONS(792), 1,
      anon_sym_LBRACE,
    ACTIONS(794), 1,
      sym_number,
    ACTIONS(798), 1,
      sym__single_quote_string_start,
    ACTIONS(800), 1,
      sym__double_quote_string_start,
    STATE(78), 1,
      sym_function_call,
    STATE(96), 1,
      sym_boolean,
    STATE(121), 1,
      sym_binary_operator,
    STATE(139), 1,
      sym_unary_operator,
    STATE(141), 1,
      sym_cell,
    STATE(147), 1,
      sym_not_operator,
    STATE(616), 1,
      sym__binary_expression,
    STATE(1003), 1,
      sym_indirect_access,
    STATE(1265), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(796), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(140), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(120), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(148), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [15953] = 25,
    ACTIONS(778), 1,
      sym_identifier,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(786), 1,
      anon_sym_QMARK,
    ACTIONS(788), 1,
      anon_sym_AT,
    ACTIONS(790), 1,
      anon_sym_LBRACK,
    ACTIONS(792), 1,
      anon_sym_LBRACE,
    ACTIONS(794), 1,
      sym_number,
    ACTIONS(798), 1,
      sym__single_quote_string_start,
    ACTIONS(800), 1,
      sym__double_quote_string_start,
    STATE(78), 1,
      sym_function_call,
    STATE(96), 1,
      sym_boolean,
    STATE(121), 1,
      sym_binary_operator,
    STATE(139), 1,
      sym_unary_operator,
    STATE(141), 1,
      sym_cell,
    STATE(147), 1,
      sym_not_operator,
    STATE(616), 1,
      sym__binary_expression,
    STATE(1003), 1,
      sym_indirect_access,
    STATE(1265), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(796), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(140), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(3), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(120), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [16041] = 25,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(861), 1,
      anon_sym_QMARK,
    ACTIONS(865), 1,
      sym_identifier,
    ACTIONS(867), 1,
      anon_sym_AT,
    ACTIONS(869), 1,
      sym_number,
    STATE(363), 1,
      sym_function_call,
    STATE(445), 1,
      sym_boolean,
    STATE(523), 1,
      sym_cell,
    STATE(524), 1,
      sym_binary_operator,
    STATE(527), 1,
      sym_not_operator,
    STATE(551), 1,
      sym_unary_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(534), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(537), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [16129] = 25,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(859), 1,
      sym_identifier,
    STATE(366), 1,
      sym_function_call,
    STATE(417), 1,
      sym_boolean,
    STATE(511), 1,
      sym_binary_operator,
    STATE(523), 1,
      sym_cell,
    STATE(548), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(516), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(584), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [16217] = 25,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(861), 1,
      anon_sym_QMARK,
    ACTIONS(865), 1,
      sym_identifier,
    ACTIONS(867), 1,
      anon_sym_AT,
    ACTIONS(869), 1,
      sym_number,
    STATE(363), 1,
      sym_function_call,
    STATE(445), 1,
      sym_boolean,
    STATE(523), 1,
      sym_cell,
    STATE(524), 1,
      sym_binary_operator,
    STATE(527), 1,
      sym_not_operator,
    STATE(551), 1,
      sym_unary_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(534), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(544), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [16305] = 25,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(861), 1,
      anon_sym_QMARK,
    ACTIONS(865), 1,
      sym_identifier,
    ACTIONS(867), 1,
      anon_sym_AT,
    ACTIONS(869), 1,
      sym_number,
    STATE(363), 1,
      sym_function_call,
    STATE(445), 1,
      sym_boolean,
    STATE(523), 1,
      sym_cell,
    STATE(524), 1,
      sym_binary_operator,
    STATE(527), 1,
      sym_not_operator,
    STATE(551), 1,
      sym_unary_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(513), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(534), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [16393] = 25,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(861), 1,
      anon_sym_QMARK,
    ACTIONS(865), 1,
      sym_identifier,
    ACTIONS(867), 1,
      anon_sym_AT,
    ACTIONS(869), 1,
      sym_number,
    STATE(363), 1,
      sym_function_call,
    STATE(445), 1,
      sym_boolean,
    STATE(523), 1,
      sym_cell,
    STATE(524), 1,
      sym_binary_operator,
    STATE(527), 1,
      sym_not_operator,
    STATE(551), 1,
      sym_unary_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(514), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(534), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [16481] = 25,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(861), 1,
      anon_sym_QMARK,
    ACTIONS(865), 1,
      sym_identifier,
    ACTIONS(867), 1,
      anon_sym_AT,
    ACTIONS(869), 1,
      sym_number,
    STATE(363), 1,
      sym_function_call,
    STATE(445), 1,
      sym_boolean,
    STATE(523), 1,
      sym_cell,
    STATE(524), 1,
      sym_binary_operator,
    STATE(527), 1,
      sym_not_operator,
    STATE(551), 1,
      sym_unary_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(518), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(534), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [16569] = 25,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(861), 1,
      anon_sym_QMARK,
    ACTIONS(865), 1,
      sym_identifier,
    ACTIONS(867), 1,
      anon_sym_AT,
    ACTIONS(869), 1,
      sym_number,
    STATE(363), 1,
      sym_function_call,
    STATE(445), 1,
      sym_boolean,
    STATE(523), 1,
      sym_cell,
    STATE(524), 1,
      sym_binary_operator,
    STATE(527), 1,
      sym_not_operator,
    STATE(551), 1,
      sym_unary_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(520), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(534), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [16657] = 25,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(625), 1,
      anon_sym_AT,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(722), 1,
      sym_identifier,
    STATE(351), 1,
      sym_function_call,
    STATE(417), 1,
      sym_boolean,
    STATE(511), 1,
      sym_binary_operator,
    STATE(523), 1,
      sym_cell,
    STATE(548), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(516), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(628), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [16745] = 25,
    ACTIONS(574), 1,
      sym__single_quote_string_start,
    ACTIONS(576), 1,
      sym__double_quote_string_start,
    ACTIONS(601), 1,
      sym_identifier,
    ACTIONS(653), 1,
      anon_sym_LPAREN,
    ACTIONS(663), 1,
      anon_sym_LBRACK,
    ACTIONS(667), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(808), 1,
      anon_sym_QMARK,
    ACTIONS(871), 1,
      anon_sym_AT,
    ACTIONS(873), 1,
      sym_number,
    STATE(215), 1,
      sym_function_call,
    STATE(349), 1,
      sym_boolean,
    STATE(460), 1,
      sym_binary_operator,
    STATE(491), 1,
      sym_not_operator,
    STATE(501), 1,
      sym_cell,
    STATE(504), 1,
      sym_unary_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(990), 1,
      sym_indirect_access,
    STATE(1203), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(572), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(655), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(451), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(461), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(489), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [16833] = 25,
    ACTIONS(574), 1,
      sym__single_quote_string_start,
    ACTIONS(576), 1,
      sym__double_quote_string_start,
    ACTIONS(601), 1,
      sym_identifier,
    ACTIONS(653), 1,
      anon_sym_LPAREN,
    ACTIONS(663), 1,
      anon_sym_LBRACK,
    ACTIONS(667), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(808), 1,
      anon_sym_QMARK,
    ACTIONS(871), 1,
      anon_sym_AT,
    ACTIONS(873), 1,
      sym_number,
    STATE(215), 1,
      sym_function_call,
    STATE(349), 1,
      sym_boolean,
    STATE(460), 1,
      sym_binary_operator,
    STATE(491), 1,
      sym_not_operator,
    STATE(501), 1,
      sym_cell,
    STATE(504), 1,
      sym_unary_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(990), 1,
      sym_indirect_access,
    STATE(1203), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(572), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(655), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(451), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(489), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(497), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [16921] = 25,
    ACTIONS(574), 1,
      sym__single_quote_string_start,
    ACTIONS(576), 1,
      sym__double_quote_string_start,
    ACTIONS(601), 1,
      sym_identifier,
    ACTIONS(653), 1,
      anon_sym_LPAREN,
    ACTIONS(663), 1,
      anon_sym_LBRACK,
    ACTIONS(667), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(808), 1,
      anon_sym_QMARK,
    ACTIONS(871), 1,
      anon_sym_AT,
    ACTIONS(873), 1,
      sym_number,
    STATE(215), 1,
      sym_function_call,
    STATE(349), 1,
      sym_boolean,
    STATE(460), 1,
      sym_binary_operator,
    STATE(491), 1,
      sym_not_operator,
    STATE(501), 1,
      sym_cell,
    STATE(504), 1,
      sym_unary_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(990), 1,
      sym_indirect_access,
    STATE(1203), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(572), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(655), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(451), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(489), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(498), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [17009] = 25,
    ACTIONS(574), 1,
      sym__single_quote_string_start,
    ACTIONS(576), 1,
      sym__double_quote_string_start,
    ACTIONS(601), 1,
      sym_identifier,
    ACTIONS(653), 1,
      anon_sym_LPAREN,
    ACTIONS(663), 1,
      anon_sym_LBRACK,
    ACTIONS(667), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(808), 1,
      anon_sym_QMARK,
    ACTIONS(871), 1,
      anon_sym_AT,
    ACTIONS(873), 1,
      sym_number,
    STATE(215), 1,
      sym_function_call,
    STATE(349), 1,
      sym_boolean,
    STATE(460), 1,
      sym_binary_operator,
    STATE(491), 1,
      sym_not_operator,
    STATE(501), 1,
      sym_cell,
    STATE(504), 1,
      sym_unary_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(990), 1,
      sym_indirect_access,
    STATE(1203), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(572), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(655), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(451), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(489), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(499), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [17097] = 25,
    ACTIONS(574), 1,
      sym__single_quote_string_start,
    ACTIONS(576), 1,
      sym__double_quote_string_start,
    ACTIONS(601), 1,
      sym_identifier,
    ACTIONS(653), 1,
      anon_sym_LPAREN,
    ACTIONS(663), 1,
      anon_sym_LBRACK,
    ACTIONS(667), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(808), 1,
      anon_sym_QMARK,
    ACTIONS(871), 1,
      anon_sym_AT,
    ACTIONS(873), 1,
      sym_number,
    STATE(215), 1,
      sym_function_call,
    STATE(349), 1,
      sym_boolean,
    STATE(460), 1,
      sym_binary_operator,
    STATE(491), 1,
      sym_not_operator,
    STATE(501), 1,
      sym_cell,
    STATE(504), 1,
      sym_unary_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(990), 1,
      sym_indirect_access,
    STATE(1203), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(572), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(655), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(451), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(489), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(500), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [17185] = 14,
    ACTIONS(356), 1,
      anon_sym_COLON,
    ACTIONS(847), 1,
      anon_sym_LPAREN,
    ACTIONS(849), 1,
      anon_sym_DOT,
    ACTIONS(851), 1,
      anon_sym_AT,
    ACTIONS(855), 1,
      anon_sym_LBRACE,
    ACTIONS(875), 1,
      anon_sym_EQ,
    STATE(416), 1,
      sym__args,
    STATE(486), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [17251] = 25,
    ACTIONS(778), 1,
      sym_identifier,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(786), 1,
      anon_sym_QMARK,
    ACTIONS(788), 1,
      anon_sym_AT,
    ACTIONS(790), 1,
      anon_sym_LBRACK,
    ACTIONS(792), 1,
      anon_sym_LBRACE,
    ACTIONS(794), 1,
      sym_number,
    ACTIONS(798), 1,
      sym__single_quote_string_start,
    ACTIONS(800), 1,
      sym__double_quote_string_start,
    STATE(78), 1,
      sym_function_call,
    STATE(96), 1,
      sym_boolean,
    STATE(121), 1,
      sym_binary_operator,
    STATE(139), 1,
      sym_unary_operator,
    STATE(141), 1,
      sym_cell,
    STATE(147), 1,
      sym_not_operator,
    STATE(616), 1,
      sym__binary_expression,
    STATE(1003), 1,
      sym_indirect_access,
    STATE(1265), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(796), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(140), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(120), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(159), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [17339] = 14,
    ACTIONS(356), 1,
      anon_sym_COLON,
    ACTIONS(847), 1,
      anon_sym_LPAREN,
    ACTIONS(849), 1,
      anon_sym_DOT,
    ACTIONS(851), 1,
      anon_sym_AT,
    ACTIONS(855), 1,
      anon_sym_LBRACE,
    ACTIONS(877), 1,
      anon_sym_EQ,
    STATE(416), 1,
      sym__args,
    STATE(486), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [17405] = 25,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(790), 1,
      anon_sym_LBRACK,
    ACTIONS(792), 1,
      anon_sym_LBRACE,
    ACTIONS(798), 1,
      sym__single_quote_string_start,
    ACTIONS(800), 1,
      sym__double_quote_string_start,
    ACTIONS(843), 1,
      anon_sym_QMARK,
    ACTIONS(879), 1,
      sym_identifier,
    ACTIONS(881), 1,
      anon_sym_AT,
    ACTIONS(883), 1,
      sym_number,
    STATE(77), 1,
      sym_function_call,
    STATE(90), 1,
      sym_boolean,
    STATE(122), 1,
      sym_unary_operator,
    STATE(124), 1,
      sym_not_operator,
    STATE(130), 1,
      sym_binary_operator,
    STATE(141), 1,
      sym_cell,
    STATE(616), 1,
      sym__binary_expression,
    STATE(1003), 1,
      sym_indirect_access,
    STATE(1265), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(796), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(140), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(111), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(123), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [17493] = 25,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(790), 1,
      anon_sym_LBRACK,
    ACTIONS(792), 1,
      anon_sym_LBRACE,
    ACTIONS(798), 1,
      sym__single_quote_string_start,
    ACTIONS(800), 1,
      sym__double_quote_string_start,
    ACTIONS(843), 1,
      anon_sym_QMARK,
    ACTIONS(879), 1,
      sym_identifier,
    ACTIONS(881), 1,
      anon_sym_AT,
    ACTIONS(883), 1,
      sym_number,
    STATE(77), 1,
      sym_function_call,
    STATE(90), 1,
      sym_boolean,
    STATE(122), 1,
      sym_unary_operator,
    STATE(124), 1,
      sym_not_operator,
    STATE(130), 1,
      sym_binary_operator,
    STATE(141), 1,
      sym_cell,
    STATE(616), 1,
      sym__binary_expression,
    STATE(1003), 1,
      sym_indirect_access,
    STATE(1265), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(796), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(140), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(123), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(125), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [17581] = 25,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(790), 1,
      anon_sym_LBRACK,
    ACTIONS(792), 1,
      anon_sym_LBRACE,
    ACTIONS(798), 1,
      sym__single_quote_string_start,
    ACTIONS(800), 1,
      sym__double_quote_string_start,
    ACTIONS(843), 1,
      anon_sym_QMARK,
    ACTIONS(879), 1,
      sym_identifier,
    ACTIONS(881), 1,
      anon_sym_AT,
    ACTIONS(883), 1,
      sym_number,
    STATE(77), 1,
      sym_function_call,
    STATE(90), 1,
      sym_boolean,
    STATE(122), 1,
      sym_unary_operator,
    STATE(124), 1,
      sym_not_operator,
    STATE(130), 1,
      sym_binary_operator,
    STATE(141), 1,
      sym_cell,
    STATE(616), 1,
      sym__binary_expression,
    STATE(1003), 1,
      sym_indirect_access,
    STATE(1265), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(796), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(140), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(123), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(126), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [17669] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(15), 1,
      anon_sym_QMARK,
    ACTIONS(17), 1,
      anon_sym_AT,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      sym_number,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(746), 1,
      anon_sym_TILDE,
    ACTIONS(802), 1,
      sym_identifier,
    STATE(193), 1,
      sym_function_call,
    STATE(214), 1,
      sym_boolean,
    STATE(384), 1,
      sym_binary_operator,
    STATE(411), 1,
      sym_unary_operator,
    STATE(430), 1,
      sym_cell,
    STATE(493), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(914), 1,
      sym_indirect_access,
    STATE(1243), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(427), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(415), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(612), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [17757] = 25,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(790), 1,
      anon_sym_LBRACK,
    ACTIONS(792), 1,
      anon_sym_LBRACE,
    ACTIONS(798), 1,
      sym__single_quote_string_start,
    ACTIONS(800), 1,
      sym__double_quote_string_start,
    ACTIONS(843), 1,
      anon_sym_QMARK,
    ACTIONS(879), 1,
      sym_identifier,
    ACTIONS(881), 1,
      anon_sym_AT,
    ACTIONS(883), 1,
      sym_number,
    STATE(77), 1,
      sym_function_call,
    STATE(90), 1,
      sym_boolean,
    STATE(122), 1,
      sym_unary_operator,
    STATE(124), 1,
      sym_not_operator,
    STATE(130), 1,
      sym_binary_operator,
    STATE(141), 1,
      sym_cell,
    STATE(616), 1,
      sym__binary_expression,
    STATE(1003), 1,
      sym_indirect_access,
    STATE(1265), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(796), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(140), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(123), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(127), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [17845] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(15), 1,
      anon_sym_QMARK,
    ACTIONS(17), 1,
      anon_sym_AT,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      sym_number,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(746), 1,
      anon_sym_TILDE,
    ACTIONS(802), 1,
      sym_identifier,
    STATE(193), 1,
      sym_function_call,
    STATE(214), 1,
      sym_boolean,
    STATE(384), 1,
      sym_binary_operator,
    STATE(411), 1,
      sym_unary_operator,
    STATE(430), 1,
      sym_cell,
    STATE(493), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(914), 1,
      sym_indirect_access,
    STATE(1243), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(427), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(415), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(629), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [17933] = 25,
    ACTIONS(778), 1,
      sym_identifier,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(786), 1,
      anon_sym_QMARK,
    ACTIONS(788), 1,
      anon_sym_AT,
    ACTIONS(790), 1,
      anon_sym_LBRACK,
    ACTIONS(792), 1,
      anon_sym_LBRACE,
    ACTIONS(794), 1,
      sym_number,
    ACTIONS(798), 1,
      sym__single_quote_string_start,
    ACTIONS(800), 1,
      sym__double_quote_string_start,
    STATE(78), 1,
      sym_function_call,
    STATE(96), 1,
      sym_boolean,
    STATE(121), 1,
      sym_binary_operator,
    STATE(139), 1,
      sym_unary_operator,
    STATE(141), 1,
      sym_cell,
    STATE(147), 1,
      sym_not_operator,
    STATE(616), 1,
      sym__binary_expression,
    STATE(1003), 1,
      sym_indirect_access,
    STATE(1265), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(796), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(140), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(2), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(120), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [18021] = 25,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(790), 1,
      anon_sym_LBRACK,
    ACTIONS(792), 1,
      anon_sym_LBRACE,
    ACTIONS(798), 1,
      sym__single_quote_string_start,
    ACTIONS(800), 1,
      sym__double_quote_string_start,
    ACTIONS(843), 1,
      anon_sym_QMARK,
    ACTIONS(879), 1,
      sym_identifier,
    ACTIONS(881), 1,
      anon_sym_AT,
    ACTIONS(883), 1,
      sym_number,
    STATE(77), 1,
      sym_function_call,
    STATE(90), 1,
      sym_boolean,
    STATE(122), 1,
      sym_unary_operator,
    STATE(124), 1,
      sym_not_operator,
    STATE(130), 1,
      sym_binary_operator,
    STATE(141), 1,
      sym_cell,
    STATE(616), 1,
      sym__binary_expression,
    STATE(1003), 1,
      sym_indirect_access,
    STATE(1265), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(796), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(140), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(123), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(128), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [18109] = 5,
    STATE(315), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(885), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(685), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(687), 18,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [18157] = 5,
    STATE(315), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(885), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(645), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(647), 18,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [18205] = 25,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(859), 1,
      sym_identifier,
    STATE(366), 1,
      sym_function_call,
    STATE(417), 1,
      sym_boolean,
    STATE(511), 1,
      sym_binary_operator,
    STATE(523), 1,
      sym_cell,
    STATE(548), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(516), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(585), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [18293] = 14,
    ACTIONS(356), 1,
      anon_sym_COLON,
    ACTIONS(847), 1,
      anon_sym_LPAREN,
    ACTIONS(849), 1,
      anon_sym_DOT,
    ACTIONS(851), 1,
      anon_sym_AT,
    ACTIONS(855), 1,
      anon_sym_LBRACE,
    ACTIONS(887), 1,
      anon_sym_EQ,
    STATE(416), 1,
      sym__args,
    STATE(486), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [18359] = 25,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(625), 1,
      anon_sym_AT,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(722), 1,
      sym_identifier,
    STATE(351), 1,
      sym_function_call,
    STATE(417), 1,
      sym_boolean,
    STATE(511), 1,
      sym_binary_operator,
    STATE(523), 1,
      sym_cell,
    STATE(548), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(516), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(637), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [18447] = 25,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(625), 1,
      anon_sym_AT,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(722), 1,
      sym_identifier,
    STATE(351), 1,
      sym_function_call,
    STATE(417), 1,
      sym_boolean,
    STATE(511), 1,
      sym_binary_operator,
    STATE(523), 1,
      sym_cell,
    STATE(548), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(516), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(639), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [18535] = 5,
    STATE(315), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(889), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(693), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(695), 18,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [18583] = 4,
    ACTIONS(892), 1,
      anon_sym_DOT,
    STATE(316), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(395), 33,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_EQ,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [18629] = 25,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(820), 1,
      sym_identifier,
    ACTIONS(822), 1,
      sym_number,
    STATE(359), 1,
      sym_function_call,
    STATE(395), 1,
      sym_boolean,
    STATE(523), 1,
      sym_cell,
    STATE(533), 1,
      sym__range_element,
    STATE(535), 1,
      sym_unary_operator,
    STATE(536), 1,
      sym_not_operator,
    STATE(554), 1,
      sym_binary_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(521), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(692), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [18717] = 25,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(625), 1,
      anon_sym_AT,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(722), 1,
      sym_identifier,
    STATE(351), 1,
      sym_function_call,
    STATE(417), 1,
      sym_boolean,
    STATE(511), 1,
      sym_binary_operator,
    STATE(523), 1,
      sym_cell,
    STATE(548), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(516), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(668), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [18805] = 25,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(895), 1,
      sym_identifier,
    ACTIONS(897), 1,
      sym_number,
    STATE(365), 1,
      sym_function_call,
    STATE(421), 1,
      sym_boolean,
    STATE(511), 1,
      sym_binary_operator,
    STATE(530), 1,
      sym_unary_operator,
    STATE(531), 1,
      sym_not_operator,
    STATE(532), 1,
      sym_cell,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(528), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(692), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [18893] = 25,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(899), 1,
      sym_identifier,
    STATE(417), 1,
      sym_boolean,
    STATE(440), 1,
      sym_function_call,
    STATE(523), 1,
      sym_cell,
    STATE(564), 1,
      sym_binary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(571), 1,
      sym_unary_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(570), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(692), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [18981] = 25,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(790), 1,
      anon_sym_LBRACK,
    ACTIONS(792), 1,
      anon_sym_LBRACE,
    ACTIONS(798), 1,
      sym__single_quote_string_start,
    ACTIONS(800), 1,
      sym__double_quote_string_start,
    ACTIONS(843), 1,
      anon_sym_QMARK,
    ACTIONS(879), 1,
      sym_identifier,
    ACTIONS(881), 1,
      anon_sym_AT,
    ACTIONS(883), 1,
      sym_number,
    STATE(77), 1,
      sym_function_call,
    STATE(90), 1,
      sym_boolean,
    STATE(122), 1,
      sym_unary_operator,
    STATE(124), 1,
      sym_not_operator,
    STATE(130), 1,
      sym_binary_operator,
    STATE(141), 1,
      sym_cell,
    STATE(616), 1,
      sym__binary_expression,
    STATE(1003), 1,
      sym_indirect_access,
    STATE(1265), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(796), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(140), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(123), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(146), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [19069] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      sym_number,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(746), 1,
      anon_sym_TILDE,
    ACTIONS(748), 1,
      anon_sym_QMARK,
    ACTIONS(802), 1,
      sym_identifier,
    ACTIONS(830), 1,
      anon_sym_AT,
    STATE(193), 1,
      sym_function_call,
    STATE(214), 1,
      sym_boolean,
    STATE(384), 1,
      sym_binary_operator,
    STATE(411), 1,
      sym_unary_operator,
    STATE(430), 1,
      sym_cell,
    STATE(493), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(914), 1,
      sym_indirect_access,
    STATE(1243), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(427), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(415), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(507), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [19157] = 25,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(859), 1,
      sym_identifier,
    STATE(366), 1,
      sym_function_call,
    STATE(417), 1,
      sym_boolean,
    STATE(511), 1,
      sym_binary_operator,
    STATE(523), 1,
      sym_cell,
    STATE(548), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(516), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(676), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [19245] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(45), 1,
      sym_number,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(746), 1,
      anon_sym_TILDE,
    ACTIONS(748), 1,
      anon_sym_QMARK,
    ACTIONS(802), 1,
      sym_identifier,
    ACTIONS(830), 1,
      anon_sym_AT,
    STATE(193), 1,
      sym_function_call,
    STATE(214), 1,
      sym_boolean,
    STATE(384), 1,
      sym_binary_operator,
    STATE(411), 1,
      sym_unary_operator,
    STATE(430), 1,
      sym_cell,
    STATE(493), 1,
      sym_not_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(914), 1,
      sym_indirect_access,
    STATE(1243), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(427), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(415), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(506), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [19333] = 25,
    ACTIONS(9), 1,
      anon_sym_LPAREN,
    ACTIONS(19), 1,
      anon_sym_LBRACK,
    ACTIONS(21), 1,
      anon_sym_LBRACE,
    ACTIONS(51), 1,
      sym__single_quote_string_start,
    ACTIONS(53), 1,
      sym__double_quote_string_start,
    ACTIONS(744), 1,
      sym_identifier,
    ACTIONS(746), 1,
      anon_sym_TILDE,
    ACTIONS(748), 1,
      anon_sym_QMARK,
    ACTIONS(750), 1,
      anon_sym_AT,
    ACTIONS(752), 1,
      sym_number,
    STATE(192), 1,
      sym_function_call,
    STATE(208), 1,
      sym_boolean,
    STATE(405), 1,
      sym_not_operator,
    STATE(413), 1,
      sym_unary_operator,
    STATE(430), 1,
      sym_cell,
    STATE(437), 1,
      sym_binary_operator,
    STATE(614), 1,
      sym__binary_expression,
    STATE(914), 1,
      sym_indirect_access,
    STATE(1243), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(11), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(47), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(427), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(389), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(447), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [19421] = 25,
    ACTIONS(574), 1,
      sym__single_quote_string_start,
    ACTIONS(576), 1,
      sym__double_quote_string_start,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(653), 1,
      anon_sym_LPAREN,
    ACTIONS(663), 1,
      anon_sym_LBRACK,
    ACTIONS(667), 1,
      anon_sym_LBRACE,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(901), 1,
      sym_identifier,
    ACTIONS(903), 1,
      sym_number,
    STATE(209), 1,
      sym_function_call,
    STATE(352), 1,
      sym_boolean,
    STATE(454), 1,
      sym_unary_operator,
    STATE(455), 1,
      sym_not_operator,
    STATE(458), 1,
      sym_cell,
    STATE(586), 1,
      sym_binary_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(990), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(572), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(655), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(452), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(692), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [19509] = 25,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(905), 1,
      sym_identifier,
    STATE(390), 1,
      sym_function_call,
    STATE(417), 1,
      sym_boolean,
    STATE(523), 1,
      sym_cell,
    STATE(566), 1,
      sym_not_operator,
    STATE(574), 1,
      sym_binary_operator,
    STATE(575), 1,
      sym_unary_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(573), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(692), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [19597] = 25,
    ACTIONS(574), 1,
      sym__single_quote_string_start,
    ACTIONS(576), 1,
      sym__double_quote_string_start,
    ACTIONS(601), 1,
      sym_identifier,
    ACTIONS(653), 1,
      anon_sym_LPAREN,
    ACTIONS(663), 1,
      anon_sym_LBRACK,
    ACTIONS(667), 1,
      anon_sym_LBRACE,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(808), 1,
      anon_sym_QMARK,
    ACTIONS(871), 1,
      anon_sym_AT,
    ACTIONS(873), 1,
      sym_number,
    STATE(215), 1,
      sym_function_call,
    STATE(349), 1,
      sym_boolean,
    STATE(460), 1,
      sym_binary_operator,
    STATE(491), 1,
      sym_not_operator,
    STATE(501), 1,
      sym_cell,
    STATE(504), 1,
      sym_unary_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(990), 1,
      sym_indirect_access,
    STATE(1203), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(572), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(655), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(451), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(462), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
    STATE(489), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
  [19685] = 25,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(790), 1,
      anon_sym_LBRACK,
    ACTIONS(792), 1,
      anon_sym_LBRACE,
    ACTIONS(798), 1,
      sym__single_quote_string_start,
    ACTIONS(800), 1,
      sym__double_quote_string_start,
    ACTIONS(907), 1,
      sym_identifier,
    ACTIONS(909), 1,
      sym_number,
    STATE(80), 1,
      sym_function_call,
    STATE(98), 1,
      sym_boolean,
    STATE(103), 1,
      sym_cell,
    STATE(144), 1,
      sym_unary_operator,
    STATE(145), 1,
      sym_not_operator,
    STATE(588), 1,
      sym_binary_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(1003), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(796), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(143), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(692), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [19773] = 25,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(911), 1,
      sym_identifier,
    STATE(403), 1,
      sym_function_call,
    STATE(417), 1,
      sym_boolean,
    STATE(523), 1,
      sym_cell,
    STATE(566), 1,
      sym_not_operator,
    STATE(577), 1,
      sym_binary_operator,
    STATE(578), 1,
      sym_unary_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(576), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(692), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [19861] = 5,
    STATE(309), 1,
      aux_sym__block_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(913), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(325), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(254), 18,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [19909] = 25,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(915), 1,
      sym_identifier,
    STATE(417), 1,
      sym_boolean,
    STATE(422), 1,
      sym_function_call,
    STATE(523), 1,
      sym_cell,
    STATE(566), 1,
      sym_not_operator,
    STATE(579), 1,
      sym_binary_operator,
    STATE(580), 1,
      sym_unary_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(572), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(692), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [19997] = 25,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(859), 1,
      sym_identifier,
    ACTIONS(861), 1,
      anon_sym_QMARK,
    ACTIONS(863), 1,
      anon_sym_AT,
    STATE(366), 1,
      sym_function_call,
    STATE(417), 1,
      sym_boolean,
    STATE(511), 1,
      sym_binary_operator,
    STATE(523), 1,
      sym_cell,
    STATE(548), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(516), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(544), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [20085] = 25,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(859), 1,
      sym_identifier,
    ACTIONS(861), 1,
      anon_sym_QMARK,
    ACTIONS(863), 1,
      anon_sym_AT,
    STATE(366), 1,
      sym_function_call,
    STATE(417), 1,
      sym_boolean,
    STATE(511), 1,
      sym_binary_operator,
    STATE(523), 1,
      sym_cell,
    STATE(548), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(516), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(583), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [20173] = 25,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(762), 1,
      sym_identifier,
    STATE(399), 1,
      sym_function_call,
    STATE(417), 1,
      sym_boolean,
    STATE(523), 1,
      sym_cell,
    STATE(557), 1,
      sym_unary_operator,
    STATE(562), 1,
      sym_binary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(561), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(680), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [20261] = 25,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(625), 1,
      anon_sym_AT,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(722), 1,
      sym_identifier,
    STATE(351), 1,
      sym_function_call,
    STATE(417), 1,
      sym_boolean,
    STATE(511), 1,
      sym_binary_operator,
    STATE(523), 1,
      sym_cell,
    STATE(548), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(516), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(584), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [20349] = 25,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(625), 1,
      anon_sym_AT,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(722), 1,
      sym_identifier,
    STATE(351), 1,
      sym_function_call,
    STATE(417), 1,
      sym_boolean,
    STATE(511), 1,
      sym_binary_operator,
    STATE(523), 1,
      sym_cell,
    STATE(548), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(516), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(585), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [20437] = 25,
    ACTIONS(548), 1,
      sym_identifier,
    ACTIONS(574), 1,
      sym__single_quote_string_start,
    ACTIONS(576), 1,
      sym__double_quote_string_start,
    ACTIONS(653), 1,
      anon_sym_LPAREN,
    ACTIONS(663), 1,
      anon_sym_LBRACK,
    ACTIONS(667), 1,
      anon_sym_LBRACE,
    ACTIONS(669), 1,
      sym_number,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(808), 1,
      anon_sym_QMARK,
    ACTIONS(810), 1,
      anon_sym_AT,
    STATE(207), 1,
      sym_function_call,
    STATE(356), 1,
      sym_boolean,
    STATE(495), 1,
      sym_binary_operator,
    STATE(496), 1,
      sym_unary_operator,
    STATE(501), 1,
      sym_cell,
    STATE(541), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(990), 1,
      sym_indirect_access,
    STATE(1203), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(572), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(655), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(451), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(494), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(555), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [20525] = 25,
    ACTIONS(548), 1,
      sym_identifier,
    ACTIONS(574), 1,
      sym__single_quote_string_start,
    ACTIONS(576), 1,
      sym__double_quote_string_start,
    ACTIONS(653), 1,
      anon_sym_LPAREN,
    ACTIONS(663), 1,
      anon_sym_LBRACK,
    ACTIONS(667), 1,
      anon_sym_LBRACE,
    ACTIONS(669), 1,
      sym_number,
    ACTIONS(770), 1,
      anon_sym_TILDE,
    ACTIONS(808), 1,
      anon_sym_QMARK,
    ACTIONS(810), 1,
      anon_sym_AT,
    STATE(207), 1,
      sym_function_call,
    STATE(356), 1,
      sym_boolean,
    STATE(495), 1,
      sym_binary_operator,
    STATE(496), 1,
      sym_unary_operator,
    STATE(501), 1,
      sym_cell,
    STATE(541), 1,
      sym_not_operator,
    STATE(615), 1,
      sym__binary_expression,
    STATE(990), 1,
      sym_indirect_access,
    STATE(1203), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(572), 2,
      anon_sym_true,
      anon_sym_false,
    ACTIONS(655), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    STATE(451), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(494), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(558), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [20613] = 25,
    ACTIONS(778), 1,
      sym_identifier,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(790), 1,
      anon_sym_LBRACK,
    ACTIONS(792), 1,
      anon_sym_LBRACE,
    ACTIONS(794), 1,
      sym_number,
    ACTIONS(798), 1,
      sym__single_quote_string_start,
    ACTIONS(800), 1,
      sym__double_quote_string_start,
    ACTIONS(843), 1,
      anon_sym_QMARK,
    ACTIONS(845), 1,
      anon_sym_AT,
    STATE(78), 1,
      sym_function_call,
    STATE(96), 1,
      sym_boolean,
    STATE(121), 1,
      sym_binary_operator,
    STATE(139), 1,
      sym_unary_operator,
    STATE(141), 1,
      sym_cell,
    STATE(147), 1,
      sym_not_operator,
    STATE(616), 1,
      sym__binary_expression,
    STATE(1003), 1,
      sym_indirect_access,
    STATE(1265), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(796), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(140), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(120), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(150), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [20701] = 25,
    ACTIONS(778), 1,
      sym_identifier,
    ACTIONS(780), 1,
      anon_sym_LPAREN,
    ACTIONS(784), 1,
      anon_sym_TILDE,
    ACTIONS(790), 1,
      anon_sym_LBRACK,
    ACTIONS(792), 1,
      anon_sym_LBRACE,
    ACTIONS(794), 1,
      sym_number,
    ACTIONS(798), 1,
      sym__single_quote_string_start,
    ACTIONS(800), 1,
      sym__double_quote_string_start,
    ACTIONS(843), 1,
      anon_sym_QMARK,
    ACTIONS(845), 1,
      anon_sym_AT,
    STATE(78), 1,
      sym_function_call,
    STATE(96), 1,
      sym_boolean,
    STATE(121), 1,
      sym_binary_operator,
    STATE(139), 1,
      sym_unary_operator,
    STATE(141), 1,
      sym_cell,
    STATE(147), 1,
      sym_not_operator,
    STATE(616), 1,
      sym__binary_expression,
    STATE(1003), 1,
      sym_indirect_access,
    STATE(1265), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(782), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(796), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(140), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(120), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(148), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [20789] = 25,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(762), 1,
      sym_identifier,
    STATE(399), 1,
      sym_function_call,
    STATE(417), 1,
      sym_boolean,
    STATE(523), 1,
      sym_cell,
    STATE(557), 1,
      sym_unary_operator,
    STATE(562), 1,
      sym_binary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(561), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(683), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [20877] = 25,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(859), 1,
      sym_identifier,
    ACTIONS(861), 1,
      anon_sym_QMARK,
    ACTIONS(863), 1,
      anon_sym_AT,
    STATE(366), 1,
      sym_function_call,
    STATE(417), 1,
      sym_boolean,
    STATE(511), 1,
      sym_binary_operator,
    STATE(523), 1,
      sym_cell,
    STATE(548), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(516), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(584), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [20965] = 25,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(635), 1,
      sym_number,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(859), 1,
      sym_identifier,
    ACTIONS(861), 1,
      anon_sym_QMARK,
    ACTIONS(863), 1,
      anon_sym_AT,
    STATE(366), 1,
      sym_function_call,
    STATE(417), 1,
      sym_boolean,
    STATE(511), 1,
      sym_binary_operator,
    STATE(523), 1,
      sym_cell,
    STATE(548), 1,
      sym_unary_operator,
    STATE(566), 1,
      sym_not_operator,
    STATE(610), 1,
      sym__binary_expression,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(522), 2,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(516), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(585), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [21053] = 23,
    ACTIONS(617), 1,
      anon_sym_LPAREN,
    ACTIONS(621), 1,
      anon_sym_TILDE,
    ACTIONS(623), 1,
      anon_sym_QMARK,
    ACTIONS(627), 1,
      anon_sym_LBRACK,
    ACTIONS(629), 1,
      anon_sym_LBRACE,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(756), 1,
      anon_sym_AT,
    ACTIONS(764), 1,
      sym_identifier,
    ACTIONS(766), 1,
      sym_number,
    STATE(358), 1,
      sym_function_call,
    STATE(392), 1,
      sym_boolean,
    STATE(515), 1,
      sym_binary_operator,
    STATE(529), 1,
      sym_cell,
    STATE(552), 1,
      sym_unary_operator,
    STATE(969), 1,
      sym_indirect_access,
    STATE(1178), 1,
      sym__range_element,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(619), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(519), 4,
      sym__binary_expression,
      sym_not_operator,
      sym_comparison_operator,
      sym_boolean_operator,
    STATE(547), 5,
      sym_parenthesis,
      sym_field_expression,
      sym_postfix_operator,
      sym_string,
      sym_matrix,
    STATE(693), 5,
      sym__expression,
      sym_metaclass_operator,
      sym_handle_operator,
      sym_range,
      sym_lambda,
  [21137] = 4,
    ACTIONS(917), 1,
      anon_sym_DOT,
    STATE(347), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(368), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [21182] = 4,
    ACTIONS(919), 1,
      anon_sym_DOT,
    STATE(347), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(380), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [21227] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(418), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(416), 32,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [21270] = 10,
    ACTIONS(349), 1,
      anon_sym_COLON,
    ACTIONS(730), 1,
      anon_sym_LPAREN,
    ACTIONS(738), 1,
      anon_sym_LBRACE,
    ACTIONS(922), 1,
      anon_sym_AT,
    STATE(348), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(352), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(347), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [21327] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(422), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(420), 32,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [21370] = 13,
    ACTIONS(356), 1,
      anon_sym_COLON,
    ACTIONS(847), 1,
      anon_sym_LPAREN,
    ACTIONS(849), 1,
      anon_sym_DOT,
    ACTIONS(851), 1,
      anon_sym_AT,
    ACTIONS(855), 1,
      anon_sym_LBRACE,
    STATE(416), 1,
      sym__args,
    STATE(472), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [21433] = 8,
    ACTIONS(730), 1,
      anon_sym_LPAREN,
    ACTIONS(738), 1,
      anon_sym_LBRACE,
    ACTIONS(922), 1,
      anon_sym_AT,
    STATE(348), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(358), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [21486] = 14,
    ACTIONS(356), 1,
      anon_sym_COLON,
    ACTIONS(847), 1,
      anon_sym_LPAREN,
    ACTIONS(849), 1,
      anon_sym_DOT,
    ACTIONS(851), 1,
      anon_sym_AT,
    ACTIONS(855), 1,
      anon_sym_LBRACE,
    ACTIONS(887), 1,
      anon_sym_EQ,
    STATE(416), 1,
      sym__args,
    STATE(486), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [21551] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(426), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(424), 32,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [21594] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(430), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(428), 32,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [21637] = 10,
    ACTIONS(354), 1,
      anon_sym_COLON,
    ACTIONS(730), 1,
      anon_sym_LPAREN,
    ACTIONS(738), 1,
      anon_sym_LBRACE,
    ACTIONS(922), 1,
      anon_sym_AT,
    STATE(348), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(352), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(347), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [21694] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(404), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(402), 32,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [21737] = 10,
    ACTIONS(847), 1,
      anon_sym_LPAREN,
    ACTIONS(849), 1,
      anon_sym_DOT,
    ACTIONS(851), 1,
      anon_sym_AT,
    ACTIONS(855), 1,
      anon_sym_LBRACE,
    STATE(416), 1,
      sym__args,
    STATE(486), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(333), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(345), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [21794] = 13,
    ACTIONS(847), 1,
      anon_sym_LPAREN,
    ACTIONS(849), 1,
      anon_sym_DOT,
    ACTIONS(851), 1,
      anon_sym_AT,
    ACTIONS(855), 1,
      anon_sym_LBRACE,
    STATE(416), 1,
      sym__args,
    STATE(486), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(349), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(356), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(924), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [21857] = 8,
    ACTIONS(730), 1,
      anon_sym_LPAREN,
    ACTIONS(738), 1,
      anon_sym_LBRACE,
    ACTIONS(922), 1,
      anon_sym_AT,
    STATE(348), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(345), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(333), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [21910] = 10,
    ACTIONS(730), 1,
      anon_sym_LPAREN,
    ACTIONS(738), 1,
      anon_sym_LBRACE,
    ACTIONS(922), 1,
      anon_sym_AT,
    STATE(348), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(356), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(354), 4,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(349), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [21967] = 4,
    ACTIONS(917), 1,
      anon_sym_DOT,
    STATE(369), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(362), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [22012] = 13,
    ACTIONS(847), 1,
      anon_sym_LPAREN,
    ACTIONS(849), 1,
      anon_sym_DOT,
    ACTIONS(851), 1,
      anon_sym_AT,
    ACTIONS(855), 1,
      anon_sym_LBRACE,
    ACTIONS(924), 1,
      anon_sym_COLON,
    STATE(416), 1,
      sym__args,
    STATE(486), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [22075] = 4,
    ACTIONS(917), 1,
      anon_sym_DOT,
    STATE(346), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(372), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [22120] = 10,
    ACTIONS(847), 1,
      anon_sym_LPAREN,
    ACTIONS(849), 1,
      anon_sym_DOT,
    ACTIONS(851), 1,
      anon_sym_AT,
    ACTIONS(855), 1,
      anon_sym_LBRACE,
    STATE(416), 1,
      sym__args,
    STATE(486), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(358), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(360), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [22177] = 13,
    ACTIONS(356), 1,
      anon_sym_COLON,
    ACTIONS(847), 1,
      anon_sym_LPAREN,
    ACTIONS(849), 1,
      anon_sym_DOT,
    ACTIONS(851), 1,
      anon_sym_AT,
    ACTIONS(855), 1,
      anon_sym_LBRACE,
    STATE(416), 1,
      sym__args,
    STATE(486), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [22240] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(414), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(412), 32,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [22283] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(410), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(408), 32,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [22326] = 4,
    ACTIONS(917), 1,
      anon_sym_DOT,
    STATE(347), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(376), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [22371] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(533), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(531), 31,
      anon_sym_SEMI,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [22413] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(380), 33,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [22453] = 14,
    ACTIONS(356), 1,
      anon_sym_COLON,
    ACTIONS(847), 1,
      anon_sym_LPAREN,
    ACTIONS(849), 1,
      anon_sym_DOT,
    ACTIONS(851), 1,
      anon_sym_AT,
    ACTIONS(855), 1,
      anon_sym_LBRACE,
    STATE(416), 1,
      sym__args,
    STATE(486), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(927), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(352), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [22517] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(929), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(931), 19,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [22559] = 7,
    ACTIONS(847), 1,
      anon_sym_LPAREN,
    ACTIONS(851), 1,
      anon_sym_AT,
    ACTIONS(855), 1,
      anon_sym_LBRACE,
    STATE(416), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(387), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(389), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [22609] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(933), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(935), 19,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [22651] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(937), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(939), 19,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [22693] = 13,
    ACTIONS(356), 1,
      anon_sym_COLON,
    ACTIONS(847), 1,
      anon_sym_LPAREN,
    ACTIONS(849), 1,
      anon_sym_DOT,
    ACTIONS(851), 1,
      anon_sym_AT,
    ACTIONS(855), 1,
      anon_sym_LBRACE,
    STATE(416), 1,
      sym__args,
    STATE(472), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [22755] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(941), 14,
      sym_command_name,
      sym__single_quote_string_start,
      sym__double_quote_string_start,
      sym__multioutput_variable_start,
      ts_builtin_sym_end,
      anon_sym_LPAREN,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_QMARK,
      anon_sym_AT,
      anon_sym_LBRACK,
      anon_sym_LBRACE,
      sym_number,
    ACTIONS(943), 19,
      sym_return_statement,
      sym_continue_statement,
      sym_break_statement,
      anon_sym_if,
      anon_sym_end,
      anon_sym_for,
      anon_sym_parfor,
      anon_sym_while,
      anon_sym_switch,
      anon_sym_global,
      anon_sym_persistent,
      anon_sym_arguments,
      anon_sym_function,
      anon_sym_endfunction,
      anon_sym_classdef,
      anon_sym_try,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [22797] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(535), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [22836] = 5,
    ACTIONS(945), 1,
      anon_sym_DOT,
    STATE(397), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(378), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(376), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [22881] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(718), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(333), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [22922] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(718), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(333), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [22963] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(718), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(358), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [23004] = 5,
    ACTIONS(499), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(718), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [23049] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(358), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [23088] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(718), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(349), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(354), 8,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [23133] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(718), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(501), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(525), 8,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [23178] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(349), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(354), 10,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [23221] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(947), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(539), 26,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [23262] = 14,
    ACTIONS(356), 1,
      anon_sym_COLON,
    ACTIONS(847), 1,
      anon_sym_LPAREN,
    ACTIONS(849), 1,
      anon_sym_DOT,
    ACTIONS(851), 1,
      anon_sym_AT,
    ACTIONS(855), 1,
      anon_sym_LBRACE,
    ACTIONS(949), 1,
      anon_sym_RPAREN,
    STATE(416), 1,
      sym__args,
    STATE(486), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [23325] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(482), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [23364] = 8,
    ACTIONS(847), 1,
      anon_sym_LPAREN,
    ACTIONS(855), 1,
      anon_sym_LBRACE,
    ACTIONS(951), 1,
      anon_sym_AT,
    STATE(418), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(333), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(345), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [23415] = 5,
    ACTIONS(945), 1,
      anon_sym_DOT,
    STATE(397), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(368), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [23460] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(718), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(333), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [23501] = 11,
    ACTIONS(847), 1,
      anon_sym_LPAREN,
    ACTIONS(855), 1,
      anon_sym_LBRACE,
    ACTIONS(951), 1,
      anon_sym_AT,
    STATE(418), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(349), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(356), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(924), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [23558] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(718), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(499), 8,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(522), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [23603] = 5,
    ACTIONS(953), 1,
      anon_sym_DOT,
    STATE(397), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(385), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(380), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [23648] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(486), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [23687] = 13,
    ACTIONS(356), 1,
      anon_sym_COLON,
    ACTIONS(847), 1,
      anon_sym_LPAREN,
    ACTIONS(849), 1,
      anon_sym_DOT,
    ACTIONS(851), 1,
      anon_sym_AT,
    ACTIONS(855), 1,
      anon_sym_LBRACE,
    STATE(416), 1,
      sym__args,
    STATE(486), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 7,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [23748] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(718), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(333), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [23789] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(718), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(358), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [23830] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(428), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(430), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [23871] = 14,
    ACTIONS(356), 1,
      anon_sym_COLON,
    ACTIONS(847), 1,
      anon_sym_LPAREN,
    ACTIONS(849), 1,
      anon_sym_DOT,
    ACTIONS(851), 1,
      anon_sym_AT,
    ACTIONS(855), 1,
      anon_sym_LBRACE,
    ACTIONS(956), 1,
      anon_sym_RPAREN,
    STATE(416), 1,
      sym__args,
    STATE(486), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [23934] = 5,
    ACTIONS(958), 1,
      anon_sym_DOT,
    STATE(404), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(400), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(395), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [23979] = 4,
    ACTIONS(349), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 17,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24022] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(470), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24061] = 4,
    ACTIONS(961), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(947), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(504), 25,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24104] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(442), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24143] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(947), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(504), 26,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24184] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(446), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24223] = 5,
    ACTIONS(525), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(718), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24268] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(402), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(404), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24309] = 5,
    ACTIONS(501), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(718), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24354] = 3,
    ACTIONS(963), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(476), 31,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24395] = 5,
    ACTIONS(354), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(718), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24440] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(408), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(410), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24481] = 11,
    ACTIONS(356), 1,
      anon_sym_COLON,
    ACTIONS(847), 1,
      anon_sym_LPAREN,
    ACTIONS(855), 1,
      anon_sym_LBRACE,
    ACTIONS(951), 1,
      anon_sym_AT,
    STATE(418), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [24538] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(416), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(418), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24579] = 14,
    ACTIONS(356), 1,
      anon_sym_COLON,
    ACTIONS(847), 1,
      anon_sym_LPAREN,
    ACTIONS(849), 1,
      anon_sym_DOT,
    ACTIONS(851), 1,
      anon_sym_AT,
    ACTIONS(855), 1,
      anon_sym_LBRACE,
    ACTIONS(965), 1,
      anon_sym_RPAREN,
    STATE(416), 1,
      sym__args,
    STATE(486), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [24642] = 5,
    ACTIONS(961), 1,
      anon_sym_AMP_AMP,
    ACTIONS(967), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(947), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(518), 24,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24687] = 8,
    ACTIONS(847), 1,
      anon_sym_LPAREN,
    ACTIONS(855), 1,
      anon_sym_LBRACE,
    ACTIONS(951), 1,
      anon_sym_AT,
    STATE(418), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(358), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(360), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24738] = 14,
    ACTIONS(356), 1,
      anon_sym_COLON,
    ACTIONS(847), 1,
      anon_sym_LPAREN,
    ACTIONS(849), 1,
      anon_sym_DOT,
    ACTIONS(851), 1,
      anon_sym_AT,
    ACTIONS(855), 1,
      anon_sym_LBRACE,
    ACTIONS(969), 1,
      anon_sym_RPAREN,
    STATE(416), 1,
      sym__args,
    STATE(486), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [24801] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(450), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24840] = 5,
    ACTIONS(945), 1,
      anon_sym_DOT,
    STATE(380), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(366), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(362), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24885] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(718), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(358), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [24926] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(412), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(414), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [24967] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 18,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25008] = 5,
    ACTIONS(945), 1,
      anon_sym_DOT,
    STATE(393), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(374), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(372), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25053] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(973), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(971), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(432), 24,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25096] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(718), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 16,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25139] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(973), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(432), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25180] = 4,
    ACTIONS(495), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(492), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(490), 23,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25223] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(454), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25262] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(973), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(432), 30,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25303] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(458), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25342] = 5,
    ACTIONS(732), 1,
      anon_sym_DOT,
    STATE(404), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(393), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(391), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25387] = 5,
    ACTIONS(522), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(718), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25432] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(973), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(975), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(971), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(432), 20,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25477] = 5,
    ACTIONS(961), 1,
      anon_sym_AMP_AMP,
    ACTIONS(967), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(947), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(512), 24,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25522] = 14,
    ACTIONS(356), 1,
      anon_sym_COLON,
    ACTIONS(847), 1,
      anon_sym_LPAREN,
    ACTIONS(849), 1,
      anon_sym_DOT,
    ACTIONS(851), 1,
      anon_sym_AT,
    ACTIONS(855), 1,
      anon_sym_LBRACE,
    ACTIONS(977), 1,
      anon_sym_RPAREN,
    STATE(416), 1,
      sym__args,
    STATE(486), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [25585] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(462), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25624] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(466), 32,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25663] = 6,
    ACTIONS(979), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(973), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(975), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(971), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(432), 19,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_COLON,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25710] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(420), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(422), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25751] = 11,
    ACTIONS(847), 1,
      anon_sym_LPAREN,
    ACTIONS(855), 1,
      anon_sym_LBRACE,
    ACTIONS(924), 1,
      anon_sym_COLON,
    ACTIONS(951), 1,
      anon_sym_AT,
    STATE(418), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [25808] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(424), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(426), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25849] = 5,
    ACTIONS(349), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(718), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [25894] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(385), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(380), 29,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25934] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(531), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(533), 27,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [25974] = 12,
    ACTIONS(356), 1,
      anon_sym_COLON,
    ACTIONS(847), 1,
      anon_sym_LPAREN,
    ACTIONS(855), 1,
      anon_sym_LBRACE,
    ACTIONS(951), 1,
      anon_sym_AT,
    STATE(418), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(927), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(352), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [26032] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(352), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 14,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26073] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(358), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26114] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(460), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(458), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26153] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(358), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26194] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(358), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26233] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(464), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(462), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26272] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(468), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(466), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26311] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(360), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(358), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26352] = 5,
    ACTIONS(981), 1,
      anon_sym_DOT,
    STATE(459), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(395), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(400), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26395] = 6,
    ACTIONS(522), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(352), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(347), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [26440] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(472), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(470), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26479] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(541), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(984), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(539), 22,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26520] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(440), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(988), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(986), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(432), 20,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26563] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(440), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(988), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(432), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26604] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(440), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(988), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(432), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26645] = 7,
    ACTIONS(992), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(440), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(988), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(990), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(986), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(432), 15,
      anon_sym_SEMI,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26692] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(440), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(988), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(990), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(986), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(432), 16,
      anon_sym_SEMI,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26737] = 4,
    ACTIONS(994), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(480), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(476), 27,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [26778] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(444), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(442), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26817] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(448), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(446), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26856] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(484), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(482), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26895] = 5,
    ACTIONS(849), 1,
      anon_sym_DOT,
    STATE(459), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(391), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(393), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26938] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(345), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(333), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [26979] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(488), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(486), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27018] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(345), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(333), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27059] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(356), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(354), 4,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(349), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [27104] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(527), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(525), 4,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(501), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [27149] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(356), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(354), 6,
      anon_sym_SEMI,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(349), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [27192] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(456), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(454), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27231] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(452), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(450), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27270] = 5,
    ACTIONS(996), 1,
      anon_sym_DOT,
    STATE(485), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(362), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(366), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27313] = 5,
    ACTIONS(996), 1,
      anon_sym_DOT,
    STATE(487), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(372), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(374), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27356] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(345), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(333), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27397] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(529), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(499), 4,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(522), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [27442] = 5,
    ACTIONS(996), 1,
      anon_sym_DOT,
    STATE(488), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(376), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(378), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27485] = 5,
    ACTIONS(849), 1,
      anon_sym_DOT,
    STATE(459), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(391), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(393), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27528] = 5,
    ACTIONS(996), 1,
      anon_sym_DOT,
    STATE(488), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(368), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(370), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27571] = 5,
    ACTIONS(998), 1,
      anon_sym_DOT,
    STATE(488), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(380), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(385), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [27614] = 6,
    ACTIONS(349), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(352), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(347), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [27659] = 5,
    ACTIONS(495), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(497), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(492), 8,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(490), 19,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [27702] = 5,
    ACTIONS(349), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(352), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(347), 13,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [27745] = 6,
    ACTIONS(354), 1,
      anon_sym_COLON,
    ACTIONS(742), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(718), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(347), 12,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [27790] = 4,
    ACTIONS(354), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [27831] = 6,
    ACTIONS(354), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(352), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(347), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [27876] = 6,
    ACTIONS(499), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(352), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(347), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [27921] = 6,
    ACTIONS(525), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(352), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(347), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [27966] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(508), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(984), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(504), 22,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28007] = 5,
    ACTIONS(1001), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(508), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(984), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(504), 21,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28050] = 6,
    ACTIONS(1001), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1003), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(516), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(984), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(512), 20,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28095] = 6,
    ACTIONS(1001), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1003), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(520), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(984), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(518), 20,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28140] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(352), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(347), 12,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [28183] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(345), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(333), 26,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28224] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(537), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(535), 28,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28263] = 6,
    ACTIONS(501), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(352), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(736), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(347), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [28308] = 4,
    ACTIONS(1007), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1005), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(504), 22,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [28348] = 5,
    ACTIONS(1007), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1009), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1005), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(518), 21,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [28390] = 5,
    ACTIONS(1007), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1009), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1005), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(512), 21,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [28432] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(380), 5,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(385), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28470] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1005), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(504), 23,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [28508] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1015), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(432), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1011), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1013), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(440), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28551] = 7,
    ACTIONS(529), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [28596] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(458), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(460), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28633] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(504), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1017), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1019), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(508), 20,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28674] = 6,
    ACTIONS(1021), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(504), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1017), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1019), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(508), 19,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28717] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(333), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(345), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28756] = 7,
    ACTIONS(356), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [28801] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(486), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(488), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28838] = 7,
    ACTIONS(1021), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1023), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(512), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1017), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1019), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(516), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28883] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1015), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(432), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1013), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(440), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28924] = 7,
    ACTIONS(1021), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1023), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(518), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1017), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1019), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(520), 18,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [28969] = 7,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(349), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(356), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(924), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [29014] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(352), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29055] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 10,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [29098] = 7,
    ACTIONS(1025), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [29143] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(535), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(537), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29180] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(462), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(464), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29217] = 6,
    ACTIONS(924), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(352), 11,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [29260] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(358), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(360), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29299] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(333), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(345), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29338] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(358), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(360), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29377] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(358), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(360), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29414] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(358), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(360), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29453] = 6,
    ACTIONS(1031), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(490), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(492), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1028), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(497), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
  [29496] = 7,
    ACTIONS(924), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [29541] = 7,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(501), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(527), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1033), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [29586] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(349), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(356), 6,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(924), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [29629] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(539), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1017), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1019), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(541), 20,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29670] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1015), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(432), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(440), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29709] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(442), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(444), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29746] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(446), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(448), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29783] = 5,
    ACTIONS(354), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(352), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(347), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(333), 14,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
  [29824] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(450), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(452), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29861] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(482), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(484), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29898] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(470), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(472), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29935] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1015), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(432), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(440), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [29974] = 7,
    ACTIONS(1036), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1015), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(432), 3,
      anon_sym_PIPE,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1011), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1013), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
    ACTIONS(440), 12,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30019] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(333), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(345), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30058] = 7,
    ACTIONS(527), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30103] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(454), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(456), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30140] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(466), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(468), 24,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30177] = 7,
    ACTIONS(1033), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30222] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(333), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(345), 22,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
      anon_sym_COLON,
  [30261] = 4,
    ACTIONS(1031), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(476), 4,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(480), 23,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
      anon_sym_RBRACE,
  [30300] = 7,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(522), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(529), 4,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
      anon_sym_COLON,
    ACTIONS(1025), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30345] = 6,
    ACTIONS(1040), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1042), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(516), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1038), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(512), 17,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [30387] = 8,
    ACTIONS(527), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(927), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(352), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30433] = 7,
    ACTIONS(527), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30477] = 6,
    ACTIONS(1040), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1042), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(520), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1038), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(518), 17,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [30519] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(508), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1038), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(504), 19,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [30557] = 8,
    ACTIONS(356), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(927), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(352), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30603] = 7,
    ACTIONS(356), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30647] = 7,
    ACTIONS(529), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 8,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30691] = 5,
    ACTIONS(1040), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(508), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1038), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
    ACTIONS(504), 18,
      anon_sym_SEMI,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE,
      anon_sym_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [30731] = 8,
    ACTIONS(529), 1,
      anon_sym_COLON,
    ACTIONS(977), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30776] = 7,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(927), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(352), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30819] = 6,
    ACTIONS(356), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(352), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30860] = 8,
    ACTIONS(527), 1,
      anon_sym_COLON,
    ACTIONS(965), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30905] = 8,
    ACTIONS(356), 1,
      anon_sym_COLON,
    ACTIONS(965), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30950] = 8,
    ACTIONS(529), 1,
      anon_sym_COLON,
    ACTIONS(965), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [30995] = 8,
    ACTIONS(356), 1,
      anon_sym_COLON,
    ACTIONS(977), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31040] = 8,
    ACTIONS(527), 1,
      anon_sym_COLON,
    ACTIONS(977), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31085] = 8,
    ACTIONS(356), 1,
      anon_sym_COLON,
    ACTIONS(969), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31130] = 8,
    ACTIONS(356), 1,
      anon_sym_COLON,
    ACTIONS(949), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31175] = 8,
    ACTIONS(529), 1,
      anon_sym_COLON,
    ACTIONS(949), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31220] = 8,
    ACTIONS(527), 1,
      anon_sym_COLON,
    ACTIONS(949), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31265] = 8,
    ACTIONS(356), 1,
      anon_sym_COLON,
    ACTIONS(956), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31310] = 8,
    ACTIONS(529), 1,
      anon_sym_COLON,
    ACTIONS(956), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31355] = 8,
    ACTIONS(527), 1,
      anon_sym_COLON,
    ACTIONS(956), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31400] = 8,
    ACTIONS(529), 1,
      anon_sym_COLON,
    ACTIONS(969), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31445] = 8,
    ACTIONS(527), 1,
      anon_sym_COLON,
    ACTIONS(969), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(853), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31490] = 7,
    ACTIONS(529), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1044), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31532] = 6,
    ACTIONS(1050), 1,
      anon_sym_AMP_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(504), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1046), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1048), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(508), 16,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
  [31572] = 5,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(504), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1046), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1048), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(508), 17,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
  [31610] = 7,
    ACTIONS(1050), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1052), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(512), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1046), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1048), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(516), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_RBRACE,
  [31652] = 7,
    ACTIONS(1050), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1052), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(518), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(1046), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1048), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
    ACTIONS(520), 15,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
      anon_sym_RBRACE,
  [31694] = 7,
    ACTIONS(529), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1054), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31736] = 7,
    ACTIONS(356), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(927), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(352), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31778] = 7,
    ACTIONS(529), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1056), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31820] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1044), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31859] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1054), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31898] = 6,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(333), 2,
      anon_sym_PIPE,
      anon_sym_AMP,
    ACTIONS(347), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1056), 2,
      anon_sym_DOT_SQUOTE,
      anon_sym_SQUOTE,
    ACTIONS(352), 6,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(345), 12,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
  [31937] = 4,
    ACTIONS(1058), 1,
      anon_sym_DOT,
    STATE(592), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(380), 21,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_AMP,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [31971] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(380), 22,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_AMP,
      anon_sym_DOT,
      anon_sym_AT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACE,
      anon_sym_EQ,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [32000] = 11,
    ACTIONS(1007), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1009), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1063), 1,
      anon_sym_end,
    ACTIONS(1065), 1,
      anon_sym_case,
    ACTIONS(1067), 1,
      anon_sym_otherwise,
    STATE(1204), 1,
      sym_otherwise_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(638), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    STATE(816), 2,
      sym_case_clause,
      aux_sym_switch_statement_repeat1,
    ACTIONS(1061), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1005), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [32045] = 16,
    ACTIONS(1069), 1,
      sym_identifier,
    ACTIONS(1071), 1,
      anon_sym_COMMA,
    ACTIONS(1073), 1,
      anon_sym_LPAREN,
    ACTIONS(1075), 1,
      anon_sym_DOT,
    ACTIONS(1077), 1,
      anon_sym_TILDE,
    ACTIONS(1079), 1,
      anon_sym_AT,
    ACTIONS(1081), 1,
      anon_sym_RBRACK,
    ACTIONS(1083), 1,
      anon_sym_LBRACE,
    STATE(635), 1,
      sym__args,
    STATE(644), 1,
      sym_function_call,
    STATE(677), 1,
      aux_sym_field_expression_repeat1,
    STATE(935), 1,
      sym_indirect_access,
    STATE(965), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(620), 3,
      sym_field_expression,
      sym_ignored_argument,
      aux_sym_multioutput_variable_repeat1,
  [32098] = 4,
    ACTIONS(1085), 1,
      anon_sym_DOT,
    STATE(597), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(372), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [32126] = 4,
    ACTIONS(1085), 1,
      anon_sym_DOT,
    STATE(592), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(368), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [32154] = 4,
    ACTIONS(1085), 1,
      anon_sym_DOT,
    STATE(592), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(376), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [32182] = 4,
    ACTIONS(1085), 1,
      anon_sym_DOT,
    STATE(598), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(362), 15,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
      anon_sym_LF,
      anon_sym_CR,
  [32210] = 14,
    ACTIONS(1087), 1,
      sym_identifier,
    ACTIONS(1091), 1,
      anon_sym_LPAREN,
    ACTIONS(1093), 1,
      anon_sym_DOT,
    ACTIONS(1095), 1,
      anon_sym_AT,
    ACTIONS(1097), 1,
      anon_sym_LBRACE,
    ACTIONS(1099), 1,
      anon_sym_EQ,
    STATE(642), 1,
      aux_sym_metaclass_operator_repeat1,
    STATE(653), 1,
      sym_dimensions,
    STATE(681), 1,
      sym_property_name,
    STATE(711), 1,
      sym_validation_functions,
    STATE(858), 1,
      sym_default_value,
    STATE(1037), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1089), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [32257] = 5,
    ACTIONS(1101), 1,
      anon_sym_DOT,
    STATE(603), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(378), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(376), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [32285] = 5,
    ACTIONS(1101), 1,
      anon_sym_DOT,
    STATE(603), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(370), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(368), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [32313] = 5,
    ACTIONS(1103), 1,
      anon_sym_DOT,
    STATE(603), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(385), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(380), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [32341] = 5,
    ACTIONS(1101), 1,
      anon_sym_DOT,
    STATE(601), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(366), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(362), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [32369] = 5,
    ACTIONS(1101), 1,
      anon_sym_DOT,
    STATE(602), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(374), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(372), 11,
      anon_sym_SEMI,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [32397] = 5,
    ACTIONS(1106), 1,
      anon_sym_DOT,
    STATE(606), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(380), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(385), 11,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [32425] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(385), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(380), 12,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [32448] = 8,
    ACTIONS(591), 1,
      aux_sym_matrix_token1,
    ACTIONS(1040), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1042), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1109), 1,
      sym__entry_delimiter,
    STATE(820), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(589), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(1038), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [32481] = 12,
    ACTIONS(1087), 1,
      sym_identifier,
    ACTIONS(1091), 1,
      anon_sym_LPAREN,
    ACTIONS(1095), 1,
      anon_sym_AT,
    ACTIONS(1097), 1,
      anon_sym_LBRACE,
    ACTIONS(1099), 1,
      anon_sym_EQ,
    STATE(653), 1,
      sym_dimensions,
    STATE(681), 1,
      sym_property_name,
    STATE(711), 1,
      sym_validation_functions,
    STATE(858), 1,
      sym_default_value,
    STATE(1037), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1089), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [32522] = 6,
    ACTIONS(1111), 1,
      anon_sym_PIPE,
    ACTIONS(1113), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1015), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1011), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1013), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [32551] = 8,
    ACTIONS(1040), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1042), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1117), 1,
      aux_sym_matrix_token1,
    ACTIONS(1119), 1,
      sym__entry_delimiter,
    STATE(786), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1115), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(1038), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [32584] = 6,
    ACTIONS(1007), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1009), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(9), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1121), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1005), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [32613] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(380), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(385), 12,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [32636] = 6,
    ACTIONS(1129), 1,
      anon_sym_PIPE,
    ACTIONS(1131), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1127), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1123), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1125), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [32665] = 6,
    ACTIONS(1139), 1,
      anon_sym_PIPE,
    ACTIONS(1141), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1137), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1133), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1135), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [32694] = 6,
    ACTIONS(1149), 1,
      anon_sym_PIPE,
    ACTIONS(1151), 1,
      anon_sym_AMP,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1147), 2,
      anon_sym_CARET,
      anon_sym_DOT_CARET,
    ACTIONS(1143), 4,
      anon_sym_PLUS,
      anon_sym_DOT_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DASH,
    ACTIONS(1145), 6,
      anon_sym_STAR,
      anon_sym_DOT_STAR,
      anon_sym_SLASH,
      anon_sym_DOT_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_BSLASH,
  [32723] = 11,
    ACTIONS(1153), 1,
      sym_identifier,
    ACTIONS(1156), 1,
      anon_sym_COMMA,
    ACTIONS(1159), 1,
      anon_sym_LPAREN,
    ACTIONS(1162), 1,
      anon_sym_TILDE,
    ACTIONS(1165), 1,
      anon_sym_RBRACK,
    STATE(644), 1,
      sym_function_call,
    STATE(935), 1,
      sym_indirect_access,
    STATE(965), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1167), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(617), 3,
      sym_field_expression,
      sym_ignored_argument,
      aux_sym_multioutput_variable_repeat1,
  [32761] = 5,
    ACTIONS(1170), 1,
      anon_sym_DOT,
    STATE(623), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(372), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(374), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
  [32787] = 6,
    ACTIONS(1040), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1042), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1174), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1172), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(1038), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [32815] = 11,
    ACTIONS(1069), 1,
      sym_identifier,
    ACTIONS(1077), 1,
      anon_sym_TILDE,
    ACTIONS(1176), 1,
      anon_sym_COMMA,
    ACTIONS(1178), 1,
      anon_sym_LPAREN,
    ACTIONS(1180), 1,
      anon_sym_RBRACK,
    STATE(644), 1,
      sym_function_call,
    STATE(935), 1,
      sym_indirect_access,
    STATE(965), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(617), 3,
      sym_field_expression,
      sym_ignored_argument,
      aux_sym_multioutput_variable_repeat1,
  [32853] = 5,
    ACTIONS(1170), 1,
      anon_sym_DOT,
    STATE(606), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(376), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(378), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
  [32879] = 6,
    ACTIONS(1007), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1009), 1,
      anon_sym_PIPE_PIPE,
    STATE(166), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1182), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1005), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [32907] = 5,
    ACTIONS(1170), 1,
      anon_sym_DOT,
    STATE(606), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(368), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(370), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
  [32933] = 6,
    ACTIONS(1007), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1009), 1,
      anon_sym_PIPE_PIPE,
    STATE(166), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1182), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1005), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [32961] = 11,
    ACTIONS(1069), 1,
      sym_identifier,
    ACTIONS(1071), 1,
      anon_sym_COMMA,
    ACTIONS(1077), 1,
      anon_sym_TILDE,
    ACTIONS(1081), 1,
      anon_sym_RBRACK,
    ACTIONS(1178), 1,
      anon_sym_LPAREN,
    STATE(644), 1,
      sym_function_call,
    STATE(935), 1,
      sym_indirect_access,
    STATE(965), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(620), 3,
      sym_field_expression,
      sym_ignored_argument,
      aux_sym_multioutput_variable_repeat1,
  [32999] = 6,
    ACTIONS(1007), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1009), 1,
      anon_sym_PIPE_PIPE,
    STATE(331), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1184), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1005), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [33027] = 5,
    ACTIONS(1170), 1,
      anon_sym_DOT,
    STATE(621), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(362), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(366), 9,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_RBRACE,
  [33053] = 8,
    ACTIONS(1050), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1052), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1186), 1,
      anon_sym_COMMA,
    STATE(930), 1,
      aux_sym_arguments_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1046), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1188), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(1048), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [33084] = 5,
    ACTIONS(1007), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1009), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1190), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1005), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [33109] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(420), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(422), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [33130] = 8,
    ACTIONS(1050), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1052), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1186), 1,
      anon_sym_COMMA,
    STATE(1006), 1,
      aux_sym_arguments_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1046), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1192), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(1048), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [33161] = 12,
    ACTIONS(639), 1,
      sym__single_quote_string_start,
    ACTIONS(641), 1,
      sym__double_quote_string_start,
    ACTIONS(1178), 1,
      anon_sym_LPAREN,
    ACTIONS(1194), 1,
      sym_identifier,
    ACTIONS(1196), 1,
      sym_number,
    STATE(861), 1,
      sym_function_call,
    STATE(935), 1,
      sym_indirect_access,
    STATE(965), 1,
      sym_boolean,
    STATE(1239), 1,
      sym_parfor_options,
    STATE(1263), 1,
      sym_string,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
  [33200] = 8,
    ACTIONS(1050), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1052), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1198), 1,
      anon_sym_COMMA,
    STATE(961), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1046), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1200), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(1048), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [33231] = 5,
    ACTIONS(1007), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1009), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1202), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
    ACTIONS(1005), 6,
      anon_sym_LT,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
      anon_sym_GT,
  [33256] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(408), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(410), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [33277] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(416), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(418), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [33298] = 8,
    ACTIONS(1050), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1052), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1186), 1,
      anon_sym_COMMA,
    STATE(1021), 1,
      aux_sym_arguments_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1046), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1204), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(1048), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [33329] = 8,
    ACTIONS(1065), 1,
      anon_sym_case,
    ACTIONS(1067), 1,
      anon_sym_otherwise,
    ACTIONS(1208), 1,
      anon_sym_end,
    STATE(1210), 1,
      sym_otherwise_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(679), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    STATE(766), 2,
      sym_case_clause,
      aux_sym_switch_statement_repeat1,
    ACTIONS(1206), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [33360] = 8,
    ACTIONS(1050), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1052), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1186), 1,
      anon_sym_COMMA,
    STATE(1022), 1,
      aux_sym_arguments_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1046), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1204), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(1048), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [33391] = 9,
    ACTIONS(1075), 1,
      anon_sym_DOT,
    ACTIONS(1079), 1,
      anon_sym_AT,
    ACTIONS(1083), 1,
      anon_sym_LBRACE,
    ACTIONS(1212), 1,
      anon_sym_LPAREN,
    STATE(635), 1,
      sym__args,
    STATE(677), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1165), 3,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_RBRACK,
    ACTIONS(1210), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
  [33424] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(424), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(426), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [33445] = 4,
    ACTIONS(1216), 1,
      anon_sym_DOT,
    STATE(592), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1214), 10,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_AMP,
      anon_sym_AT,
      anon_sym_LBRACE,
      anon_sym_EQ,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [33468] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(428), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(430), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [33489] = 9,
    ACTIONS(1075), 1,
      anon_sym_DOT,
    ACTIONS(1079), 1,
      anon_sym_AT,
    ACTIONS(1083), 1,
      anon_sym_LBRACE,
    ACTIONS(1212), 1,
      anon_sym_LPAREN,
    STATE(635), 1,
      sym__args,
    STATE(677), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1218), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(1220), 3,
      anon_sym_COMMA,
      anon_sym_TILDE,
      anon_sym_RBRACK,
  [33522] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(402), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(404), 9,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [33543] = 8,
    ACTIONS(1222), 1,
      anon_sym_SEMI,
    ACTIONS(1224), 1,
      anon_sym_end,
    ACTIONS(1226), 1,
      anon_sym_properties,
    ACTIONS(1228), 1,
      anon_sym_methods,
    ACTIONS(1230), 1,
      anon_sym_events,
    ACTIONS(1232), 1,
      anon_sym_enumeration,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(660), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [33573] = 8,
    ACTIONS(1222), 1,
      anon_sym_SEMI,
    ACTIONS(1226), 1,
      anon_sym_properties,
    ACTIONS(1228), 1,
      anon_sym_methods,
    ACTIONS(1230), 1,
      anon_sym_events,
    ACTIONS(1232), 1,
      anon_sym_enumeration,
    ACTIONS(1234), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(660), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [33603] = 8,
    ACTIONS(1224), 1,
      anon_sym_end,
    ACTIONS(1226), 1,
      anon_sym_properties,
    ACTIONS(1228), 1,
      anon_sym_methods,
    ACTIONS(1230), 1,
      anon_sym_events,
    ACTIONS(1232), 1,
      anon_sym_enumeration,
    ACTIONS(1236), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(647), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [33633] = 8,
    ACTIONS(1226), 1,
      anon_sym_properties,
    ACTIONS(1228), 1,
      anon_sym_methods,
    ACTIONS(1230), 1,
      anon_sym_events,
    ACTIONS(1232), 1,
      anon_sym_enumeration,
    ACTIONS(1238), 1,
      anon_sym_SEMI,
    ACTIONS(1240), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(655), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [33663] = 8,
    ACTIONS(1222), 1,
      anon_sym_SEMI,
    ACTIONS(1226), 1,
      anon_sym_properties,
    ACTIONS(1228), 1,
      anon_sym_methods,
    ACTIONS(1230), 1,
      anon_sym_events,
    ACTIONS(1232), 1,
      anon_sym_enumeration,
    ACTIONS(1242), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(660), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [33693] = 10,
    ACTIONS(55), 1,
      sym__multioutput_variable_start,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1246), 1,
      anon_sym_end,
    ACTIONS(1248), 1,
      anon_sym_function,
    STATE(796), 1,
      sym__function_definition_with_end,
    STATE(1072), 1,
      sym_function_output,
    STATE(1244), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1250), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    STATE(657), 2,
      sym_function_signature,
      aux_sym_methods_repeat1,
  [33727] = 10,
    ACTIONS(55), 1,
      sym__multioutput_variable_start,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1246), 1,
      anon_sym_end,
    ACTIONS(1248), 1,
      anon_sym_function,
    STATE(796), 1,
      sym__function_definition_with_end,
    STATE(1072), 1,
      sym_function_output,
    STATE(1244), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1250), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    STATE(658), 2,
      sym_function_signature,
      aux_sym_methods_repeat1,
  [33761] = 9,
    ACTIONS(1097), 1,
      anon_sym_LBRACE,
    ACTIONS(1099), 1,
      anon_sym_EQ,
    ACTIONS(1252), 1,
      sym_identifier,
    STATE(675), 1,
      sym_property_name,
    STATE(748), 1,
      sym_validation_functions,
    STATE(901), 1,
      sym_default_value,
    STATE(1098), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1254), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [33793] = 8,
    ACTIONS(1226), 1,
      anon_sym_properties,
    ACTIONS(1228), 1,
      anon_sym_methods,
    ACTIONS(1230), 1,
      anon_sym_events,
    ACTIONS(1232), 1,
      anon_sym_enumeration,
    ACTIONS(1256), 1,
      anon_sym_SEMI,
    ACTIONS(1258), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(650), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [33823] = 8,
    ACTIONS(1222), 1,
      anon_sym_SEMI,
    ACTIONS(1226), 1,
      anon_sym_properties,
    ACTIONS(1228), 1,
      anon_sym_methods,
    ACTIONS(1230), 1,
      anon_sym_events,
    ACTIONS(1232), 1,
      anon_sym_enumeration,
    ACTIONS(1258), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(660), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [33853] = 9,
    ACTIONS(1093), 1,
      anon_sym_DOT,
    ACTIONS(1097), 1,
      anon_sym_LBRACE,
    ACTIONS(1099), 1,
      anon_sym_EQ,
    STATE(642), 1,
      aux_sym_metaclass_operator_repeat1,
    STATE(748), 1,
      sym_validation_functions,
    STATE(901), 1,
      sym_default_value,
    STATE(1098), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1254), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [33885] = 10,
    ACTIONS(55), 1,
      sym__multioutput_variable_start,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1248), 1,
      anon_sym_function,
    ACTIONS(1260), 1,
      anon_sym_end,
    STATE(796), 1,
      sym__function_definition_with_end,
    STATE(1072), 1,
      sym_function_output,
    STATE(1244), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1250), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    STATE(658), 2,
      sym_function_signature,
      aux_sym_methods_repeat1,
  [33919] = 10,
    ACTIONS(1262), 1,
      sym_identifier,
    ACTIONS(1265), 1,
      anon_sym_end,
    ACTIONS(1267), 1,
      anon_sym_function,
    ACTIONS(1273), 1,
      sym__multioutput_variable_start,
    STATE(796), 1,
      sym__function_definition_with_end,
    STATE(1072), 1,
      sym_function_output,
    STATE(1244), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1270), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    STATE(658), 2,
      sym_function_signature,
      aux_sym_methods_repeat1,
  [33953] = 7,
    ACTIONS(1079), 1,
      anon_sym_AT,
    ACTIONS(1083), 1,
      anon_sym_LBRACE,
    ACTIONS(1212), 1,
      anon_sym_LPAREN,
    STATE(635), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(387), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(389), 4,
      anon_sym_COMMA,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_RBRACK,
  [33981] = 8,
    ACTIONS(1276), 1,
      anon_sym_SEMI,
    ACTIONS(1279), 1,
      anon_sym_end,
    ACTIONS(1281), 1,
      anon_sym_properties,
    ACTIONS(1284), 1,
      anon_sym_methods,
    ACTIONS(1287), 1,
      anon_sym_events,
    ACTIONS(1290), 1,
      anon_sym_enumeration,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(660), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [34011] = 9,
    ACTIONS(1093), 1,
      anon_sym_DOT,
    ACTIONS(1097), 1,
      anon_sym_LBRACE,
    ACTIONS(1099), 1,
      anon_sym_EQ,
    STATE(642), 1,
      aux_sym_metaclass_operator_repeat1,
    STATE(717), 1,
      sym_validation_functions,
    STATE(859), 1,
      sym_default_value,
    STATE(1040), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1293), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34043] = 10,
    ACTIONS(1077), 1,
      anon_sym_TILDE,
    ACTIONS(1178), 1,
      anon_sym_LPAREN,
    ACTIONS(1295), 1,
      sym_identifier,
    ACTIONS(1297), 1,
      anon_sym_RBRACK,
    STATE(595), 1,
      sym_function_call,
    STATE(935), 1,
      sym_indirect_access,
    STATE(965), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(625), 2,
      sym_field_expression,
      sym_ignored_argument,
  [34077] = 10,
    ACTIONS(1077), 1,
      anon_sym_TILDE,
    ACTIONS(1178), 1,
      anon_sym_LPAREN,
    ACTIONS(1299), 1,
      sym_identifier,
    ACTIONS(1301), 1,
      anon_sym_RBRACK,
    STATE(640), 1,
      sym_function_call,
    STATE(935), 1,
      sym_indirect_access,
    STATE(965), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(705), 2,
      sym_field_expression,
      sym_ignored_argument,
  [34111] = 8,
    ACTIONS(1226), 1,
      anon_sym_properties,
    ACTIONS(1228), 1,
      anon_sym_methods,
    ACTIONS(1230), 1,
      anon_sym_events,
    ACTIONS(1232), 1,
      anon_sym_enumeration,
    ACTIONS(1303), 1,
      anon_sym_SEMI,
    ACTIONS(1305), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(646), 5,
      sym_properties,
      sym_methods,
      sym_events,
      sym_enumeration,
      aux_sym_class_definition_repeat1,
  [34141] = 10,
    ACTIONS(55), 1,
      sym__multioutput_variable_start,
    ACTIONS(1244), 1,
      sym_identifier,
    ACTIONS(1248), 1,
      anon_sym_function,
    ACTIONS(1307), 1,
      anon_sym_end,
    STATE(796), 1,
      sym__function_definition_with_end,
    STATE(1072), 1,
      sym_function_output,
    STATE(1244), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1250), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
    STATE(652), 2,
      sym_function_signature,
      aux_sym_methods_repeat1,
  [34175] = 10,
    ACTIONS(1077), 1,
      anon_sym_TILDE,
    ACTIONS(1178), 1,
      anon_sym_LPAREN,
    ACTIONS(1180), 1,
      anon_sym_RBRACK,
    ACTIONS(1299), 1,
      sym_identifier,
    STATE(640), 1,
      sym_function_call,
    STATE(935), 1,
      sym_indirect_access,
    STATE(965), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(705), 2,
      sym_field_expression,
      sym_ignored_argument,
  [34209] = 6,
    ACTIONS(1050), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1052), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1046), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1309), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(1048), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [34235] = 6,
    ACTIONS(1050), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1052), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1046), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1311), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
    ACTIONS(1048), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [34261] = 6,
    ACTIONS(1050), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1052), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1046), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1313), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
    ACTIONS(1048), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [34286] = 9,
    ACTIONS(1077), 1,
      anon_sym_TILDE,
    ACTIONS(1178), 1,
      anon_sym_LPAREN,
    ACTIONS(1299), 1,
      sym_identifier,
    STATE(640), 1,
      sym_function_call,
    STATE(935), 1,
      sym_indirect_access,
    STATE(965), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(705), 2,
      sym_field_expression,
      sym_ignored_argument,
  [34317] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(412), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(414), 7,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_DOT,
      anon_sym_TILDE,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_LBRACE,
  [34336] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1315), 10,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_AMP,
      anon_sym_AT,
      anon_sym_LBRACE,
      anon_sym_EQ,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [34353] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1317), 10,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_AMP,
      anon_sym_AT,
      anon_sym_LBRACE,
      anon_sym_EQ,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [34370] = 6,
    ACTIONS(1099), 1,
      anon_sym_EQ,
    STATE(859), 1,
      sym_default_value,
    STATE(1040), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1319), 3,
      anon_sym_vector,
      anon_sym_matrix,
      anon_sym_scalar,
    ACTIONS(1293), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34395] = 7,
    ACTIONS(1097), 1,
      anon_sym_LBRACE,
    ACTIONS(1099), 1,
      anon_sym_EQ,
    STATE(717), 1,
      sym_validation_functions,
    STATE(859), 1,
      sym_default_value,
    STATE(1040), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1293), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34421] = 6,
    ACTIONS(580), 1,
      anon_sym_COMMA,
    ACTIONS(1050), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1052), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1046), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1048), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [34445] = 5,
    ACTIONS(1075), 1,
      anon_sym_DOT,
    STATE(685), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(391), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(393), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_RBRACK,
  [34467] = 6,
    ACTIONS(1050), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1052), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1321), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1046), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1048), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [34491] = 4,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(679), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(582), 3,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
    ACTIONS(1323), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34511] = 6,
    ACTIONS(1050), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1052), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1326), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1046), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1048), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [34535] = 7,
    ACTIONS(1097), 1,
      anon_sym_LBRACE,
    ACTIONS(1099), 1,
      anon_sym_EQ,
    STATE(748), 1,
      sym_validation_functions,
    STATE(901), 1,
      sym_default_value,
    STATE(1098), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1254), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34561] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(603), 9,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_AT,
      anon_sym_LBRACE,
      anon_sym_EQ,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [34577] = 6,
    ACTIONS(1050), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1052), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1328), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1046), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1048), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [34601] = 6,
    ACTIONS(1050), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1052), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(1330), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1046), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1048), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [34625] = 5,
    ACTIONS(1332), 1,
      anon_sym_DOT,
    STATE(685), 1,
      aux_sym_field_expression_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(395), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(400), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_RBRACK,
  [34647] = 6,
    ACTIONS(1337), 1,
      anon_sym_LPAREN,
    ACTIONS(1339), 1,
      anon_sym_EQ,
    STATE(31), 1,
      sym__end_of_line,
    STATE(857), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1335), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34670] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(603), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(611), 5,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_TILDE,
      anon_sym_RBRACK,
  [34687] = 6,
    ACTIONS(1337), 1,
      anon_sym_LPAREN,
    ACTIONS(1339), 1,
      anon_sym_EQ,
    STATE(45), 1,
      sym__end_of_line,
    STATE(844), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1341), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34710] = 6,
    ACTIONS(1337), 1,
      anon_sym_LPAREN,
    ACTIONS(1339), 1,
      anon_sym_EQ,
    STATE(812), 1,
      sym__end_of_line,
    STATE(860), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1343), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34733] = 6,
    ACTIONS(1337), 1,
      anon_sym_LPAREN,
    ACTIONS(1339), 1,
      anon_sym_EQ,
    STATE(61), 1,
      sym__end_of_line,
    STATE(897), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1345), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34756] = 6,
    ACTIONS(1337), 1,
      anon_sym_LPAREN,
    ACTIONS(1339), 1,
      anon_sym_EQ,
    STATE(23), 1,
      sym__end_of_line,
    STATE(853), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1347), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34779] = 5,
    ACTIONS(1050), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1052), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1046), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1048), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [34800] = 5,
    ACTIONS(1021), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1023), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1017), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1019), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [34821] = 5,
    ACTIONS(1351), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1353), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(947), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1349), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [34842] = 5,
    ACTIONS(1357), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1359), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(984), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1355), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [34863] = 5,
    ACTIONS(1363), 1,
      anon_sym_AMP_AMP,
    ACTIONS(1365), 1,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(506), 2,
      anon_sym_LT,
      anon_sym_GT,
    ACTIONS(1361), 4,
      anon_sym_LT_EQ,
      anon_sym_EQ_EQ,
      anon_sym_TILDE_EQ,
      anon_sym_GT_EQ,
  [34884] = 5,
    ACTIONS(1337), 1,
      anon_sym_LPAREN,
    STATE(62), 1,
      sym__end_of_line,
    STATE(898), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1367), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [34904] = 6,
    ACTIONS(1369), 1,
      sym_identifier,
    ACTIONS(1371), 1,
      anon_sym_TILDE,
    ACTIONS(1373), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(609), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(714), 2,
      sym_property,
      aux_sym_arguments_statement_repeat1,
  [34926] = 6,
    ACTIONS(1369), 1,
      sym_identifier,
    ACTIONS(1371), 1,
      anon_sym_TILDE,
    ACTIONS(1373), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(609), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(713), 2,
      sym_property,
      aux_sym_arguments_statement_repeat1,
  [34948] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1375), 7,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_EQ,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [34962] = 4,
    ACTIONS(1379), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1377), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1381), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [34980] = 5,
    ACTIONS(1385), 1,
      anon_sym_LT,
    STATE(664), 1,
      sym__end_of_line,
    STATE(856), 1,
      sym_superclasses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1383), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35000] = 5,
    ACTIONS(1337), 1,
      anon_sym_LPAREN,
    STATE(57), 1,
      sym__end_of_line,
    STATE(837), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1387), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35020] = 4,
    ACTIONS(1389), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(16), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1391), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35038] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1210), 3,
      anon_sym_true,
      anon_sym_false,
      sym_identifier,
    ACTIONS(1165), 4,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_TILDE,
      anon_sym_RBRACK,
  [35054] = 5,
    ACTIONS(1385), 1,
      anon_sym_LT,
    STATE(649), 1,
      sym__end_of_line,
    STATE(843), 1,
      sym_superclasses,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1393), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35074] = 6,
    ACTIONS(1369), 1,
      sym_identifier,
    ACTIONS(1371), 1,
      anon_sym_TILDE,
    ACTIONS(1395), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(609), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(713), 2,
      sym_property,
      aux_sym_arguments_statement_repeat1,
  [35096] = 7,
    ACTIONS(1178), 1,
      anon_sym_LPAREN,
    ACTIONS(1397), 1,
      sym_identifier,
    STATE(743), 1,
      sym_function_call,
    STATE(935), 1,
      sym_indirect_access,
    STATE(965), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
  [35120] = 6,
    ACTIONS(1399), 1,
      sym_identifier,
    ACTIONS(1401), 1,
      anon_sym_LPAREN,
    STATE(940), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(194), 2,
      sym_indirect_access,
      sym_function_call,
  [35142] = 5,
    ACTIONS(1337), 1,
      anon_sym_LPAREN,
    STATE(28), 1,
      sym__end_of_line,
    STATE(839), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1403), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35162] = 5,
    ACTIONS(1099), 1,
      anon_sym_EQ,
    STATE(901), 1,
      sym_default_value,
    STATE(1098), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1254), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35182] = 5,
    ACTIONS(1337), 1,
      anon_sym_LPAREN,
    STATE(56), 1,
      sym__end_of_line,
    STATE(852), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1405), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35202] = 6,
    ACTIONS(1407), 1,
      sym_identifier,
    ACTIONS(1410), 1,
      anon_sym_TILDE,
    ACTIONS(1413), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(609), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(713), 2,
      sym_property,
      aux_sym_arguments_statement_repeat1,
  [35224] = 6,
    ACTIONS(1369), 1,
      sym_identifier,
    ACTIONS(1371), 1,
      anon_sym_TILDE,
    ACTIONS(1415), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(609), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(713), 2,
      sym_property,
      aux_sym_arguments_statement_repeat1,
  [35246] = 5,
    ACTIONS(1419), 1,
      anon_sym_LPAREN,
    STATE(727), 1,
      sym__end_of_line,
    STATE(887), 1,
      sym__argument_attributes,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1417), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35266] = 5,
    ACTIONS(1337), 1,
      anon_sym_LPAREN,
    STATE(828), 1,
      sym__end_of_line,
    STATE(908), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1421), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35286] = 5,
    ACTIONS(1099), 1,
      anon_sym_EQ,
    STATE(838), 1,
      sym_default_value,
    STATE(1071), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1423), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35306] = 4,
    ACTIONS(1093), 1,
      anon_sym_DOT,
    STATE(642), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1425), 5,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_AMP,
      anon_sym_LF,
      anon_sym_CR,
  [35324] = 4,
    ACTIONS(1429), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1427), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1431), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [35342] = 5,
    ACTIONS(1337), 1,
      anon_sym_LPAREN,
    STATE(27), 1,
      sym__end_of_line,
    STATE(891), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1433), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35362] = 4,
    ACTIONS(1437), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1435), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1439), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [35380] = 6,
    ACTIONS(1178), 1,
      anon_sym_LPAREN,
    ACTIONS(1441), 1,
      sym_identifier,
    STATE(965), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(659), 2,
      sym_indirect_access,
      sym_function_call,
  [35402] = 7,
    ACTIONS(1178), 1,
      anon_sym_LPAREN,
    ACTIONS(1443), 1,
      sym_identifier,
    STATE(763), 1,
      sym_function_call,
    STATE(935), 1,
      sym_indirect_access,
    STATE(965), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
  [35426] = 4,
    ACTIONS(1447), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1445), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1449), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [35444] = 4,
    ACTIONS(1453), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1451), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1455), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [35462] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1457), 7,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LBRACE,
      anon_sym_EQ,
      sym_identifier,
      anon_sym_LF,
      anon_sym_CR,
  [35476] = 6,
    ACTIONS(1369), 1,
      sym_identifier,
    ACTIONS(1371), 1,
      anon_sym_TILDE,
    ACTIONS(1459), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(609), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(740), 2,
      sym_property,
      aux_sym_arguments_statement_repeat1,
  [35498] = 4,
    ACTIONS(1463), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1461), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1465), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [35516] = 5,
    ACTIONS(1337), 1,
      anon_sym_LPAREN,
    STATE(38), 1,
      sym__end_of_line,
    STATE(900), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1467), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35536] = 4,
    ACTIONS(1471), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1469), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1473), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [35554] = 4,
    ACTIONS(1477), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1475), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1479), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [35572] = 5,
    ACTIONS(1483), 1,
      anon_sym_LPAREN,
    STATE(742), 1,
      sym__end_of_line,
    STATE(905), 1,
      sym_attributes,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1481), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35592] = 6,
    ACTIONS(1369), 1,
      sym_identifier,
    ACTIONS(1371), 1,
      anon_sym_TILDE,
    ACTIONS(1485), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(609), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(707), 2,
      sym_property,
      aux_sym_arguments_statement_repeat1,
  [35614] = 6,
    ACTIONS(1487), 1,
      sym_identifier,
    ACTIONS(1489), 1,
      anon_sym_LPAREN,
    STATE(1033), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(374), 2,
      sym_indirect_access,
      sym_function_call,
  [35636] = 4,
    ACTIONS(1493), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1491), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1495), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [35654] = 4,
    ACTIONS(1499), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1497), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1501), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [35672] = 5,
    ACTIONS(1483), 1,
      anon_sym_LPAREN,
    STATE(665), 1,
      sym__end_of_line,
    STATE(907), 1,
      sym_attributes,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1503), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35692] = 5,
    ACTIONS(1483), 1,
      anon_sym_LPAREN,
    STATE(875), 1,
      sym_attributes,
    STATE(1095), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1505), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35712] = 6,
    ACTIONS(1507), 1,
      sym_identifier,
    ACTIONS(1509), 1,
      anon_sym_LPAREN,
    STATE(993), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(259), 2,
      sym_indirect_access,
      sym_function_call,
  [35734] = 6,
    ACTIONS(1369), 1,
      sym_identifier,
    ACTIONS(1371), 1,
      anon_sym_TILDE,
    ACTIONS(1511), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(609), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(713), 2,
      sym_property,
      aux_sym_arguments_statement_repeat1,
  [35756] = 6,
    ACTIONS(1513), 1,
      sym_identifier,
    ACTIONS(1515), 1,
      anon_sym_LPAREN,
    STATE(1004), 1,
      sym_boolean,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(637), 2,
      anon_sym_true,
      anon_sym_false,
    STATE(86), 2,
      sym_indirect_access,
      sym_function_call,
  [35778] = 6,
    ACTIONS(1369), 1,
      sym_identifier,
    ACTIONS(1371), 1,
      anon_sym_TILDE,
    ACTIONS(1517), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(609), 2,
      sym_ignored_argument,
      sym_property_name,
    STATE(699), 2,
      sym_property,
      aux_sym_arguments_statement_repeat1,
  [35800] = 8,
    ACTIONS(1079), 1,
      anon_sym_AT,
    ACTIONS(1083), 1,
      anon_sym_LBRACE,
    ACTIONS(1212), 1,
      anon_sym_LPAREN,
    ACTIONS(1519), 1,
      anon_sym_COMMA,
    ACTIONS(1521), 1,
      anon_sym_RBRACE,
    STATE(635), 1,
      sym__args,
    STATE(1048), 1,
      aux_sym_validation_functions_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [35826] = 5,
    ACTIONS(1483), 1,
      anon_sym_LPAREN,
    STATE(836), 1,
      sym_attributes,
    STATE(1026), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1523), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35846] = 5,
    ACTIONS(1337), 1,
      anon_sym_LPAREN,
    STATE(821), 1,
      sym__end_of_line,
    STATE(873), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1525), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35866] = 5,
    ACTIONS(1337), 1,
      anon_sym_LPAREN,
    STATE(68), 1,
      sym__end_of_line,
    STATE(899), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1527), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35886] = 4,
    ACTIONS(1531), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1529), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1533), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [35904] = 5,
    ACTIONS(1099), 1,
      anon_sym_EQ,
    STATE(859), 1,
      sym_default_value,
    STATE(1040), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1293), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35924] = 4,
    ACTIONS(1537), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1535), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1539), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [35942] = 5,
    ACTIONS(1337), 1,
      anon_sym_LPAREN,
    STATE(21), 1,
      sym__end_of_line,
    STATE(855), 1,
      sym_function_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1541), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [35962] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1543), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [35975] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1491), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1495), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [35990] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1497), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1501), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36005] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1529), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1533), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36020] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1535), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1539), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36035] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1545), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1547), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36050] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1435), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1439), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36065] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1549), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1551), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36080] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1377), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1381), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36095] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1553), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1555), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36110] = 6,
    ACTIONS(83), 1,
      anon_sym_else,
    ACTIONS(1557), 1,
      anon_sym_elseif,
    ACTIONS(1559), 1,
      anon_sym_end,
    STATE(1245), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(840), 2,
      sym_elseif_clause,
      aux_sym_if_statement_repeat1,
  [36131] = 6,
    ACTIONS(83), 1,
      anon_sym_else,
    ACTIONS(1557), 1,
      anon_sym_elseif,
    ACTIONS(1559), 1,
      anon_sym_end,
    STATE(1245), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(773), 2,
      sym_elseif_clause,
      aux_sym_if_statement_repeat1,
  [36152] = 6,
    ACTIONS(1079), 1,
      anon_sym_AT,
    ACTIONS(1083), 1,
      anon_sym_LBRACE,
    ACTIONS(1212), 1,
      anon_sym_LPAREN,
    STATE(635), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1561), 2,
      anon_sym_COMMA,
      anon_sym_RBRACE,
  [36173] = 4,
    ACTIONS(1563), 1,
      ts_builtin_sym_end,
    ACTIONS(1565), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1553), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36190] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1567), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1569), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36205] = 6,
    ACTIONS(1571), 1,
      anon_sym_end,
    ACTIONS(1573), 1,
      anon_sym_case,
    ACTIONS(1575), 1,
      anon_sym_otherwise,
    STATE(1186), 1,
      sym_otherwise_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(879), 2,
      sym_case_clause,
      aux_sym_switch_statement_repeat1,
  [36226] = 5,
    ACTIONS(153), 1,
      ts_builtin_sym_end,
    ACTIONS(1577), 1,
      anon_sym_SEMI,
    ACTIONS(1579), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1427), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36245] = 4,
    ACTIONS(1583), 1,
      sym_command_argument,
    STATE(791), 1,
      aux_sym_command_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1581), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36262] = 4,
    ACTIONS(1587), 1,
      anon_sym_AMP,
    STATE(777), 1,
      aux_sym_superclasses_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1585), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36279] = 6,
    ACTIONS(55), 1,
      sym__multioutput_variable_start,
    ACTIONS(1589), 1,
      sym_identifier,
    STATE(1081), 1,
      sym_function_output,
    STATE(1244), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1591), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36300] = 4,
    ACTIONS(1595), 1,
      sym_command_argument,
    STATE(771), 1,
      aux_sym_command_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1593), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36317] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(17), 2,
      sym__end_of_line,
      aux_sym_elseif_clause_repeat1,
    ACTIONS(1598), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36332] = 6,
    ACTIONS(83), 1,
      anon_sym_else,
    ACTIONS(1557), 1,
      anon_sym_elseif,
    ACTIONS(1600), 1,
      anon_sym_end,
    STATE(1212), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(840), 2,
      sym_elseif_clause,
      aux_sym_if_statement_repeat1,
  [36353] = 5,
    ACTIONS(161), 1,
      ts_builtin_sym_end,
    ACTIONS(1602), 1,
      anon_sym_SEMI,
    ACTIONS(1604), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1445), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36372] = 5,
    ACTIONS(165), 1,
      ts_builtin_sym_end,
    ACTIONS(1606), 1,
      anon_sym_SEMI,
    ACTIONS(1608), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1451), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36391] = 4,
    ACTIONS(165), 1,
      ts_builtin_sym_end,
    ACTIONS(1608), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1451), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36408] = 4,
    ACTIONS(1587), 1,
      anon_sym_AMP,
    STATE(793), 1,
      aux_sym_superclasses_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1610), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36425] = 4,
    ACTIONS(1612), 1,
      sym_identifier,
    STATE(817), 1,
      aux_sym_global_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1614), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36442] = 4,
    ACTIONS(1612), 1,
      sym_identifier,
    STATE(817), 1,
      aux_sym_global_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1616), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36459] = 4,
    ACTIONS(1618), 1,
      sym_identifier,
    STATE(778), 1,
      aux_sym_global_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1620), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36476] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1622), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [36489] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1624), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [36502] = 4,
    ACTIONS(1626), 1,
      sym_identifier,
    STATE(779), 1,
      aux_sym_global_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1628), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36519] = 5,
    ACTIONS(591), 1,
      aux_sym_matrix_token1,
    ACTIONS(1109), 1,
      sym__entry_delimiter,
    STATE(820), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(589), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [36538] = 5,
    ACTIONS(179), 1,
      ts_builtin_sym_end,
    ACTIONS(1630), 1,
      anon_sym_SEMI,
    ACTIONS(1632), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1461), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36557] = 5,
    ACTIONS(591), 1,
      aux_sym_matrix_token1,
    ACTIONS(1109), 1,
      sym__entry_delimiter,
    STATE(826), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(589), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [36576] = 4,
    ACTIONS(179), 1,
      ts_builtin_sym_end,
    ACTIONS(1632), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1461), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36593] = 4,
    ACTIONS(1634), 1,
      ts_builtin_sym_end,
    ACTIONS(1636), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1469), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36610] = 5,
    ACTIONS(1634), 1,
      ts_builtin_sym_end,
    ACTIONS(1636), 1,
      anon_sym_function,
    ACTIONS(1638), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1469), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36629] = 6,
    ACTIONS(55), 1,
      sym__multioutput_variable_start,
    ACTIONS(1640), 1,
      sym_identifier,
    STATE(1078), 1,
      sym_function_output,
    STATE(1244), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1642), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36650] = 4,
    ACTIONS(1646), 1,
      sym_command_argument,
    STATE(771), 1,
      aux_sym_command_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1644), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36667] = 5,
    ACTIONS(183), 1,
      ts_builtin_sym_end,
    ACTIONS(1648), 1,
      anon_sym_SEMI,
    ACTIONS(1650), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1475), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36686] = 4,
    ACTIONS(1654), 1,
      anon_sym_AMP,
    STATE(793), 1,
      aux_sym_superclasses_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1652), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36703] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1657), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [36716] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1469), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1473), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36731] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1659), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1661), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36746] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1663), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [36759] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1665), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [36772] = 6,
    ACTIONS(55), 1,
      sym__multioutput_variable_start,
    ACTIONS(1667), 1,
      sym_identifier,
    STATE(1047), 1,
      sym_function_output,
    STATE(1244), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1669), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [36793] = 6,
    ACTIONS(83), 1,
      anon_sym_else,
    ACTIONS(1557), 1,
      anon_sym_elseif,
    ACTIONS(1671), 1,
      anon_sym_end,
    STATE(1248), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(761), 2,
      sym_elseif_clause,
      aux_sym_if_statement_repeat1,
  [36814] = 6,
    ACTIONS(83), 1,
      anon_sym_else,
    ACTIONS(1557), 1,
      anon_sym_elseif,
    ACTIONS(1671), 1,
      anon_sym_end,
    STATE(1248), 1,
      sym_else_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(840), 2,
      sym_elseif_clause,
      aux_sym_if_statement_repeat1,
  [36835] = 5,
    ACTIONS(1117), 1,
      aux_sym_matrix_token1,
    ACTIONS(1119), 1,
      sym__entry_delimiter,
    STATE(786), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1115), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [36854] = 4,
    ACTIONS(1673), 1,
      ts_builtin_sym_end,
    ACTIONS(1675), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1491), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36871] = 5,
    ACTIONS(1673), 1,
      ts_builtin_sym_end,
    ACTIONS(1675), 1,
      anon_sym_function,
    ACTIONS(1677), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1491), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36890] = 4,
    ACTIONS(1679), 1,
      ts_builtin_sym_end,
    ACTIONS(1681), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1497), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36907] = 5,
    ACTIONS(1679), 1,
      ts_builtin_sym_end,
    ACTIONS(1681), 1,
      anon_sym_function,
    ACTIONS(1683), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1497), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36926] = 4,
    ACTIONS(1685), 1,
      ts_builtin_sym_end,
    ACTIONS(1687), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1549), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36943] = 5,
    ACTIONS(193), 1,
      ts_builtin_sym_end,
    ACTIONS(1689), 1,
      anon_sym_SEMI,
    ACTIONS(1691), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1529), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36962] = 4,
    ACTIONS(193), 1,
      ts_builtin_sym_end,
    ACTIONS(1691), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1529), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [36979] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1693), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [36992] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1695), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [37005] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1697), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1699), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [37020] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1701), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [37033] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1703), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [37046] = 4,
    ACTIONS(1705), 1,
      ts_builtin_sym_end,
    ACTIONS(1707), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1377), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37063] = 6,
    ACTIONS(1573), 1,
      anon_sym_case,
    ACTIONS(1575), 1,
      anon_sym_otherwise,
    ACTIONS(1709), 1,
      anon_sym_end,
    STATE(1210), 1,
      sym_otherwise_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(879), 2,
      sym_case_clause,
      aux_sym_switch_statement_repeat1,
  [37084] = 4,
    ACTIONS(1711), 1,
      sym_identifier,
    STATE(817), 1,
      aux_sym_global_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1714), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37101] = 5,
    ACTIONS(1705), 1,
      ts_builtin_sym_end,
    ACTIONS(1707), 1,
      anon_sym_function,
    ACTIONS(1716), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1377), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37120] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1718), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1720), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [37135] = 5,
    ACTIONS(599), 1,
      aux_sym_matrix_token1,
    ACTIONS(1722), 1,
      sym__entry_delimiter,
    STATE(826), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(597), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [37154] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1724), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1726), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [37169] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1728), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1730), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [37184] = 4,
    ACTIONS(1732), 1,
      ts_builtin_sym_end,
    ACTIONS(1734), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1535), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37201] = 5,
    ACTIONS(1732), 1,
      ts_builtin_sym_end,
    ACTIONS(1734), 1,
      anon_sym_function,
    ACTIONS(1736), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1535), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37220] = 4,
    ACTIONS(1738), 1,
      ts_builtin_sym_end,
    ACTIONS(1740), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1545), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37237] = 5,
    ACTIONS(1174), 1,
      aux_sym_matrix_token1,
    ACTIONS(1742), 1,
      sym__entry_delimiter,
    STATE(826), 1,
      aux_sym_row_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1172), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [37256] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1461), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1465), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [37271] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1745), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1747), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [37286] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1451), 3,
      anon_sym_end,
      anon_sym_function,
      sym_identifier,
    ACTIONS(1455), 3,
      sym__multioutput_variable_start,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [37301] = 4,
    ACTIONS(1749), 1,
      ts_builtin_sym_end,
    ACTIONS(1751), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1435), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37318] = 5,
    ACTIONS(1749), 1,
      ts_builtin_sym_end,
    ACTIONS(1751), 1,
      anon_sym_function,
    ACTIONS(1753), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1435), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37337] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1755), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [37350] = 6,
    ACTIONS(55), 1,
      sym__multioutput_variable_start,
    ACTIONS(1757), 1,
      sym_identifier,
    STATE(1034), 1,
      sym_function_output,
    STATE(1244), 1,
      sym_multioutput_variable,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1759), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [37371] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1761), 6,
      anon_sym_SEMI,
      anon_sym_end,
      anon_sym_properties,
      anon_sym_methods,
      anon_sym_events,
      anon_sym_enumeration,
  [37384] = 6,
    ACTIONS(1077), 1,
      anon_sym_TILDE,
    ACTIONS(1763), 1,
      sym_identifier,
    ACTIONS(1765), 1,
      anon_sym_RPAREN,
    STATE(1046), 1,
      sym_ignored_argument,
    STATE(1188), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [37404] = 3,
    STATE(968), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1767), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37418] = 3,
    STATE(49), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1769), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37432] = 3,
    STATE(1067), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1771), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37446] = 3,
    STATE(35), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1773), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37460] = 5,
    ACTIONS(1775), 1,
      anon_sym_elseif,
    ACTIONS(1778), 1,
      anon_sym_else,
    ACTIONS(1780), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(840), 2,
      sym_elseif_clause,
      aux_sym_if_statement_repeat1,
  [37478] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1782), 5,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LF,
      anon_sym_CR,
  [37490] = 6,
    ACTIONS(1077), 1,
      anon_sym_TILDE,
    ACTIONS(1763), 1,
      sym_identifier,
    ACTIONS(1784), 1,
      anon_sym_RPAREN,
    STATE(1046), 1,
      sym_ignored_argument,
    STATE(1198), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [37510] = 3,
    STATE(654), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1786), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37524] = 3,
    STATE(59), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1788), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37538] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1652), 5,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_AMP,
      anon_sym_LF,
      anon_sym_CR,
  [37550] = 4,
    ACTIONS(1790), 1,
      sym__single_quote_string_end,
    STATE(872), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1792), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [37566] = 4,
    ACTIONS(1794), 1,
      sym__double_quote_string_end,
    STATE(847), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1796), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [37582] = 3,
    STATE(166), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1182), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37596] = 3,
    STATE(1107), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1799), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37610] = 3,
    ACTIONS(1803), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1801), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37624] = 3,
    STATE(1164), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1805), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37638] = 3,
    STATE(51), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1807), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37652] = 3,
    STATE(29), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1809), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37666] = 4,
    ACTIONS(1790), 1,
      sym__double_quote_string_end,
    STATE(874), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1811), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [37682] = 3,
    STATE(41), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1813), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37696] = 3,
    STATE(648), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1815), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37710] = 3,
    STATE(44), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1817), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37724] = 3,
    STATE(1098), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1254), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37738] = 3,
    STATE(1071), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1423), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37752] = 3,
    STATE(822), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1819), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37766] = 6,
    ACTIONS(1079), 1,
      anon_sym_AT,
    ACTIONS(1083), 1,
      anon_sym_LBRACE,
    ACTIONS(1212), 1,
      anon_sym_LPAREN,
    ACTIONS(1821), 1,
      anon_sym_RPAREN,
    STATE(635), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [37786] = 4,
    ACTIONS(1794), 1,
      sym__single_quote_string_end,
    STATE(862), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1823), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [37802] = 4,
    ACTIONS(1826), 1,
      sym__single_quote_string_end,
    STATE(868), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1828), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [37818] = 4,
    ACTIONS(1826), 1,
      sym__double_quote_string_end,
    STATE(869), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1830), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [37834] = 3,
    STATE(166), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1182), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37848] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1832), 5,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_EQ,
      anon_sym_LF,
      anon_sym_CR,
  [37860] = 3,
    STATE(175), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1834), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37874] = 4,
    ACTIONS(1836), 1,
      sym__single_quote_string_end,
    STATE(862), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1838), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [37890] = 4,
    ACTIONS(1836), 1,
      sym__double_quote_string_end,
    STATE(847), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1840), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [37906] = 6,
    ACTIONS(1077), 1,
      anon_sym_TILDE,
    ACTIONS(1763), 1,
      sym_identifier,
    ACTIONS(1842), 1,
      anon_sym_RPAREN,
    STATE(1046), 1,
      sym_ignored_argument,
    STATE(1264), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [37926] = 3,
    STATE(175), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1834), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37940] = 4,
    ACTIONS(1844), 1,
      sym__single_quote_string_end,
    STATE(862), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1838), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [37956] = 3,
    STATE(765), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1846), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [37970] = 4,
    ACTIONS(1844), 1,
      sym__double_quote_string_end,
    STATE(847), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1840), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [37986] = 3,
    STATE(1074), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1848), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38000] = 4,
    ACTIONS(1850), 1,
      sym__double_quote_string_end,
    STATE(882), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1852), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [38016] = 5,
    ACTIONS(1854), 1,
      anon_sym_SEMI,
    ACTIONS(1857), 1,
      aux_sym_matrix_token1,
    STATE(877), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1860), 2,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [38034] = 3,
    STATE(331), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1184), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38048] = 4,
    ACTIONS(1864), 1,
      anon_sym_case,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1862), 2,
      anon_sym_end,
      anon_sym_otherwise,
    STATE(879), 2,
      sym_case_clause,
      aux_sym_switch_statement_repeat1,
  [38064] = 3,
    STATE(264), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1867), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38078] = 4,
    ACTIONS(1869), 1,
      sym__single_quote_string_end,
    STATE(862), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1838), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [38094] = 4,
    ACTIONS(1869), 1,
      sym__double_quote_string_end,
    STATE(847), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1840), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [38110] = 6,
    ACTIONS(1077), 1,
      anon_sym_TILDE,
    ACTIONS(1763), 1,
      sym_identifier,
    ACTIONS(1871), 1,
      anon_sym_RPAREN,
    STATE(1046), 1,
      sym_ignored_argument,
    STATE(1218), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38130] = 6,
    ACTIONS(1077), 1,
      anon_sym_TILDE,
    ACTIONS(1763), 1,
      sym_identifier,
    ACTIONS(1873), 1,
      anon_sym_RPAREN,
    STATE(1046), 1,
      sym_ignored_argument,
    STATE(1237), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38150] = 4,
    ACTIONS(1875), 1,
      sym__single_quote_string_end,
    STATE(888), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1877), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [38166] = 4,
    ACTIONS(1875), 1,
      sym__double_quote_string_end,
    STATE(889), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1879), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [38182] = 3,
    STATE(733), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1881), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38196] = 4,
    ACTIONS(1883), 1,
      sym__single_quote_string_end,
    STATE(862), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1838), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [38212] = 4,
    ACTIONS(1883), 1,
      sym__double_quote_string_end,
    STATE(847), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1840), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [38228] = 3,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1174), 2,
      sym__entry_delimiter,
      aux_sym_matrix_token1,
    ACTIONS(1172), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [38242] = 3,
    STATE(33), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1885), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38256] = 6,
    ACTIONS(1077), 1,
      anon_sym_TILDE,
    ACTIONS(1763), 1,
      sym_identifier,
    ACTIONS(1887), 1,
      anon_sym_RPAREN,
    STATE(1046), 1,
      sym_ignored_argument,
    STATE(1206), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38276] = 6,
    ACTIONS(1077), 1,
      anon_sym_TILDE,
    ACTIONS(1763), 1,
      sym_identifier,
    ACTIONS(1889), 1,
      anon_sym_RPAREN,
    STATE(1046), 1,
      sym_ignored_argument,
    STATE(1215), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38296] = 6,
    ACTIONS(1077), 1,
      anon_sym_TILDE,
    ACTIONS(1763), 1,
      sym_identifier,
    ACTIONS(1891), 1,
      anon_sym_RPAREN,
    STATE(1046), 1,
      sym_ignored_argument,
    STATE(1220), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38316] = 6,
    ACTIONS(1077), 1,
      anon_sym_TILDE,
    ACTIONS(1763), 1,
      sym_identifier,
    ACTIONS(1893), 1,
      anon_sym_RPAREN,
    STATE(1046), 1,
      sym_ignored_argument,
    STATE(1272), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38336] = 6,
    ACTIONS(1077), 1,
      anon_sym_TILDE,
    ACTIONS(1763), 1,
      sym_identifier,
    ACTIONS(1895), 1,
      anon_sym_RPAREN,
    STATE(1046), 1,
      sym_ignored_argument,
    STATE(1236), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38356] = 3,
    STATE(63), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1897), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38370] = 3,
    STATE(65), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1899), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38384] = 3,
    STATE(69), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1901), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38398] = 3,
    STATE(24), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1903), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38412] = 3,
    STATE(1040), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1293), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38426] = 6,
    ACTIONS(1077), 1,
      anon_sym_TILDE,
    ACTIONS(1763), 1,
      sym_identifier,
    ACTIONS(1905), 1,
      anon_sym_RPAREN,
    STATE(1046), 1,
      sym_ignored_argument,
    STATE(1250), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38446] = 6,
    ACTIONS(1077), 1,
      anon_sym_TILDE,
    ACTIONS(1763), 1,
      sym_identifier,
    ACTIONS(1907), 1,
      anon_sym_RPAREN,
    STATE(1046), 1,
      sym_ignored_argument,
    STATE(1252), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38466] = 6,
    ACTIONS(1077), 1,
      anon_sym_TILDE,
    ACTIONS(1763), 1,
      sym_identifier,
    ACTIONS(1909), 1,
      anon_sym_RPAREN,
    STATE(1046), 1,
      sym_ignored_argument,
    STATE(1254), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38486] = 3,
    STATE(698), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1911), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38500] = 6,
    ACTIONS(1077), 1,
      anon_sym_TILDE,
    ACTIONS(1763), 1,
      sym_identifier,
    ACTIONS(1913), 1,
      anon_sym_RPAREN,
    STATE(1046), 1,
      sym_ignored_argument,
    STATE(1261), 1,
      sym__lambda_arguments,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38520] = 3,
    STATE(651), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1915), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38534] = 3,
    STATE(819), 1,
      sym__end_of_line,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1917), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38548] = 4,
    ACTIONS(1850), 1,
      sym__single_quote_string_end,
    STATE(881), 1,
      aux_sym_string_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1919), 3,
      sym_formatting_sequence,
      sym_escape_sequence,
      sym_string_content,
  [38564] = 3,
    ACTIONS(1921), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1475), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38577] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1923), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38588] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1925), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38599] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1927), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38610] = 5,
    ACTIONS(1929), 1,
      anon_sym_LPAREN,
    ACTIONS(1931), 1,
      anon_sym_AT,
    ACTIONS(1933), 1,
      anon_sym_LBRACE,
    STATE(195), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38627] = 4,
    ACTIONS(181), 1,
      anon_sym_end,
    ACTIONS(1935), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(179), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [38642] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1549), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38653] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1937), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38664] = 4,
    ACTIONS(195), 1,
      anon_sym_end,
    ACTIONS(1939), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(193), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [38679] = 5,
    ACTIONS(1941), 1,
      anon_sym_SEMI,
    ACTIONS(1943), 1,
      aux_sym_matrix_token1,
    ACTIONS(1945), 1,
      anon_sym_RBRACE,
    STATE(986), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38696] = 4,
    ACTIONS(1947), 1,
      anon_sym_end,
    ACTIONS(1949), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1749), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [38711] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1951), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38722] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1953), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38733] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1955), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38744] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1377), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38755] = 3,
    ACTIONS(1957), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1377), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38768] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1959), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38779] = 4,
    ACTIONS(1961), 1,
      anon_sym_end,
    ACTIONS(1963), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1634), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [38794] = 5,
    ACTIONS(1965), 1,
      sym_identifier,
    ACTIONS(1967), 1,
      anon_sym_end,
    STATE(851), 1,
      sym_enum,
    STATE(932), 1,
      aux_sym_enumeration_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38811] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1969), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38822] = 4,
    ACTIONS(1186), 1,
      anon_sym_COMMA,
    STATE(953), 1,
      aux_sym_arguments_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1971), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [38837] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1973), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38848] = 5,
    ACTIONS(1975), 1,
      sym_identifier,
    ACTIONS(1978), 1,
      anon_sym_end,
    STATE(851), 1,
      sym_enum,
    STATE(932), 1,
      aux_sym_enumeration_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38865] = 4,
    ACTIONS(1980), 1,
      ts_builtin_sym_end,
    ACTIONS(1982), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1029), 2,
      sym_function_definition,
      aux_sym_source_file_repeat1,
  [38880] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1553), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38891] = 5,
    ACTIONS(1079), 1,
      anon_sym_AT,
    ACTIONS(1083), 1,
      anon_sym_LBRACE,
    ACTIONS(1212), 1,
      anon_sym_LPAREN,
    STATE(635), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38908] = 3,
    ACTIONS(1984), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1427), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38921] = 4,
    ACTIONS(185), 1,
      anon_sym_end,
    ACTIONS(1986), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(183), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [38936] = 5,
    ACTIONS(1941), 1,
      anon_sym_SEMI,
    ACTIONS(1943), 1,
      aux_sym_matrix_token1,
    ACTIONS(1988), 1,
      anon_sym_RBRACK,
    STATE(877), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38953] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1990), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38964] = 5,
    ACTIONS(1929), 1,
      anon_sym_LPAREN,
    ACTIONS(1933), 1,
      anon_sym_LBRACE,
    ACTIONS(1992), 1,
      anon_sym_AT,
    STATE(203), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [38981] = 3,
    ACTIONS(1994), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1461), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [38994] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1996), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39005] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1998), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39016] = 5,
    ACTIONS(1941), 1,
      anon_sym_SEMI,
    ACTIONS(1943), 1,
      aux_sym_matrix_token1,
    ACTIONS(2000), 1,
      anon_sym_RBRACK,
    STATE(950), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39033] = 5,
    ACTIONS(1941), 1,
      anon_sym_SEMI,
    ACTIONS(1943), 1,
      aux_sym_matrix_token1,
    ACTIONS(2002), 1,
      anon_sym_RBRACE,
    STATE(951), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39050] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2004), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39061] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1461), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39072] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1469), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39083] = 3,
    ACTIONS(2006), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1469), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39096] = 5,
    ACTIONS(1941), 1,
      anon_sym_SEMI,
    ACTIONS(1943), 1,
      aux_sym_matrix_token1,
    ACTIONS(2008), 1,
      anon_sym_RBRACK,
    STATE(877), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39113] = 5,
    ACTIONS(1941), 1,
      anon_sym_SEMI,
    ACTIONS(1943), 1,
      aux_sym_matrix_token1,
    ACTIONS(2010), 1,
      anon_sym_RBRACE,
    STATE(877), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39130] = 4,
    ACTIONS(1198), 1,
      anon_sym_COMMA,
    STATE(963), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1200), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [39145] = 4,
    ACTIONS(2012), 1,
      anon_sym_COMMA,
    STATE(953), 1,
      aux_sym_arguments_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2015), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [39160] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2017), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39171] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1497), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39182] = 4,
    ACTIONS(197), 1,
      anon_sym_end,
    ACTIONS(2019), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(179), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [39197] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2021), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39208] = 4,
    ACTIONS(163), 1,
      anon_sym_end,
    ACTIONS(2023), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(161), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [39223] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2025), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39234] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2027), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39245] = 4,
    ACTIONS(2029), 1,
      anon_sym_COMMA,
    STATE(966), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2031), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [39260] = 4,
    ACTIONS(155), 1,
      anon_sym_end,
    ACTIONS(2033), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(153), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [39275] = 4,
    ACTIONS(2035), 1,
      anon_sym_COMMA,
    STATE(966), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2031), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [39290] = 4,
    ACTIONS(2037), 1,
      anon_sym_end,
    ACTIONS(2039), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1634), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [39305] = 5,
    ACTIONS(1083), 1,
      anon_sym_LBRACE,
    ACTIONS(1212), 1,
      anon_sym_LPAREN,
    ACTIONS(2041), 1,
      anon_sym_AT,
    STATE(636), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39322] = 4,
    ACTIONS(2043), 1,
      anon_sym_COMMA,
    STATE(966), 1,
      aux_sym_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2046), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [39337] = 4,
    ACTIONS(167), 1,
      anon_sym_end,
    ACTIONS(2048), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(165), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [39352] = 5,
    ACTIONS(1965), 1,
      sym_identifier,
    ACTIONS(2050), 1,
      anon_sym_end,
    STATE(851), 1,
      sym_enum,
    STATE(928), 1,
      aux_sym_enumeration_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39369] = 5,
    ACTIONS(847), 1,
      anon_sym_LPAREN,
    ACTIONS(851), 1,
      anon_sym_AT,
    ACTIONS(855), 1,
      anon_sym_LBRACE,
    STATE(416), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39386] = 4,
    ACTIONS(2054), 1,
      anon_sym_DOT,
    STATE(606), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2052), 2,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [39401] = 4,
    ACTIONS(2058), 1,
      anon_sym_DOT,
    STATE(970), 1,
      aux_sym_metaclass_operator_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2056), 2,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [39416] = 4,
    ACTIONS(175), 1,
      anon_sym_end,
    ACTIONS(2060), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(153), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [39431] = 4,
    ACTIONS(199), 1,
      anon_sym_end,
    ACTIONS(2062), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(183), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [39446] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2064), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39457] = 5,
    ACTIONS(1965), 1,
      sym_identifier,
    ACTIONS(2050), 1,
      anon_sym_end,
    STATE(851), 1,
      sym_enum,
    STATE(932), 1,
      aux_sym_enumeration_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39474] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2066), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39485] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2068), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39496] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2070), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39507] = 5,
    ACTIONS(1941), 1,
      anon_sym_SEMI,
    ACTIONS(1943), 1,
      aux_sym_matrix_token1,
    ACTIONS(2072), 1,
      anon_sym_RBRACK,
    STATE(982), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39524] = 5,
    ACTIONS(1941), 1,
      anon_sym_SEMI,
    ACTIONS(1943), 1,
      aux_sym_matrix_token1,
    ACTIONS(2074), 1,
      anon_sym_RBRACE,
    STATE(983), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39541] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2076), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39552] = 5,
    ACTIONS(1941), 1,
      anon_sym_SEMI,
    ACTIONS(1943), 1,
      aux_sym_matrix_token1,
    ACTIONS(2078), 1,
      anon_sym_RBRACK,
    STATE(877), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39569] = 5,
    ACTIONS(1941), 1,
      anon_sym_SEMI,
    ACTIONS(1943), 1,
      aux_sym_matrix_token1,
    ACTIONS(2080), 1,
      anon_sym_RBRACE,
    STATE(877), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39586] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1491), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39597] = 3,
    ACTIONS(2082), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1445), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39610] = 5,
    ACTIONS(1941), 1,
      anon_sym_SEMI,
    ACTIONS(1943), 1,
      aux_sym_matrix_token1,
    ACTIONS(2084), 1,
      anon_sym_RBRACE,
    STATE(877), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39627] = 4,
    ACTIONS(318), 1,
      ts_builtin_sym_end,
    ACTIONS(1982), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1029), 2,
      sym_function_definition,
      aux_sym_source_file_repeat1,
  [39642] = 3,
    ACTIONS(2086), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1497), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39655] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1535), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39666] = 5,
    ACTIONS(2088), 1,
      anon_sym_LPAREN,
    ACTIONS(2090), 1,
      anon_sym_AT,
    ACTIONS(2092), 1,
      anon_sym_LBRACE,
    STATE(368), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39683] = 3,
    ACTIONS(2094), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1451), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39696] = 4,
    ACTIONS(201), 1,
      anon_sym_end,
    ACTIONS(2096), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(193), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [39711] = 5,
    ACTIONS(2088), 1,
      anon_sym_LPAREN,
    ACTIONS(2092), 1,
      anon_sym_LBRACE,
    ACTIONS(2098), 1,
      anon_sym_AT,
    STATE(348), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39728] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1451), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39739] = 3,
    ACTIONS(2100), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1529), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39752] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2102), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39763] = 5,
    ACTIONS(1941), 1,
      anon_sym_SEMI,
    ACTIONS(1943), 1,
      aux_sym_matrix_token1,
    ACTIONS(2104), 1,
      anon_sym_RBRACK,
    STATE(1001), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39780] = 5,
    ACTIONS(1941), 1,
      anon_sym_SEMI,
    ACTIONS(1943), 1,
      aux_sym_matrix_token1,
    ACTIONS(2106), 1,
      anon_sym_RBRACE,
    STATE(1002), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39797] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2108), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39808] = 3,
    ACTIONS(2110), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1535), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39821] = 5,
    ACTIONS(1941), 1,
      anon_sym_SEMI,
    ACTIONS(1943), 1,
      aux_sym_matrix_token1,
    ACTIONS(2112), 1,
      anon_sym_RBRACK,
    STATE(877), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39838] = 5,
    ACTIONS(1941), 1,
      anon_sym_SEMI,
    ACTIONS(1943), 1,
      aux_sym_matrix_token1,
    ACTIONS(2114), 1,
      anon_sym_RBRACE,
    STATE(877), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39855] = 5,
    ACTIONS(2116), 1,
      anon_sym_LPAREN,
    ACTIONS(2118), 1,
      anon_sym_AT,
    ACTIONS(2120), 1,
      anon_sym_LBRACE,
    STATE(94), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39872] = 5,
    ACTIONS(2116), 1,
      anon_sym_LPAREN,
    ACTIONS(2120), 1,
      anon_sym_LBRACE,
    ACTIONS(2122), 1,
      anon_sym_AT,
    STATE(97), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39889] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1545), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39900] = 4,
    ACTIONS(1186), 1,
      anon_sym_COMMA,
    STATE(953), 1,
      aux_sym_arguments_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2124), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [39915] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2126), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39926] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1435), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39937] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2128), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39948] = 3,
    ACTIONS(2130), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1491), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39961] = 5,
    ACTIONS(1941), 1,
      anon_sym_SEMI,
    ACTIONS(1943), 1,
      aux_sym_matrix_token1,
    ACTIONS(2132), 1,
      anon_sym_RBRACK,
    STATE(938), 1,
      aux_sym_matrix_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [39978] = 3,
    ACTIONS(2134), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1435), 3,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [39991] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2136), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40002] = 3,
    ACTIONS(2138), 1,
      aux_sym_matrix_token1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1860), 3,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
  [40015] = 4,
    ACTIONS(187), 1,
      anon_sym_end,
    ACTIONS(2140), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(161), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [40030] = 4,
    ACTIONS(2142), 1,
      anon_sym_end,
    ACTIONS(2144), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1673), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [40045] = 4,
    ACTIONS(189), 1,
      anon_sym_end,
    ACTIONS(2146), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(165), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [40060] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2148), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40071] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2150), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40082] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2152), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40093] = 4,
    ACTIONS(1186), 1,
      anon_sym_COMMA,
    STATE(953), 1,
      aux_sym_arguments_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2154), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [40108] = 4,
    ACTIONS(1186), 1,
      anon_sym_COMMA,
    STATE(953), 1,
      aux_sym_arguments_repeat2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2154), 2,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [40123] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2156), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40134] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2158), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40145] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2160), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40156] = 5,
    ACTIONS(1965), 1,
      sym_identifier,
    ACTIONS(2162), 1,
      anon_sym_end,
    STATE(851), 1,
      sym_enum,
    STATE(975), 1,
      aux_sym_enumeration_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40173] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2164), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40184] = 4,
    ACTIONS(2166), 1,
      anon_sym_end,
    ACTIONS(2168), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1749), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [40199] = 4,
    ACTIONS(2170), 1,
      ts_builtin_sym_end,
    ACTIONS(2172), 1,
      anon_sym_function,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    STATE(1029), 2,
      sym_function_definition,
      aux_sym_source_file_repeat1,
  [40214] = 4,
    ACTIONS(2175), 1,
      anon_sym_end,
    ACTIONS(2177), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1673), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [40229] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1529), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40240] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2179), 4,
      anon_sym_SEMI,
      anon_sym_COMMA,
      anon_sym_LF,
      anon_sym_CR,
  [40251] = 5,
    ACTIONS(847), 1,
      anon_sym_LPAREN,
    ACTIONS(855), 1,
      anon_sym_LBRACE,
    ACTIONS(951), 1,
      anon_sym_AT,
    STATE(418), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40268] = 3,
    ACTIONS(2181), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2183), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [40280] = 4,
    ACTIONS(1929), 1,
      anon_sym_LPAREN,
    ACTIONS(1933), 1,
      anon_sym_LBRACE,
    STATE(204), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40294] = 4,
    ACTIONS(2185), 1,
      anon_sym_COMMA,
    ACTIONS(2187), 1,
      anon_sym_RPAREN,
    STATE(1100), 1,
      aux_sym_dimensions_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40308] = 3,
    ACTIONS(2191), 1,
      anon_sym_TILDE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2189), 2,
      anon_sym_end,
      sym_identifier,
  [40320] = 4,
    ACTIONS(2193), 1,
      sym_identifier,
    ACTIONS(2195), 1,
      anon_sym_LPAREN,
    STATE(1225), 1,
      sym_attributes,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40334] = 4,
    ACTIONS(2197), 1,
      anon_sym_COMMA,
    ACTIONS(2200), 1,
      anon_sym_RPAREN,
    STATE(1039), 1,
      aux_sym__lambda_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40348] = 3,
    ACTIONS(2204), 1,
      anon_sym_TILDE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2202), 2,
      anon_sym_end,
      sym_identifier,
  [40360] = 3,
    ACTIONS(2206), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1673), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [40372] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1309), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [40382] = 4,
    ACTIONS(2208), 1,
      anon_sym_COMMA,
    ACTIONS(2211), 1,
      anon_sym_RPAREN,
    STATE(1043), 1,
      aux_sym_enum_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40396] = 4,
    ACTIONS(2213), 1,
      sym_identifier,
    ACTIONS(2215), 1,
      anon_sym_end,
    STATE(1045), 1,
      aux_sym_events_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40410] = 4,
    ACTIONS(2217), 1,
      sym_identifier,
    ACTIONS(2220), 1,
      anon_sym_end,
    STATE(1045), 1,
      aux_sym_events_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40424] = 4,
    ACTIONS(2222), 1,
      anon_sym_COMMA,
    ACTIONS(2224), 1,
      anon_sym_RPAREN,
    STATE(1061), 1,
      aux_sym__lambda_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40438] = 3,
    ACTIONS(2226), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2228), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [40450] = 4,
    ACTIONS(1519), 1,
      anon_sym_COMMA,
    ACTIONS(2230), 1,
      anon_sym_RBRACE,
    STATE(1055), 1,
      aux_sym_validation_functions_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40464] = 3,
    ACTIONS(2232), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(153), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [40476] = 3,
    ACTIONS(2236), 1,
      anon_sym_else,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2234), 2,
      anon_sym_elseif,
      anon_sym_end,
  [40488] = 3,
    ACTIONS(111), 1,
      anon_sym_else,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2238), 2,
      anon_sym_elseif,
      anon_sym_end,
  [40500] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2240), 3,
      anon_sym_end,
      anon_sym_case,
      anon_sym_otherwise,
  [40510] = 4,
    ACTIONS(2242), 1,
      anon_sym_COMMA,
    ACTIONS(2244), 1,
      anon_sym_RPAREN,
    STATE(1083), 1,
      aux_sym_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40524] = 4,
    ACTIONS(1077), 1,
      anon_sym_TILDE,
    ACTIONS(2246), 1,
      sym_identifier,
    STATE(1121), 1,
      sym_ignored_argument,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40538] = 4,
    ACTIONS(1561), 1,
      anon_sym_RBRACE,
    ACTIONS(2248), 1,
      anon_sym_COMMA,
    STATE(1055), 1,
      aux_sym_validation_functions_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40552] = 4,
    ACTIONS(2242), 1,
      anon_sym_COMMA,
    ACTIONS(2251), 1,
      anon_sym_RPAREN,
    STATE(1059), 1,
      aux_sym_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40566] = 4,
    ACTIONS(1083), 1,
      anon_sym_LBRACE,
    ACTIONS(1212), 1,
      anon_sym_LPAREN,
    STATE(643), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40580] = 4,
    ACTIONS(1083), 1,
      anon_sym_LBRACE,
    ACTIONS(1212), 1,
      anon_sym_LPAREN,
    STATE(645), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40594] = 4,
    ACTIONS(2242), 1,
      anon_sym_COMMA,
    ACTIONS(2253), 1,
      anon_sym_RPAREN,
    STATE(1083), 1,
      aux_sym_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40608] = 4,
    ACTIONS(2255), 1,
      anon_sym_COMMA,
    ACTIONS(2257), 1,
      anon_sym_RPAREN,
    STATE(1101), 1,
      aux_sym__argument_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40622] = 4,
    ACTIONS(2222), 1,
      anon_sym_COMMA,
    ACTIONS(2259), 1,
      anon_sym_RPAREN,
    STATE(1039), 1,
      aux_sym__lambda_arguments_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40636] = 3,
    ACTIONS(2261), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1749), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [40648] = 3,
    ACTIONS(2263), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(179), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [40660] = 4,
    ACTIONS(2265), 1,
      anon_sym_end,
    ACTIONS(2267), 1,
      anon_sym_catch,
    STATE(1199), 1,
      sym_catch_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40674] = 3,
    ACTIONS(2269), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1634), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [40686] = 3,
    ACTIONS(2271), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1705), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [40698] = 3,
    ACTIONS(2275), 1,
      anon_sym_TILDE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2273), 2,
      anon_sym_end,
      sym_identifier,
  [40710] = 3,
    ACTIONS(2277), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(183), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [40722] = 4,
    ACTIONS(1929), 1,
      anon_sym_LPAREN,
    ACTIONS(1933), 1,
      anon_sym_LBRACE,
    STATE(199), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40736] = 4,
    ACTIONS(633), 1,
      anon_sym_COLON,
    ACTIONS(2279), 1,
      sym_number,
    STATE(1106), 1,
      sym_spread_operator,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40750] = 3,
    ACTIONS(2283), 1,
      anon_sym_TILDE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2281), 2,
      anon_sym_end,
      sym_identifier,
  [40762] = 3,
    ACTIONS(2285), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2287), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [40774] = 3,
    ACTIONS(2289), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(193), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [40786] = 4,
    ACTIONS(2213), 1,
      sym_identifier,
    ACTIONS(2291), 1,
      anon_sym_end,
    STATE(1044), 1,
      aux_sym_events_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40800] = 4,
    ACTIONS(2213), 1,
      sym_identifier,
    ACTIONS(2291), 1,
      anon_sym_end,
    STATE(1045), 1,
      aux_sym_events_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40814] = 4,
    ACTIONS(2267), 1,
      anon_sym_catch,
    ACTIONS(2293), 1,
      anon_sym_end,
    STATE(1249), 1,
      sym_catch_clause,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40828] = 4,
    ACTIONS(847), 1,
      anon_sym_LPAREN,
    ACTIONS(855), 1,
      anon_sym_LBRACE,
    STATE(402), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40842] = 3,
    ACTIONS(2295), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2297), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [40854] = 4,
    ACTIONS(847), 1,
      anon_sym_LPAREN,
    ACTIONS(855), 1,
      anon_sym_LBRACE,
    STATE(412), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40868] = 4,
    ACTIONS(2299), 1,
      anon_sym_COMMA,
    ACTIONS(2301), 1,
      anon_sym_RPAREN,
    STATE(1043), 1,
      aux_sym_enum_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40882] = 3,
    ACTIONS(2303), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2305), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [40894] = 4,
    ACTIONS(2242), 1,
      anon_sym_COMMA,
    ACTIONS(2307), 1,
      anon_sym_RPAREN,
    STATE(1053), 1,
      aux_sym_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40908] = 4,
    ACTIONS(2309), 1,
      anon_sym_COMMA,
    ACTIONS(2312), 1,
      anon_sym_RPAREN,
    STATE(1083), 1,
      aux_sym_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40922] = 4,
    ACTIONS(2314), 1,
      anon_sym_COMMA,
    ACTIONS(2317), 1,
      anon_sym_RPAREN,
    STATE(1084), 1,
      aux_sym__argument_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40936] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2319), 3,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_RBRACE,
  [40946] = 4,
    ACTIONS(2088), 1,
      anon_sym_LPAREN,
    ACTIONS(2092), 1,
      anon_sym_LBRACE,
    STATE(355), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40960] = 4,
    ACTIONS(2088), 1,
      anon_sym_LPAREN,
    ACTIONS(2092), 1,
      anon_sym_LBRACE,
    STATE(357), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [40974] = 3,
    ACTIONS(2321), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2323), 2,
      anon_sym_get_DOT,
      anon_sym_set_DOT,
  [40986] = 3,
    ACTIONS(2325), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(161), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [40998] = 4,
    ACTIONS(2185), 1,
      anon_sym_COMMA,
    ACTIONS(2327), 1,
      anon_sym_RPAREN,
    STATE(1036), 1,
      aux_sym_dimensions_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41012] = 3,
    ACTIONS(2331), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2329), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [41024] = 4,
    ACTIONS(2116), 1,
      anon_sym_LPAREN,
    ACTIONS(2120), 1,
      anon_sym_LBRACE,
    STATE(101), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41038] = 4,
    ACTIONS(2116), 1,
      anon_sym_LPAREN,
    ACTIONS(2120), 1,
      anon_sym_LBRACE,
    STATE(89), 1,
      sym__args,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41052] = 3,
    ACTIONS(2333), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(165), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41064] = 4,
    ACTIONS(2213), 1,
      sym_identifier,
    ACTIONS(2335), 1,
      anon_sym_end,
    STATE(1075), 1,
      aux_sym_events_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41078] = 4,
    ACTIONS(2299), 1,
      anon_sym_COMMA,
    ACTIONS(2337), 1,
      anon_sym_RPAREN,
    STATE(1080), 1,
      aux_sym_enum_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41092] = 4,
    ACTIONS(2339), 1,
      sym_identifier,
    ACTIONS(2341), 1,
      anon_sym_LPAREN,
    STATE(10), 1,
      sym_iterator,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41106] = 3,
    ACTIONS(2345), 1,
      anon_sym_TILDE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2343), 2,
      anon_sym_end,
      sym_identifier,
  [41118] = 3,
    ACTIONS(2347), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1732), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41130] = 4,
    ACTIONS(2349), 1,
      anon_sym_COMMA,
    ACTIONS(2352), 1,
      anon_sym_RPAREN,
    STATE(1100), 1,
      aux_sym_dimensions_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41144] = 4,
    ACTIONS(2255), 1,
      anon_sym_COMMA,
    ACTIONS(2354), 1,
      anon_sym_RPAREN,
    STATE(1084), 1,
      aux_sym__argument_attributes_repeat1,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41158] = 4,
    ACTIONS(633), 1,
      anon_sym_COLON,
    ACTIONS(2356), 1,
      sym_number,
    STATE(1090), 1,
      sym_spread_operator,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41172] = 3,
    ACTIONS(2358), 1,
      anon_sym_SEMI,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1679), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41184] = 3,
    ACTIONS(2360), 1,
      sym_identifier,
    STATE(1069), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41195] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1749), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41204] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2352), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [41213] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2220), 2,
      anon_sym_end,
      sym_identifier,
  [41222] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1673), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41231] = 3,
    ACTIONS(2362), 1,
      sym_identifier,
    STATE(1122), 1,
      sym_attribute,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41242] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1563), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41251] = 3,
    ACTIONS(2364), 1,
      sym_identifier,
    ACTIONS(2366), 1,
      anon_sym_STAR,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41262] = 3,
    ACTIONS(215), 1,
      anon_sym_end,
    ACTIONS(2368), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41273] = 3,
    ACTIONS(308), 1,
      anon_sym_end,
    ACTIONS(2370), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41284] = 3,
    ACTIONS(2372), 1,
      sym_identifier,
    STATE(1259), 1,
      sym_iterator,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41295] = 3,
    ACTIONS(310), 1,
      anon_sym_end,
    ACTIONS(2374), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41306] = 3,
    ACTIONS(2362), 1,
      sym_identifier,
    STATE(1082), 1,
      sym_attribute,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41317] = 3,
    ACTIONS(225), 1,
      anon_sym_end,
    ACTIONS(2376), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41328] = 3,
    ACTIONS(2378), 1,
      sym_identifier,
    ACTIONS(2380), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41339] = 3,
    ACTIONS(219), 1,
      anon_sym_end,
    ACTIONS(2382), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41350] = 3,
    ACTIONS(211), 1,
      anon_sym_end,
    ACTIONS(2384), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41361] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2200), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [41370] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2312), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [41379] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2386), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [41388] = 3,
    ACTIONS(217), 1,
      anon_sym_end,
    ACTIONS(2388), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41399] = 3,
    ACTIONS(312), 1,
      anon_sym_end,
    ACTIONS(2390), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41410] = 3,
    ACTIONS(2392), 1,
      sym_identifier,
    STATE(845), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41421] = 3,
    ACTIONS(2339), 1,
      sym_identifier,
    STATE(10), 1,
      sym_iterator,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41432] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1732), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41441] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2394), 2,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [41450] = 3,
    ACTIONS(2396), 1,
      anon_sym_end,
    ACTIONS(2398), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41461] = 3,
    ACTIONS(316), 1,
      anon_sym_end,
    ACTIONS(2400), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41472] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1679), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41481] = 3,
    ACTIONS(2402), 1,
      sym_identifier,
    ACTIONS(2404), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41492] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2211), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [41501] = 3,
    ACTIONS(2406), 1,
      anon_sym_end,
    ACTIONS(2408), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41512] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(2410), 2,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [41521] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1738), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41530] = 3,
    ACTIONS(207), 1,
      anon_sym_end,
    ACTIONS(2412), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41541] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(179), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41550] = 3,
    ACTIONS(2414), 1,
      anon_sym_end,
    ACTIONS(2416), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41561] = 3,
    ACTIONS(2418), 1,
      sym_identifier,
    ACTIONS(2420), 1,
      anon_sym_STAR,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41572] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1685), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41581] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1634), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41590] = 3,
    ACTIONS(2422), 1,
      anon_sym_end,
    ACTIONS(2424), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41601] = 3,
    ACTIONS(213), 1,
      anon_sym_end,
    ACTIONS(2426), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41612] = 3,
    ACTIONS(2428), 1,
      sym_identifier,
    ACTIONS(2430), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41623] = 3,
    ACTIONS(2432), 1,
      sym_identifier,
    ACTIONS(2434), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41634] = 3,
    ACTIONS(2436), 1,
      sym_identifier,
    ACTIONS(2438), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41645] = 3,
    ACTIONS(2440), 1,
      sym_identifier,
    ACTIONS(2442), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41656] = 3,
    ACTIONS(2428), 1,
      sym_identifier,
    ACTIONS(2444), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41667] = 3,
    ACTIONS(2432), 1,
      sym_identifier,
    ACTIONS(2446), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41678] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(165), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41687] = 3,
    ACTIONS(2362), 1,
      sym_identifier,
    STATE(1056), 1,
      sym_attribute,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41698] = 3,
    ACTIONS(2360), 1,
      sym_identifier,
    STATE(1057), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41709] = 3,
    ACTIONS(2360), 1,
      sym_identifier,
    STATE(1058), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41720] = 3,
    ACTIONS(2364), 1,
      sym_identifier,
    ACTIONS(2448), 1,
      anon_sym_STAR,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41731] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1705), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41740] = 3,
    ACTIONS(2450), 1,
      sym_identifier,
    ACTIONS(2452), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41751] = 3,
    ACTIONS(2454), 1,
      anon_sym_end,
    ACTIONS(2456), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41762] = 3,
    ACTIONS(2418), 1,
      sym_identifier,
    ACTIONS(2458), 1,
      anon_sym_STAR,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41773] = 3,
    ACTIONS(205), 1,
      anon_sym_end,
    ACTIONS(2460), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41784] = 3,
    ACTIONS(2436), 1,
      sym_identifier,
    ACTIONS(2462), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41795] = 3,
    ACTIONS(2464), 1,
      sym_identifier,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41806] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(1978), 2,
      anon_sym_end,
      sym_identifier,
  [41815] = 3,
    ACTIONS(2392), 1,
      sym_identifier,
    STATE(769), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41826] = 3,
    ACTIONS(2360), 1,
      sym_identifier,
    STATE(1077), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41837] = 3,
    ACTIONS(2360), 1,
      sym_identifier,
    STATE(1079), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41848] = 3,
    ACTIONS(2468), 1,
      anon_sym_end,
    ACTIONS(2470), 1,
      anon_sym_endfunction,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41859] = 2,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
    ACTIONS(193), 2,
      ts_builtin_sym_end,
      anon_sym_function,
  [41868] = 3,
    ACTIONS(2360), 1,
      sym_identifier,
    STATE(1035), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41879] = 3,
    ACTIONS(2360), 1,
      sym_identifier,
    STATE(1086), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41890] = 3,
    ACTIONS(2360), 1,
      sym_identifier,
    STATE(1087), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41901] = 3,
    ACTIONS(2360), 1,
      sym_identifier,
    STATE(1092), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41912] = 3,
    ACTIONS(2360), 1,
      sym_identifier,
    STATE(1093), 1,
      sym_property_name,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41923] = 3,
    ACTIONS(2464), 1,
      sym_identifier,
    ACTIONS(2472), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41934] = 3,
    ACTIONS(2440), 1,
      sym_identifier,
    ACTIONS(2474), 1,
      anon_sym_LPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41945] = 2,
    ACTIONS(2476), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41953] = 2,
    ACTIONS(2478), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41961] = 2,
    ACTIONS(2480), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41969] = 2,
    ACTIONS(2482), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41977] = 2,
    ACTIONS(2484), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41985] = 2,
    ACTIONS(2486), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [41993] = 2,
    ACTIONS(2488), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42001] = 2,
    ACTIONS(2490), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42009] = 2,
    ACTIONS(2364), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42017] = 2,
    ACTIONS(2492), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42025] = 2,
    ACTIONS(2494), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42033] = 2,
    ACTIONS(2496), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42041] = 2,
    ACTIONS(2490), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42049] = 2,
    ACTIONS(1671), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42057] = 2,
    ACTIONS(2498), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42065] = 2,
    ACTIONS(2500), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42073] = 2,
    ACTIONS(2498), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42081] = 2,
    ACTIONS(2502), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42089] = 2,
    ACTIONS(2504), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42097] = 2,
    ACTIONS(2506), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42105] = 2,
    ACTIONS(2508), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42113] = 2,
    ACTIONS(2510), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42121] = 2,
    ACTIONS(2293), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42129] = 2,
    ACTIONS(2512), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42137] = 2,
    ACTIONS(2514), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42145] = 2,
    ACTIONS(2516), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42153] = 2,
    ACTIONS(2518), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42161] = 2,
    ACTIONS(1709), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42169] = 2,
    ACTIONS(2520), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42177] = 2,
    ACTIONS(2522), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42185] = 2,
    ACTIONS(2524), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42193] = 2,
    ACTIONS(2526), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42201] = 2,
    ACTIONS(2524), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42209] = 2,
    ACTIONS(1571), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42217] = 2,
    ACTIONS(2528), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42225] = 2,
    ACTIONS(2530), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42233] = 2,
    ACTIONS(2532), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42241] = 2,
    ACTIONS(2534), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42249] = 2,
    ACTIONS(2536), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42257] = 2,
    ACTIONS(2538), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42265] = 2,
    ACTIONS(2540), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42273] = 2,
    ACTIONS(2542), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42281] = 2,
    ACTIONS(2544), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42289] = 2,
    ACTIONS(2546), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42297] = 2,
    ACTIONS(2548), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42305] = 2,
    ACTIONS(2550), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42313] = 2,
    ACTIONS(2552), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42321] = 2,
    ACTIONS(2554), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42329] = 2,
    ACTIONS(2556), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42337] = 2,
    ACTIONS(2558), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42345] = 2,
    ACTIONS(2560), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42353] = 2,
    ACTIONS(2265), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42361] = 2,
    ACTIONS(2562), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42369] = 2,
    ACTIONS(2564), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42377] = 2,
    ACTIONS(2566), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42385] = 2,
    ACTIONS(2568), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42393] = 2,
    ACTIONS(2570), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42401] = 2,
    ACTIONS(2572), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42409] = 2,
    ACTIONS(2574), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42417] = 2,
    ACTIONS(2576), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42425] = 2,
    ACTIONS(2578), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42433] = 2,
    ACTIONS(2580), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42441] = 2,
    ACTIONS(2582), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42449] = 2,
    ACTIONS(2584), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42457] = 2,
    ACTIONS(2476), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42465] = 2,
    ACTIONS(2586), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42473] = 2,
    ACTIONS(2588), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42481] = 2,
    ACTIONS(2590), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42489] = 2,
    ACTIONS(1600), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42497] = 2,
    ACTIONS(2552), 1,
      anon_sym_RBRACE,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42505] = 2,
    ACTIONS(2592), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42513] = 2,
    ACTIONS(1559), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42521] = 2,
    ACTIONS(2594), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42529] = 2,
    ACTIONS(2596), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42537] = 2,
    ACTIONS(2598), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42545] = 2,
    ACTIONS(2600), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42553] = 2,
    ACTIONS(2602), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42561] = 2,
    ACTIONS(2604), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42569] = 2,
    ACTIONS(2606), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42577] = 2,
    ACTIONS(2608), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42585] = 2,
    ACTIONS(2610), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42593] = 2,
    ACTIONS(2612), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42601] = 2,
    ACTIONS(2614), 1,
      anon_sym_COMMA,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42609] = 2,
    ACTIONS(2616), 1,
      ts_builtin_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42617] = 2,
    ACTIONS(2618), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42625] = 2,
    ACTIONS(2418), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42633] = 2,
    ACTIONS(1821), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42641] = 2,
    ACTIONS(2620), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42649] = 2,
    ACTIONS(2622), 1,
      anon_sym_COLON,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42657] = 2,
    ACTIONS(2624), 1,
      anon_sym_end,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42665] = 2,
    ACTIONS(2626), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42673] = 2,
    ACTIONS(2628), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42681] = 2,
    ACTIONS(2630), 1,
      anon_sym_EQ,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42689] = 2,
    ACTIONS(2632), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42697] = 2,
    ACTIONS(2634), 1,
      sym_identifier,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
  [42705] = 2,
    ACTIONS(2636), 1,
      anon_sym_RPAREN,
    ACTIONS(3), 2,
      sym_comment,
      sym_line_continuation,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(76)] = 0,
  [SMALL_STATE(77)] = 85,
  [SMALL_STATE(78)] = 174,
  [SMALL_STATE(79)] = 263,
  [SMALL_STATE(80)] = 352,
  [SMALL_STATE(81)] = 437,
  [SMALL_STATE(82)] = 511,
  [SMALL_STATE(83)] = 585,
  [SMALL_STATE(84)] = 659,
  [SMALL_STATE(85)] = 733,
  [SMALL_STATE(86)] = 807,
  [SMALL_STATE(87)] = 885,
  [SMALL_STATE(88)] = 959,
  [SMALL_STATE(89)] = 1033,
  [SMALL_STATE(90)] = 1102,
  [SMALL_STATE(91)] = 1185,
  [SMALL_STATE(92)] = 1264,
  [SMALL_STATE(93)] = 1333,
  [SMALL_STATE(94)] = 1416,
  [SMALL_STATE(95)] = 1485,
  [SMALL_STATE(96)] = 1554,
  [SMALL_STATE(97)] = 1637,
  [SMALL_STATE(98)] = 1706,
  [SMALL_STATE(99)] = 1785,
  [SMALL_STATE(100)] = 1854,
  [SMALL_STATE(101)] = 1923,
  [SMALL_STATE(102)] = 1992,
  [SMALL_STATE(103)] = 2066,
  [SMALL_STATE(104)] = 2136,
  [SMALL_STATE(105)] = 2204,
  [SMALL_STATE(106)] = 2272,
  [SMALL_STATE(107)] = 2340,
  [SMALL_STATE(108)] = 2408,
  [SMALL_STATE(109)] = 2476,
  [SMALL_STATE(110)] = 2544,
  [SMALL_STATE(111)] = 2612,
  [SMALL_STATE(112)] = 2680,
  [SMALL_STATE(113)] = 2752,
  [SMALL_STATE(114)] = 2822,
  [SMALL_STATE(115)] = 2892,
  [SMALL_STATE(116)] = 2968,
  [SMALL_STATE(117)] = 3038,
  [SMALL_STATE(118)] = 3106,
  [SMALL_STATE(119)] = 3174,
  [SMALL_STATE(120)] = 3246,
  [SMALL_STATE(121)] = 3320,
  [SMALL_STATE(122)] = 3394,
  [SMALL_STATE(123)] = 3468,
  [SMALL_STATE(124)] = 3542,
  [SMALL_STATE(125)] = 3614,
  [SMALL_STATE(126)] = 3684,
  [SMALL_STATE(127)] = 3756,
  [SMALL_STATE(128)] = 3830,
  [SMALL_STATE(129)] = 3904,
  [SMALL_STATE(130)] = 3974,
  [SMALL_STATE(131)] = 4048,
  [SMALL_STATE(132)] = 4118,
  [SMALL_STATE(133)] = 4188,
  [SMALL_STATE(134)] = 4262,
  [SMALL_STATE(135)] = 4336,
  [SMALL_STATE(136)] = 4408,
  [SMALL_STATE(137)] = 4478,
  [SMALL_STATE(138)] = 4552,
  [SMALL_STATE(139)] = 4620,
  [SMALL_STATE(140)] = 4694,
  [SMALL_STATE(141)] = 4764,
  [SMALL_STATE(142)] = 4836,
  [SMALL_STATE(143)] = 4904,
  [SMALL_STATE(144)] = 4974,
  [SMALL_STATE(145)] = 5044,
  [SMALL_STATE(146)] = 5112,
  [SMALL_STATE(147)] = 5182,
  [SMALL_STATE(148)] = 5252,
  [SMALL_STATE(149)] = 5323,
  [SMALL_STATE(150)] = 5392,
  [SMALL_STATE(151)] = 5463,
  [SMALL_STATE(152)] = 5530,
  [SMALL_STATE(153)] = 5589,
  [SMALL_STATE(154)] = 5648,
  [SMALL_STATE(155)] = 5707,
  [SMALL_STATE(156)] = 5766,
  [SMALL_STATE(157)] = 5825,
  [SMALL_STATE(158)] = 5879,
  [SMALL_STATE(159)] = 5984,
  [SMALL_STATE(160)] = 6041,
  [SMALL_STATE(161)] = 6095,
  [SMALL_STATE(162)] = 6194,
  [SMALL_STATE(163)] = 6293,
  [SMALL_STATE(164)] = 6392,
  [SMALL_STATE(165)] = 6489,
  [SMALL_STATE(166)] = 6589,
  [SMALL_STATE(167)] = 6641,
  [SMALL_STATE(168)] = 6693,
  [SMALL_STATE(169)] = 6793,
  [SMALL_STATE(170)] = 6893,
  [SMALL_STATE(171)] = 6993,
  [SMALL_STATE(172)] = 7093,
  [SMALL_STATE(173)] = 7193,
  [SMALL_STATE(174)] = 7293,
  [SMALL_STATE(175)] = 7393,
  [SMALL_STATE(176)] = 7445,
  [SMALL_STATE(177)] = 7497,
  [SMALL_STATE(178)] = 7597,
  [SMALL_STATE(179)] = 7697,
  [SMALL_STATE(180)] = 7749,
  [SMALL_STATE(181)] = 7849,
  [SMALL_STATE(182)] = 7949,
  [SMALL_STATE(183)] = 8049,
  [SMALL_STATE(184)] = 8149,
  [SMALL_STATE(185)] = 8249,
  [SMALL_STATE(186)] = 8349,
  [SMALL_STATE(187)] = 8449,
  [SMALL_STATE(188)] = 8549,
  [SMALL_STATE(189)] = 8649,
  [SMALL_STATE(190)] = 8712,
  [SMALL_STATE(191)] = 8771,
  [SMALL_STATE(192)] = 8830,
  [SMALL_STATE(193)] = 8893,
  [SMALL_STATE(194)] = 8956,
  [SMALL_STATE(195)] = 9009,
  [SMALL_STATE(196)] = 9053,
  [SMALL_STATE(197)] = 9097,
  [SMALL_STATE(198)] = 9141,
  [SMALL_STATE(199)] = 9235,
  [SMALL_STATE(200)] = 9279,
  [SMALL_STATE(201)] = 9373,
  [SMALL_STATE(202)] = 9417,
  [SMALL_STATE(203)] = 9511,
  [SMALL_STATE(204)] = 9555,
  [SMALL_STATE(205)] = 9599,
  [SMALL_STATE(206)] = 9693,
  [SMALL_STATE(207)] = 9752,
  [SMALL_STATE(208)] = 9815,
  [SMALL_STATE(209)] = 9872,
  [SMALL_STATE(210)] = 9931,
  [SMALL_STATE(211)] = 10022,
  [SMALL_STATE(212)] = 10085,
  [SMALL_STATE(213)] = 10176,
  [SMALL_STATE(214)] = 10267,
  [SMALL_STATE(215)] = 10324,
  [SMALL_STATE(216)] = 10387,
  [SMALL_STATE(217)] = 10480,
  [SMALL_STATE(218)] = 10533,
  [SMALL_STATE(219)] = 10590,
  [SMALL_STATE(220)] = 10653,
  [SMALL_STATE(221)] = 10706,
  [SMALL_STATE(222)] = 10799,
  [SMALL_STATE(223)] = 10887,
  [SMALL_STATE(224)] = 10975,
  [SMALL_STATE(225)] = 11063,
  [SMALL_STATE(226)] = 11147,
  [SMALL_STATE(227)] = 11231,
  [SMALL_STATE(228)] = 11319,
  [SMALL_STATE(229)] = 11407,
  [SMALL_STATE(230)] = 11495,
  [SMALL_STATE(231)] = 11579,
  [SMALL_STATE(232)] = 11663,
  [SMALL_STATE(233)] = 11747,
  [SMALL_STATE(234)] = 11831,
  [SMALL_STATE(235)] = 11915,
  [SMALL_STATE(236)] = 12003,
  [SMALL_STATE(237)] = 12091,
  [SMALL_STATE(238)] = 12179,
  [SMALL_STATE(239)] = 12267,
  [SMALL_STATE(240)] = 12355,
  [SMALL_STATE(241)] = 12443,
  [SMALL_STATE(242)] = 12527,
  [SMALL_STATE(243)] = 12615,
  [SMALL_STATE(244)] = 12703,
  [SMALL_STATE(245)] = 12745,
  [SMALL_STATE(246)] = 12833,
  [SMALL_STATE(247)] = 12917,
  [SMALL_STATE(248)] = 13005,
  [SMALL_STATE(249)] = 13093,
  [SMALL_STATE(250)] = 13181,
  [SMALL_STATE(251)] = 13265,
  [SMALL_STATE(252)] = 13349,
  [SMALL_STATE(253)] = 13433,
  [SMALL_STATE(254)] = 13517,
  [SMALL_STATE(255)] = 13601,
  [SMALL_STATE(256)] = 13689,
  [SMALL_STATE(257)] = 13777,
  [SMALL_STATE(258)] = 13865,
  [SMALL_STATE(259)] = 13953,
  [SMALL_STATE(260)] = 14005,
  [SMALL_STATE(261)] = 14093,
  [SMALL_STATE(262)] = 14181,
  [SMALL_STATE(263)] = 14227,
  [SMALL_STATE(264)] = 14315,
  [SMALL_STATE(265)] = 14363,
  [SMALL_STATE(266)] = 14451,
  [SMALL_STATE(267)] = 14539,
  [SMALL_STATE(268)] = 14627,
  [SMALL_STATE(269)] = 14715,
  [SMALL_STATE(270)] = 14799,
  [SMALL_STATE(271)] = 14883,
  [SMALL_STATE(272)] = 14931,
  [SMALL_STATE(273)] = 15015,
  [SMALL_STATE(274)] = 15099,
  [SMALL_STATE(275)] = 15183,
  [SMALL_STATE(276)] = 15271,
  [SMALL_STATE(277)] = 15359,
  [SMALL_STATE(278)] = 15447,
  [SMALL_STATE(279)] = 15535,
  [SMALL_STATE(280)] = 15601,
  [SMALL_STATE(281)] = 15689,
  [SMALL_STATE(282)] = 15777,
  [SMALL_STATE(283)] = 15865,
  [SMALL_STATE(284)] = 15953,
  [SMALL_STATE(285)] = 16041,
  [SMALL_STATE(286)] = 16129,
  [SMALL_STATE(287)] = 16217,
  [SMALL_STATE(288)] = 16305,
  [SMALL_STATE(289)] = 16393,
  [SMALL_STATE(290)] = 16481,
  [SMALL_STATE(291)] = 16569,
  [SMALL_STATE(292)] = 16657,
  [SMALL_STATE(293)] = 16745,
  [SMALL_STATE(294)] = 16833,
  [SMALL_STATE(295)] = 16921,
  [SMALL_STATE(296)] = 17009,
  [SMALL_STATE(297)] = 17097,
  [SMALL_STATE(298)] = 17185,
  [SMALL_STATE(299)] = 17251,
  [SMALL_STATE(300)] = 17339,
  [SMALL_STATE(301)] = 17405,
  [SMALL_STATE(302)] = 17493,
  [SMALL_STATE(303)] = 17581,
  [SMALL_STATE(304)] = 17669,
  [SMALL_STATE(305)] = 17757,
  [SMALL_STATE(306)] = 17845,
  [SMALL_STATE(307)] = 17933,
  [SMALL_STATE(308)] = 18021,
  [SMALL_STATE(309)] = 18109,
  [SMALL_STATE(310)] = 18157,
  [SMALL_STATE(311)] = 18205,
  [SMALL_STATE(312)] = 18293,
  [SMALL_STATE(313)] = 18359,
  [SMALL_STATE(314)] = 18447,
  [SMALL_STATE(315)] = 18535,
  [SMALL_STATE(316)] = 18583,
  [SMALL_STATE(317)] = 18629,
  [SMALL_STATE(318)] = 18717,
  [SMALL_STATE(319)] = 18805,
  [SMALL_STATE(320)] = 18893,
  [SMALL_STATE(321)] = 18981,
  [SMALL_STATE(322)] = 19069,
  [SMALL_STATE(323)] = 19157,
  [SMALL_STATE(324)] = 19245,
  [SMALL_STATE(325)] = 19333,
  [SMALL_STATE(326)] = 19421,
  [SMALL_STATE(327)] = 19509,
  [SMALL_STATE(328)] = 19597,
  [SMALL_STATE(329)] = 19685,
  [SMALL_STATE(330)] = 19773,
  [SMALL_STATE(331)] = 19861,
  [SMALL_STATE(332)] = 19909,
  [SMALL_STATE(333)] = 19997,
  [SMALL_STATE(334)] = 20085,
  [SMALL_STATE(335)] = 20173,
  [SMALL_STATE(336)] = 20261,
  [SMALL_STATE(337)] = 20349,
  [SMALL_STATE(338)] = 20437,
  [SMALL_STATE(339)] = 20525,
  [SMALL_STATE(340)] = 20613,
  [SMALL_STATE(341)] = 20701,
  [SMALL_STATE(342)] = 20789,
  [SMALL_STATE(343)] = 20877,
  [SMALL_STATE(344)] = 20965,
  [SMALL_STATE(345)] = 21053,
  [SMALL_STATE(346)] = 21137,
  [SMALL_STATE(347)] = 21182,
  [SMALL_STATE(348)] = 21227,
  [SMALL_STATE(349)] = 21270,
  [SMALL_STATE(350)] = 21327,
  [SMALL_STATE(351)] = 21370,
  [SMALL_STATE(352)] = 21433,
  [SMALL_STATE(353)] = 21486,
  [SMALL_STATE(354)] = 21551,
  [SMALL_STATE(355)] = 21594,
  [SMALL_STATE(356)] = 21637,
  [SMALL_STATE(357)] = 21694,
  [SMALL_STATE(358)] = 21737,
  [SMALL_STATE(359)] = 21794,
  [SMALL_STATE(360)] = 21857,
  [SMALL_STATE(361)] = 21910,
  [SMALL_STATE(362)] = 21967,
  [SMALL_STATE(363)] = 22012,
  [SMALL_STATE(364)] = 22075,
  [SMALL_STATE(365)] = 22120,
  [SMALL_STATE(366)] = 22177,
  [SMALL_STATE(367)] = 22240,
  [SMALL_STATE(368)] = 22283,
  [SMALL_STATE(369)] = 22326,
  [SMALL_STATE(370)] = 22371,
  [SMALL_STATE(371)] = 22413,
  [SMALL_STATE(372)] = 22453,
  [SMALL_STATE(373)] = 22517,
  [SMALL_STATE(374)] = 22559,
  [SMALL_STATE(375)] = 22609,
  [SMALL_STATE(376)] = 22651,
  [SMALL_STATE(377)] = 22693,
  [SMALL_STATE(378)] = 22755,
  [SMALL_STATE(379)] = 22797,
  [SMALL_STATE(380)] = 22836,
  [SMALL_STATE(381)] = 22881,
  [SMALL_STATE(382)] = 22922,
  [SMALL_STATE(383)] = 22963,
  [SMALL_STATE(384)] = 23004,
  [SMALL_STATE(385)] = 23049,
  [SMALL_STATE(386)] = 23088,
  [SMALL_STATE(387)] = 23133,
  [SMALL_STATE(388)] = 23178,
  [SMALL_STATE(389)] = 23221,
  [SMALL_STATE(390)] = 23262,
  [SMALL_STATE(391)] = 23325,
  [SMALL_STATE(392)] = 23364,
  [SMALL_STATE(393)] = 23415,
  [SMALL_STATE(394)] = 23460,
  [SMALL_STATE(395)] = 23501,
  [SMALL_STATE(396)] = 23558,
  [SMALL_STATE(397)] = 23603,
  [SMALL_STATE(398)] = 23648,
  [SMALL_STATE(399)] = 23687,
  [SMALL_STATE(400)] = 23748,
  [SMALL_STATE(401)] = 23789,
  [SMALL_STATE(402)] = 23830,
  [SMALL_STATE(403)] = 23871,
  [SMALL_STATE(404)] = 23934,
  [SMALL_STATE(405)] = 23979,
  [SMALL_STATE(406)] = 24022,
  [SMALL_STATE(407)] = 24061,
  [SMALL_STATE(408)] = 24104,
  [SMALL_STATE(409)] = 24143,
  [SMALL_STATE(410)] = 24184,
  [SMALL_STATE(411)] = 24223,
  [SMALL_STATE(412)] = 24268,
  [SMALL_STATE(413)] = 24309,
  [SMALL_STATE(414)] = 24354,
  [SMALL_STATE(415)] = 24395,
  [SMALL_STATE(416)] = 24440,
  [SMALL_STATE(417)] = 24481,
  [SMALL_STATE(418)] = 24538,
  [SMALL_STATE(419)] = 24579,
  [SMALL_STATE(420)] = 24642,
  [SMALL_STATE(421)] = 24687,
  [SMALL_STATE(422)] = 24738,
  [SMALL_STATE(423)] = 24801,
  [SMALL_STATE(424)] = 24840,
  [SMALL_STATE(425)] = 24885,
  [SMALL_STATE(426)] = 24926,
  [SMALL_STATE(427)] = 24967,
  [SMALL_STATE(428)] = 25008,
  [SMALL_STATE(429)] = 25053,
  [SMALL_STATE(430)] = 25096,
  [SMALL_STATE(431)] = 25139,
  [SMALL_STATE(432)] = 25180,
  [SMALL_STATE(433)] = 25223,
  [SMALL_STATE(434)] = 25262,
  [SMALL_STATE(435)] = 25303,
  [SMALL_STATE(436)] = 25342,
  [SMALL_STATE(437)] = 25387,
  [SMALL_STATE(438)] = 25432,
  [SMALL_STATE(439)] = 25477,
  [SMALL_STATE(440)] = 25522,
  [SMALL_STATE(441)] = 25585,
  [SMALL_STATE(442)] = 25624,
  [SMALL_STATE(443)] = 25663,
  [SMALL_STATE(444)] = 25710,
  [SMALL_STATE(445)] = 25751,
  [SMALL_STATE(446)] = 25808,
  [SMALL_STATE(447)] = 25849,
  [SMALL_STATE(448)] = 25894,
  [SMALL_STATE(449)] = 25934,
  [SMALL_STATE(450)] = 25974,
  [SMALL_STATE(451)] = 26032,
  [SMALL_STATE(452)] = 26073,
  [SMALL_STATE(453)] = 26114,
  [SMALL_STATE(454)] = 26153,
  [SMALL_STATE(455)] = 26194,
  [SMALL_STATE(456)] = 26233,
  [SMALL_STATE(457)] = 26272,
  [SMALL_STATE(458)] = 26311,
  [SMALL_STATE(459)] = 26352,
  [SMALL_STATE(460)] = 26395,
  [SMALL_STATE(461)] = 26440,
  [SMALL_STATE(462)] = 26479,
  [SMALL_STATE(463)] = 26520,
  [SMALL_STATE(464)] = 26563,
  [SMALL_STATE(465)] = 26604,
  [SMALL_STATE(466)] = 26645,
  [SMALL_STATE(467)] = 26692,
  [SMALL_STATE(468)] = 26737,
  [SMALL_STATE(469)] = 26778,
  [SMALL_STATE(470)] = 26817,
  [SMALL_STATE(471)] = 26856,
  [SMALL_STATE(472)] = 26895,
  [SMALL_STATE(473)] = 26938,
  [SMALL_STATE(474)] = 26979,
  [SMALL_STATE(475)] = 27018,
  [SMALL_STATE(476)] = 27059,
  [SMALL_STATE(477)] = 27104,
  [SMALL_STATE(478)] = 27149,
  [SMALL_STATE(479)] = 27192,
  [SMALL_STATE(480)] = 27231,
  [SMALL_STATE(481)] = 27270,
  [SMALL_STATE(482)] = 27313,
  [SMALL_STATE(483)] = 27356,
  [SMALL_STATE(484)] = 27397,
  [SMALL_STATE(485)] = 27442,
  [SMALL_STATE(486)] = 27485,
  [SMALL_STATE(487)] = 27528,
  [SMALL_STATE(488)] = 27571,
  [SMALL_STATE(489)] = 27614,
  [SMALL_STATE(490)] = 27659,
  [SMALL_STATE(491)] = 27702,
  [SMALL_STATE(492)] = 27745,
  [SMALL_STATE(493)] = 27790,
  [SMALL_STATE(494)] = 27831,
  [SMALL_STATE(495)] = 27876,
  [SMALL_STATE(496)] = 27921,
  [SMALL_STATE(497)] = 27966,
  [SMALL_STATE(498)] = 28007,
  [SMALL_STATE(499)] = 28050,
  [SMALL_STATE(500)] = 28095,
  [SMALL_STATE(501)] = 28140,
  [SMALL_STATE(502)] = 28183,
  [SMALL_STATE(503)] = 28224,
  [SMALL_STATE(504)] = 28263,
  [SMALL_STATE(505)] = 28308,
  [SMALL_STATE(506)] = 28348,
  [SMALL_STATE(507)] = 28390,
  [SMALL_STATE(508)] = 28432,
  [SMALL_STATE(509)] = 28470,
  [SMALL_STATE(510)] = 28508,
  [SMALL_STATE(511)] = 28551,
  [SMALL_STATE(512)] = 28596,
  [SMALL_STATE(513)] = 28633,
  [SMALL_STATE(514)] = 28674,
  [SMALL_STATE(515)] = 28717,
  [SMALL_STATE(516)] = 28756,
  [SMALL_STATE(517)] = 28801,
  [SMALL_STATE(518)] = 28838,
  [SMALL_STATE(519)] = 28883,
  [SMALL_STATE(520)] = 28924,
  [SMALL_STATE(521)] = 28969,
  [SMALL_STATE(522)] = 29014,
  [SMALL_STATE(523)] = 29055,
  [SMALL_STATE(524)] = 29098,
  [SMALL_STATE(525)] = 29143,
  [SMALL_STATE(526)] = 29180,
  [SMALL_STATE(527)] = 29217,
  [SMALL_STATE(528)] = 29260,
  [SMALL_STATE(529)] = 29299,
  [SMALL_STATE(530)] = 29338,
  [SMALL_STATE(531)] = 29377,
  [SMALL_STATE(532)] = 29414,
  [SMALL_STATE(533)] = 29453,
  [SMALL_STATE(534)] = 29496,
  [SMALL_STATE(535)] = 29541,
  [SMALL_STATE(536)] = 29586,
  [SMALL_STATE(537)] = 29629,
  [SMALL_STATE(538)] = 29670,
  [SMALL_STATE(539)] = 29709,
  [SMALL_STATE(540)] = 29746,
  [SMALL_STATE(541)] = 29783,
  [SMALL_STATE(542)] = 29824,
  [SMALL_STATE(543)] = 29861,
  [SMALL_STATE(544)] = 29898,
  [SMALL_STATE(545)] = 29935,
  [SMALL_STATE(546)] = 29974,
  [SMALL_STATE(547)] = 30019,
  [SMALL_STATE(548)] = 30058,
  [SMALL_STATE(549)] = 30103,
  [SMALL_STATE(550)] = 30140,
  [SMALL_STATE(551)] = 30177,
  [SMALL_STATE(552)] = 30222,
  [SMALL_STATE(553)] = 30261,
  [SMALL_STATE(554)] = 30300,
  [SMALL_STATE(555)] = 30345,
  [SMALL_STATE(556)] = 30387,
  [SMALL_STATE(557)] = 30433,
  [SMALL_STATE(558)] = 30477,
  [SMALL_STATE(559)] = 30519,
  [SMALL_STATE(560)] = 30557,
  [SMALL_STATE(561)] = 30603,
  [SMALL_STATE(562)] = 30647,
  [SMALL_STATE(563)] = 30691,
  [SMALL_STATE(564)] = 30731,
  [SMALL_STATE(565)] = 30776,
  [SMALL_STATE(566)] = 30819,
  [SMALL_STATE(567)] = 30860,
  [SMALL_STATE(568)] = 30905,
  [SMALL_STATE(569)] = 30950,
  [SMALL_STATE(570)] = 30995,
  [SMALL_STATE(571)] = 31040,
  [SMALL_STATE(572)] = 31085,
  [SMALL_STATE(573)] = 31130,
  [SMALL_STATE(574)] = 31175,
  [SMALL_STATE(575)] = 31220,
  [SMALL_STATE(576)] = 31265,
  [SMALL_STATE(577)] = 31310,
  [SMALL_STATE(578)] = 31355,
  [SMALL_STATE(579)] = 31400,
  [SMALL_STATE(580)] = 31445,
  [SMALL_STATE(581)] = 31490,
  [SMALL_STATE(582)] = 31532,
  [SMALL_STATE(583)] = 31572,
  [SMALL_STATE(584)] = 31610,
  [SMALL_STATE(585)] = 31652,
  [SMALL_STATE(586)] = 31694,
  [SMALL_STATE(587)] = 31736,
  [SMALL_STATE(588)] = 31778,
  [SMALL_STATE(589)] = 31820,
  [SMALL_STATE(590)] = 31859,
  [SMALL_STATE(591)] = 31898,
  [SMALL_STATE(592)] = 31937,
  [SMALL_STATE(593)] = 31971,
  [SMALL_STATE(594)] = 32000,
  [SMALL_STATE(595)] = 32045,
  [SMALL_STATE(596)] = 32098,
  [SMALL_STATE(597)] = 32126,
  [SMALL_STATE(598)] = 32154,
  [SMALL_STATE(599)] = 32182,
  [SMALL_STATE(600)] = 32210,
  [SMALL_STATE(601)] = 32257,
  [SMALL_STATE(602)] = 32285,
  [SMALL_STATE(603)] = 32313,
  [SMALL_STATE(604)] = 32341,
  [SMALL_STATE(605)] = 32369,
  [SMALL_STATE(606)] = 32397,
  [SMALL_STATE(607)] = 32425,
  [SMALL_STATE(608)] = 32448,
  [SMALL_STATE(609)] = 32481,
  [SMALL_STATE(610)] = 32522,
  [SMALL_STATE(611)] = 32551,
  [SMALL_STATE(612)] = 32584,
  [SMALL_STATE(613)] = 32613,
  [SMALL_STATE(614)] = 32636,
  [SMALL_STATE(615)] = 32665,
  [SMALL_STATE(616)] = 32694,
  [SMALL_STATE(617)] = 32723,
  [SMALL_STATE(618)] = 32761,
  [SMALL_STATE(619)] = 32787,
  [SMALL_STATE(620)] = 32815,
  [SMALL_STATE(621)] = 32853,
  [SMALL_STATE(622)] = 32879,
  [SMALL_STATE(623)] = 32907,
  [SMALL_STATE(624)] = 32933,
  [SMALL_STATE(625)] = 32961,
  [SMALL_STATE(626)] = 32999,
  [SMALL_STATE(627)] = 33027,
  [SMALL_STATE(628)] = 33053,
  [SMALL_STATE(629)] = 33084,
  [SMALL_STATE(630)] = 33109,
  [SMALL_STATE(631)] = 33130,
  [SMALL_STATE(632)] = 33161,
  [SMALL_STATE(633)] = 33200,
  [SMALL_STATE(634)] = 33231,
  [SMALL_STATE(635)] = 33256,
  [SMALL_STATE(636)] = 33277,
  [SMALL_STATE(637)] = 33298,
  [SMALL_STATE(638)] = 33329,
  [SMALL_STATE(639)] = 33360,
  [SMALL_STATE(640)] = 33391,
  [SMALL_STATE(641)] = 33424,
  [SMALL_STATE(642)] = 33445,
  [SMALL_STATE(643)] = 33468,
  [SMALL_STATE(644)] = 33489,
  [SMALL_STATE(645)] = 33522,
  [SMALL_STATE(646)] = 33543,
  [SMALL_STATE(647)] = 33573,
  [SMALL_STATE(648)] = 33603,
  [SMALL_STATE(649)] = 33633,
  [SMALL_STATE(650)] = 33663,
  [SMALL_STATE(651)] = 33693,
  [SMALL_STATE(652)] = 33727,
  [SMALL_STATE(653)] = 33761,
  [SMALL_STATE(654)] = 33793,
  [SMALL_STATE(655)] = 33823,
  [SMALL_STATE(656)] = 33853,
  [SMALL_STATE(657)] = 33885,
  [SMALL_STATE(658)] = 33919,
  [SMALL_STATE(659)] = 33953,
  [SMALL_STATE(660)] = 33981,
  [SMALL_STATE(661)] = 34011,
  [SMALL_STATE(662)] = 34043,
  [SMALL_STATE(663)] = 34077,
  [SMALL_STATE(664)] = 34111,
  [SMALL_STATE(665)] = 34141,
  [SMALL_STATE(666)] = 34175,
  [SMALL_STATE(667)] = 34209,
  [SMALL_STATE(668)] = 34235,
  [SMALL_STATE(669)] = 34261,
  [SMALL_STATE(670)] = 34286,
  [SMALL_STATE(671)] = 34317,
  [SMALL_STATE(672)] = 34336,
  [SMALL_STATE(673)] = 34353,
  [SMALL_STATE(674)] = 34370,
  [SMALL_STATE(675)] = 34395,
  [SMALL_STATE(676)] = 34421,
  [SMALL_STATE(677)] = 34445,
  [SMALL_STATE(678)] = 34467,
  [SMALL_STATE(679)] = 34491,
  [SMALL_STATE(680)] = 34511,
  [SMALL_STATE(681)] = 34535,
  [SMALL_STATE(682)] = 34561,
  [SMALL_STATE(683)] = 34577,
  [SMALL_STATE(684)] = 34601,
  [SMALL_STATE(685)] = 34625,
  [SMALL_STATE(686)] = 34647,
  [SMALL_STATE(687)] = 34670,
  [SMALL_STATE(688)] = 34687,
  [SMALL_STATE(689)] = 34710,
  [SMALL_STATE(690)] = 34733,
  [SMALL_STATE(691)] = 34756,
  [SMALL_STATE(692)] = 34779,
  [SMALL_STATE(693)] = 34800,
  [SMALL_STATE(694)] = 34821,
  [SMALL_STATE(695)] = 34842,
  [SMALL_STATE(696)] = 34863,
  [SMALL_STATE(697)] = 34884,
  [SMALL_STATE(698)] = 34904,
  [SMALL_STATE(699)] = 34926,
  [SMALL_STATE(700)] = 34948,
  [SMALL_STATE(701)] = 34962,
  [SMALL_STATE(702)] = 34980,
  [SMALL_STATE(703)] = 35000,
  [SMALL_STATE(704)] = 35020,
  [SMALL_STATE(705)] = 35038,
  [SMALL_STATE(706)] = 35054,
  [SMALL_STATE(707)] = 35074,
  [SMALL_STATE(708)] = 35096,
  [SMALL_STATE(709)] = 35120,
  [SMALL_STATE(710)] = 35142,
  [SMALL_STATE(711)] = 35162,
  [SMALL_STATE(712)] = 35182,
  [SMALL_STATE(713)] = 35202,
  [SMALL_STATE(714)] = 35224,
  [SMALL_STATE(715)] = 35246,
  [SMALL_STATE(716)] = 35266,
  [SMALL_STATE(717)] = 35286,
  [SMALL_STATE(718)] = 35306,
  [SMALL_STATE(719)] = 35324,
  [SMALL_STATE(720)] = 35342,
  [SMALL_STATE(721)] = 35362,
  [SMALL_STATE(722)] = 35380,
  [SMALL_STATE(723)] = 35402,
  [SMALL_STATE(724)] = 35426,
  [SMALL_STATE(725)] = 35444,
  [SMALL_STATE(726)] = 35462,
  [SMALL_STATE(727)] = 35476,
  [SMALL_STATE(728)] = 35498,
  [SMALL_STATE(729)] = 35516,
  [SMALL_STATE(730)] = 35536,
  [SMALL_STATE(731)] = 35554,
  [SMALL_STATE(732)] = 35572,
  [SMALL_STATE(733)] = 35592,
  [SMALL_STATE(734)] = 35614,
  [SMALL_STATE(735)] = 35636,
  [SMALL_STATE(736)] = 35654,
  [SMALL_STATE(737)] = 35672,
  [SMALL_STATE(738)] = 35692,
  [SMALL_STATE(739)] = 35712,
  [SMALL_STATE(740)] = 35734,
  [SMALL_STATE(741)] = 35756,
  [SMALL_STATE(742)] = 35778,
  [SMALL_STATE(743)] = 35800,
  [SMALL_STATE(744)] = 35826,
  [SMALL_STATE(745)] = 35846,
  [SMALL_STATE(746)] = 35866,
  [SMALL_STATE(747)] = 35886,
  [SMALL_STATE(748)] = 35904,
  [SMALL_STATE(749)] = 35924,
  [SMALL_STATE(750)] = 35942,
  [SMALL_STATE(751)] = 35962,
  [SMALL_STATE(752)] = 35975,
  [SMALL_STATE(753)] = 35990,
  [SMALL_STATE(754)] = 36005,
  [SMALL_STATE(755)] = 36020,
  [SMALL_STATE(756)] = 36035,
  [SMALL_STATE(757)] = 36050,
  [SMALL_STATE(758)] = 36065,
  [SMALL_STATE(759)] = 36080,
  [SMALL_STATE(760)] = 36095,
  [SMALL_STATE(761)] = 36110,
  [SMALL_STATE(762)] = 36131,
  [SMALL_STATE(763)] = 36152,
  [SMALL_STATE(764)] = 36173,
  [SMALL_STATE(765)] = 36190,
  [SMALL_STATE(766)] = 36205,
  [SMALL_STATE(767)] = 36226,
  [SMALL_STATE(768)] = 36245,
  [SMALL_STATE(769)] = 36262,
  [SMALL_STATE(770)] = 36279,
  [SMALL_STATE(771)] = 36300,
  [SMALL_STATE(772)] = 36317,
  [SMALL_STATE(773)] = 36332,
  [SMALL_STATE(774)] = 36353,
  [SMALL_STATE(775)] = 36372,
  [SMALL_STATE(776)] = 36391,
  [SMALL_STATE(777)] = 36408,
  [SMALL_STATE(778)] = 36425,
  [SMALL_STATE(779)] = 36442,
  [SMALL_STATE(780)] = 36459,
  [SMALL_STATE(781)] = 36476,
  [SMALL_STATE(782)] = 36489,
  [SMALL_STATE(783)] = 36502,
  [SMALL_STATE(784)] = 36519,
  [SMALL_STATE(785)] = 36538,
  [SMALL_STATE(786)] = 36557,
  [SMALL_STATE(787)] = 36576,
  [SMALL_STATE(788)] = 36593,
  [SMALL_STATE(789)] = 36610,
  [SMALL_STATE(790)] = 36629,
  [SMALL_STATE(791)] = 36650,
  [SMALL_STATE(792)] = 36667,
  [SMALL_STATE(793)] = 36686,
  [SMALL_STATE(794)] = 36703,
  [SMALL_STATE(795)] = 36716,
  [SMALL_STATE(796)] = 36731,
  [SMALL_STATE(797)] = 36746,
  [SMALL_STATE(798)] = 36759,
  [SMALL_STATE(799)] = 36772,
  [SMALL_STATE(800)] = 36793,
  [SMALL_STATE(801)] = 36814,
  [SMALL_STATE(802)] = 36835,
  [SMALL_STATE(803)] = 36854,
  [SMALL_STATE(804)] = 36871,
  [SMALL_STATE(805)] = 36890,
  [SMALL_STATE(806)] = 36907,
  [SMALL_STATE(807)] = 36926,
  [SMALL_STATE(808)] = 36943,
  [SMALL_STATE(809)] = 36962,
  [SMALL_STATE(810)] = 36979,
  [SMALL_STATE(811)] = 36992,
  [SMALL_STATE(812)] = 37005,
  [SMALL_STATE(813)] = 37020,
  [SMALL_STATE(814)] = 37033,
  [SMALL_STATE(815)] = 37046,
  [SMALL_STATE(816)] = 37063,
  [SMALL_STATE(817)] = 37084,
  [SMALL_STATE(818)] = 37101,
  [SMALL_STATE(819)] = 37120,
  [SMALL_STATE(820)] = 37135,
  [SMALL_STATE(821)] = 37154,
  [SMALL_STATE(822)] = 37169,
  [SMALL_STATE(823)] = 37184,
  [SMALL_STATE(824)] = 37201,
  [SMALL_STATE(825)] = 37220,
  [SMALL_STATE(826)] = 37237,
  [SMALL_STATE(827)] = 37256,
  [SMALL_STATE(828)] = 37271,
  [SMALL_STATE(829)] = 37286,
  [SMALL_STATE(830)] = 37301,
  [SMALL_STATE(831)] = 37318,
  [SMALL_STATE(832)] = 37337,
  [SMALL_STATE(833)] = 37350,
  [SMALL_STATE(834)] = 37371,
  [SMALL_STATE(835)] = 37384,
  [SMALL_STATE(836)] = 37404,
  [SMALL_STATE(837)] = 37418,
  [SMALL_STATE(838)] = 37432,
  [SMALL_STATE(839)] = 37446,
  [SMALL_STATE(840)] = 37460,
  [SMALL_STATE(841)] = 37478,
  [SMALL_STATE(842)] = 37490,
  [SMALL_STATE(843)] = 37510,
  [SMALL_STATE(844)] = 37524,
  [SMALL_STATE(845)] = 37538,
  [SMALL_STATE(846)] = 37550,
  [SMALL_STATE(847)] = 37566,
  [SMALL_STATE(848)] = 37582,
  [SMALL_STATE(849)] = 37596,
  [SMALL_STATE(850)] = 37610,
  [SMALL_STATE(851)] = 37624,
  [SMALL_STATE(852)] = 37638,
  [SMALL_STATE(853)] = 37652,
  [SMALL_STATE(854)] = 37666,
  [SMALL_STATE(855)] = 37682,
  [SMALL_STATE(856)] = 37696,
  [SMALL_STATE(857)] = 37710,
  [SMALL_STATE(858)] = 37724,
  [SMALL_STATE(859)] = 37738,
  [SMALL_STATE(860)] = 37752,
  [SMALL_STATE(861)] = 37766,
  [SMALL_STATE(862)] = 37786,
  [SMALL_STATE(863)] = 37802,
  [SMALL_STATE(864)] = 37818,
  [SMALL_STATE(865)] = 37834,
  [SMALL_STATE(866)] = 37848,
  [SMALL_STATE(867)] = 37860,
  [SMALL_STATE(868)] = 37874,
  [SMALL_STATE(869)] = 37890,
  [SMALL_STATE(870)] = 37906,
  [SMALL_STATE(871)] = 37926,
  [SMALL_STATE(872)] = 37940,
  [SMALL_STATE(873)] = 37956,
  [SMALL_STATE(874)] = 37970,
  [SMALL_STATE(875)] = 37986,
  [SMALL_STATE(876)] = 38000,
  [SMALL_STATE(877)] = 38016,
  [SMALL_STATE(878)] = 38034,
  [SMALL_STATE(879)] = 38048,
  [SMALL_STATE(880)] = 38064,
  [SMALL_STATE(881)] = 38078,
  [SMALL_STATE(882)] = 38094,
  [SMALL_STATE(883)] = 38110,
  [SMALL_STATE(884)] = 38130,
  [SMALL_STATE(885)] = 38150,
  [SMALL_STATE(886)] = 38166,
  [SMALL_STATE(887)] = 38182,
  [SMALL_STATE(888)] = 38196,
  [SMALL_STATE(889)] = 38212,
  [SMALL_STATE(890)] = 38228,
  [SMALL_STATE(891)] = 38242,
  [SMALL_STATE(892)] = 38256,
  [SMALL_STATE(893)] = 38276,
  [SMALL_STATE(894)] = 38296,
  [SMALL_STATE(895)] = 38316,
  [SMALL_STATE(896)] = 38336,
  [SMALL_STATE(897)] = 38356,
  [SMALL_STATE(898)] = 38370,
  [SMALL_STATE(899)] = 38384,
  [SMALL_STATE(900)] = 38398,
  [SMALL_STATE(901)] = 38412,
  [SMALL_STATE(902)] = 38426,
  [SMALL_STATE(903)] = 38446,
  [SMALL_STATE(904)] = 38466,
  [SMALL_STATE(905)] = 38486,
  [SMALL_STATE(906)] = 38500,
  [SMALL_STATE(907)] = 38520,
  [SMALL_STATE(908)] = 38534,
  [SMALL_STATE(909)] = 38548,
  [SMALL_STATE(910)] = 38564,
  [SMALL_STATE(911)] = 38577,
  [SMALL_STATE(912)] = 38588,
  [SMALL_STATE(913)] = 38599,
  [SMALL_STATE(914)] = 38610,
  [SMALL_STATE(915)] = 38627,
  [SMALL_STATE(916)] = 38642,
  [SMALL_STATE(917)] = 38653,
  [SMALL_STATE(918)] = 38664,
  [SMALL_STATE(919)] = 38679,
  [SMALL_STATE(920)] = 38696,
  [SMALL_STATE(921)] = 38711,
  [SMALL_STATE(922)] = 38722,
  [SMALL_STATE(923)] = 38733,
  [SMALL_STATE(924)] = 38744,
  [SMALL_STATE(925)] = 38755,
  [SMALL_STATE(926)] = 38768,
  [SMALL_STATE(927)] = 38779,
  [SMALL_STATE(928)] = 38794,
  [SMALL_STATE(929)] = 38811,
  [SMALL_STATE(930)] = 38822,
  [SMALL_STATE(931)] = 38837,
  [SMALL_STATE(932)] = 38848,
  [SMALL_STATE(933)] = 38865,
  [SMALL_STATE(934)] = 38880,
  [SMALL_STATE(935)] = 38891,
  [SMALL_STATE(936)] = 38908,
  [SMALL_STATE(937)] = 38921,
  [SMALL_STATE(938)] = 38936,
  [SMALL_STATE(939)] = 38953,
  [SMALL_STATE(940)] = 38964,
  [SMALL_STATE(941)] = 38981,
  [SMALL_STATE(942)] = 38994,
  [SMALL_STATE(943)] = 39005,
  [SMALL_STATE(944)] = 39016,
  [SMALL_STATE(945)] = 39033,
  [SMALL_STATE(946)] = 39050,
  [SMALL_STATE(947)] = 39061,
  [SMALL_STATE(948)] = 39072,
  [SMALL_STATE(949)] = 39083,
  [SMALL_STATE(950)] = 39096,
  [SMALL_STATE(951)] = 39113,
  [SMALL_STATE(952)] = 39130,
  [SMALL_STATE(953)] = 39145,
  [SMALL_STATE(954)] = 39160,
  [SMALL_STATE(955)] = 39171,
  [SMALL_STATE(956)] = 39182,
  [SMALL_STATE(957)] = 39197,
  [SMALL_STATE(958)] = 39208,
  [SMALL_STATE(959)] = 39223,
  [SMALL_STATE(960)] = 39234,
  [SMALL_STATE(961)] = 39245,
  [SMALL_STATE(962)] = 39260,
  [SMALL_STATE(963)] = 39275,
  [SMALL_STATE(964)] = 39290,
  [SMALL_STATE(965)] = 39305,
  [SMALL_STATE(966)] = 39322,
  [SMALL_STATE(967)] = 39337,
  [SMALL_STATE(968)] = 39352,
  [SMALL_STATE(969)] = 39369,
  [SMALL_STATE(970)] = 39386,
  [SMALL_STATE(971)] = 39401,
  [SMALL_STATE(972)] = 39416,
  [SMALL_STATE(973)] = 39431,
  [SMALL_STATE(974)] = 39446,
  [SMALL_STATE(975)] = 39457,
  [SMALL_STATE(976)] = 39474,
  [SMALL_STATE(977)] = 39485,
  [SMALL_STATE(978)] = 39496,
  [SMALL_STATE(979)] = 39507,
  [SMALL_STATE(980)] = 39524,
  [SMALL_STATE(981)] = 39541,
  [SMALL_STATE(982)] = 39552,
  [SMALL_STATE(983)] = 39569,
  [SMALL_STATE(984)] = 39586,
  [SMALL_STATE(985)] = 39597,
  [SMALL_STATE(986)] = 39610,
  [SMALL_STATE(987)] = 39627,
  [SMALL_STATE(988)] = 39642,
  [SMALL_STATE(989)] = 39655,
  [SMALL_STATE(990)] = 39666,
  [SMALL_STATE(991)] = 39683,
  [SMALL_STATE(992)] = 39696,
  [SMALL_STATE(993)] = 39711,
  [SMALL_STATE(994)] = 39728,
  [SMALL_STATE(995)] = 39739,
  [SMALL_STATE(996)] = 39752,
  [SMALL_STATE(997)] = 39763,
  [SMALL_STATE(998)] = 39780,
  [SMALL_STATE(999)] = 39797,
  [SMALL_STATE(1000)] = 39808,
  [SMALL_STATE(1001)] = 39821,
  [SMALL_STATE(1002)] = 39838,
  [SMALL_STATE(1003)] = 39855,
  [SMALL_STATE(1004)] = 39872,
  [SMALL_STATE(1005)] = 39889,
  [SMALL_STATE(1006)] = 39900,
  [SMALL_STATE(1007)] = 39915,
  [SMALL_STATE(1008)] = 39926,
  [SMALL_STATE(1009)] = 39937,
  [SMALL_STATE(1010)] = 39948,
  [SMALL_STATE(1011)] = 39961,
  [SMALL_STATE(1012)] = 39978,
  [SMALL_STATE(1013)] = 39991,
  [SMALL_STATE(1014)] = 40002,
  [SMALL_STATE(1015)] = 40015,
  [SMALL_STATE(1016)] = 40030,
  [SMALL_STATE(1017)] = 40045,
  [SMALL_STATE(1018)] = 40060,
  [SMALL_STATE(1019)] = 40071,
  [SMALL_STATE(1020)] = 40082,
  [SMALL_STATE(1021)] = 40093,
  [SMALL_STATE(1022)] = 40108,
  [SMALL_STATE(1023)] = 40123,
  [SMALL_STATE(1024)] = 40134,
  [SMALL_STATE(1025)] = 40145,
  [SMALL_STATE(1026)] = 40156,
  [SMALL_STATE(1027)] = 40173,
  [SMALL_STATE(1028)] = 40184,
  [SMALL_STATE(1029)] = 40199,
  [SMALL_STATE(1030)] = 40214,
  [SMALL_STATE(1031)] = 40229,
  [SMALL_STATE(1032)] = 40240,
  [SMALL_STATE(1033)] = 40251,
  [SMALL_STATE(1034)] = 40268,
  [SMALL_STATE(1035)] = 40280,
  [SMALL_STATE(1036)] = 40294,
  [SMALL_STATE(1037)] = 40308,
  [SMALL_STATE(1038)] = 40320,
  [SMALL_STATE(1039)] = 40334,
  [SMALL_STATE(1040)] = 40348,
  [SMALL_STATE(1041)] = 40360,
  [SMALL_STATE(1042)] = 40372,
  [SMALL_STATE(1043)] = 40382,
  [SMALL_STATE(1044)] = 40396,
  [SMALL_STATE(1045)] = 40410,
  [SMALL_STATE(1046)] = 40424,
  [SMALL_STATE(1047)] = 40438,
  [SMALL_STATE(1048)] = 40450,
  [SMALL_STATE(1049)] = 40464,
  [SMALL_STATE(1050)] = 40476,
  [SMALL_STATE(1051)] = 40488,
  [SMALL_STATE(1052)] = 40500,
  [SMALL_STATE(1053)] = 40510,
  [SMALL_STATE(1054)] = 40524,
  [SMALL_STATE(1055)] = 40538,
  [SMALL_STATE(1056)] = 40552,
  [SMALL_STATE(1057)] = 40566,
  [SMALL_STATE(1058)] = 40580,
  [SMALL_STATE(1059)] = 40594,
  [SMALL_STATE(1060)] = 40608,
  [SMALL_STATE(1061)] = 40622,
  [SMALL_STATE(1062)] = 40636,
  [SMALL_STATE(1063)] = 40648,
  [SMALL_STATE(1064)] = 40660,
  [SMALL_STATE(1065)] = 40674,
  [SMALL_STATE(1066)] = 40686,
  [SMALL_STATE(1067)] = 40698,
  [SMALL_STATE(1068)] = 40710,
  [SMALL_STATE(1069)] = 40722,
  [SMALL_STATE(1070)] = 40736,
  [SMALL_STATE(1071)] = 40750,
  [SMALL_STATE(1072)] = 40762,
  [SMALL_STATE(1073)] = 40774,
  [SMALL_STATE(1074)] = 40786,
  [SMALL_STATE(1075)] = 40800,
  [SMALL_STATE(1076)] = 40814,
  [SMALL_STATE(1077)] = 40828,
  [SMALL_STATE(1078)] = 40842,
  [SMALL_STATE(1079)] = 40854,
  [SMALL_STATE(1080)] = 40868,
  [SMALL_STATE(1081)] = 40882,
  [SMALL_STATE(1082)] = 40894,
  [SMALL_STATE(1083)] = 40908,
  [SMALL_STATE(1084)] = 40922,
  [SMALL_STATE(1085)] = 40936,
  [SMALL_STATE(1086)] = 40946,
  [SMALL_STATE(1087)] = 40960,
  [SMALL_STATE(1088)] = 40974,
  [SMALL_STATE(1089)] = 40986,
  [SMALL_STATE(1090)] = 40998,
  [SMALL_STATE(1091)] = 41012,
  [SMALL_STATE(1092)] = 41024,
  [SMALL_STATE(1093)] = 41038,
  [SMALL_STATE(1094)] = 41052,
  [SMALL_STATE(1095)] = 41064,
  [SMALL_STATE(1096)] = 41078,
  [SMALL_STATE(1097)] = 41092,
  [SMALL_STATE(1098)] = 41106,
  [SMALL_STATE(1099)] = 41118,
  [SMALL_STATE(1100)] = 41130,
  [SMALL_STATE(1101)] = 41144,
  [SMALL_STATE(1102)] = 41158,
  [SMALL_STATE(1103)] = 41172,
  [SMALL_STATE(1104)] = 41184,
  [SMALL_STATE(1105)] = 41195,
  [SMALL_STATE(1106)] = 41204,
  [SMALL_STATE(1107)] = 41213,
  [SMALL_STATE(1108)] = 41222,
  [SMALL_STATE(1109)] = 41231,
  [SMALL_STATE(1110)] = 41242,
  [SMALL_STATE(1111)] = 41251,
  [SMALL_STATE(1112)] = 41262,
  [SMALL_STATE(1113)] = 41273,
  [SMALL_STATE(1114)] = 41284,
  [SMALL_STATE(1115)] = 41295,
  [SMALL_STATE(1116)] = 41306,
  [SMALL_STATE(1117)] = 41317,
  [SMALL_STATE(1118)] = 41328,
  [SMALL_STATE(1119)] = 41339,
  [SMALL_STATE(1120)] = 41350,
  [SMALL_STATE(1121)] = 41361,
  [SMALL_STATE(1122)] = 41370,
  [SMALL_STATE(1123)] = 41379,
  [SMALL_STATE(1124)] = 41388,
  [SMALL_STATE(1125)] = 41399,
  [SMALL_STATE(1126)] = 41410,
  [SMALL_STATE(1127)] = 41421,
  [SMALL_STATE(1128)] = 41432,
  [SMALL_STATE(1129)] = 41441,
  [SMALL_STATE(1130)] = 41450,
  [SMALL_STATE(1131)] = 41461,
  [SMALL_STATE(1132)] = 41472,
  [SMALL_STATE(1133)] = 41481,
  [SMALL_STATE(1134)] = 41492,
  [SMALL_STATE(1135)] = 41501,
  [SMALL_STATE(1136)] = 41512,
  [SMALL_STATE(1137)] = 41521,
  [SMALL_STATE(1138)] = 41530,
  [SMALL_STATE(1139)] = 41541,
  [SMALL_STATE(1140)] = 41550,
  [SMALL_STATE(1141)] = 41561,
  [SMALL_STATE(1142)] = 41572,
  [SMALL_STATE(1143)] = 41581,
  [SMALL_STATE(1144)] = 41590,
  [SMALL_STATE(1145)] = 41601,
  [SMALL_STATE(1146)] = 41612,
  [SMALL_STATE(1147)] = 41623,
  [SMALL_STATE(1148)] = 41634,
  [SMALL_STATE(1149)] = 41645,
  [SMALL_STATE(1150)] = 41656,
  [SMALL_STATE(1151)] = 41667,
  [SMALL_STATE(1152)] = 41678,
  [SMALL_STATE(1153)] = 41687,
  [SMALL_STATE(1154)] = 41698,
  [SMALL_STATE(1155)] = 41709,
  [SMALL_STATE(1156)] = 41720,
  [SMALL_STATE(1157)] = 41731,
  [SMALL_STATE(1158)] = 41740,
  [SMALL_STATE(1159)] = 41751,
  [SMALL_STATE(1160)] = 41762,
  [SMALL_STATE(1161)] = 41773,
  [SMALL_STATE(1162)] = 41784,
  [SMALL_STATE(1163)] = 41795,
  [SMALL_STATE(1164)] = 41806,
  [SMALL_STATE(1165)] = 41815,
  [SMALL_STATE(1166)] = 41826,
  [SMALL_STATE(1167)] = 41837,
  [SMALL_STATE(1168)] = 41848,
  [SMALL_STATE(1169)] = 41859,
  [SMALL_STATE(1170)] = 41868,
  [SMALL_STATE(1171)] = 41879,
  [SMALL_STATE(1172)] = 41890,
  [SMALL_STATE(1173)] = 41901,
  [SMALL_STATE(1174)] = 41912,
  [SMALL_STATE(1175)] = 41923,
  [SMALL_STATE(1176)] = 41934,
  [SMALL_STATE(1177)] = 41945,
  [SMALL_STATE(1178)] = 41953,
  [SMALL_STATE(1179)] = 41961,
  [SMALL_STATE(1180)] = 41969,
  [SMALL_STATE(1181)] = 41977,
  [SMALL_STATE(1182)] = 41985,
  [SMALL_STATE(1183)] = 41993,
  [SMALL_STATE(1184)] = 42001,
  [SMALL_STATE(1185)] = 42009,
  [SMALL_STATE(1186)] = 42017,
  [SMALL_STATE(1187)] = 42025,
  [SMALL_STATE(1188)] = 42033,
  [SMALL_STATE(1189)] = 42041,
  [SMALL_STATE(1190)] = 42049,
  [SMALL_STATE(1191)] = 42057,
  [SMALL_STATE(1192)] = 42065,
  [SMALL_STATE(1193)] = 42073,
  [SMALL_STATE(1194)] = 42081,
  [SMALL_STATE(1195)] = 42089,
  [SMALL_STATE(1196)] = 42097,
  [SMALL_STATE(1197)] = 42105,
  [SMALL_STATE(1198)] = 42113,
  [SMALL_STATE(1199)] = 42121,
  [SMALL_STATE(1200)] = 42129,
  [SMALL_STATE(1201)] = 42137,
  [SMALL_STATE(1202)] = 42145,
  [SMALL_STATE(1203)] = 42153,
  [SMALL_STATE(1204)] = 42161,
  [SMALL_STATE(1205)] = 42169,
  [SMALL_STATE(1206)] = 42177,
  [SMALL_STATE(1207)] = 42185,
  [SMALL_STATE(1208)] = 42193,
  [SMALL_STATE(1209)] = 42201,
  [SMALL_STATE(1210)] = 42209,
  [SMALL_STATE(1211)] = 42217,
  [SMALL_STATE(1212)] = 42225,
  [SMALL_STATE(1213)] = 42233,
  [SMALL_STATE(1214)] = 42241,
  [SMALL_STATE(1215)] = 42249,
  [SMALL_STATE(1216)] = 42257,
  [SMALL_STATE(1217)] = 42265,
  [SMALL_STATE(1218)] = 42273,
  [SMALL_STATE(1219)] = 42281,
  [SMALL_STATE(1220)] = 42289,
  [SMALL_STATE(1221)] = 42297,
  [SMALL_STATE(1222)] = 42305,
  [SMALL_STATE(1223)] = 42313,
  [SMALL_STATE(1224)] = 42321,
  [SMALL_STATE(1225)] = 42329,
  [SMALL_STATE(1226)] = 42337,
  [SMALL_STATE(1227)] = 42345,
  [SMALL_STATE(1228)] = 42353,
  [SMALL_STATE(1229)] = 42361,
  [SMALL_STATE(1230)] = 42369,
  [SMALL_STATE(1231)] = 42377,
  [SMALL_STATE(1232)] = 42385,
  [SMALL_STATE(1233)] = 42393,
  [SMALL_STATE(1234)] = 42401,
  [SMALL_STATE(1235)] = 42409,
  [SMALL_STATE(1236)] = 42417,
  [SMALL_STATE(1237)] = 42425,
  [SMALL_STATE(1238)] = 42433,
  [SMALL_STATE(1239)] = 42441,
  [SMALL_STATE(1240)] = 42449,
  [SMALL_STATE(1241)] = 42457,
  [SMALL_STATE(1242)] = 42465,
  [SMALL_STATE(1243)] = 42473,
  [SMALL_STATE(1244)] = 42481,
  [SMALL_STATE(1245)] = 42489,
  [SMALL_STATE(1246)] = 42497,
  [SMALL_STATE(1247)] = 42505,
  [SMALL_STATE(1248)] = 42513,
  [SMALL_STATE(1249)] = 42521,
  [SMALL_STATE(1250)] = 42529,
  [SMALL_STATE(1251)] = 42537,
  [SMALL_STATE(1252)] = 42545,
  [SMALL_STATE(1253)] = 42553,
  [SMALL_STATE(1254)] = 42561,
  [SMALL_STATE(1255)] = 42569,
  [SMALL_STATE(1256)] = 42577,
  [SMALL_STATE(1257)] = 42585,
  [SMALL_STATE(1258)] = 42593,
  [SMALL_STATE(1259)] = 42601,
  [SMALL_STATE(1260)] = 42609,
  [SMALL_STATE(1261)] = 42617,
  [SMALL_STATE(1262)] = 42625,
  [SMALL_STATE(1263)] = 42633,
  [SMALL_STATE(1264)] = 42641,
  [SMALL_STATE(1265)] = 42649,
  [SMALL_STATE(1266)] = 42657,
  [SMALL_STATE(1267)] = 42665,
  [SMALL_STATE(1268)] = 42673,
  [SMALL_STATE(1269)] = 42681,
  [SMALL_STATE(1270)] = 42689,
  [SMALL_STATE(1271)] = 42697,
  [SMALL_STATE(1272)] = 42705,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 0, 0, 0),
  [7] = {.entry = {.count = 1, .reusable = false}}, SHIFT(211),
  [9] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(243),
  [13] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1200),
  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1158),
  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(177),
  [23] = {.entry = {.count = 1, .reusable = false}}, SHIFT(848),
  [25] = {.entry = {.count = 1, .reusable = false}}, SHIFT(307),
  [27] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1127),
  [29] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1097),
  [31] = {.entry = {.count = 1, .reusable = false}}, SHIFT(239),
  [33] = {.entry = {.count = 1, .reusable = false}}, SHIFT(242),
  [35] = {.entry = {.count = 1, .reusable = false}}, SHIFT(780),
  [37] = {.entry = {.count = 1, .reusable = false}}, SHIFT(783),
  [39] = {.entry = {.count = 1, .reusable = false}}, SHIFT(799),
  [41] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1038),
  [43] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6),
  [45] = {.entry = {.count = 1, .reusable = true}}, SHIFT(415),
  [47] = {.entry = {.count = 1, .reusable = false}}, SHIFT(244),
  [49] = {.entry = {.count = 1, .reusable = true}}, SHIFT(768),
  [51] = {.entry = {.count = 1, .reusable = true}}, SHIFT(846),
  [53] = {.entry = {.count = 1, .reusable = true}}, SHIFT(854),
  [55] = {.entry = {.count = 1, .reusable = true}}, SHIFT(662),
  [57] = {.entry = {.count = 1, .reusable = false}}, SHIFT(5),
  [59] = {.entry = {.count = 1, .reusable = false}}, SHIFT(224),
  [61] = {.entry = {.count = 1, .reusable = false}}, SHIFT(243),
  [63] = {.entry = {.count = 1, .reusable = false}}, SHIFT(212),
  [65] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1200),
  [67] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1158),
  [69] = {.entry = {.count = 1, .reusable = false}}, SHIFT(276),
  [71] = {.entry = {.count = 1, .reusable = false}}, SHIFT(277),
  [73] = {.entry = {.count = 1, .reusable = false}}, SHIFT(278),
  [75] = {.entry = {.count = 1, .reusable = false}}, SHIFT(169),
  [77] = {.entry = {.count = 1, .reusable = false}}, SHIFT(177),
  [79] = {.entry = {.count = 1, .reusable = false}}, SHIFT(865),
  [81] = {.entry = {.count = 1, .reusable = false}}, SHIFT(284),
  [83] = {.entry = {.count = 1, .reusable = false}}, SHIFT(11),
  [85] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1009),
  [87] = {.entry = {.count = 1, .reusable = false}}, SHIFT(790),
  [89] = {.entry = {.count = 1, .reusable = false}}, SHIFT(415),
  [91] = {.entry = {.count = 1, .reusable = false}}, SHIFT(8),
  [93] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elseif_clause, 2, 0, 7),
  [95] = {.entry = {.count = 1, .reusable = false}}, SHIFT(13),
  [97] = {.entry = {.count = 1, .reusable = false}}, SHIFT(913),
  [99] = {.entry = {.count = 1, .reusable = false}}, SHIFT(160),
  [101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(974),
  [103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(7),
  [105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(929),
  [107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(704),
  [109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(922),
  [111] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elseif_clause, 3, 0, 7),
  [113] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_case_clause, 3, 0, 7),
  [115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(12),
  [117] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1018),
  [119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(18),
  [121] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_clause, 1, 0, 0),
  [123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1025),
  [125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1032),
  [127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(15),
  [129] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_otherwise_clause, 1, 0, 0),
  [131] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_otherwise_clause, 2, 0, 0),
  [133] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_catch_clause, 2, 0, 0),
  [135] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_catch_clause, 3, 0, 0),
  [137] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_clause, 2, 0, 0),
  [139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(20),
  [141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1024),
  [143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(981),
  [145] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, 0, 20),
  [147] = {.entry = {.count = 1, .reusable = false}}, SHIFT(878),
  [149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1068),
  [151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(715),
  [153] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 4, 0, 8),
  [155] = {.entry = {.count = 1, .reusable = false}}, SHIFT(775),
  [157] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 3, 0, 8),
  [159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1049),
  [161] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, 0, 14),
  [163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(785),
  [165] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 5, 0, 8),
  [167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(789),
  [169] = {.entry = {.count = 1, .reusable = false}}, SHIFT(792),
  [171] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 4, 0, 14),
  [173] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1089),
  [175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1094),
  [177] = {.entry = {.count = 1, .reusable = false}}, SHIFT(767),
  [179] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, 0, 14),
  [181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(804),
  [183] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, 0, 20),
  [185] = {.entry = {.count = 1, .reusable = false}}, SHIFT(808),
  [187] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1063),
  [189] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1065),
  [191] = {.entry = {.count = 1, .reusable = false}}, SHIFT(774),
  [193] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 7, 0, 20),
  [195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(831),
  [197] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1041),
  [199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1073),
  [201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1062),
  [203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(936),
  [205] = {.entry = {.count = 1, .reusable = false}}, SHIFT(991),
  [207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(721),
  [209] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_block, 1, 0, 0),
  [211] = {.entry = {.count = 1, .reusable = false}}, SHIFT(941),
  [213] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1010),
  [215] = {.entry = {.count = 1, .reusable = false}}, SHIFT(995),
  [217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(949),
  [219] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1012),
  [221] = {.entry = {.count = 1, .reusable = false}}, SHIFT(910),
  [223] = {.entry = {.count = 1, .reusable = false}}, SHIFT(985),
  [225] = {.entry = {.count = 1, .reusable = false}}, SHIFT(730),
  [227] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(211),
  [230] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(224),
  [233] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(243),
  [236] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(212),
  [239] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1200),
  [242] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1158),
  [245] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(169),
  [248] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(177),
  [251] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(865),
  [254] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0),
  [256] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(307),
  [259] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1127),
  [262] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1097),
  [265] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(239),
  [268] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(242),
  [271] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(780),
  [274] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(783),
  [277] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(790),
  [280] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(1038),
  [283] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(6),
  [286] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(415),
  [289] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(244),
  [292] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(768),
  [295] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(846),
  [298] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(854),
  [301] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(662),
  [304] = {.entry = {.count = 1, .reusable = false}}, SHIFT(719),
  [306] = {.entry = {.count = 1, .reusable = false}}, SHIFT(724),
  [308] = {.entry = {.count = 1, .reusable = false}}, SHIFT(725),
  [310] = {.entry = {.count = 1, .reusable = false}}, SHIFT(728),
  [312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(735),
  [314] = {.entry = {.count = 1, .reusable = false}}, SHIFT(731),
  [316] = {.entry = {.count = 1, .reusable = false}}, SHIFT(747),
  [318] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 1, 0, 0),
  [320] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_block, 1, 0, 0),
  [322] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_block, 1, 0, 0), SHIFT(790),
  [325] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 0),
  [327] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(878),
  [330] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 0), SHIFT_REPEAT(848),
  [333] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__binary_expression, 1, 0, 0),
  [335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(188),
  [337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(741),
  [339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1173),
  [341] = {.entry = {.count = 1, .reusable = false}}, SHIFT(106),
  [343] = {.entry = {.count = 1, .reusable = false}}, SHIFT(170),
  [345] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__binary_expression, 1, 0, 0),
  [347] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0),
  [349] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__range_element, 1, 0, 0),
  [352] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0),
  [354] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__range_element, 1, 0, 0),
  [356] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__range_element, 1, 0, 0),
  [358] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unary_operator, 2, 0, 1),
  [360] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unary_operator, 2, 0, 1),
  [362] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_metaclass_operator, 2, 0, 0),
  [364] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1224),
  [366] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metaclass_operator, 2, 0, 0),
  [368] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_handle_operator, 3, 0, 0),
  [370] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_handle_operator, 3, 0, 0),
  [372] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_handle_operator, 2, 0, 0),
  [374] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_handle_operator, 2, 0, 0),
  [376] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_metaclass_operator, 3, 0, 0),
  [378] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metaclass_operator, 3, 0, 0),
  [380] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0),
  [382] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1224),
  [385] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0),
  [387] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 10),
  [389] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 10),
  [391] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_expression, 2, 0, 4),
  [393] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_expression, 2, 0, 4),
  [395] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 12),
  [397] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 12), SHIFT_REPEAT(741),
  [400] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 12),
  [402] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 4, 0, 17),
  [404] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 4, 0, 17),
  [406] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1174),
  [408] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 2, 0, 3),
  [410] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 2, 0, 3),
  [412] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_indirect_access, 3, 0, 0),
  [414] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_indirect_access, 3, 0, 0),
  [416] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 2, 0, 6),
  [418] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 2, 0, 6),
  [420] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__args, 2, 0, 0),
  [422] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__args, 2, 0, 0),
  [424] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__args, 3, 0, 0),
  [426] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__args, 3, 0, 0),
  [428] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_call, 4, 0, 16),
  [430] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_call, 4, 0, 16),
  [432] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_operator, 3, 0, 11),
  [434] = {.entry = {.count = 1, .reusable = false}}, SHIFT(250),
  [436] = {.entry = {.count = 1, .reusable = false}}, SHIFT(251),
  [438] = {.entry = {.count = 1, .reusable = false}}, SHIFT(252),
  [440] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_operator, 3, 0, 11),
  [442] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_matrix, 2, 0, 0),
  [444] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_matrix, 2, 0, 0),
  [446] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cell, 2, 0, 0),
  [448] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cell, 2, 0, 0),
  [450] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_postfix_operator, 2, 0, 2),
  [452] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_postfix_operator, 2, 0, 2),
  [454] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 3, 0, 0),
  [456] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 3, 0, 0),
  [458] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_parenthesis, 3, 0, 0),
  [460] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parenthesis, 3, 0, 0),
  [462] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_matrix, 3, 0, 0),
  [464] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_matrix, 3, 0, 0),
  [466] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cell, 3, 0, 0),
  [468] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cell, 3, 0, 0),
  [470] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_comparison_operator, 3, 0, 0),
  [472] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_comparison_operator, 3, 0, 0),
  [474] = {.entry = {.count = 1, .reusable = false}}, SHIFT(254),
  [476] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_range, 3, 0, 0),
  [478] = {.entry = {.count = 1, .reusable = false}}, SHIFT(266),
  [480] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range, 3, 0, 0),
  [482] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_matrix, 4, 0, 0),
  [484] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_matrix, 4, 0, 0),
  [486] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_cell, 4, 0, 0),
  [488] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cell, 4, 0, 0),
  [490] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_range, 5, 0, 0),
  [492] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym_range, 3, 0, 0), REDUCE(sym_range, 5, 0, 0),
  [495] = {.entry = {.count = 1, .reusable = false}}, SHIFT(317),
  [497] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_range, 5, 0, 0),
  [499] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__range_element, 1, 1, 0),
  [501] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__range_element, 1, -1, 0),
  [504] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_boolean_operator, 3, 0, 11),
  [506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(301),
  [508] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_boolean_operator, 3, 0, 11),
  [510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(302),
  [512] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda, 4, 0, 13),
  [514] = {.entry = {.count = 1, .reusable = false}}, SHIFT(303),
  [516] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda, 4, 0, 13),
  [518] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lambda, 5, 0, 18),
  [520] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lambda, 5, 0, 18),
  [522] = {.entry = {.count = 2, .reusable = false}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__range_element, 1, 1, 0),
  [525] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__range_element, 1, -1, 0),
  [527] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__range_element, 1, -1, 0),
  [529] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__range_element, 1, 1, 0),
  [531] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_boolean, 1, 0, 0),
  [533] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_boolean, 1, 0, 0),
  [535] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 2, 0, 0),
  [537] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 2, 0, 0),
  [539] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_not_operator, 2, 0, 0),
  [541] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_not_operator, 2, 0, 0),
  [543] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1205),
  [545] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1205),
  [548] = {.entry = {.count = 1, .reusable = false}}, SHIFT(207),
  [550] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_matrix_repeat1, 1, 0, 0),
  [552] = {.entry = {.count = 1, .reusable = false}}, SHIFT(210),
  [554] = {.entry = {.count = 1, .reusable = false}}, SHIFT(342),
  [556] = {.entry = {.count = 1, .reusable = false}}, SHIFT(326),
  [558] = {.entry = {.count = 1, .reusable = false}}, SHIFT(164),
  [560] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1257),
  [562] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1118),
  [564] = {.entry = {.count = 1, .reusable = false}}, SHIFT(180),
  [566] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_matrix_repeat1, 1, 0, 0),
  [568] = {.entry = {.count = 1, .reusable = false}}, SHIFT(181),
  [570] = {.entry = {.count = 1, .reusable = false}}, SHIFT(494),
  [572] = {.entry = {.count = 1, .reusable = false}}, SHIFT(370),
  [574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(909),
  [576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(876),
  [578] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_iterator, 3, 0, 0),
  [580] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_iterator, 3, 0, 0),
  [582] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_elseif_clause_repeat1, 2, 0, 0),
  [584] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_elseif_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(160),
  [587] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_elseif_clause_repeat1, 2, 0, 0),
  [589] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_row, 2, 0, 0),
  [591] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_row, 2, 0, 0),
  [593] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_row, 4, 0, 0),
  [595] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_row, 4, 0, 0),
  [597] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_row, 3, 0, 0),
  [599] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_row, 3, 0, 0),
  [601] = {.entry = {.count = 1, .reusable = false}}, SHIFT(215),
  [603] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_ignored_argument, 1, 0, 0),
  [605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(328),
  [607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1216),
  [609] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1146),
  [611] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_ignored_argument, 1, 0, 0),
  [613] = {.entry = {.count = 1, .reusable = false}}, SHIFT(489),
  [615] = {.entry = {.count = 1, .reusable = false}}, SHIFT(312),
  [617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(335),
  [619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(285),
  [623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1201),
  [625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1175),
  [627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(172),
  [631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(196),
  [633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1085),
  [635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(516),
  [637] = {.entry = {.count = 1, .reusable = false}}, SHIFT(449),
  [639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(863),
  [641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(864),
  [643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(176),
  [645] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__block, 3, 0, 5),
  [647] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__block, 3, 0, 5),
  [649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(179),
  [651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(342),
  [655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(326),
  [657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(164),
  [659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1257),
  [661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1118),
  [663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(180),
  [665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(408),
  [667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(181),
  [669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(494),
  [671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(99),
  [673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(539),
  [675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(540),
  [677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(630),
  [679] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__block, 2, 0, 5),
  [681] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__block, 2, 0, 5),
  [683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [685] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__block, 3, 0, 0),
  [687] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__block, 3, 0, 0),
  [689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(410),
  [691] = {.entry = {.count = 1, .reusable = false}}, SHIFT(353),
  [693] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__block_repeat1, 2, 0, 0),
  [695] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__block_repeat1, 2, 0, 0),
  [697] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block_repeat1, 2, 0, 0), SHIFT_REPEAT(179),
  [700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(469),
  [702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(470),
  [704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(444),
  [706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(104),
  [708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(105),
  [710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(350),
  [712] = {.entry = {.count = 1, .reusable = false}}, SHIFT(168),
  [714] = {.entry = {.count = 1, .reusable = false}}, SHIFT(709),
  [716] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1170),
  [718] = {.entry = {.count = 1, .reusable = false}}, SHIFT(423),
  [720] = {.entry = {.count = 1, .reusable = false}}, SHIFT(165),
  [722] = {.entry = {.count = 1, .reusable = false}}, SHIFT(351),
  [724] = {.entry = {.count = 1, .reusable = false}}, SHIFT(279),
  [726] = {.entry = {.count = 1, .reusable = false}}, SHIFT(298),
  [728] = {.entry = {.count = 1, .reusable = false}}, SHIFT(300),
  [730] = {.entry = {.count = 1, .reusable = false}}, SHIFT(186),
  [732] = {.entry = {.count = 1, .reusable = false}}, SHIFT(739),
  [734] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1171),
  [736] = {.entry = {.count = 1, .reusable = false}}, SHIFT(480),
  [738] = {.entry = {.count = 1, .reusable = false}}, SHIFT(187),
  [740] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1104),
  [742] = {.entry = {.count = 1, .reusable = false}}, SHIFT(260),
  [744] = {.entry = {.count = 1, .reusable = false}}, SHIFT(192),
  [746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(325),
  [748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1194),
  [750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1162),
  [752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(447),
  [754] = {.entry = {.count = 1, .reusable = false}}, SHIFT(372),
  [756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1163),
  [758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(560),
  [760] = {.entry = {.count = 1, .reusable = false}}, SHIFT(419),
  [762] = {.entry = {.count = 1, .reusable = false}}, SHIFT(399),
  [764] = {.entry = {.count = 1, .reusable = false}}, SHIFT(358),
  [766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(547),
  [768] = {.entry = {.count = 1, .reusable = false}}, SHIFT(206),
  [770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(328),
  [772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(473),
  [774] = {.entry = {.count = 1, .reusable = false}}, SHIFT(219),
  [776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(476),
  [778] = {.entry = {.count = 1, .reusable = false}}, SHIFT(78),
  [780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(329),
  [784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(321),
  [786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1195),
  [788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1133),
  [790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(184),
  [792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(185),
  [794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(120),
  [796] = {.entry = {.count = 1, .reusable = false}}, SHIFT(138),
  [798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(885),
  [800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(886),
  [802] = {.entry = {.count = 1, .reusable = false}}, SHIFT(193),
  [804] = {.entry = {.count = 1, .reusable = false}}, SHIFT(190),
  [806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(425),
  [808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1216),
  [810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1150),
  [812] = {.entry = {.count = 1, .reusable = false}}, SHIFT(76),
  [814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [816] = {.entry = {.count = 1, .reusable = false}}, SHIFT(79),
  [818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(133),
  [820] = {.entry = {.count = 1, .reusable = false}}, SHIFT(359),
  [822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(521),
  [824] = {.entry = {.count = 1, .reusable = false}}, SHIFT(189),
  [826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(386),
  [828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(310),
  [830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1148),
  [832] = {.entry = {.count = 1, .reusable = false}}, SHIFT(191),
  [834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(381),
  [836] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0),
  [838] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0),
  [840] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_function_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(715),
  [843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1221),
  [845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1151),
  [847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(182),
  [849] = {.entry = {.count = 1, .reusable = false}}, SHIFT(734),
  [851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1166),
  [853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(542),
  [855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [857] = {.entry = {.count = 1, .reusable = false}}, SHIFT(292),
  [859] = {.entry = {.count = 1, .reusable = false}}, SHIFT(366),
  [861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1211),
  [863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1149),
  [865] = {.entry = {.count = 1, .reusable = false}}, SHIFT(363),
  [867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1176),
  [869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(534),
  [871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1146),
  [873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(489),
  [875] = {.entry = {.count = 1, .reusable = false}}, SHIFT(313),
  [877] = {.entry = {.count = 1, .reusable = false}}, SHIFT(314),
  [879] = {.entry = {.count = 1, .reusable = false}}, SHIFT(77),
  [881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1147),
  [883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(315),
  [887] = {.entry = {.count = 1, .reusable = false}}, SHIFT(256),
  [889] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__block_repeat1, 2, 0, 0), SHIFT_REPEAT(315),
  [892] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 12), SHIFT_REPEAT(709),
  [895] = {.entry = {.count = 1, .reusable = false}}, SHIFT(365),
  [897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(528),
  [899] = {.entry = {.count = 1, .reusable = false}}, SHIFT(440),
  [901] = {.entry = {.count = 1, .reusable = false}}, SHIFT(209),
  [903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(452),
  [905] = {.entry = {.count = 1, .reusable = false}}, SHIFT(390),
  [907] = {.entry = {.count = 1, .reusable = false}}, SHIFT(80),
  [909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(143),
  [911] = {.entry = {.count = 1, .reusable = false}}, SHIFT(403),
  [913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(309),
  [915] = {.entry = {.count = 1, .reusable = false}}, SHIFT(422),
  [917] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1235),
  [919] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1235),
  [922] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1172),
  [924] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__range_element, 1, 0, 0),
  [927] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__enum_value, 1, 0, 0),
  [929] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments_statement, 4, 0, 0),
  [931] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments_statement, 4, 0, 0),
  [933] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments_statement, 4, 0, 23),
  [935] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments_statement, 4, 0, 23),
  [937] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments_statement, 3, 0, 0),
  [939] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments_statement, 3, 0, 0),
  [941] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments_statement, 5, 0, 23),
  [943] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arguments_statement, 5, 0, 23),
  [945] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1219),
  [947] = {.entry = {.count = 1, .reusable = false}}, SHIFT(227),
  [949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(426),
  [951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1167),
  [953] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1219),
  [956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(367),
  [958] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 12), SHIFT_REPEAT(739),
  [961] = {.entry = {.count = 1, .reusable = false}}, SHIFT(228),
  [963] = {.entry = {.count = 1, .reusable = false}}, SHIFT(261),
  [965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(671),
  [967] = {.entry = {.count = 1, .reusable = false}}, SHIFT(229),
  [969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(95),
  [971] = {.entry = {.count = 1, .reusable = false}}, SHIFT(270),
  [973] = {.entry = {.count = 1, .reusable = false}}, SHIFT(272),
  [975] = {.entry = {.count = 1, .reusable = false}}, SHIFT(269),
  [977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(201),
  [979] = {.entry = {.count = 1, .reusable = false}}, SHIFT(274),
  [981] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 12), SHIFT_REPEAT(734),
  [984] = {.entry = {.count = 1, .reusable = false}}, SHIFT(293),
  [986] = {.entry = {.count = 1, .reusable = false}}, SHIFT(231),
  [988] = {.entry = {.count = 1, .reusable = false}}, SHIFT(232),
  [990] = {.entry = {.count = 1, .reusable = false}}, SHIFT(230),
  [992] = {.entry = {.count = 1, .reusable = false}}, SHIFT(234),
  [994] = {.entry = {.count = 1, .reusable = false}}, SHIFT(238),
  [996] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1214),
  [998] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1214),
  [1001] = {.entry = {.count = 1, .reusable = false}}, SHIFT(294),
  [1003] = {.entry = {.count = 1, .reusable = false}}, SHIFT(295),
  [1005] = {.entry = {.count = 1, .reusable = false}}, SHIFT(265),
  [1007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(267),
  [1009] = {.entry = {.count = 1, .reusable = false}}, SHIFT(268),
  [1011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(345),
  [1013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [1015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(226),
  [1017] = {.entry = {.count = 1, .reusable = false}}, SHIFT(287),
  [1019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(287),
  [1021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(288),
  [1023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(289),
  [1025] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__range_element, 1, 1, 0),
  [1028] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_range, 3, 0, 0), REDUCE(sym_range, 5, 0, 0),
  [1031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(317),
  [1033] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__expression, 1, 0, 0), REDUCE(sym__range_element, 1, -1, 0),
  [1036] = {.entry = {.count = 1, .reusable = false}}, SHIFT(246),
  [1038] = {.entry = {.count = 1, .reusable = false}}, SHIFT(247),
  [1040] = {.entry = {.count = 1, .reusable = false}}, SHIFT(248),
  [1042] = {.entry = {.count = 1, .reusable = false}}, SHIFT(249),
  [1044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(423),
  [1046] = {.entry = {.count = 1, .reusable = false}}, SHIFT(333),
  [1048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(333),
  [1050] = {.entry = {.count = 1, .reusable = true}}, SHIFT(334),
  [1052] = {.entry = {.count = 1, .reusable = true}}, SHIFT(282),
  [1054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(480),
  [1056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(106),
  [1058] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1185),
  [1061] = {.entry = {.count = 1, .reusable = false}}, SHIFT(638),
  [1063] = {.entry = {.count = 1, .reusable = false}}, SHIFT(931),
  [1065] = {.entry = {.count = 1, .reusable = false}}, SHIFT(304),
  [1067] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14),
  [1069] = {.entry = {.count = 1, .reusable = false}}, SHIFT(644),
  [1071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(666),
  [1073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(178),
  [1075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(722),
  [1077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(687),
  [1079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1154),
  [1081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1226),
  [1083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(174),
  [1085] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1185),
  [1087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(656),
  [1089] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1037),
  [1091] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1102),
  [1093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1111),
  [1095] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1267),
  [1097] = {.entry = {.count = 1, .reusable = false}}, SHIFT(708),
  [1099] = {.entry = {.count = 1, .reusable = false}}, SHIFT(306),
  [1101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1187),
  [1103] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1187),
  [1106] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_metaclass_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(1262),
  [1109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(163),
  [1111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(241),
  [1113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(246),
  [1115] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_row, 1, 0, 0),
  [1117] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_row, 1, 0, 0),
  [1119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(161),
  [1121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(9),
  [1123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(269),
  [1125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(270),
  [1127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(272),
  [1129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(273),
  [1131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(274),
  [1133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(230),
  [1135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [1137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [1139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [1141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(234),
  [1143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [1145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(251),
  [1147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [1149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(253),
  [1151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(254),
  [1153] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0), SHIFT_REPEAT(644),
  [1156] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0), SHIFT_REPEAT(670),
  [1159] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0), SHIFT_REPEAT(222),
  [1162] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0), SHIFT_REPEAT(687),
  [1165] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0),
  [1167] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0), SHIFT_REPEAT(449),
  [1170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1262),
  [1172] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_row_repeat1, 2, 0, 0),
  [1174] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_row_repeat1, 2, 0, 0),
  [1176] = {.entry = {.count = 1, .reusable = true}}, SHIFT(663),
  [1178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [1180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1182),
  [1182] = {.entry = {.count = 1, .reusable = false}}, SHIFT(166),
  [1184] = {.entry = {.count = 1, .reusable = false}}, SHIFT(331),
  [1186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1183),
  [1188] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 5, 0, 9),
  [1190] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_default_value, 2, 0, 0),
  [1192] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 3, 0, 0),
  [1194] = {.entry = {.count = 1, .reusable = false}}, SHIFT(861),
  [1196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1263),
  [1198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(200),
  [1200] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 1, 0, 9),
  [1202] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_assignment, 3, 0, 11),
  [1204] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 6, 0, 15),
  [1206] = {.entry = {.count = 1, .reusable = false}}, SHIFT(679),
  [1208] = {.entry = {.count = 1, .reusable = false}}, SHIFT(957),
  [1210] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_multioutput_variable_repeat1, 2, 0, 0),
  [1212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [1214] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_name, 2, -1, 0),
  [1216] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1156),
  [1218] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_multioutput_variable_repeat1, 1, 0, 0),
  [1220] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_multioutput_variable_repeat1, 1, 0, 0),
  [1222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(660),
  [1224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1019),
  [1226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(732),
  [1228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(737),
  [1230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(738),
  [1232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(744),
  [1234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(954),
  [1236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(647),
  [1238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(655),
  [1240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(996),
  [1242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(939),
  [1244] = {.entry = {.count = 1, .reusable = false}}, SHIFT(689),
  [1246] = {.entry = {.count = 1, .reusable = false}}, SHIFT(811),
  [1248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(833),
  [1250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1208),
  [1252] = {.entry = {.count = 1, .reusable = false}}, SHIFT(661),
  [1254] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1098),
  [1256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(650),
  [1258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(978),
  [1260] = {.entry = {.count = 1, .reusable = false}}, SHIFT(751),
  [1262] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0), SHIFT_REPEAT(689),
  [1265] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0),
  [1267] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0), SHIFT_REPEAT(833),
  [1270] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0), SHIFT_REPEAT(1208),
  [1273] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_methods_repeat1, 2, 0, 0), SHIFT_REPEAT(662),
  [1276] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(660),
  [1279] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0),
  [1281] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(732),
  [1284] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(737),
  [1287] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(738),
  [1290] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_class_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(744),
  [1293] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1040),
  [1295] = {.entry = {.count = 1, .reusable = false}}, SHIFT(595),
  [1297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1251),
  [1299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(640),
  [1301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1269),
  [1303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(646),
  [1305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(923),
  [1307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(834),
  [1309] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_arguments_repeat1, 2, 0, 21),
  [1311] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_arguments_repeat2, 4, 0, 0),
  [1313] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 3, 0, 0),
  [1315] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_name, 4, -1, 0),
  [1317] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_name, 3, -1, 0),
  [1319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(717),
  [1321] = {.entry = {.count = 1, .reusable = true}}, SHIFT(435),
  [1323] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_elseif_clause_repeat1, 2, 0, 0), SHIFT_REPEAT(679),
  [1326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(512),
  [1328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(453),
  [1330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [1332] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_field_expression_repeat1, 2, 0, 12), SHIFT_REPEAT(722),
  [1335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(31),
  [1337] = {.entry = {.count = 1, .reusable = false}}, SHIFT(883),
  [1339] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1088),
  [1341] = {.entry = {.count = 1, .reusable = false}}, SHIFT(45),
  [1343] = {.entry = {.count = 1, .reusable = false}}, SHIFT(812),
  [1345] = {.entry = {.count = 1, .reusable = false}}, SHIFT(61),
  [1347] = {.entry = {.count = 1, .reusable = false}}, SHIFT(23),
  [1349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [1351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [1353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [1355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(293),
  [1357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(294),
  [1359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(295),
  [1361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(301),
  [1363] = {.entry = {.count = 1, .reusable = true}}, SHIFT(302),
  [1365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(303),
  [1367] = {.entry = {.count = 1, .reusable = false}}, SHIFT(62),
  [1369] = {.entry = {.count = 1, .reusable = false}}, SHIFT(600),
  [1371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(682),
  [1373] = {.entry = {.count = 1, .reusable = false}}, SHIFT(810),
  [1375] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dimensions, 3, 0, 0),
  [1377] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 9, 0, 20),
  [1379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(760),
  [1381] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 9, 0, 20),
  [1383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(664),
  [1385] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1165),
  [1387] = {.entry = {.count = 1, .reusable = false}}, SHIFT(57),
  [1389] = {.entry = {.count = 1, .reusable = false}}, SHIFT(772),
  [1391] = {.entry = {.count = 1, .reusable = false}}, SHIFT(16),
  [1393] = {.entry = {.count = 1, .reusable = false}}, SHIFT(649),
  [1395] = {.entry = {.count = 1, .reusable = false}}, SHIFT(378),
  [1397] = {.entry = {.count = 1, .reusable = false}}, SHIFT(743),
  [1399] = {.entry = {.count = 1, .reusable = false}}, SHIFT(194),
  [1401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(320),
  [1403] = {.entry = {.count = 1, .reusable = false}}, SHIFT(28),
  [1405] = {.entry = {.count = 1, .reusable = false}}, SHIFT(56),
  [1407] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_arguments_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(600),
  [1410] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_arguments_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(682),
  [1413] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_arguments_statement_repeat1, 2, 0, 0),
  [1415] = {.entry = {.count = 1, .reusable = false}}, SHIFT(832),
  [1417] = {.entry = {.count = 1, .reusable = false}}, SHIFT(727),
  [1419] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1229),
  [1421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(828),
  [1423] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1071),
  [1425] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property_name, 1, -1, 0),
  [1427] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 4, 0, 8),
  [1429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(829),
  [1431] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 4, 0, 8),
  [1433] = {.entry = {.count = 1, .reusable = false}}, SHIFT(27),
  [1435] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 8, 0, 20),
  [1437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(759),
  [1439] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 8, 0, 20),
  [1441] = {.entry = {.count = 1, .reusable = false}}, SHIFT(659),
  [1443] = {.entry = {.count = 1, .reusable = false}}, SHIFT(763),
  [1445] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 5, 0, 14),
  [1447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(827),
  [1449] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 5, 0, 14),
  [1451] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 5, 0, 8),
  [1453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(795),
  [1455] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 5, 0, 8),
  [1457] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_dimensions, 4, 0, 0),
  [1459] = {.entry = {.count = 1, .reusable = false}}, SHIFT(376),
  [1461] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 6, 0, 14),
  [1463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(752),
  [1465] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 6, 0, 14),
  [1467] = {.entry = {.count = 1, .reusable = false}}, SHIFT(38),
  [1469] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 6, 0, 8),
  [1471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(753),
  [1473] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 6, 0, 8),
  [1475] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 6, 0, 20),
  [1477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(754),
  [1479] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 6, 0, 20),
  [1481] = {.entry = {.count = 1, .reusable = false}}, SHIFT(742),
  [1483] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1153),
  [1485] = {.entry = {.count = 1, .reusable = false}}, SHIFT(375),
  [1487] = {.entry = {.count = 1, .reusable = false}}, SHIFT(374),
  [1489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(327),
  [1491] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 7, 0, 14),
  [1493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(755),
  [1495] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 7, 0, 14),
  [1497] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 7, 0, 8),
  [1499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(756),
  [1501] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 7, 0, 8),
  [1503] = {.entry = {.count = 1, .reusable = false}}, SHIFT(665),
  [1505] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1095),
  [1507] = {.entry = {.count = 1, .reusable = false}}, SHIFT(259),
  [1509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [1511] = {.entry = {.count = 1, .reusable = false}}, SHIFT(373),
  [1513] = {.entry = {.count = 1, .reusable = false}}, SHIFT(86),
  [1515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(332),
  [1517] = {.entry = {.count = 1, .reusable = false}}, SHIFT(794),
  [1519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(723),
  [1521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(866),
  [1523] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1026),
  [1525] = {.entry = {.count = 1, .reusable = false}}, SHIFT(821),
  [1527] = {.entry = {.count = 1, .reusable = false}}, SHIFT(68),
  [1529] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 7, 0, 20),
  [1531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(757),
  [1533] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 7, 0, 20),
  [1535] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 8, 0, 14),
  [1537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(758),
  [1539] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 8, 0, 14),
  [1541] = {.entry = {.count = 1, .reusable = false}}, SHIFT(21),
  [1543] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methods, 5, 0, 0),
  [1545] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 8, 0, 8),
  [1547] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 8, 0, 8),
  [1549] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 9, 0, 14),
  [1551] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 9, 0, 14),
  [1553] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__function_definition_with_end, 10, 0, 20),
  [1555] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__function_definition_with_end, 10, 0, 20),
  [1557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(284),
  [1559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(917),
  [1561] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_validation_functions_repeat1, 2, 0, 0),
  [1563] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 10, 0, 20),
  [1565] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 10, 0, 20),
  [1567] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 5, 0, 14),
  [1569] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_signature, 5, 0, 14),
  [1571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(942),
  [1573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(304),
  [1575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14),
  [1577] = {.entry = {.count = 1, .reusable = false}}, SHIFT(776),
  [1579] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 4, 0, 8),
  [1581] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_command, 1, 0, 0),
  [1583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(791),
  [1585] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_superclasses, 2, 0, 0),
  [1587] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1126),
  [1589] = {.entry = {.count = 1, .reusable = false}}, SHIFT(691),
  [1591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1202),
  [1593] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_command_repeat1, 2, 0, 0),
  [1595] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_command_repeat1, 2, 0, 0), SHIFT_REPEAT(771),
  [1598] = {.entry = {.count = 1, .reusable = false}}, SHIFT(17),
  [1600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1013),
  [1602] = {.entry = {.count = 1, .reusable = false}}, SHIFT(787),
  [1604] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 5, 0, 14),
  [1606] = {.entry = {.count = 1, .reusable = false}}, SHIFT(788),
  [1608] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 5, 0, 8),
  [1610] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_superclasses, 3, 0, 0),
  [1612] = {.entry = {.count = 1, .reusable = false}}, SHIFT(817),
  [1614] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_global_operator, 2, 0, 0),
  [1616] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_persistent_operator, 2, 0, 0),
  [1618] = {.entry = {.count = 1, .reusable = false}}, SHIFT(778),
  [1620] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_global_operator, 1, 0, 0),
  [1622] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_events, 5, 0, 0),
  [1624] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumeration, 5, 0, 0),
  [1626] = {.entry = {.count = 1, .reusable = false}}, SHIFT(779),
  [1628] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_persistent_operator, 1, 0, 0),
  [1630] = {.entry = {.count = 1, .reusable = false}}, SHIFT(803),
  [1632] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 6, 0, 14),
  [1634] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 6, 0, 8),
  [1636] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 6, 0, 8),
  [1638] = {.entry = {.count = 1, .reusable = false}}, SHIFT(805),
  [1640] = {.entry = {.count = 1, .reusable = false}}, SHIFT(688),
  [1642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1231),
  [1644] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_command, 2, 0, 0),
  [1646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(771),
  [1648] = {.entry = {.count = 1, .reusable = false}}, SHIFT(809),
  [1650] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 6, 0, 20),
  [1652] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_superclasses_repeat1, 2, 0, 0),
  [1654] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_superclasses_repeat1, 2, 0, 0), SHIFT_REPEAT(1126),
  [1657] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_properties, 3, 0, 0),
  [1659] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_methods_repeat1, 1, 0, 5),
  [1661] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_methods_repeat1, 1, 0, 5),
  [1663] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_events, 3, 0, 0),
  [1665] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumeration, 3, 0, 0),
  [1667] = {.entry = {.count = 1, .reusable = false}}, SHIFT(686),
  [1669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1180),
  [1671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(974),
  [1673] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 7, 0, 14),
  [1675] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 7, 0, 14),
  [1677] = {.entry = {.count = 1, .reusable = false}}, SHIFT(823),
  [1679] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 7, 0, 8),
  [1681] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 7, 0, 8),
  [1683] = {.entry = {.count = 1, .reusable = false}}, SHIFT(825),
  [1685] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 9, 0, 14),
  [1687] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 9, 0, 14),
  [1689] = {.entry = {.count = 1, .reusable = false}}, SHIFT(830),
  [1691] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 7, 0, 20),
  [1693] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_properties, 4, 0, 0),
  [1695] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methods, 4, 0, 0),
  [1697] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 2, 0, 3),
  [1699] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_signature, 2, 0, 3),
  [1701] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_events, 4, 0, 0),
  [1703] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enumeration, 4, 0, 0),
  [1705] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 9, 0, 20),
  [1707] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 9, 0, 20),
  [1709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(957),
  [1711] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_global_operator_repeat1, 2, 0, 0), SHIFT_REPEAT(817),
  [1714] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_global_operator_repeat1, 2, 0, 0),
  [1716] = {.entry = {.count = 1, .reusable = false}}, SHIFT(764),
  [1718] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 4, 0, 8),
  [1720] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_signature, 4, 0, 8),
  [1722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [1724] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 4, 0, 14),
  [1726] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_signature, 4, 0, 14),
  [1728] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 3, 0, 3),
  [1730] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_signature, 3, 0, 3),
  [1732] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 8, 0, 14),
  [1734] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 8, 0, 14),
  [1736] = {.entry = {.count = 1, .reusable = false}}, SHIFT(807),
  [1738] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 8, 0, 8),
  [1740] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 8, 0, 8),
  [1742] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_row_repeat1, 2, 0, 0), SHIFT_REPEAT(213),
  [1745] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_signature, 3, 0, 8),
  [1747] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_signature, 3, 0, 8),
  [1749] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_definition, 8, 0, 20),
  [1751] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_definition, 8, 0, 20),
  [1753] = {.entry = {.count = 1, .reusable = false}}, SHIFT(815),
  [1755] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_properties, 5, 0, 0),
  [1757] = {.entry = {.count = 1, .reusable = false}}, SHIFT(690),
  [1759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1268),
  [1761] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_methods, 3, 0, 0),
  [1763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1046),
  [1765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [1767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(968),
  [1769] = {.entry = {.count = 1, .reusable = false}}, SHIFT(49),
  [1771] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1067),
  [1773] = {.entry = {.count = 1, .reusable = false}}, SHIFT(35),
  [1775] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_if_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(284),
  [1778] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_if_statement_repeat1, 2, 0, 0),
  [1780] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_if_statement_repeat1, 2, 0, 0),
  [1782] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_validation_functions, 4, 0, 0),
  [1784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(281),
  [1786] = {.entry = {.count = 1, .reusable = false}}, SHIFT(654),
  [1788] = {.entry = {.count = 1, .reusable = false}}, SHIFT(59),
  [1790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(379),
  [1792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(872),
  [1794] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0),
  [1796] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0), SHIFT_REPEAT(847),
  [1799] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1107),
  [1801] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum, 1, 0, 0),
  [1803] = {.entry = {.count = 1, .reusable = false}}, SHIFT(216),
  [1805] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1164),
  [1807] = {.entry = {.count = 1, .reusable = false}}, SHIFT(51),
  [1809] = {.entry = {.count = 1, .reusable = false}}, SHIFT(29),
  [1811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(874),
  [1813] = {.entry = {.count = 1, .reusable = false}}, SHIFT(41),
  [1815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(648),
  [1817] = {.entry = {.count = 1, .reusable = false}}, SHIFT(44),
  [1819] = {.entry = {.count = 1, .reusable = false}}, SHIFT(822),
  [1821] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parfor_options, 1, 0, 0),
  [1823] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0), SHIFT_REPEAT(862),
  [1826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(525),
  [1828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(868),
  [1830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(869),
  [1832] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_validation_functions, 3, 0, 0),
  [1834] = {.entry = {.count = 1, .reusable = false}}, SHIFT(175),
  [1836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(549),
  [1838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(862),
  [1840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(847),
  [1842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(286),
  [1844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(433),
  [1846] = {.entry = {.count = 1, .reusable = false}}, SHIFT(765),
  [1848] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1074),
  [1850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(503),
  [1852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(882),
  [1854] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_matrix_repeat1, 2, 0, 0), SHIFT_REPEAT(158),
  [1857] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_matrix_repeat1, 2, 0, 0), SHIFT_REPEAT(158),
  [1860] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_matrix_repeat1, 2, 0, 0),
  [1862] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_switch_statement_repeat1, 2, 0, 0),
  [1864] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_switch_statement_repeat1, 2, 0, 0), SHIFT_REPEAT(304),
  [1867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(264),
  [1869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(479),
  [1871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1027),
  [1873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [1875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(142),
  [1877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(888),
  [1879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(889),
  [1881] = {.entry = {.count = 1, .reusable = false}}, SHIFT(733),
  [1883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [1885] = {.entry = {.count = 1, .reusable = false}}, SHIFT(33),
  [1887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [1889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(290),
  [1891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(296),
  [1893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(305),
  [1895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(322),
  [1897] = {.entry = {.count = 1, .reusable = false}}, SHIFT(63),
  [1899] = {.entry = {.count = 1, .reusable = false}}, SHIFT(65),
  [1901] = {.entry = {.count = 1, .reusable = false}}, SHIFT(69),
  [1903] = {.entry = {.count = 1, .reusable = false}}, SHIFT(24),
  [1905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(336),
  [1907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(338),
  [1909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(340),
  [1911] = {.entry = {.count = 1, .reusable = false}}, SHIFT(698),
  [1913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(343),
  [1915] = {.entry = {.count = 1, .reusable = false}}, SHIFT(651),
  [1917] = {.entry = {.count = 1, .reusable = false}}, SHIFT(819),
  [1919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(881),
  [1921] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1031),
  [1923] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__argument_attributes, 3, 0, 21),
  [1925] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 9, 0, 0),
  [1927] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 3, 0, 7),
  [1929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(168),
  [1931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1170),
  [1933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(165),
  [1935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(804),
  [1937] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 5, 0, 7),
  [1939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(831),
  [1941] = {.entry = {.count = 1, .reusable = false}}, SHIFT(158),
  [1943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(158),
  [1945] = {.entry = {.count = 1, .reusable = false}}, SHIFT(442),
  [1947] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1066),
  [1949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1066),
  [1951] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 5, 0, 0),
  [1953] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 3, 0, 0),
  [1955] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 4, 0, 8),
  [1957] = {.entry = {.count = 1, .reusable = false}}, SHIFT(934),
  [1959] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 5, 0, 7),
  [1961] = {.entry = {.count = 1, .reusable = false}}, SHIFT(806),
  [1963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(806),
  [1965] = {.entry = {.count = 1, .reusable = false}}, SHIFT(850),
  [1967] = {.entry = {.count = 1, .reusable = false}}, SHIFT(782),
  [1969] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 2, 0, 0),
  [1971] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 6, 0, 9),
  [1973] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_statement, 3, 0, 7),
  [1975] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_enumeration_repeat1, 2, 0, 0), SHIFT_REPEAT(850),
  [1978] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_enumeration_repeat1, 2, 0, 0),
  [1980] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 2, 0, 0),
  [1982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(770),
  [1984] = {.entry = {.count = 1, .reusable = false}}, SHIFT(994),
  [1986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(808),
  [1988] = {.entry = {.count = 1, .reusable = false}}, SHIFT(391),
  [1990] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 7, 0, 14),
  [1992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1104),
  [1994] = {.entry = {.count = 1, .reusable = false}}, SHIFT(984),
  [1996] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_statement, 5, 0, 7),
  [1998] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum, 5, 0, 0),
  [2000] = {.entry = {.count = 1, .reusable = false}}, SHIFT(526),
  [2002] = {.entry = {.count = 1, .reusable = false}}, SHIFT(550),
  [2004] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 5, 0, 0),
  [2006] = {.entry = {.count = 1, .reusable = false}}, SHIFT(955),
  [2008] = {.entry = {.count = 1, .reusable = false}}, SHIFT(543),
  [2010] = {.entry = {.count = 1, .reusable = false}}, SHIFT(517),
  [2012] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_arguments_repeat2, 2, 0, 0), SHIFT_REPEAT(1183),
  [2015] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_arguments_repeat2, 2, 0, 0),
  [2017] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 6, 0, 8),
  [2019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1041),
  [2021] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_statement, 4, 0, 7),
  [2023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(785),
  [2025] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_arguments, 3, 0, 19),
  [2027] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_try_statement, 4, 0, 0),
  [2029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [2031] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 2, 0, 15),
  [2033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(775),
  [2035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [2037] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1103),
  [2039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1103),
  [2041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1155),
  [2043] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_arguments_repeat1, 2, 0, 22), SHIFT_REPEAT(198),
  [2046] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_arguments_repeat1, 2, 0, 22),
  [2048] = {.entry = {.count = 1, .reusable = true}}, SHIFT(789),
  [2050] = {.entry = {.count = 1, .reusable = false}}, SHIFT(814),
  [2052] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_name, 2, -1, 0),
  [2054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1160),
  [2056] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_name, 1, -1, 0),
  [2058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1141),
  [2060] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1094),
  [2062] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1073),
  [2064] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 4, 0, 7),
  [2066] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attributes, 3, 0, 0),
  [2068] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_enum, 4, 0, 0),
  [2070] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 6, 0, 14),
  [2072] = {.entry = {.count = 1, .reusable = false}}, SHIFT(456),
  [2074] = {.entry = {.count = 1, .reusable = false}}, SHIFT(457),
  [2076] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 8, 0, 0),
  [2078] = {.entry = {.count = 1, .reusable = false}}, SHIFT(471),
  [2080] = {.entry = {.count = 1, .reusable = false}}, SHIFT(474),
  [2082] = {.entry = {.count = 1, .reusable = false}}, SHIFT(947),
  [2084] = {.entry = {.count = 1, .reusable = false}}, SHIFT(398),
  [2086] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1005),
  [2088] = {.entry = {.count = 1, .reusable = true}}, SHIFT(186),
  [2090] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1171),
  [2092] = {.entry = {.count = 1, .reusable = true}}, SHIFT(187),
  [2094] = {.entry = {.count = 1, .reusable = false}}, SHIFT(948),
  [2096] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1062),
  [2098] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1172),
  [2100] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1008),
  [2102] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 5, 0, 14),
  [2104] = {.entry = {.count = 1, .reusable = false}}, SHIFT(109),
  [2106] = {.entry = {.count = 1, .reusable = false}}, SHIFT(110),
  [2108] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__argument_attributes, 4, 0, 24),
  [2110] = {.entry = {.count = 1, .reusable = false}}, SHIFT(916),
  [2112] = {.entry = {.count = 1, .reusable = false}}, SHIFT(117),
  [2114] = {.entry = {.count = 1, .reusable = false}}, SHIFT(118),
  [2116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(188),
  [2118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1173),
  [2120] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [2122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1174),
  [2124] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 4, 0, 0),
  [2126] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attributes, 4, 0, 0),
  [2128] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 3, 0, 7),
  [2130] = {.entry = {.count = 1, .reusable = false}}, SHIFT(989),
  [2132] = {.entry = {.count = 1, .reusable = false}}, SHIFT(441),
  [2134] = {.entry = {.count = 1, .reusable = false}}, SHIFT(924),
  [2136] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 6, 0, 7),
  [2138] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_matrix_repeat1, 2, 0, 0),
  [2140] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1063),
  [2142] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1099),
  [2144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1099),
  [2146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1065),
  [2148] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 3, 0, 0),
  [2150] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_class_definition, 5, 0, 8),
  [2152] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_switch_statement, 6, 0, 7),
  [2154] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arguments, 7, 0, 15),
  [2156] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_if_statement, 7, 0, 7),
  [2158] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 7, 0, 0),
  [2160] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_for_statement, 4, 0, 0),
  [2162] = {.entry = {.count = 1, .reusable = false}}, SHIFT(798),
  [2164] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_arguments, 2, 0, 0),
  [2166] = {.entry = {.count = 1, .reusable = false}}, SHIFT(818),
  [2168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(818),
  [2170] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0),
  [2172] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(770),
  [2175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(824),
  [2177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(824),
  [2179] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_while_statement, 4, 0, 7),
  [2181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(697),
  [2183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1270),
  [2185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1070),
  [2187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(726),
  [2189] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 2, 0, 3),
  [2191] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 2, 0, 3),
  [2193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(702),
  [2195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1116),
  [2197] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__lambda_arguments_repeat1, 2, 0, 0), SHIFT_REPEAT(1054),
  [2200] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__lambda_arguments_repeat1, 2, 0, 0),
  [2202] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 4, 0, 3),
  [2204] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 4, 0, 3),
  [2206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1128),
  [2208] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_repeat1, 2, 0, 0), SHIFT_REPEAT(221),
  [2211] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_repeat1, 2, 0, 0),
  [2213] = {.entry = {.count = 1, .reusable = false}}, SHIFT(849),
  [2215] = {.entry = {.count = 1, .reusable = false}}, SHIFT(781),
  [2217] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_events_repeat1, 2, 0, 0), SHIFT_REPEAT(849),
  [2220] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_events_repeat1, 2, 0, 0),
  [2222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1054),
  [2224] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__lambda_arguments, 1, 0, 0),
  [2226] = {.entry = {.count = 1, .reusable = false}}, SHIFT(729),
  [2228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1217),
  [2230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(841),
  [2232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1152),
  [2234] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_elseif_clause, 4, 0, 7),
  [2236] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_elseif_clause, 4, 0, 7),
  [2238] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_elseif_clause, 3, 0, 7),
  [2240] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_clause, 4, 0, 7),
  [2242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1109),
  [2244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1271),
  [2246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1121),
  [2248] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_validation_functions_repeat1, 2, 0, 0), SHIFT_REPEAT(723),
  [2251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(976),
  [2253] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1007),
  [2255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1253),
  [2257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(911),
  [2259] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__lambda_arguments, 2, 0, 0),
  [2261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1157),
  [2263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1108),
  [2265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(922),
  [2267] = {.entry = {.count = 1, .reusable = true}}, SHIFT(704),
  [2269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1132),
  [2271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1110),
  [2273] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 6, 0, 3),
  [2275] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 6, 0, 3),
  [2277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1169),
  [2279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1106),
  [2281] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 5, 0, 3),
  [2283] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 5, 0, 3),
  [2285] = {.entry = {.count = 1, .reusable = false}}, SHIFT(716),
  [2287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1196),
  [2289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1105),
  [2291] = {.entry = {.count = 1, .reusable = false}}, SHIFT(813),
  [2293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(960),
  [2295] = {.entry = {.count = 1, .reusable = false}}, SHIFT(703),
  [2297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1227),
  [2299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(221),
  [2301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(943),
  [2303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(710),
  [2305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1255),
  [2307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1222),
  [2309] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attributes_repeat1, 2, 0, 0), SHIFT_REPEAT(1109),
  [2312] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_attributes_repeat1, 2, 0, 0),
  [2314] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__argument_attributes_repeat1, 2, 0, 22), SHIFT_REPEAT(1253),
  [2317] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__argument_attributes_repeat1, 2, 0, 22),
  [2319] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_spread_operator, 1, 0, 0),
  [2321] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function_output, 2, 0, 0),
  [2323] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_output, 2, 0, 0),
  [2325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1139),
  [2327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(700),
  [2329] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attribute, 1, 0, 0),
  [2331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [2333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1143),
  [2335] = {.entry = {.count = 1, .reusable = false}}, SHIFT(797),
  [2337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(977),
  [2339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1197),
  [2341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1114),
  [2343] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_property, 3, 0, 3),
  [2345] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property, 3, 0, 3),
  [2347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1142),
  [2349] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_dimensions_repeat1, 2, 0, 0), SHIFT_REPEAT(1070),
  [2352] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_dimensions_repeat1, 2, 0, 0),
  [2354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(999),
  [2356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1090),
  [2358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1137),
  [2360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(971),
  [2362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1091),
  [2364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(593),
  [2366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(673),
  [2368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(995),
  [2370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(725),
  [2372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1232),
  [2374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(728),
  [2376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(730),
  [2378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(605),
  [2380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(835),
  [2382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1012),
  [2384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(941),
  [2386] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__argument_attributes_repeat1, 2, 0, 21),
  [2388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(949),
  [2390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(735),
  [2392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(718),
  [2394] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_name, 3, -1, 0),
  [2396] = {.entry = {.count = 1, .reusable = false}}, SHIFT(736),
  [2398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(736),
  [2400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(747),
  [2402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [2404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(892),
  [2406] = {.entry = {.count = 1, .reusable = false}}, SHIFT(749),
  [2408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(749),
  [2410] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_property_name, 4, -1, 0),
  [2412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(721),
  [2414] = {.entry = {.count = 1, .reusable = false}}, SHIFT(701),
  [2416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(701),
  [2418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(613),
  [2420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1129),
  [2422] = {.entry = {.count = 1, .reusable = false}}, SHIFT(988),
  [2424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(988),
  [2426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1010),
  [2428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(428),
  [2430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(894),
  [2432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(83),
  [2434] = {.entry = {.count = 1, .reusable = true}}, SHIFT(895),
  [2436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(364),
  [2438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(896),
  [2440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(482),
  [2442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(906),
  [2444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(903),
  [2446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(904),
  [2448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(672),
  [2450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(596),
  [2452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(842),
  [2454] = {.entry = {.count = 1, .reusable = false}}, SHIFT(925),
  [2456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(925),
  [2458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1136),
  [2460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(991),
  [2462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(884),
  [2464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(618),
  [2466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(870),
  [2468] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1000),
  [2470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1000),
  [2472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(902),
  [2474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(893),
  [2476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(446),
  [2478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(257),
  [2480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(260),
  [2482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(729),
  [2484] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_otherwise_clause, 3, 0, 0),
  [2486] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_multioutput_variable, 4, 0, 0),
  [2488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1213),
  [2490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(641),
  [2492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1020),
  [2494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(607),
  [2496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [2498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(354),
  [2500] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_clause, 2, 0, 0),
  [2502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(362),
  [2504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(153),
  [2506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(745),
  [2508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(299),
  [2510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(240),
  [2512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(599),
  [2514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(627),
  [2516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(710),
  [2518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [2520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(157),
  [2522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(283),
  [2524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(100),
  [2526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(716),
  [2528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(481),
  [2530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1023),
  [2532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(318),
  [2534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(508),
  [2536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(291),
  [2538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(424),
  [2540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(720),
  [2542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(959),
  [2544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(448),
  [2546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(297),
  [2548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(81),
  [2550] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attributes, 3, 0, 0),
  [2552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(197),
  [2554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [2556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(706),
  [2558] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_multioutput_variable, 3, 0, 0),
  [2560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(712),
  [2562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1060),
  [2564] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_clause, 4, 0, 0),
  [2566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(703),
  [2568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [2570] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_clause, 3, 0, 0),
  [2572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(912),
  [2574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(371),
  [2576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(324),
  [2578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [2580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1025),
  [2582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [2584] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_catch_clause, 3, 0, 0),
  [2586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(981),
  [2588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(275),
  [2590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1088),
  [2592] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_otherwise_clause, 2, 0, 0),
  [2594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(946),
  [2596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(337),
  [2598] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_multioutput_variable, 2, 0, 0),
  [2600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(339),
  [2602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1123),
  [2604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(341),
  [2606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(750),
  [2608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1032),
  [2610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(604),
  [2612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(921),
  [2614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(632),
  [2616] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [2618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(344),
  [2620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(311),
  [2622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(255),
  [2624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(926),
  [2626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(674),
  [2628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(697),
  [2630] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_multioutput_variable, 5, 0, 0),
  [2632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(746),
  [2634] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attributes, 4, 0, 0),
  [2636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(308),
};

enum ts_external_scanner_symbol_identifiers {
  ts_external_token_comment = 0,
  ts_external_token_line_continuation = 1,
  ts_external_token_command_name = 2,
  ts_external_token_command_argument = 3,
  ts_external_token__single_quote_string_start = 4,
  ts_external_token__single_quote_string_end = 5,
  ts_external_token__double_quote_string_start = 6,
  ts_external_token__double_quote_string_end = 7,
  ts_external_token_formatting_sequence = 8,
  ts_external_token_escape_sequence = 9,
  ts_external_token_string_content = 10,
  ts_external_token__entry_delimiter = 11,
  ts_external_token__multioutput_variable_start = 12,
  ts_external_token_error_sentinel = 13,
};

static const TSSymbol ts_external_scanner_symbol_map[EXTERNAL_TOKEN_COUNT] = {
  [ts_external_token_comment] = sym_comment,
  [ts_external_token_line_continuation] = sym_line_continuation,
  [ts_external_token_command_name] = sym_command_name,
  [ts_external_token_command_argument] = sym_command_argument,
  [ts_external_token__single_quote_string_start] = sym__single_quote_string_start,
  [ts_external_token__single_quote_string_end] = sym__single_quote_string_end,
  [ts_external_token__double_quote_string_start] = sym__double_quote_string_start,
  [ts_external_token__double_quote_string_end] = sym__double_quote_string_end,
  [ts_external_token_formatting_sequence] = sym_formatting_sequence,
  [ts_external_token_escape_sequence] = sym_escape_sequence,
  [ts_external_token_string_content] = sym_string_content,
  [ts_external_token__entry_delimiter] = sym__entry_delimiter,
  [ts_external_token__multioutput_variable_start] = sym__multioutput_variable_start,
  [ts_external_token_error_sentinel] = sym_error_sentinel,
};

static const bool ts_external_scanner_states[11][EXTERNAL_TOKEN_COUNT] = {
  [1] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token_command_name] = true,
    [ts_external_token_command_argument] = true,
    [ts_external_token__single_quote_string_start] = true,
    [ts_external_token__single_quote_string_end] = true,
    [ts_external_token__double_quote_string_start] = true,
    [ts_external_token__double_quote_string_end] = true,
    [ts_external_token_formatting_sequence] = true,
    [ts_external_token_escape_sequence] = true,
    [ts_external_token_string_content] = true,
    [ts_external_token__entry_delimiter] = true,
    [ts_external_token__multioutput_variable_start] = true,
    [ts_external_token_error_sentinel] = true,
  },
  [2] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token_command_name] = true,
    [ts_external_token__single_quote_string_start] = true,
    [ts_external_token__double_quote_string_start] = true,
    [ts_external_token__multioutput_variable_start] = true,
  },
  [3] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__single_quote_string_start] = true,
    [ts_external_token__double_quote_string_start] = true,
  },
  [4] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__single_quote_string_start] = true,
    [ts_external_token__double_quote_string_start] = true,
    [ts_external_token__entry_delimiter] = true,
  },
  [5] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
  },
  [6] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__entry_delimiter] = true,
  },
  [7] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__multioutput_variable_start] = true,
  },
  [8] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token_command_argument] = true,
  },
  [9] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__single_quote_string_end] = true,
    [ts_external_token_formatting_sequence] = true,
    [ts_external_token_escape_sequence] = true,
    [ts_external_token_string_content] = true,
  },
  [10] = {
    [ts_external_token_comment] = true,
    [ts_external_token_line_continuation] = true,
    [ts_external_token__double_quote_string_end] = true,
    [ts_external_token_formatting_sequence] = true,
    [ts_external_token_escape_sequence] = true,
    [ts_external_token_string_content] = true,
  },
};

#ifdef __cplusplus
extern "C" {
#endif
void *tree_sitter_matlab_external_scanner_create(void);
void tree_sitter_matlab_external_scanner_destroy(void *);
bool tree_sitter_matlab_external_scanner_scan(void *, TSLexer *, const bool *);
unsigned tree_sitter_matlab_external_scanner_serialize(void *, char *);
void tree_sitter_matlab_external_scanner_deserialize(void *, const char *, unsigned);

#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_matlab(void) {
  static const TSLanguage language = {
    .version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = ts_lex_modes,
    .lex_fn = ts_lex,
    .keyword_lex_fn = ts_lex_keywords,
    .keyword_capture_token = sym_identifier,
    .external_scanner = {
      &ts_external_scanner_states[0][0],
      ts_external_scanner_symbol_map,
      tree_sitter_matlab_external_scanner_create,
      tree_sitter_matlab_external_scanner_destroy,
      tree_sitter_matlab_external_scanner_scan,
      tree_sitter_matlab_external_scanner_serialize,
      tree_sitter_matlab_external_scanner_deserialize,
    },
    .primary_state_ids = ts_primary_state_ids,
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
